from tests.utils.tests_utils import test_dependencies, test_function

from tests.data.geolayers import (
    geolayer_fr_dept_data_only,
    geolayer_fr_dept_data_and_geometry,
    geolayer_fr_dept_data_and_geometry_4326_precision_6,
    geolayer_idf_reseau_ferre,
    geolayer_geometry_2d,
    geolayer_geometry_3d,
)

from tests.data.fields_metadata import geolayer_data_fields_metadata_complete

from geoformat.conversion.feature_conversion import feature_serialize

from geoformat.conversion.geolayer_conversion import (
    create_geolayer_from_i_feat_list,
    reproject_geolayer,
    multi_geometry_to_single_geometry_geolayer,
    geolayer_to_2d_geolayer,
)

geolayer_to_2d_geolayer_parameters = {
    0: {
        "input_geolayer": geolayer_fr_dept_data_only,
        "return_value": geolayer_fr_dept_data_only,
    },
    1: {
        "input_geolayer": geolayer_fr_dept_data_and_geometry,
        "return_value": geolayer_fr_dept_data_and_geometry,
    },
    2: {
        "input_geolayer": geolayer_geometry_3d,
        "return_value": geolayer_geometry_2d,
    },
}

create_geolayer_from_i_feat_list_parameters = {
    0: {
        "geolayer": geolayer_fr_dept_data_only,
        "i_feat_list": 0,
        "serialize": False,
        "reset_i_feat": True,
        "return_value": {
            "metadata": {
                "fields": geolayer_data_fields_metadata_complete,
                "name": "FRANCE_DPT_GENERALIZE_LAMB93_ROUND_DATA_ONLY",
            },
            "features": {0: {"attributes": {"CODE_DEPT": "32", "NOM_DEPT": "GERS"}}},
        },
    },
    1: {
        "geolayer": geolayer_fr_dept_data_only,
        "i_feat_list": [0],
        "serialize": False,
        "reset_i_feat": True,
        "return_value": {
            "metadata": {
                "fields": geolayer_data_fields_metadata_complete,
                "name": "FRANCE_DPT_GENERALIZE_LAMB93_ROUND_DATA_ONLY",
            },
            "features": {0: {"attributes": {"CODE_DEPT": "32", "NOM_DEPT": "GERS"}}},
        },
    },
    2: {
        "geolayer": geolayer_fr_dept_data_only,
        "i_feat_list": [0, 95],
        "serialize": False,
        "reset_i_feat": True,
        "return_value": {
            "metadata": {
                "fields": geolayer_data_fields_metadata_complete,
                "name": "FRANCE_DPT_GENERALIZE_LAMB93_ROUND_DATA_ONLY",
            },
            "features": {
                0: {"attributes": {"CODE_DEPT": "32", "NOM_DEPT": "GERS"}},
                1: {"attributes": {"CODE_DEPT": "93", "NOM_DEPT": "SEINE-SAINT-DENIS"}},
            },
        },
    },
    3: {
        "geolayer": geolayer_fr_dept_data_only,
        "i_feat_list": [0, 95],
        "serialize": False,
        "reset_i_feat": False,
        "return_value": {
            "metadata": {
                "fields": geolayer_data_fields_metadata_complete,
                "name": "FRANCE_DPT_GENERALIZE_LAMB93_ROUND_DATA_ONLY",
            },
            "features": {
                0: {"attributes": {"CODE_DEPT": "32", "NOM_DEPT": "GERS"}},
                95: {
                    "attributes": {"CODE_DEPT": "93", "NOM_DEPT": "SEINE-SAINT-DENIS"}
                },
            },
        },
    },
    4: {
        "geolayer": geolayer_fr_dept_data_only,
        "i_feat_list": [0, 95],
        "serialize": True,
        "reset_i_feat": False,
        "return_value": {
            "metadata": {
                "fields": geolayer_data_fields_metadata_complete,
                "name": "FRANCE_DPT_GENERALIZE_LAMB93_ROUND_DATA_ONLY",
            },
            "features": {
                0: feature_serialize(
                    {"attributes": {"CODE_DEPT": "32", "NOM_DEPT": "GERS"}}
                ),
                95: feature_serialize(
                    {"attributes": {"CODE_DEPT": "93", "NOM_DEPT": "SEINE-SAINT-DENIS"}}
                ),
            },
        },
    },
}

reproject_geolayer_parameters = {
    0: {
        "geolayer": geolayer_fr_dept_data_and_geometry,
        "out_crs": 4326,
        "in_crs": None,
        "precision": 6,
        "return_value": geolayer_fr_dept_data_and_geometry_4326_precision_6,
    },
    1: {
        "geolayer": geolayer_fr_dept_data_and_geometry,
        "out_crs": 4326,
        "in_crs": 2154,
        "precision": 6,
        "return_value": geolayer_fr_dept_data_and_geometry_4326_precision_6,
    },
}

multi_geometry_to_single_geometry_geolayer_parameters = {
    0: {
        "geolayer": geolayer_idf_reseau_ferre,
        "return_value": {
            "metadata": {
                "name": "traces-du-reseau-ferre-idf",
                "fields": {
                    "reseau": {"type": "String", "width": 0, "index": 0},
                    "val": {"type": "Integer", "index": 1},
                    "metro": {"type": "Integer", "index": 2},
                    "res_com": {"type": "String", "width": 0, "index": 3},
                    "rer": {"type": "Integer", "index": 4},
                    "extcode": {"type": "String", "width": 0, "index": 5},
                    "geo_point_2d": {
                        "type": "RealList",
                        "width": 0,
                        "precision": 0,
                        "index": 6,
                    },
                    "indice_lig": {"type": "String", "width": 0, "index": 7},
                    "idf": {"type": "Integer", "index": 8},
                    "train": {"type": "Integer", "index": 9},
                    "fer": {"type": "Integer", "index": 10},
                    "mode": {"type": "String", "width": 0, "index": 11},
                    "tramway": {"type": "Integer", "index": 12},
                    "idrefligc": {"type": "String", "width": 0, "index": 13},
                    "navette": {"type": "Integer", "index": 14},
                    "idrefliga": {"type": "String", "width": 0, "index": 15},
                    "shape_leng": {
                        "type": "Real",
                        "width": 0,
                        "precision": 0,
                        "index": 16,
                    },
                },
                "geometry_ref": {
                    "type": {"LineString"},
                    "crs": 'GEOGCS["WGS 84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.257223563,AUTHORITY["EPSG","7030"]],AUTHORITY["EPSG","6326"]],PRIMEM["Greenwich",0,AUTHORITY["EPSG","8901"]],UNIT["degree",0.0174532925199433,AUTHORITY["EPSG","9122"]],AXIS["Latitude",NORTH],AXIS["Longitude",EAST],AUTHORITY["EPSG","4326"]]',
                    "extent": (
                        1.149003549412462,
                        47.95742785371423,
                        3.514336465015477,
                        49.42620159228318,
                    ),
                },
            },
            "features": {
                0: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.79486075047856, 2.1040231487081065],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 5003.12924709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.071847005929401,
                            48.79197130289541,
                            2.136050489663708,
                            48.798774681352754,
                        ),
                        "coordinates": [
                            [2.071847005929401, 48.79870763528835],
                            [2.071930959217986, 48.79871552851866],
                            [2.072216710538763, 48.7987359766609],
                            [2.072579474675331, 48.79875781412333],
                            [2.072862898980037, 48.79877217510979],
                            [2.07339670251307, 48.798774681352754],
                            [2.073713874486058, 48.798774514434655],
                            [2.074120918822997, 48.79876825942257],
                            [2.074570257201611, 48.79874411437348],
                            [2.075095898700846, 48.79870575443047],
                            [2.075455455431691, 48.79866970976342],
                            [2.075887224661105, 48.79862123822052],
                            [2.076227752121453, 48.79857975186269],
                            [2.076626900075734, 48.798521310787564],
                            [2.07716506105974, 48.79843081224707],
                            [2.07764852043101, 48.798316933934665],
                            [2.078167738891175, 48.798203905116274],
                            [2.078658217708944, 48.798076532368164],
                            [2.079083828515797, 48.79795614915085],
                            [2.07970072398773, 48.79775767757964],
                            [2.08020225629617, 48.79758035736656],
                            [2.080682237327531, 48.79739108945262],
                            [2.082831239058495, 48.79647994934646],
                            [2.08407821011798, 48.79595569704254],
                            [2.084495051075953, 48.79578292818973],
                            [2.084798183357852, 48.795662251920504],
                            [2.085068779097173, 48.79556529741404],
                            [2.085472803759792, 48.795432945457634],
                            [2.085851533812421, 48.795317192821884],
                            [2.086342037093098, 48.795175510300744],
                            [2.086926168987106, 48.795034032056186],
                            [2.087503001665491, 48.794911569452395],
                            [2.088104956144356, 48.79480581469834],
                            [2.088696007853362, 48.794719067792464],
                            [2.089301405013185, 48.794644244904084],
                            [2.089913909264423, 48.794588469047525],
                            [2.09054429876811, 48.794556522554586],
                            [2.091113408132319, 48.79453633626861],
                            [2.09172199049859, 48.79454478562203],
                            [2.092341270622694, 48.79457466828989],
                            [2.093068461780212, 48.79463095098126],
                            [2.093925150711385, 48.79471843643121],
                            [2.094774639817521, 48.794805900752586],
                            [2.098176203113287, 48.7951604600855],
                            [2.101567045015145, 48.79550775765459],
                            [2.10300329181604, 48.795658232499086],
                            [2.103510872100985, 48.79570448052273],
                            [2.103986129960595, 48.795731624861844],
                            [2.104472236811199, 48.795749272395476],
                            [2.104962034435666, 48.79574789032003],
                            [2.105455511439231, 48.79572985839365],
                            [2.105949086909674, 48.79569041070288],
                            [2.106424732283703, 48.79563426936188],
                            [2.106914848316776, 48.7955638785091],
                            [2.107390620647533, 48.795479181062994],
                            [2.107816052636528, 48.795377724667944],
                            [2.108270390515862, 48.79525491057731],
                            [2.108728360406763, 48.79512496420476],
                            [2.109154025991882, 48.79497115721885],
                            [2.109680764025691, 48.79476520547845],
                            [2.110294111936995, 48.794518974053865],
                            [2.110961593718655, 48.79424667472427],
                            [2.111369258162332, 48.794088065982855],
                            [2.111697533309683, 48.79396498860572],
                            [2.112061828922531, 48.79383960199691],
                            [2.112483806336287, 48.79370005213547],
                            [2.112801132518071, 48.793607882006135],
                            [2.113176151228948, 48.79349916875279],
                            [2.11369172125704, 48.793366936094806],
                            [2.114286612721081, 48.79321344201142],
                            [2.114690340145993, 48.79312619386876],
                            [2.115083250085545, 48.79304130261554],
                            [2.115443696458172, 48.792968243717226],
                            [2.11591216526011, 48.79289777277563],
                            [2.116330153700183, 48.792841477695944],
                            [2.11687422424131, 48.79277590713132],
                            [2.117843448911033, 48.79266118584478],
                            [2.120895214199257, 48.79230058968553],
                            [2.12276515961669, 48.79208045968901],
                            [2.123371895057395, 48.792006960314865],
                            [2.123854964587829, 48.79198209806883],
                            [2.124117106316824, 48.79197237837199],
                            [2.124505010430262, 48.79197130289541],
                            [2.124978607028827, 48.791982975227185],
                            [2.125773213019912, 48.79204200359494],
                            [2.126103812899514, 48.792074090135145],
                            [2.126404451834651, 48.79211061667671],
                            [2.126827479735518, 48.79217254796331],
                            [2.127227320272672, 48.79224612597793],
                            [2.12760129539878, 48.792321452990265],
                            [2.127994261423026, 48.792412101522544],
                            [2.128362701359944, 48.79250989839397],
                            [2.128830302441107, 48.79265463765974],
                            [2.129149705918469, 48.79276223361234],
                            [2.129462265955019, 48.792878809983584],
                            [2.130050581171206, 48.79312718041466],
                            [2.130828967598358, 48.7934927980301],
                            [2.13206509185052, 48.79409304530295],
                            [2.132487588843224, 48.794289846410095],
                            [2.133002509056168, 48.794520084339],
                            [2.13335716335117, 48.7946664018369],
                            [2.13369969439922, 48.79478212009287],
                            [2.13399604854809, 48.79487347462278],
                            [2.134304686413588, 48.794956757804414],
                            [2.134637837020887, 48.79503738448375],
                            [2.135009117560278, 48.7951135822115],
                            [2.1359721799146, 48.79526816122795],
                            [2.136050489663708, 48.79528024627206],
                        ],
                    },
                },
                1: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.705597373499494, 2.2254005317983756],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2050.60936272,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.212262378017492,
                            48.70508587906037,
                            2.237314364639455,
                            48.708140583645324,
                        ),
                        "coordinates": [
                            [2.212262378017492, 48.705968984822285],
                            [2.212463435358097, 48.7059409026929],
                            [2.21268724018887, 48.70590061682936],
                            [2.21313889652569, 48.70580601699101],
                            [2.2139705366341, 48.70562503440158],
                            [2.21412414672051, 48.70559372612131],
                            [2.21448574534873, 48.705518576519175],
                            [2.214753101604864, 48.70547513211355],
                            [2.215098957101641, 48.70542776015219],
                            [2.215411294805012, 48.70540446183589],
                            [2.21579511124345, 48.7053877346906],
                            [2.216155296477162, 48.705396683340126],
                            [2.216664258131225, 48.70542720158098],
                            [2.217309054069744, 48.70547927455073],
                            [2.217856807928669, 48.705524104727324],
                            [2.218270877698805, 48.70555023408847],
                            [2.218646153215624, 48.70556347287892],
                            [2.219131461438564, 48.705563976273424],
                            [2.219530524215565, 48.70555154109456],
                            [2.219916671575999, 48.705527668643256],
                            [2.220279048117843, 48.70549632588],
                            [2.220787528230438, 48.705452342498944],
                            [2.221404500232453, 48.705398114753784],
                            [2.221777916835139, 48.70537544306055],
                            [2.222281071919556, 48.705353053871605],
                            [2.222522646715806, 48.70535329724141],
                            [2.222780927950786, 48.70536623094234],
                            [2.223100626178597, 48.70538671135744],
                            [2.2234348745451, 48.70541988019707],
                            [2.223784206743701, 48.70546020088952],
                            [2.224521669657798, 48.70555229806244],
                            [2.224849437954961, 48.705589738318835],
                            [2.225134106662692, 48.705611432924556],
                            [2.225315262409366, 48.705623031733],
                            [2.225666833114333, 48.705627659137704],
                            [2.226061586993946, 48.7056123407807],
                            [2.226508153904358, 48.705575657036505],
                            [2.227223540004041, 48.70550639166542],
                            [2.228055231596783, 48.705428054089694],
                            [2.230479608507602, 48.70520822772064],
                            [2.231785518993102, 48.705106925287254],
                            [2.232030111795038, 48.70509276272904],
                            [2.232367080077087, 48.70508587906037],
                            [2.232633368097813, 48.70509241794143],
                            [2.232985227129844, 48.7051116251601],
                            [2.233319399032826, 48.705142504493764],
                            [2.233646265589325, 48.70518263391184],
                            [2.233945566079325, 48.70523300053064],
                            [2.234260663427292, 48.70529083904784],
                            [2.234532270974559, 48.705354032942694],
                            [2.234771262858926, 48.70542169251568],
                            [2.234989856661979, 48.705497427676136],
                            [2.235241018388028, 48.7055938749017],
                            [2.235528143905083, 48.70572966872062],
                            [2.235758663732209, 48.705864068411316],
                            [2.23597118018682, 48.70599829836783],
                            [2.236163648551814, 48.70612282278379],
                            [2.236322992223034, 48.70625715775707],
                            [2.236447839147068, 48.7063843241211],
                            [2.236596332216985, 48.70655291164955],
                            [2.236688518249153, 48.70670486080525],
                            [2.236832098804893, 48.706926207989866],
                            [2.236934942988355, 48.70713582962608],
                            [2.237045871456509, 48.707379629124354],
                            [2.237203919574737, 48.70784289350996],
                            [2.237314364639455, 48.708140583645324],
                        ],
                    },
                },
                2: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.56843332780098, 2.5188146833364926],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4173.15137828,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.492713002881577,
                            48.56448587191694,
                            2.54265182270078,
                            48.571143418979055,
                        ),
                        "coordinates": [
                            [2.54265182270078, 48.56448587191694],
                            [2.542632112539303, 48.564963414971864],
                            [2.542548622110391, 48.56541679511847],
                            [2.542347785796335, 48.56599898228977],
                            [2.542081640061914, 48.56651564101072],
                            [2.541657294782628, 48.56711351973032],
                            [2.54123239143263, 48.567577407131346],
                            [2.540624772726035, 48.5680928806298],
                            [2.53988357818143, 48.568551810802504],
                            [2.539177442853698, 48.56891850547845],
                            [2.538442439305356, 48.5692217649704],
                            [2.537212189861203, 48.5696500679459],
                            [2.536029553548685, 48.569985912843855],
                            [2.534501212524553, 48.570353692811175],
                            [2.533270427801306, 48.570587844658014],
                            [2.532153247834778, 48.57076963016007],
                            [2.530839530357968, 48.57093825246705],
                            [2.529358977223124, 48.571065777994775],
                            [2.528108508755293, 48.5711245515006],
                            [2.527051654550542, 48.571143418979055],
                            [2.526023163579781, 48.57113794820847],
                            [2.525353919016563, 48.57111352904154],
                            [2.524578454516361, 48.57107290979653],
                            [2.523227071119833, 48.57096093721537],
                            [2.52229171681967, 48.57085725996125],
                            [2.521321013856532, 48.57072035999768],
                            [2.520530537789475, 48.57058495841179],
                            [2.519692553507267, 48.570425347875485],
                            [2.518831442561021, 48.57023968922527],
                            [2.518029778485811, 48.57003929826953],
                            [2.517221512393022, 48.56981421907329],
                            [2.516532437797655, 48.56960938470932],
                            [2.515884056068005, 48.56941527270209],
                            [2.515180061745829, 48.56920325957478],
                            [2.513819555121602, 48.568790837286585],
                            [2.511992462634034, 48.568234339678334],
                            [2.511103988065934, 48.56795334421567],
                            [2.509283741714297, 48.567400390289585],
                            [2.507724066054226, 48.56696032090451],
                            [2.507001610867432, 48.56678012842227],
                            [2.506296194312994, 48.566623448382046],
                            [2.505065119235051, 48.56638068715553],
                            [2.503092653791063, 48.56605537309182],
                            [2.501107961458334, 48.565730636943755],
                            [2.500068272789582, 48.56556158869476],
                            [2.499576253141722, 48.56550114838491],
                            [2.499055348099611, 48.56545447725449],
                            [2.498566604637839, 48.5654198649025],
                            [2.498006045002383, 48.565409459716705],
                            [2.49749653457783, 48.56541303173543],
                            [2.496974707104717, 48.565445512721226],
                            [2.496107840693743, 48.56552587153183],
                            [2.495372418654648, 48.56561323421448],
                            [2.494651908737701, 48.56571545710675],
                            [2.493967602843918, 48.56584013429816],
                            [2.493239680856003, 48.565997491801305],
                            [2.492713002881577, 48.5661178207362],
                        ],
                    },
                },
                3: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.12137306210128, 2.7670868898131036],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 5856.19123313,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.762728388543796,
                            48.09650277877714,
                            2.774122167142249,
                            48.14721803991587,
                        ),
                        "coordinates": [
                            [2.762728388543796, 48.14721803991587],
                            [2.76273124070775, 48.14692600279808],
                            [2.762737587948206, 48.14608701359404],
                            [2.762731355484866, 48.145190522916145],
                            [2.762737017123065, 48.1442706069449],
                            [2.762732068918912, 48.143366918204336],
                            [2.762740038379433, 48.142561194296455],
                            [2.762749366108946, 48.1415981038468],
                            [2.762761928003978, 48.14069974419957],
                            [2.762767771373231, 48.13980141098956],
                            [2.762772377652811, 48.13891567061274],
                            [2.762774289639833, 48.13802904155212],
                            [2.762780581342609, 48.13718376005438],
                            [2.762787334268553, 48.136234168354456],
                            [2.762786065436448, 48.13528910318546],
                            [2.76279185536933, 48.13438447673979],
                            [2.762795723004767, 48.13341151679277],
                            [2.76279800660798, 48.132568949314575],
                            [2.762797785334969, 48.132383712904534],
                            [2.762792466697309, 48.131754286685364],
                            [2.762804865578496, 48.13083704575186],
                            [2.762810212589824, 48.12988026735892],
                            [2.762817913102712, 48.12888391545409],
                            [2.762827917607845, 48.12768343432905],
                            [2.762832292342056, 48.1266115614433],
                            [2.762836012496911, 48.12546235950826],
                            [2.762851370833684, 48.12410090014393],
                            [2.762868537246985, 48.12374834587039],
                            [2.76289268551721, 48.12342723794915],
                            [2.762916575377397, 48.12323471695812],
                            [2.762954784014198, 48.12298819005845],
                            [2.763002490295106, 48.1227533162626],
                            [2.763085704013368, 48.12242928620231],
                            [2.763185215189774, 48.12212677610113],
                            [2.763290507295784, 48.12187280062092],
                            [2.763414432253781, 48.12159897224304],
                            [2.763561048419426, 48.12130887231516],
                            [2.763766242014921, 48.12095830301011],
                            [2.764018198635113, 48.12057968062769],
                            [2.764182768967725, 48.12034885962159],
                            [2.764403459228069, 48.12008455388772],
                            [2.764634866271736, 48.11981751016425],
                            [2.76494501251472, 48.11949261621677],
                            [2.765250188618764, 48.11921539968384],
                            [2.765536821318116, 48.11896882477002],
                            [2.765879582481076, 48.11869056363751],
                            [2.766161189825298, 48.11848537094358],
                            [2.771079631821379, 48.11361145787937],
                            [2.773060532582075, 48.10992778590111],
                            [2.774122167142249, 48.10575752160171],
                            [2.773713826426943, 48.10085776549668],
                            [2.77230261766097, 48.09650277877714],
                        ],
                    },
                },
                4: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.627581714147084, 2.4614413777361728],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2070.25939143,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.452289891181863,
                            48.620290259939715,
                            2.470234997616056,
                            48.6344790233052,
                        ),
                        "coordinates": [
                            [2.470234997616056, 48.620290259939715],
                            [2.468818696186112, 48.62113191977028],
                            [2.467965403141835, 48.62168767432524],
                            [2.467572035679736, 48.62198516100947],
                            [2.467231905661427, 48.622294864345484],
                            [2.46694904647745, 48.62257012837191],
                            [2.466558981773188, 48.62298087986408],
                            [2.46627143006039, 48.62332269211523],
                            [2.465862972716693, 48.623782684008845],
                            [2.465388180929839, 48.624296705067536],
                            [2.465014848470467, 48.624707194205996],
                            [2.464154585799172, 48.625671278782264],
                            [2.463336122330352, 48.626548981301895],
                            [2.462809711454819, 48.62705585563435],
                            [2.462357661382666, 48.62746822226067],
                            [2.461502077649284, 48.628173293134275],
                            [2.461114852369585, 48.62847677224858],
                            [2.460592158762573, 48.628859532855465],
                            [2.459371922687139, 48.62969717926501],
                            [2.458893787414651, 48.630004345456435],
                            [2.458331659466724, 48.630362859058614],
                            [2.457540381851508, 48.63087297212455],
                            [2.456852507432761, 48.63131765985182],
                            [2.45591124343995, 48.6319368225547],
                            [2.454889751910423, 48.63260747395128],
                            [2.453991025272698, 48.63323631275906],
                            [2.453204787772405, 48.63379445345111],
                            [2.452816068915519, 48.63407992000851],
                            [2.452289891181863, 48.6344790233052],
                        ],
                    },
                },
                5: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.74657775229024, 2.2243940870104537],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1712.81148115,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.215860857351649,
                            48.74018152105127,
                            2.230961125063006,
                            48.751023275119756,
                        ),
                        "coordinates": [
                            [2.215860857351649, 48.751023275119756],
                            [2.216402248560275, 48.750780173208625],
                            [2.217980125073538, 48.75006061337667],
                            [2.218118985524632, 48.749997809315595],
                            [2.218995689410336, 48.74960843478377],
                            [2.219758055068794, 48.749258504004665],
                            [2.220043940273481, 48.74912660465951],
                            [2.220626584775005, 48.74886371316532],
                            [2.221063566104835, 48.748665418788136],
                            [2.223321959610476, 48.74762813211571],
                            [2.225376013529548, 48.74671200282293],
                            [2.226267659665766, 48.746277623305524],
                            [2.226881707520914, 48.74592660266426],
                            [2.227102294945866, 48.745790125055635],
                            [2.227343334682708, 48.74562848859509],
                            [2.227569399736954, 48.74547313097266],
                            [2.227745087109964, 48.74534740153055],
                            [2.227934420668569, 48.74519920270087],
                            [2.228396181947704, 48.74483363897137],
                            [2.228806262351471, 48.74446892324872],
                            [2.229040656326748, 48.744230838090324],
                            [2.229230612579832, 48.74401993036308],
                            [2.229362350347043, 48.74386333868691],
                            [2.229640486712221, 48.743514682361436],
                            [2.229779598120949, 48.74331967081882],
                            [2.229880556496796, 48.74316239332066],
                            [2.23004289796115, 48.7429125476522],
                            [2.230229415721035, 48.74259773622583],
                            [2.230408768999338, 48.74222584475121],
                            [2.230601520702954, 48.74174041653679],
                            [2.230741137079111, 48.74130439882057],
                            [2.230834485527692, 48.740885424204855],
                            [2.23090742321191, 48.74047362506254],
                            [2.230961125063006, 48.74018152105127],
                        ],
                    },
                },
                6: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.33084189358218, 2.0166602802282845],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 4670.22185495,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.003525000097989,
                            48.31129627475171,
                            2.032239773386701,
                            48.34841601424845,
                        ),
                        "coordinates": [
                            [2.003525000097989, 48.31129627475171],
                            [2.003702807903224, 48.31159108385618],
                            [2.004722623312976, 48.313281883838236],
                            [2.007146685603181, 48.317312264918264],
                            [2.008417155259732, 48.319414448638945],
                            [2.009705521170246, 48.32152380785578],
                            [2.01086534372533, 48.32346943213367],
                            [2.011736612274597, 48.324898131021094],
                            [2.012605233723637, 48.32632681662795],
                            [2.013400506828508, 48.327635686299296],
                            [2.014195810049701, 48.32894634975154],
                            [2.014989810912541, 48.33025610555778],
                            [2.016451072961751, 48.33267830627975],
                            [2.016966737620091, 48.33345041450526],
                            [2.017363815686869, 48.333997375021305],
                            [2.018107851003259, 48.334916698222614],
                            [2.018738537174137, 48.33563606750387],
                            [2.019187325847652, 48.33611572415417],
                            [2.01986819957429, 48.33679476317343],
                            [2.020834847680739, 48.33771739075223],
                            [2.022855454137321, 48.339637501705546],
                            [2.025174120794123, 48.341806589740145],
                            [2.026486340842052, 48.34302234619641],
                            [2.027392249474961, 48.34390521382073],
                            [2.030102887187705, 48.34645565124682],
                            [2.031337488389282, 48.34757753545706],
                            [2.032239773386701, 48.34841601424845],
                        ],
                    },
                },
                7: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [49.028171202330086, 2.4701018555958556],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1608.78315616,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.462168966135235,
                            49.023161999031025,
                            2.478033365115083,
                            49.033182769031264,
                        ),
                        "coordinates": [
                            [2.478033365115083, 49.033182769031264],
                            [2.476579460789503, 49.03226199604023],
                            [2.475261556334177, 49.031422443060364],
                            [2.472731440110162, 49.02982654697679],
                            [2.470186920742401, 49.028194922678715],
                            [2.467773230317047, 49.026717749750894],
                            [2.466044492685873, 49.02562045194961],
                            [2.46386288351023, 49.02425238540592],
                            [2.463418001262921, 49.02396601912603],
                            [2.462168966135235, 49.023161999031025],
                        ],
                    },
                },
                8: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.36147836978959, 2.046068678082501],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 3552.93433795,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.032239773386701,
                            48.34841601424845,
                            2.059912347637065,
                            48.37452501337592,
                        ),
                        "coordinates": [
                            [2.032239773386701, 48.34841601424845],
                            [2.032290730648379, 48.348463366712274],
                            [2.033314534971492, 48.34941472547342],
                            [2.034586205685321, 48.35062221533428],
                            [2.036000109636696, 48.35196945113331],
                            [2.03649655270448, 48.35242848434254],
                            [2.038173676289573, 48.35402927874207],
                            [2.041204466390754, 48.35690022587377],
                            [2.043246881117582, 48.35882484895548],
                            [2.044995558703508, 48.36045308376973],
                            [2.045858458667284, 48.361273617026804],
                            [2.048530531464787, 48.36381542186702],
                            [2.049617806785911, 48.36482893668195],
                            [2.051554696353337, 48.36666649291564],
                            [2.052284587349211, 48.36734662380235],
                            [2.053687616445963, 48.368661111550495],
                            [2.054500011607147, 48.36943995220021],
                            [2.055492001109102, 48.37037391450988],
                            [2.056547321687121, 48.371386507416794],
                            [2.059557757949159, 48.37419956338156],
                            [2.059901437730507, 48.374514999081164],
                            [2.059912347637065, 48.37452501337592],
                        ],
                    },
                },
                9: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.60716009644471, 2.465222640174841],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 556.533229431,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.462456492779697,
                            48.60555582637839,
                            2.467812581880024,
                            48.60904470232516,
                        ),
                        "coordinates": [
                            [2.462456492779697, 48.60555582637839],
                            [2.462964808935407, 48.605790758221325],
                            [2.463694338541454, 48.606133236247146],
                            [2.464153553682927, 48.60636679027209],
                            [2.464518853336865, 48.606576642856105],
                            [2.464836893889323, 48.60678149903763],
                            [2.465211605728296, 48.6070487469428],
                            [2.46552522948962, 48.60727769606698],
                            [2.465931400444536, 48.60756750906768],
                            [2.466198279382182, 48.607754277049374],
                            [2.466470203844905, 48.60795671799666],
                            [2.466689001631515, 48.60813991768482],
                            [2.466994759314531, 48.608388662159996],
                            [2.467812581880024, 48.60904470232516],
                        ],
                    },
                },
                10: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.507195562132665, 2.364828653284794],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 5732.12017965,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351858421416974,
                            48.484957377176464,
                            2.370518497736708,
                            48.53150198648683,
                        ),
                        "coordinates": [
                            [2.370518497736708, 48.53150198648683],
                            [2.369782967672895, 48.53066504028073],
                            [2.369001172633517, 48.52977500533413],
                            [2.368330547109638, 48.529080072980506],
                            [2.367777821720014, 48.528536177487275],
                            [2.367502816369961, 48.528262880639495],
                            [2.366725234340153, 48.527496027113514],
                            [2.366577566830953, 48.52733330139564],
                            [2.366377066753841, 48.5271112386537],
                            [2.366085781009335, 48.52675251246034],
                            [2.365797185119591, 48.5263578157052],
                            [2.365527502691939, 48.5258830797868],
                            [2.365339088279061, 48.52547037005822],
                            [2.365111283629784, 48.524820268284145],
                            [2.365031179501694, 48.52441112819864],
                            [2.364978156520305, 48.5240100751952],
                            [2.364964484315445, 48.523769079280754],
                            [2.364967039213341, 48.52344932961314],
                            [2.364993830967873, 48.52299481547527],
                            [2.365036979124143, 48.52269085731438],
                            [2.365143638651926, 48.522186350233426],
                            [2.365228775069171, 48.5219255452245],
                            [2.365416684347494, 48.52147946904553],
                            [2.365534319755073, 48.52124113750787],
                            [2.365641136882604, 48.52102708781103],
                            [2.366645950297917, 48.519396482601294],
                            [2.3673058723346, 48.518324397306635],
                            [2.368061787731844, 48.51712189082662],
                            [2.368277584646867, 48.516764806757415],
                            [2.368641864037752, 48.51616582359326],
                            [2.369079939104525, 48.51542921187838],
                            [2.369253820816311, 48.51505096019996],
                            [2.369386734396402, 48.51472770794959],
                            [2.369533949372972, 48.514241170238925],
                            [2.369664837787011, 48.51363143927057],
                            [2.369787433543211, 48.512763626643135],
                            [2.369978162457463, 48.5105532116889],
                            [2.369997077479935, 48.51024039511414],
                            [2.370003512251351, 48.51000286210088],
                            [2.370002144288867, 48.50975980813285],
                            [2.369995085938944, 48.50954065007167],
                            [2.369937890880547, 48.50900561195673],
                            [2.369796752618062, 48.50841394662481],
                            [2.369537500880608, 48.50758836341424],
                            [2.369380396622795, 48.50705799832348],
                            [2.369006115904586, 48.50585850499112],
                            [2.368595237760598, 48.5045385224811],
                            [2.36815047528607, 48.50309445156857],
                            [2.367703032548536, 48.50165127876548],
                            [2.36725696807109, 48.50020810444684],
                            [2.367112382576333, 48.49984106916265],
                            [2.366913456411754, 48.49935725482325],
                            [2.366702763364148, 48.49890523911615],
                            [2.366513145671601, 48.49856032453469],
                            [2.366319442232059, 48.498231801353015],
                            [2.366169333496484, 48.49798638982355],
                            [2.36600795161212, 48.49774179142645],
                            [2.365563790660651, 48.49711692663012],
                            [2.365317361664009, 48.49680584957771],
                            [2.365062811931172, 48.496485779970264],
                            [2.364440049266327, 48.49580969899613],
                            [2.364131397662917, 48.495503129780765],
                            [2.363278612314385, 48.494743468035274],
                            [2.362910448732153, 48.49444680148072],
                            [2.362333400496063, 48.494008826775286],
                            [2.360905896234596, 48.492926400915344],
                            [2.360345671354884, 48.49250229133352],
                            [2.3590099049025, 48.49150169810289],
                            [2.357672839996874, 48.490501090766955],
                            [2.356338532882637, 48.489500466070396],
                            [2.355568554680084, 48.488916985041335],
                            [2.354954207128473, 48.488445880003944],
                            [2.354415282544769, 48.488006780108776],
                            [2.353970528329367, 48.487615769430754],
                            [2.353507032163732, 48.48716504628661],
                            [2.353043474664347, 48.48666745900562],
                            [2.352695683414058, 48.4862457610922],
                            [2.352489974259953, 48.48595263472164],
                            [2.352080440525532, 48.485345166827706],
                            [2.351858421416974, 48.484957377176464],
                        ],
                    },
                },
                11: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.575356963680164, 2.4557352317571963],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4383.55009934,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.432098533660357,
                            48.57059685871919,
                            2.473503765153183,
                            48.58715390715936,
                        ),
                        "coordinates": [
                            [2.473490366344224, 48.58715390715936],
                            [2.473503765153183, 48.58660174499059],
                            [2.473477967577842, 48.58609009670576],
                            [2.473426522034749, 48.5856791706745],
                            [2.47336458051269, 48.5852701077813],
                            [2.473238468550363, 48.5847522866102],
                            [2.473008896263801, 48.584068226036216],
                            [2.472554554, 48.5829644803769],
                            [2.472098872864541, 48.58185893675706],
                            [2.471782128496486, 48.58109168417483],
                            [2.471601538045066, 48.58067288962167],
                            [2.470845717704695, 48.579020567157265],
                            [2.470653489963128, 48.57859544514867],
                            [2.470071506012449, 48.577323682399395],
                            [2.469903331796089, 48.57698671694772],
                            [2.469663733800497, 48.57656312847582],
                            [2.469532139375638, 48.57636193441902],
                            [2.469339685405699, 48.57609474713919],
                            [2.46914552082931, 48.57584994723141],
                            [2.468864615746486, 48.57553197299926],
                            [2.468636357052715, 48.57530652595332],
                            [2.468410813631614, 48.57508287347395],
                            [2.468188058652502, 48.5748879927555],
                            [2.467826865926937, 48.57461054094352],
                            [2.46746435479674, 48.57434567947425],
                            [2.467066633378702, 48.57408805170524],
                            [2.466684267494194, 48.57386812441463],
                            [2.466331265847153, 48.573685095230076],
                            [2.46600548419132, 48.57352633399355],
                            [2.465536073280723, 48.57331374481202],
                            [2.46500980155598, 48.57312010367917],
                            [2.464427996674808, 48.57293461570908],
                            [2.463866999630313, 48.572786716768185],
                            [2.463288930688561, 48.57267197959238],
                            [2.462874242531003, 48.572604533978755],
                            [2.462413381839517, 48.57255019270054],
                            [2.461570332466472, 48.57247199157937],
                            [2.459800236543603, 48.57231836099495],
                            [2.459247284028652, 48.5722829919008],
                            [2.458759425643469, 48.572268232035064],
                            [2.458197087730036, 48.57227333428105],
                            [2.457786564366662, 48.572298055247636],
                            [2.457355746800001, 48.57233628450668],
                            [2.45674481876237, 48.572422364342316],
                            [2.455959253824132, 48.57257876824822],
                            [2.455485288112232, 48.57270876004451],
                            [2.45500864079603, 48.57285224277212],
                            [2.45080310992175, 48.5743160633727],
                            [2.449960778851302, 48.57455971079759],
                            [2.449432564347195, 48.57468613525646],
                            [2.448436949140885, 48.574866076264016],
                            [2.448023760738403, 48.57492313810675],
                            [2.4474777667121, 48.57497942809493],
                            [2.446853140865172, 48.57502140509936],
                            [2.446145800606674, 48.575040077569184],
                            [2.444530399814989, 48.575003861495986],
                            [2.443898831249863, 48.57496849230246],
                            [2.443046282880645, 48.57488926386505],
                            [2.44244008760732, 48.57479735317022],
                            [2.44212043190075, 48.57474894823654],
                            [2.441788396927756, 48.574681897648844],
                            [2.441435635241651, 48.57460817034715],
                            [2.441155146993709, 48.574541216907335],
                            [2.440882632503369, 48.5744767218846],
                            [2.440253470169857, 48.57429025526651],
                            [2.439801902675254, 48.57413779373232],
                            [2.439084453555834, 48.5738470867982],
                            [2.43877930408544, 48.573724164859755],
                            [2.438116028813668, 48.573412719770445],
                            [2.43715842595586, 48.57296034970965],
                            [2.436040075175235, 48.572449650493795],
                            [2.43546748977633, 48.57218824526225],
                            [2.434950375884485, 48.57195152557246],
                            [2.434413160759013, 48.57168965158499],
                            [2.433745652909737, 48.57136986008346],
                            [2.432854891688207, 48.57094795904131],
                            [2.432098533660357, 48.57059685871919],
                        ],
                    },
                },
                12: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.3817678729322, 2.916855356028169],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 3199.11206586,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.89720177783042,
                            48.378795760781145,
                            2.936180968314843,
                            48.38468131279181,
                        ),
                        "coordinates": [
                            [2.936180968314843, 48.37999957527981],
                            [2.934908556263945, 48.379945094509075],
                            [2.934343402316594, 48.379929026804426],
                            [2.933842607430669, 48.37991261717875],
                            [2.933459832304337, 48.379897964936035],
                            [2.933157302729277, 48.37989332873406],
                            [2.932801772400575, 48.37989332923899],
                            [2.93242317332602, 48.37991248760334],
                            [2.932130556722254, 48.37993920900663],
                            [2.931816363911015, 48.37996784078308],
                            [2.931475343709777, 48.380011002165496],
                            [2.931094127435304, 48.380079553223744],
                            [2.930753457159952, 48.38015238580757],
                            [2.930507066845852, 48.38021015008532],
                            [2.930194983432587, 48.380300100632155],
                            [2.929715062684075, 48.38046988255187],
                            [2.929434323656812, 48.38058825958691],
                            [2.929204632763628, 48.38068568513686],
                            [2.928933018224873, 48.38081025617642],
                            [2.928742953438621, 48.3809147184292],
                            [2.928539247592428, 48.381040783223526],
                            [2.928328928634067, 48.381178572711065],
                            [2.928024858464159, 48.38137980032377],
                            [2.927668765441012, 48.38163435595594],
                            [2.927108123670214, 48.382059040917014],
                            [2.926566179767029, 48.38246743799783],
                            [2.926227487066166, 48.382734476547334],
                            [2.925909485554005, 48.3829915370427],
                            [2.925637750952431, 48.38318899265284],
                            [2.925414180158933, 48.38334932773829],
                            [2.92524529691606, 48.38346162197285],
                            [2.925099641314644, 48.38354336785668],
                            [2.924907807347333, 48.383651556280014],
                            [2.924705270747713, 48.383762181997376],
                            [2.924532683984613, 48.38384807734107],
                            [2.924397436514429, 48.38391036365294],
                            [2.924180741558208, 48.38400429320013],
                            [2.923977196053016, 48.38408860788371],
                            [2.923761866950689, 48.384166358723384],
                            [2.923512300819755, 48.38424614823105],
                            [2.923288373686647, 48.38431359860544],
                            [2.922951933961305, 48.38440527022479],
                            [2.922534453300523, 48.38449376339217],
                            [2.922158610434262, 48.38456405507815],
                            [2.921832421999865, 48.38460890860832],
                            [2.921611496116461, 48.38463574838564],
                            [2.921354286696245, 48.3846585178601],
                            [2.921099994891111, 48.38466840001788],
                            [2.920868220456624, 48.38467692466362],
                            [2.920699223899258, 48.38468131279181],
                            [2.920363051268959, 48.384680351499355],
                            [2.920028102554904, 48.38466859131676],
                            [2.91972815803245, 48.384648556221045],
                            [2.91943887893585, 48.38461677429952],
                            [2.919160347576653, 48.38458044036269],
                            [2.918847900699907, 48.38452989292958],
                            [2.918543449407775, 48.384470310259694],
                            [2.918199632145059, 48.38439204404506],
                            [2.917601013362818, 48.384227858525406],
                            [2.91460179522727, 48.38333856956497],
                            [2.913402941151773, 48.38298228759372],
                            [2.912252856898915, 48.3826392340088],
                            [2.911478017965539, 48.3824084683481],
                            [2.910349661136737, 48.38207427864092],
                            [2.90822976955379, 48.38144384091659],
                            [2.906347054415935, 48.380891304257396],
                            [2.904515728287218, 48.380342974026526],
                            [2.904028119760863, 48.3802067139952],
                            [2.903482404342524, 48.38006521621463],
                            [2.902885087702344, 48.37991727784598],
                            [2.902313083661703, 48.379782984696476],
                            [2.901508007465895, 48.37961615019661],
                            [2.899424697247027, 48.37921917323933],
                            [2.897377939078802, 48.37882826848556],
                            [2.89720177783042, 48.378795760781145],
                        ],
                    },
                },
                13: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.41422607564345, 2.390506570940111],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 5068.48366431,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.376672818506992,
                            48.393641547740856,
                            2.399724480290099,
                            48.43449061286291,
                        ),
                        "coordinates": [
                            [2.376672818506992, 48.43449061286291],
                            [2.377944361246022, 48.43345812219093],
                            [2.378518238881933, 48.43293994641521],
                            [2.378781513148704, 48.4326673784374],
                            [2.379494207695649, 48.431744487689556],
                            [2.381156877356871, 48.42938243404588],
                            [2.381463213559586, 48.428948878777035],
                            [2.381661584969088, 48.428666437886505],
                            [2.3816939894959, 48.428639447553635],
                            [2.38226341505357, 48.42778673729532],
                            [2.382426691276003, 48.42755196921832],
                            [2.382677674533057, 48.42719037197099],
                            [2.382881437217691, 48.42690792709255],
                            [2.383727474170215, 48.42570619052647],
                            [2.384994411388416, 48.42388738918657],
                            [2.385258807151863, 48.423462834034645],
                            [2.385793002554799, 48.42262720690158],
                            [2.386727780968657, 48.4211430486371],
                            [2.387779805202364, 48.4194322208155],
                            [2.388044169631636, 48.41902204748705],
                            [2.388323374475548, 48.41859837748569],
                            [2.388503250786556, 48.41832255481767],
                            [2.388711868392753, 48.418049661742565],
                            [2.389587466667926, 48.41697196485423],
                            [2.390650565631598, 48.41568195032109],
                            [2.392110197591911, 48.413897150522224],
                            [2.392264413825362, 48.41371128453138],
                            [2.392657880236009, 48.41323593860022],
                            [2.39307201455852, 48.4127404839023],
                            [2.393537388820268, 48.412182489309586],
                            [2.394729780786517, 48.41074489664629],
                            [2.396344242875188, 48.40878551132365],
                            [2.396685464240191, 48.40837257901008],
                            [2.397096811538713, 48.40787687871588],
                            [2.397799442301978, 48.407018625902886],
                            [2.398654413899097, 48.40595705784972],
                            [2.398872810710566, 48.405636808125315],
                            [2.399081696384446, 48.40527340050349],
                            [2.399232605779722, 48.40499095547699],
                            [2.399308034170875, 48.40482815202271],
                            [2.399395559716458, 48.40462037878873],
                            [2.39951263842496, 48.40428669586576],
                            [2.39962153465357, 48.403890970471544],
                            [2.399677811433466, 48.40353573961727],
                            [2.399724480290099, 48.40305911679867],
                            [2.399722536734974, 48.402587916643235],
                            [2.399688346341769, 48.40224622476595],
                            [2.399624392265597, 48.40186228580065],
                            [2.399481923446543, 48.40132731824217],
                            [2.399300366978953, 48.40084902416577],
                            [2.399101342568212, 48.40043908118435],
                            [2.398956530503003, 48.400183777239924],
                            [2.398698132739097, 48.39980713840452],
                            [2.398454650634904, 48.399477250340354],
                            [2.398115204450287, 48.39907367600658],
                            [2.397643260412243, 48.39853528582518],
                            [2.397102338797336, 48.39789891307257],
                            [2.396469495884509, 48.39716816726632],
                            [2.395485121527657, 48.3960419350061],
                            [2.394707634019301, 48.395130506425716],
                            [2.394047827974065, 48.39437548114887],
                            [2.393410724066637, 48.393641547740856],
                        ],
                    },
                },
                14: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.37935127537549, 2.8078546326901286],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 1374.7591127,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.799307429283779,
                            48.37816709633966,
                            2.815956767081606,
                            48.38235800575609,
                        ),
                        "coordinates": [
                            [2.799307429283779, 48.37859776792736],
                            [2.799803327928466, 48.378487925384775],
                            [2.800366205602521, 48.37839574452107],
                            [2.800948063452046, 48.37831294951513],
                            [2.801847561834057, 48.37822022703036],
                            [2.802327896533707, 48.378190193475696],
                            [2.803018317163776, 48.37816954367282],
                            [2.803611332627112, 48.37816709633966],
                            [2.8044930312979, 48.37819312775507],
                            [2.805257482986111, 48.37823942142173],
                            [2.805934010057579, 48.378313709972595],
                            [2.806594191757865, 48.37842092050679],
                            [2.806910635712471, 48.3784825524816],
                            [2.807186705936732, 48.37853641579208],
                            [2.807551194220757, 48.3786186737446],
                            [2.807903431398984, 48.378695140179275],
                            [2.808287262620804, 48.378793671789765],
                            [2.808628543499887, 48.37888512406479],
                            [2.808902176344857, 48.37896524732036],
                            [2.809241587874725, 48.37906965466149],
                            [2.809650949017997, 48.379208514074946],
                            [2.809885694672334, 48.379293354367505],
                            [2.810210371582848, 48.37941210222083],
                            [2.810473299640536, 48.379523408186195],
                            [2.810726550726919, 48.37963326581886],
                            [2.811046045893848, 48.37977749273188],
                            [2.811350410874251, 48.37991810047534],
                            [2.811656440634826, 48.38007248502223],
                            [2.812060016684274, 48.380291481722075],
                            [2.812336511570756, 48.380447351580074],
                            [2.812648811678011, 48.38061258812495],
                            [2.812975400167187, 48.380777763598246],
                            [2.813505941425138, 48.38105314749179],
                            [2.814195510599813, 48.38142357181096],
                            [2.814697122491966, 48.38168763282923],
                            [2.815956767081606, 48.38235800575609],
                        ],
                    },
                },
                15: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.90262725574345, 2.4679101210146492],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 616.196297122,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.465460481358355,
                            48.90041730406597,
                            2.47012779650017,
                            48.90470320378032,
                        ),
                        "coordinates": [
                            [2.465460481358355, 48.90041730406597],
                            [2.467116481813503, 48.90191711436425],
                            [2.468416665841674, 48.903085921169556],
                            [2.46849252392469, 48.903155394456974],
                            [2.46854066547474, 48.903213797493926],
                            [2.468578771880285, 48.90327533771868],
                            [2.468600085394008, 48.903322086329204],
                            [2.468624986154655, 48.903433294005566],
                            [2.468668730527054, 48.90359736984167],
                            [2.468701368575596, 48.90365262030313],
                            [2.468744056263245, 48.9037048082361],
                            [2.46879614826199, 48.90375314207967],
                            [2.468856858118281, 48.903796889899404],
                            [2.468925260897719, 48.903835387493444],
                            [2.469000321702074, 48.903868051110344],
                            [2.469114836310395, 48.90390315849666],
                            [2.469817504991337, 48.90403647638106],
                            [2.469882876078477, 48.904055703233254],
                            [2.469943027356725, 48.90408128390304],
                            [2.469996551677461, 48.90411261863169],
                            [2.470042191960136, 48.90414897163208],
                            [2.47007888054973, 48.9041894910465],
                            [2.470105756749369, 48.90423322880764],
                            [2.470122191210356, 48.90427915693315],
                            [2.47012779650017, 48.90432620174507],
                            [2.470122443318826, 48.90437325922918],
                            [2.470107545927654, 48.904416477634754],
                            [2.469971544978576, 48.90470320378032],
                        ],
                    },
                },
                16: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.928664240036156, 2.3886083548532833],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 633.55105646,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.384758860075984,
                            48.92740289165737,
                            2.392471119316831,
                            48.92997102620736,
                        ),
                        "coordinates": [
                            [2.392471119316831, 48.92740289165737],
                            [2.391836211901909, 48.92758089052949],
                            [2.391136916896356, 48.92777328656105],
                            [2.390830671891319, 48.92786873110464],
                            [2.390517782334991, 48.92798243261007],
                            [2.389744348724997, 48.92826783726493],
                            [2.388682609351352, 48.92865069816692],
                            [2.387613792493625, 48.929008061775086],
                            [2.38635510926902, 48.92943733823412],
                            [2.385377677582306, 48.92976683203266],
                            [2.384758860075984, 48.92997102620736],
                        ],
                    },
                },
                17: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.91138369912571, 2.4366617245490527],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 384.982043229,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.435420992985438,
                            48.90966636535197,
                            2.437487802213591,
                            48.912704975295874,
                        ),
                        "coordinates": [
                            [2.437487802213591, 48.90966636535197],
                            [2.436754109878076, 48.911425903113],
                            [2.436551200634872, 48.91192895909945],
                            [2.436515311974023, 48.91200686649315],
                            [2.43646662616851, 48.91208822992942],
                            [2.436407781849653, 48.91216662372897],
                            [2.436339191544517, 48.91224149585091],
                            [2.436261337057295, 48.91231232335641],
                            [2.43617476268792, 48.91237860878022],
                            [2.436080077902407, 48.912439885539676],
                            [2.435977943612283, 48.912495725064915],
                            [2.435869078996207, 48.9125457368318],
                            [2.435779008047241, 48.912580822333695],
                            [2.435420992985438, 48.912704975295874],
                        ],
                    },
                },
                18: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.04534072858193, 2.106172270618482],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 155.514119079,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.105110703444507,
                            49.04530962796638,
                            2.107233059674136,
                            49.04539401994291,
                        ),
                        "coordinates": [
                            [2.107233059674136, 49.04539401994291],
                            [2.106582403517276, 49.045354551360596],
                            [2.105934758426439, 49.04532512796745],
                            [2.105610917541017, 49.04531443254045],
                            [2.105221049327595, 49.04530962796638],
                            [2.105110703444507, 49.045311648350264],
                        ],
                    },
                },
                19: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.379019778726, 2.7978126302895676],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 242.866386249,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.796343615000022,
                            48.37859776792736,
                            2.799307429283779,
                            48.37952262366741,
                        ),
                        "coordinates": [
                            [2.796343615000022, 48.37952262366741],
                            [2.797000319222841, 48.379261615476885],
                            [2.797352123268005, 48.37914233984695],
                            [2.797712535958334, 48.379027793970415],
                            [2.798227371862114, 48.37887612293043],
                            [2.798788288699348, 48.378724651131996],
                            [2.799307429283779, 48.37859776792736],
                        ],
                    },
                },
                20: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.4485479385079, 2.7215062118150843],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 8032.72570966,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.692033259866399,
                            48.416377033006604,
                            2.738210817166725,
                            48.4755230723766,
                        ),
                        "coordinates": [
                            [2.726661533081673, 48.416377033006604],
                            [2.726986658138678, 48.417140693732],
                            [2.727345798186738, 48.41781992946304],
                            [2.72756299250814, 48.418171315205484],
                            [2.727769356616908, 48.418508461065514],
                            [2.728040486983366, 48.41890010574532],
                            [2.728327871012224, 48.4192457453491],
                            [2.728747401941021, 48.419711375333925],
                            [2.72916444440831, 48.42015199572559],
                            [2.729615026131733, 48.420587471154015],
                            [2.731704867667564, 48.422457844225114],
                            [2.732971511748013, 48.42357568931441],
                            [2.733394952468326, 48.42398786445735],
                            [2.733732765200332, 48.42433469227287],
                            [2.734369037023407, 48.42500510323783],
                            [2.734742799502794, 48.42543221475421],
                            [2.735127207635353, 48.425881012242726],
                            [2.735648973640984, 48.42658958823863],
                            [2.736210954113941, 48.4274257138859],
                            [2.736730454016712, 48.42835461167416],
                            [2.737135656378466, 48.42918139628824],
                            [2.737510994353277, 48.430158460754086],
                            [2.73783011986764, 48.43120137002651],
                            [2.738021024736048, 48.43209275809406],
                            [2.73815117113718, 48.432989757189816],
                            [2.738204246230493, 48.433711674231525],
                            [2.738210817166725, 48.43453267473404],
                            [2.738141759308018, 48.4355284000061],
                            [2.73807930659066, 48.435998933932474],
                            [2.737904590944704, 48.436964459468705],
                            [2.737792210896972, 48.43744506188221],
                            [2.737644851044388, 48.43794557219136],
                            [2.737409615252215, 48.43861185773486],
                            [2.737328729907203, 48.438806384111295],
                            [2.73713516648589, 48.43927648216298],
                            [2.736854910517911, 48.43989166840407],
                            [2.736499659938606, 48.44059434617139],
                            [2.73594322006713, 48.4414919727546],
                            [2.735877769268981, 48.44158932353692],
                            [2.735823015788552, 48.44167224811111],
                            [2.735551768498164, 48.44206438251455],
                            [2.735162575327905, 48.44258192873389],
                            [2.734750956827061, 48.443080217028324],
                            [2.73436322948491, 48.44353345843046],
                            [2.733928996334741, 48.44399900105242],
                            [2.733462333564197, 48.44446645460683],
                            [2.732945792565143, 48.44495206555066],
                            [2.732644783463515, 48.445234763087655],
                            [2.732307339435341, 48.44552621654909],
                            [2.731796479442139, 48.44592818242115],
                            [2.730798450089744, 48.446724808273025],
                            [2.730018583174712, 48.4473567337031],
                            [2.7290885349158, 48.448103017909496],
                            [2.728259830237224, 48.448783030154914],
                            [2.724639493027038, 48.451705498734896],
                            [2.722789500915932, 48.453194701843216],
                            [2.721497028570242, 48.45423954633243],
                            [2.720205861987529, 48.455285269735846],
                            [2.718913282743654, 48.456330084394196],
                            [2.715445018169386, 48.45912404962778],
                            [2.713398167495356, 48.460757639459445],
                            [2.712165878245331, 48.461766206352465],
                            [2.709699680779072, 48.46376711696281],
                            [2.708385183253715, 48.46483256670907],
                            [2.707918179574805, 48.46521748545662],
                            [2.707472557188555, 48.465552641976224],
                            [2.706746521306709, 48.4660689450631],
                            [2.70624991460592, 48.46640604810272],
                            [2.705774523643334, 48.46672145861911],
                            [2.703917070452122, 48.46789743379212],
                            [2.702652340069023, 48.46871256264989],
                            [2.701567007157238, 48.46940499589657],
                            [2.701093226192951, 48.46971137063555],
                            [2.700167154487338, 48.470306060098345],
                            [2.699601805454366, 48.470668476723255],
                            [2.698619207161681, 48.471305600481685],
                            [2.698328470599237, 48.47149537441684],
                            [2.697796766943694, 48.471838790344904],
                            [2.697426598303561, 48.472079172956064],
                            [2.696527280390612, 48.47264497231067],
                            [2.69559027026669, 48.4732378607693],
                            [2.695053138658947, 48.473583978661615],
                            [2.694416366210666, 48.47399245821119],
                            [2.694007081165644, 48.47425183793106],
                            [2.693121255546687, 48.47482386183596],
                            [2.692269154612462, 48.47537853176761],
                            [2.692033259866399, 48.4755230723766],
                        ],
                    },
                },
                21: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.74114985174119, 2.2932186867638236],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3269.47188174,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.273483464396533,
                            48.734716586800225,
                            2.312711013515798,
                            48.747941901886946,
                        ),
                        "coordinates": [
                            [2.273483464396533, 48.734716586800225],
                            [2.274031620340385, 48.73489774142893],
                            [2.275473449753474, 48.73538233747892],
                            [2.276333671280968, 48.73566876733563],
                            [2.276904428808763, 48.73586780974144],
                            [2.277130016218571, 48.73594616481338],
                            [2.277400450874468, 48.736038931251876],
                            [2.278114751585832, 48.73629061184682],
                            [2.278288585868304, 48.73634661778088],
                            [2.278468848814772, 48.736401603656944],
                            [2.278655448101448, 48.73645132616507],
                            [2.278824707294772, 48.736493872116554],
                            [2.27896942208531, 48.73652677404454],
                            [2.27917117419971, 48.73656756304211],
                            [2.279459465816022, 48.73662002100706],
                            [2.279772100456614, 48.73667323497265],
                            [2.280207071036519, 48.73674719326826],
                            [2.280557756121379, 48.73681571212309],
                            [2.28079833681008, 48.736868888460535],
                            [2.281050094857402, 48.736934177101105],
                            [2.281649451204855, 48.73708723570982],
                            [2.282179988699193, 48.737229321493196],
                            [2.282715905060216, 48.73736076879698],
                            [2.28346081322031, 48.73755968148079],
                            [2.28402909496622, 48.73771125523257],
                            [2.284358003944237, 48.73781302524864],
                            [2.284654278956173, 48.73792107484667],
                            [2.284907058945396, 48.738018311686574],
                            [2.285234579335344, 48.738152452980955],
                            [2.285793129839512, 48.73838651607704],
                            [2.286662910560374, 48.73874121723714],
                            [2.287618993349294, 48.73913942065063],
                            [2.288441910765133, 48.73948119063661],
                            [2.289417744531419, 48.73987458505421],
                            [2.290606959593062, 48.74037507043785],
                            [2.290952185464527, 48.74051010131528],
                            [2.291393925343595, 48.74066945042673],
                            [2.291777456021941, 48.74079103458878],
                            [2.292338621659828, 48.74096568480165],
                            [2.293081974937282, 48.74118454072133],
                            [2.293736004545056, 48.741369098253784],
                            [2.295511505203764, 48.741870524410345],
                            [2.297202400269014, 48.74233887743137],
                            [2.300400244584853, 48.74318740057063],
                            [2.301246714029321, 48.74344721845134],
                            [2.302263413507445, 48.74375938173845],
                            [2.302933781349519, 48.7439711063506],
                            [2.303303545232317, 48.74409981029637],
                            [2.303797013418046, 48.74428070792639],
                            [2.304335176901581, 48.74448769775749],
                            [2.304745197893997, 48.74467102201594],
                            [2.304981031273856, 48.744791829642836],
                            [2.305547870507395, 48.74508334955477],
                            [2.306037219836903, 48.7453568609457],
                            [2.306682871457191, 48.74576170539381],
                            [2.307403275670077, 48.746247498851424],
                            [2.308134578430528, 48.746719802528396],
                            [2.308449949484962, 48.746909627458685],
                            [2.308724546587425, 48.74706347071359],
                            [2.309017596454245, 48.74720002578425],
                            [2.309251525322473, 48.74729439605155],
                            [2.309557930520907, 48.74741258935359],
                            [2.309762132361388, 48.7474767165459],
                            [2.310015491351156, 48.74756048434858],
                            [2.310271728727082, 48.74763037994978],
                            [2.310543117409528, 48.74769384872567],
                            [2.310818322496114, 48.74775190717779],
                            [2.311142616636978, 48.747811629750544],
                            [2.31142748001463, 48.747856358817074],
                            [2.311790727320648, 48.747898337007165],
                            [2.312197969687264, 48.74792673771592],
                            [2.312529148392644, 48.74793905512518],
                            [2.312711013515798, 48.747941901886946],
                        ],
                    },
                },
                22: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.128051381836364, 2.223634602836481],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 3625.59315599,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.210019869292197,
                            49.114783970085064,
                            2.242677776778168,
                            49.13600056459098,
                        ),
                        "coordinates": [
                            [2.242677776778168, 49.13600056459098],
                            [2.241404282416625, 49.1355703825226],
                            [2.240852323823804, 49.13538647153163],
                            [2.239903183445893, 49.135070030821836],
                            [2.239733353511173, 49.13501323374128],
                            [2.238975968880641, 49.134760794546416],
                            [2.23626698026539, 49.13385738564339],
                            [2.236053332870124, 49.133786156468716],
                            [2.234913897603343, 49.1334038604228],
                            [2.233299268950995, 49.13286285319506],
                            [2.232265317849512, 49.13251839510503],
                            [2.230411092950836, 49.131898893401264],
                            [2.227976310400957, 49.13107917438867],
                            [2.225163674043916, 49.130132239341],
                            [2.224399589170243, 49.12987879906107],
                            [2.223561565325184, 49.129602798510454],
                            [2.222749622606446, 49.129311530450956],
                            [2.222014466740057, 49.12900324716752],
                            [2.22145734679115, 49.128744598056585],
                            [2.219669739220031, 49.12788668171439],
                            [2.218502185456426, 49.1273387281673],
                            [2.216959664985112, 49.126601524850045],
                            [2.21657232880148, 49.1264167691166],
                            [2.215867501979152, 49.126067111456834],
                            [2.215692350594532, 49.12596890618907],
                            [2.215155950925862, 49.12566978102914],
                            [2.21467847964165, 49.12536981698402],
                            [2.214511599403723, 49.12525363348429],
                            [2.214258536460963, 49.12508070339735],
                            [2.213887936254705, 49.12478714432074],
                            [2.213618539565318, 49.12457282931554],
                            [2.213059357801466, 49.1240803267129],
                            [2.212499109566168, 49.12347181356781],
                            [2.212317456009334, 49.123241404054305],
                            [2.211986931907959, 49.12282288389816],
                            [2.211543402886758, 49.12212366657644],
                            [2.211261266494421, 49.1215406304532],
                            [2.211214921604879, 49.12144615593669],
                            [2.211086443078509, 49.12114608550616],
                            [2.210991765668457, 49.12083980317458],
                            [2.210890299210122, 49.12033340171316],
                            [2.210767574732576, 49.11956708727531],
                            [2.210635861786001, 49.11856695283363],
                            [2.21050845506467, 49.117492183205364],
                            [2.210364598647382, 49.116423690022614],
                            [2.210244763764672, 49.11560611982857],
                            [2.210087426728598, 49.1149908444586],
                            [2.210019869292197, 49.114783970085064],
                        ],
                    },
                },
                23: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.8629041109497, 2.2209433949796162],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 1218.02571756,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.220352142320904,
                            48.85747140891035,
                            2.221790167679187,
                            48.86823878484656,
                        ),
                        "coordinates": [
                            [2.220603560028727, 48.85747140891035],
                            [2.220796099243322, 48.858379764558386],
                            [2.220844099807766, 48.858684461158816],
                            [2.220870845109435, 48.858903911665365],
                            [2.220877333911554, 48.859043306574904],
                            [2.220864171444983, 48.85942728465891],
                            [2.220839133160909, 48.85964398486926],
                            [2.220819751331364, 48.85977346125759],
                            [2.220793615687503, 48.85987595236301],
                            [2.220759780494999, 48.860033371312625],
                            [2.220577919206502, 48.860699401793596],
                            [2.220484145427779, 48.86107797159799],
                            [2.220428615668951, 48.8613202583737],
                            [2.220379185425627, 48.86166509304043],
                            [2.220363693005537, 48.861878206215565],
                            [2.220352142320904, 48.86215427236642],
                            [2.220352920857938, 48.862403373215614],
                            [2.220364692253167, 48.86261471584999],
                            [2.220422318949099, 48.863033837617856],
                            [2.220520827126257, 48.863457497425074],
                            [2.220627705277193, 48.86379933205886],
                            [2.220735896736426, 48.86408298923023],
                            [2.220829177858702, 48.86429008659731],
                            [2.220934122341877, 48.86449658345503],
                            [2.221066149341154, 48.864740022203506],
                            [2.221327686544535, 48.86523528810059],
                            [2.221489206123383, 48.865530414380956],
                            [2.221586754218678, 48.865742251237855],
                            [2.221676348484428, 48.86598741497979],
                            [2.221733521037887, 48.86621588885668],
                            [2.221776211792053, 48.86647052250906],
                            [2.221790167679187, 48.866672780498185],
                            [2.22178248140956, 48.86687739614003],
                            [2.221749515195155, 48.867096261345],
                            [2.221683994746964, 48.86735554410614],
                            [2.22163673149517, 48.86751967136353],
                            [2.221571358838069, 48.8677147112664],
                            [2.221410602618016, 48.86823878484656],
                        ],
                    },
                },
                24: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.76624571222825, 2.1546265860375127],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1535.54348104,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.146831644750671,
                            48.764776012952915,
                            2.163947085881832,
                            48.77042520300475,
                        ),
                        "coordinates": [
                            [2.146831644750671, 48.77042520300475],
                            [2.146839575361204, 48.770321959612254],
                            [2.146873092690811, 48.770093682186655],
                            [2.14693520256974, 48.76985347182722],
                            [2.147032885748731, 48.7695758827279],
                            [2.147161777495458, 48.769310810798224],
                            [2.147427373432981, 48.768871505640504],
                            [2.147572381326453, 48.76866041672841],
                            [2.147691286307381, 48.768515830601466],
                            [2.147863449005765, 48.76831827559078],
                            [2.147993178295162, 48.76818899483355],
                            [2.14829351412852, 48.76791251510234],
                            [2.148440898967235, 48.76779045723079],
                            [2.148595671417843, 48.767662475921256],
                            [2.148751952214536, 48.767556260007716],
                            [2.14907649251712, 48.767352659983054],
                            [2.149560438791216, 48.76708367301127],
                            [2.14979685464987, 48.766972065613906],
                            [2.150079001396661, 48.76686020301495],
                            [2.150327388968289, 48.76676194385585],
                            [2.150697958710484, 48.766630916480445],
                            [2.151146005275975, 48.76650883849901],
                            [2.151387073138179, 48.766445477534695],
                            [2.152968950578792, 48.76613509322431],
                            [2.154530379153004, 48.76583095001423],
                            [2.156517878035001, 48.76544202913235],
                            [2.157218934575256, 48.765306445903285],
                            [2.157745735806253, 48.76520745606435],
                            [2.158269800867355, 48.765112055896395],
                            [2.158906826270819, 48.765000643720605],
                            [2.159421272692855, 48.76493130235175],
                            [2.160116648983136, 48.764858642212516],
                            [2.160764321506296, 48.764811983998186],
                            [2.161308536428679, 48.76478584523993],
                            [2.163872745041115, 48.764777178118926],
                            [2.163947085881832, 48.764776012952915],
                        ],
                    },
                },
                25: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.822937011110035, 2.256054955971231],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 782.849804392,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.251336154852571,
                            48.82151752250999,
                            2.260539912317944,
                            48.824767024606686,
                        ),
                        "coordinates": [
                            [2.260539912317944, 48.824767024606686],
                            [2.260361800996562, 48.824585850728525],
                            [2.260182095794907, 48.82440305138972],
                            [2.259908714053019, 48.82416455941692],
                            [2.259667912664161, 48.82399623265351],
                            [2.259482862906137, 48.823884597211375],
                            [2.259175292282888, 48.82374050360679],
                            [2.258971134252713, 48.823657631871036],
                            [2.258790101633279, 48.823591861062354],
                            [2.258503435067726, 48.82351179040565],
                            [2.258262086132251, 48.823461658349814],
                            [2.258089172071254, 48.82343060729822],
                            [2.257822094537732, 48.82339155526009],
                            [2.25757837205502, 48.82335361626446],
                            [2.257429907966087, 48.82333021873776],
                            [2.25726420407571, 48.82329679190478],
                            [2.257102108326206, 48.82326098948832],
                            [2.25693642989142, 48.82321328637516],
                            [2.256756095386268, 48.82315520204152],
                            [2.256472963787103, 48.82306507528023],
                            [2.256218416396302, 48.82298485970566],
                            [2.256041450439721, 48.822935274654164],
                            [2.255733787318334, 48.82285681953932],
                            [2.255368947728279, 48.82276573274445],
                            [2.255027248562904, 48.82268185548021],
                            [2.254693718237483, 48.82260068133661],
                            [2.254436434426526, 48.822532150389456],
                            [2.254248598067071, 48.82246906519939],
                            [2.254022664602985, 48.822383198875414],
                            [2.253814453784881, 48.822289794304915],
                            [2.253588554752909, 48.822186212991184],
                            [2.253378991073308, 48.82208713933748],
                            [2.253215668768215, 48.82202586940999],
                            [2.253048253563228, 48.82196909221765],
                            [2.252771933725496, 48.82188525611853],
                            [2.252462920427197, 48.82180769059293],
                            [2.251873487594521, 48.82165707376658],
                            [2.251336154852571, 48.82151752250999],
                        ],
                    },
                },
                26: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.82549558320644, 2.2280569437156292],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 878.449458672,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.225312853267071,
                            48.82230993293686,
                            2.231323159873781,
                            48.829010503694406,
                        ),
                        "coordinates": [
                            [2.231323159873781, 48.82230993293686],
                            [2.231093432592597, 48.822609125995406],
                            [2.230985735061066, 48.822756742992965],
                            [2.230870117837719, 48.82290177535579],
                            [2.230729226056609, 48.823070576885335],
                            [2.230581162715179, 48.82322271764547],
                            [2.230342885458203, 48.82343425704192],
                            [2.23020074747098, 48.8235444420029],
                            [2.229451831903581, 48.824109383985665],
                            [2.229140950957088, 48.824356312591775],
                            [2.228934718487942, 48.82454234745027],
                            [2.228624881845852, 48.824852304299846],
                            [2.228053019357066, 48.82540211807331],
                            [2.227713222595891, 48.8257057496553],
                            [2.227088244535708, 48.82624561542054],
                            [2.226757827914828, 48.826535893977926],
                            [2.226259773336329, 48.82702808523784],
                            [2.225975732623674, 48.827360542420614],
                            [2.225744847312255, 48.827675064752256],
                            [2.225651871516851, 48.82783504479516],
                            [2.225568948585039, 48.8280027939963],
                            [2.225510991577847, 48.82813598036601],
                            [2.225463806945631, 48.828285832849254],
                            [2.225428518470811, 48.82843374591898],
                            [2.225347274716438, 48.82882582988393],
                            [2.225312853267071, 48.829010503694406],
                        ],
                    },
                },
                27: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.921736659128335, 2.4086047925293763],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 361.696596821,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.406622752354694,
                            48.920785969955396,
                            2.410598615094689,
                            48.922711188353,
                        ),
                        "coordinates": [
                            [2.410598615094689, 48.920785969955396],
                            [2.409991799676058, 48.921091218861285],
                            [2.40902538594671, 48.921522870475776],
                            [2.408374933942032, 48.921837923853985],
                            [2.407057468263527, 48.922474234749],
                            [2.406622752354694, 48.922711188353],
                        ],
                    },
                },
                28: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.716884021644645, 2.4470935220619707],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 3717.07077233,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.438093383889102,
                            48.70823782858165,
                            2.462282244689792,
                            48.73011683142026,
                        ),
                        "coordinates": [
                            [2.462282244689792, 48.70823782858165],
                            [2.460983910433233, 48.70879460381943],
                            [2.460264468713545, 48.70910940162476],
                            [2.45989156299872, 48.70928770107002],
                            [2.459540394511254, 48.70947546745735],
                            [2.459186371898107, 48.70968137901128],
                            [2.458828870992446, 48.70990805478701],
                            [2.4581193284077, 48.710365645385814],
                            [2.45788462065311, 48.71051697335805],
                            [2.4573934369007, 48.710810659335635],
                            [2.457066390778859, 48.71098996065503],
                            [2.456146253745974, 48.71147204257776],
                            [2.455711881415892, 48.71166494265567],
                            [2.455406437124127, 48.711790260756786],
                            [2.45442359216518, 48.71220045254005],
                            [2.453762414097586, 48.71245293242585],
                            [2.451625523919498, 48.7133130196957],
                            [2.451142189484145, 48.713502354460644],
                            [2.450760658087116, 48.713643024944055],
                            [2.450474138316585, 48.713735037731645],
                            [2.45012376227197, 48.71383340884293],
                            [2.449712228421354, 48.71392914211516],
                            [2.449243587887568, 48.71401144056516],
                            [2.448787122355311, 48.71407034461838],
                            [2.448427319688785, 48.7141076013759],
                            [2.448015377294803, 48.71412506080166],
                            [2.447647093473568, 48.71411822694539],
                            [2.446926798726546, 48.71408835290434],
                            [2.446281276317311, 48.714072790965105],
                            [2.445407435106446, 48.71404755225977],
                            [2.44471845892446, 48.7140464104308],
                            [2.444150481297779, 48.714070330422494],
                            [2.443659987170575, 48.714105865696325],
                            [2.443169542254486, 48.71416477873885],
                            [2.442869323816343, 48.714213620946566],
                            [2.442552623224028, 48.71426550651059],
                            [2.442255364780425, 48.71434368775591],
                            [2.441614354305444, 48.71453582667013],
                            [2.441231430498669, 48.71467646649414],
                            [2.440803740234079, 48.714856713288114],
                            [2.440404624068385, 48.71505491884784],
                            [2.44005715933288, 48.71526026876353],
                            [2.439504846271283, 48.715639363933136],
                            [2.439275602654027, 48.715844604756086],
                            [2.439032833066198, 48.71608133259323],
                            [2.438822682066663, 48.71632072727946],
                            [2.438653267876831, 48.71654479851283],
                            [2.438431101762117, 48.716906959958216],
                            [2.438249711512178, 48.71729614086154],
                            [2.438178333422549, 48.717559518330255],
                            [2.438116704366139, 48.7179021951341],
                            [2.438093383889102, 48.71822263243712],
                            [2.438108347463893, 48.71850813798271],
                            [2.43815434831925, 48.7187313567867],
                            [2.438233522983043, 48.71911851748304],
                            [2.438364435249654, 48.7194806567947],
                            [2.43852495245468, 48.71982326862533],
                            [2.438704570856386, 48.720127660535574],
                            [2.43895095254639, 48.72041813306976],
                            [2.439645733248798, 48.72115958316324],
                            [2.43999873658582, 48.72144716199589],
                            [2.440384148210437, 48.72175374324625],
                            [2.440884786413756, 48.722131597580464],
                            [2.441352983723824, 48.722469032149334],
                            [2.441752777144327, 48.72276607883646],
                            [2.442040937787661, 48.72298946892722],
                            [2.44223548143611, 48.72315584184236],
                            [2.442469725183576, 48.72338879718654],
                            [2.442657165211647, 48.7235956239343],
                            [2.442844687405979, 48.72384051987785],
                            [2.443028625997199, 48.724090176611114],
                            [2.443194594919307, 48.72434460977975],
                            [2.4434291891175, 48.724736978193924],
                            [2.443839778338836, 48.725681117140645],
                            [2.444123624612847, 48.726203326118146],
                            [2.444202786960045, 48.7263543286648],
                            [2.444305117491671, 48.726533186922836],
                            [2.444408805593823, 48.72671114474048],
                            [2.444523377410538, 48.72689268881358],
                            [2.444943425580544, 48.72755208104018],
                            [2.44541690109799, 48.728360348361576],
                            [2.445687086449872, 48.72883670349414],
                            [2.445830415179587, 48.72911084413214],
                            [2.445921963217562, 48.72932658073056],
                            [2.446005440453732, 48.729580994507565],
                            [2.446054793282373, 48.72977069404581],
                            [2.446105500724956, 48.729957693392315],
                            [2.446135830934545, 48.73011683142026],
                        ],
                    },
                },
                29: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.80659675454427, 2.926148663533012],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 5114.77794539,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.906161397416222,
                            48.78949667687371,
                            2.953730383101934,
                            48.813619747962505,
                        ),
                        "coordinates": [
                            [2.953730383101934, 48.81077532178037],
                            [2.953329211502365, 48.81087793726541],
                            [2.952789100876691, 48.8109998660778],
                            [2.952324895610694, 48.811078507869055],
                            [2.951854017070723, 48.811147814330866],
                            [2.951134958747968, 48.81123811218608],
                            [2.95046067222862, 48.81132537814673],
                            [2.947656093543874, 48.811687566673115],
                            [2.946816530371679, 48.811803417376616],
                            [2.946083033892751, 48.81193038023987],
                            [2.945431494854362, 48.81204659363544],
                            [2.944607032364517, 48.812214664030705],
                            [2.943441809812445, 48.812466379048445],
                            [2.939602450196421, 48.81329431293807],
                            [2.939011335808973, 48.81339456086146],
                            [2.938611363484698, 48.81344999751361],
                            [2.938140520447207, 48.81350871839909],
                            [2.937572957442571, 48.81355704977085],
                            [2.937042075280546, 48.813597393501475],
                            [2.936448304364605, 48.813616795038996],
                            [2.93588630545274, 48.813619747962505],
                            [2.935324105164708, 48.81360604386553],
                            [2.934808596099368, 48.813580195208004],
                            [2.934159799589404, 48.81354476750924],
                            [2.933568659139823, 48.813503208649074],
                            [2.932980950953201, 48.813434338047145],
                            [2.932569371105819, 48.81337073351317],
                            [2.932121129536421, 48.81329682800951],
                            [2.931669677002505, 48.813208264876295],
                            [2.931153569433, 48.81309134838635],
                            [2.93063038464191, 48.81295381949701],
                            [2.929978271724415, 48.81275834916493],
                            [2.929432082661814, 48.81257559445242],
                            [2.928811872222717, 48.81232113420862],
                            [2.928019212768972, 48.81196192678717],
                            [2.927584841926005, 48.811745245852975],
                            [2.927164166842634, 48.81151186247822],
                            [2.926685206783411, 48.81122405228713],
                            [2.92634251858611, 48.81099845987687],
                            [2.9256642643071, 48.81052353423742],
                            [2.925300071307058, 48.81023853707957],
                            [2.924939817954663, 48.80994092680508],
                            [2.923592052916786, 48.808803057183],
                            [2.922736550761754, 48.80807092654039],
                            [2.921069715830944, 48.8066769264118],
                            [2.920660616016986, 48.80636390621538],
                            [2.920067475727485, 48.80593887378623],
                            [2.919624356893845, 48.80565156412965],
                            [2.918827852885868, 48.80518169993301],
                            [2.917996240911639, 48.804735391940746],
                            [2.917063121751383, 48.804240104709315],
                            [2.915817875932205, 48.80355939534779],
                            [2.914634404566135, 48.80293768714485],
                            [2.913450961583915, 48.80231422211566],
                            [2.912102067667015, 48.80158343167483],
                            [2.911372307606685, 48.80115017377197],
                            [2.910578352990439, 48.80063696892352],
                            [2.90977821719795, 48.80008892681216],
                            [2.909333548296815, 48.799775505424456],
                            [2.909064360102315, 48.79956911741686],
                            [2.908585670802458, 48.79915928469009],
                            [2.908092969009444, 48.798670189515406],
                            [2.907814541634286, 48.79836941887951],
                            [2.907625554744399, 48.79813618818794],
                            [2.907417861804971, 48.79784621138876],
                            [2.907276445483669, 48.79762209330325],
                            [2.907126327468852, 48.79735125501844],
                            [2.906807827098722, 48.79675930847902],
                            [2.906632133484097, 48.79639417028809],
                            [2.906469209773402, 48.79596537710317],
                            [2.906311180527012, 48.795348984970815],
                            [2.906226777756416, 48.79492202704146],
                            [2.906179382374182, 48.79453667318341],
                            [2.906161397416222, 48.79427326736863],
                            [2.90617093462054, 48.793818259358204],
                            [2.906224503946948, 48.79330090616567],
                            [2.906317326397706, 48.79276344833569],
                            [2.906430964025943, 48.79232455258264],
                            [2.906526129566338, 48.79200879778995],
                            [2.907387270372533, 48.78949667687371],
                        ],
                    },
                },
                30: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.8111628812768, 3.061798363457108],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2985.59158757,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.042938266046296,
                            48.80850206349516,
                            3.080343011929784,
                            48.81379848212747,
                        ),
                        "coordinates": [
                            [3.080343011929784, 48.80850206349516],
                            [3.077337778782705, 48.80999479199734],
                            [3.076203956715552, 48.81054704631031],
                            [3.075637423893467, 48.81079534474709],
                            [3.074624970621095, 48.811206866164355],
                            [3.074109584200572, 48.811415209083286],
                            [3.073608284995546, 48.81160257434704],
                            [3.073257314184835, 48.811717256529384],
                            [3.072842308029973, 48.81182965276151],
                            [3.072397161657425, 48.81192965196878],
                            [3.072056771736029, 48.811985988283766],
                            [3.07154987570324, 48.81204763426375],
                            [3.071150429905094, 48.81207876106522],
                            [3.07064266552498, 48.812093925838596],
                            [3.070174614624569, 48.81209325355607],
                            [3.069730800639253, 48.81206885645771],
                            [3.06922741406098, 48.81201542050371],
                            [3.068768605683843, 48.811948501513655],
                            [3.068281031903928, 48.81184910701382],
                            [3.067869039132653, 48.81174758022826],
                            [3.067258228455184, 48.81158362811228],
                            [3.066055549972939, 48.811255417993024],
                            [3.064562672837766, 48.81084766964273],
                            [3.063570161269064, 48.810576107919594],
                            [3.063190249204707, 48.81048077320204],
                            [3.062731238120739, 48.81037820479021],
                            [3.062299734494043, 48.810293716266784],
                            [3.061734649862922, 48.81019928447444],
                            [3.061337177726046, 48.810142780910866],
                            [3.060850704234703, 48.810087987868364],
                            [3.060318775992009, 48.81004214102092],
                            [3.059727520435087, 48.810004282581815],
                            [3.059162589014512, 48.809990013659],
                            [3.058539993926606, 48.80999022031065],
                            [3.05795603690172, 48.81001192664627],
                            [3.057420476558753, 48.81005655942325],
                            [3.056979738827774, 48.8100945127738],
                            [3.056536570203853, 48.81014407546588],
                            [3.056114288123208, 48.810204396527894],
                            [3.055736420541823, 48.810271429791825],
                            [3.055361687483528, 48.8103457371135],
                            [3.054923853522874, 48.810442370048946],
                            [3.054450694137266, 48.810562084202886],
                            [3.053470575770452, 48.8108306791563],
                            [3.052621725555496, 48.81107612898464],
                            [3.051925008576484, 48.811273284102455],
                            [3.05109163126128, 48.81150829539009],
                            [3.050282368077969, 48.81173650053079],
                            [3.049613514773414, 48.811926650424],
                            [3.048899124828313, 48.81212859854744],
                            [3.04806640062477, 48.81236457758318],
                            [3.047031617794968, 48.81265700927636],
                            [3.045692455870439, 48.81302268428452],
                            [3.04425523172087, 48.813428793955524],
                            [3.042938266046296, 48.81379848212747],
                        ],
                    },
                },
                31: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.7063564569781, 2.4731877714913058],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 1679.0416788,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.462282244689792,
                            48.70563117036449,
                            2.484245146583624,
                            48.70823782858165,
                        ),
                        "coordinates": [
                            [2.484245146583624, 48.70661094689584],
                            [2.483999090311285, 48.706578257972986],
                            [2.48299836448982, 48.70643143780319],
                            [2.482413004274576, 48.7063340427909],
                            [2.481458498299263, 48.7061728730927],
                            [2.480704140633706, 48.70604107453491],
                            [2.48011354949652, 48.70594646880368],
                            [2.479517385293175, 48.705865980715004],
                            [2.478807926423619, 48.70578953251095],
                            [2.478110095024648, 48.705730431143486],
                            [2.477258683545632, 48.70567275667939],
                            [2.476822478805115, 48.705649914143045],
                            [2.476243636639174, 48.70563623900458],
                            [2.475977319575276, 48.70563117036449],
                            [2.475494992029789, 48.70563445835077],
                            [2.474875455476397, 48.70564420577465],
                            [2.474666234679159, 48.705650755584216],
                            [2.474510000606064, 48.70565634035054],
                            [2.474245076312613, 48.70566385562254],
                            [2.473408270082582, 48.70571792284229],
                            [2.472821455820152, 48.70576988616582],
                            [2.472192567143237, 48.705838983167816],
                            [2.471522957362155, 48.70592341216338],
                            [2.471028580198388, 48.705994141285274],
                            [2.470418799794077, 48.706097377111234],
                            [2.469476054655626, 48.70628194199456],
                            [2.468648054671239, 48.70647714204885],
                            [2.468087275787389, 48.706618079066395],
                            [2.466859775096365, 48.70691715067424],
                            [2.4655133330434, 48.70724299521899],
                            [2.464567693276872, 48.707482698255745],
                            [2.46392409849711, 48.70765877891531],
                            [2.463453002050065, 48.70781128272832],
                            [2.462804681259587, 48.708024074480846],
                            [2.462437563629043, 48.7081712211007],
                            [2.462282244689792, 48.70823782858165],
                        ],
                    },
                },
                32: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.61195541721638, 2.5767288541006903],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 3798.63575937,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.56958354823646,
                            48.595563837991776,
                            2.58394771106125,
                            48.62837555172384,
                        ),
                        "coordinates": [
                            [2.58394771106125, 48.595563837991776],
                            [2.583117344654084, 48.59747915687793],
                            [2.582574627318395, 48.598818573486696],
                            [2.582073603471251, 48.59996344602832],
                            [2.581087273327229, 48.60219500150275],
                            [2.580061588083991, 48.60446708110959],
                            [2.57951153778809, 48.605705508428805],
                            [2.578744745254357, 48.60738457044565],
                            [2.578446637034757, 48.60805855514081],
                            [2.577967609656476, 48.60916120253005],
                            [2.577655265455324, 48.60986376665252],
                            [2.577413868423425, 48.61039962783699],
                            [2.57667563520148, 48.61207861536173],
                            [2.576015382845692, 48.61356708785904],
                            [2.575553905565817, 48.61461020447449],
                            [2.575163322747977, 48.61547472146526],
                            [2.574698130966103, 48.61649880773506],
                            [2.574378699718054, 48.61723944756969],
                            [2.574123182059039, 48.617839572326695],
                            [2.573853385855744, 48.61845638251498],
                            [2.573217440869168, 48.619818948949],
                            [2.572913166623866, 48.620506889587936],
                            [2.57278970824799, 48.62078771955357],
                            [2.572663601230039, 48.62108204337581],
                            [2.572528048157026, 48.62138717766877],
                            [2.572392486483136, 48.62169051357187],
                            [2.572189848438892, 48.62215226050985],
                            [2.572032792067063, 48.622500604154915],
                            [2.571867703899166, 48.622872345615335],
                            [2.571656994738576, 48.62335029486997],
                            [2.571456971374416, 48.62379404918274],
                            [2.571285164909932, 48.62418109122728],
                            [2.570953586615855, 48.62492007805811],
                            [2.570797867899989, 48.625268416959315],
                            [2.570660987433426, 48.62558434382758],
                            [2.570541557777406, 48.625861565249814],
                            [2.570313429010005, 48.6264135510181],
                            [2.57010763665612, 48.62696626527897],
                            [2.569971896368711, 48.627297121567615],
                            [2.569800402378706, 48.62775385935917],
                            [2.569698750821867, 48.62803512581767],
                            [2.56958354823646, 48.62837555172384],
                        ],
                    },
                },
                33: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.862011753167764, 2.486683183549044],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 1774.87225707,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.485192413733974,
                            48.85426899363537,
                            2.489167460948015,
                            48.86991241918608,
                        ),
                        "coordinates": [
                            [2.485761140611789, 48.86991241918608],
                            [2.485403140820869, 48.86804852924353],
                            [2.485296894981928, 48.867494280596155],
                            [2.485237977223209, 48.86708748898079],
                            [2.485204566862315, 48.86676869949371],
                            [2.48519291070255, 48.86648795169036],
                            [2.485192413733974, 48.86632139865094],
                            [2.485195565335754, 48.866169116595756],
                            [2.485205832004424, 48.86598351428096],
                            [2.485219795221389, 48.86582883789328],
                            [2.485237338016089, 48.86566464035502],
                            [2.48525851491468, 48.86550995537428],
                            [2.485286891217929, 48.86535050159098],
                            [2.485322444662407, 48.86517914269481],
                            [2.48536163207203, 48.865017296347084],
                            [2.485400847911842, 48.864864966831185],
                            [2.485454390657542, 48.86467930842683],
                            [2.485511551502227, 48.86449840411123],
                            [2.485575917800938, 48.86431511060469],
                            [2.485650961964073, 48.86408421531657],
                            [2.485915670629444, 48.86336292829613],
                            [2.486530753394955, 48.861634717413814],
                            [2.487149450555291, 48.859923154078274],
                            [2.487764484693475, 48.858206834380155],
                            [2.488286436263018, 48.8567238098652],
                            [2.488872799812502, 48.85509079809266],
                            [2.489137306418753, 48.85435309723007],
                            [2.489167460948015, 48.85426899363537],
                        ],
                    },
                },
                34: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.83918106271761, 2.1451699821754406],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1296.24745061,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.138125058777295,
                            48.83664331803193,
                            2.152697400276265,
                            48.84271995435486,
                        ),
                        "coordinates": [
                            [2.152697400276265, 48.83664331803193],
                            [2.151494450276671, 48.83716336132657],
                            [2.151448055590113, 48.837183969970084],
                            [2.151304790197782, 48.83724398874261],
                            [2.151201096376565, 48.83728698482183],
                            [2.151011429272439, 48.8373694095978],
                            [2.150595324053422, 48.837530601038715],
                            [2.150199753356664, 48.837664846442614],
                            [2.149982900686715, 48.83773013915898],
                            [2.149798805622502, 48.837779297255494],
                            [2.149389755027156, 48.83787394933208],
                            [2.148417688555967, 48.83806928990928],
                            [2.14827453022489, 48.83809962869864],
                            [2.147561473468476, 48.83824772762844],
                            [2.147317431968593, 48.838296782967966],
                            [2.14727925589169, 48.838304813075155],
                            [2.147183822059724, 48.83832353880348],
                            [2.147110194706043, 48.83833960395889],
                            [2.146597544958928, 48.838448461902],
                            [2.14461117078485, 48.83882732423409],
                            [2.144365707474712, 48.8388898605139],
                            [2.144079298144692, 48.83897211019468],
                            [2.143608678111592, 48.83912958650049],
                            [2.14328669413643, 48.839250443934375],
                            [2.142919592427779, 48.839411690719615],
                            [2.142703918167032, 48.83952013581845],
                            [2.142292943197358, 48.839751450500074],
                            [2.14169049027014, 48.840172182428645],
                            [2.138556300228687, 48.84240418422912],
                            [2.138125058777295, 48.84271995435486],
                        ],
                    },
                },
                35: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.92909136234755, 2.5174275746191577],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 579.755346369,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.515049661053076,
                            48.92664020200147,
                            2.519103763829303,
                            48.93093418298108,
                        ),
                        "coordinates": [
                            [2.519103763829303, 48.92664020200147],
                            [2.51906853702209, 48.926880573079195],
                            [2.519011538134676, 48.92709242687639],
                            [2.518940174352807, 48.92732571662312],
                            [2.518829209567769, 48.92759238140457],
                            [2.518725242726364, 48.92779717134455],
                            [2.518621176026457, 48.92797578813974],
                            [2.518502684983046, 48.928159186781215],
                            [2.518366160674937, 48.92834975109646],
                            [2.518222362070218, 48.92852605130038],
                            [2.518089309729086, 48.92867854115958],
                            [2.517913044745209, 48.92886440999888],
                            [2.517362540898407, 48.92941252991702],
                            [2.517193415230611, 48.92957697317273],
                            [2.516894626256906, 48.92983441301489],
                            [2.516584964309326, 48.9300823540995],
                            [2.516372465360181, 48.93023734420043],
                            [2.516095058540809, 48.93041860950493],
                            [2.51581759837837, 48.93058559970386],
                            [2.515572481458548, 48.930709709364464],
                            [2.515049661053076, 48.93093418298108],
                        ],
                    },
                },
                36: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.95568359366042, 3.0755669614314884],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 7364.99319997,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.026111294286066,
                            48.95045023942411,
                            3.124909020747328,
                            48.95947688730028,
                        ),
                        "coordinates": [
                            [3.026111294286066, 48.959164063062694],
                            [3.028700339714932, 48.959193407815334],
                            [3.033946724675614, 48.95925150744609],
                            [3.036649619814603, 48.95928211943009],
                            [3.045346964591205, 48.95937421664601],
                            [3.054158214157287, 48.959469220501],
                            [3.054984354226941, 48.95947688730028],
                            [3.055621642034194, 48.95946860277293],
                            [3.056213158979291, 48.95944346934821],
                            [3.056849887850346, 48.959396634586696],
                            [3.057479831969095, 48.95933056502685],
                            [3.058148361922584, 48.95923426809352],
                            [3.058836055738936, 48.95911428921469],
                            [3.059672640722872, 48.95894625269894],
                            [3.06121578830073, 48.958615266944285],
                            [3.066240709199769, 48.95754471309947],
                            [3.069939562176635, 48.95675655335456],
                            [3.070561972051204, 48.95662407343478],
                            [3.071194070612321, 48.956487243887274],
                            [3.071657652190732, 48.95639004146513],
                            [3.072286557106454, 48.95625750909456],
                            [3.072928493980969, 48.95612703193325],
                            [3.073473295421727, 48.95602501605137],
                            [3.073933935981002, 48.95594923815714],
                            [3.077012249740354, 48.95545238059269],
                            [3.081461644560318, 48.954742722850455],
                            [3.084169028973149, 48.95430512396928],
                            [3.084719225170145, 48.954228242540474],
                            [3.085264437290602, 48.95415638618454],
                            [3.085876360562912, 48.954096069899954],
                            [3.086699114158378, 48.9540511101323],
                            [3.089247190882916, 48.953947043576704],
                            [3.0902886086884, 48.95390854339689],
                            [3.09109494003099, 48.95387824503366],
                            [3.091878339602421, 48.95384887334951],
                            [3.093106365654227, 48.95378500340465],
                            [3.093460417621238, 48.95376102214178],
                            [3.094061543767709, 48.95371114683146],
                            [3.094882389551664, 48.953635015922984],
                            [3.095445459643547, 48.95357465254015],
                            [3.095937671185737, 48.95351142518824],
                            [3.097449368054931, 48.953299843715264],
                            [3.10039458288502, 48.95289379700788],
                            [3.103709434527481, 48.95242926121986],
                            [3.104407135569551, 48.952332250555486],
                            [3.105514713256113, 48.95216891903031],
                            [3.106833856894506, 48.951948789644746],
                            [3.107848778818346, 48.95175569470668],
                            [3.108771581874937, 48.95156240587081],
                            [3.110671654770488, 48.951167342277074],
                            [3.111304695356839, 48.951036599676925],
                            [3.111977229784618, 48.95091534073006],
                            [3.112423718937953, 48.950842354777215],
                            [3.112889737442756, 48.950771518644686],
                            [3.113397872871054, 48.95071248301526],
                            [3.11399370778419, 48.95064846998484],
                            [3.114476089073836, 48.95060687892097],
                            [3.114938396771792, 48.950575416264996],
                            [3.115476616716733, 48.95054676620583],
                            [3.116558532170003, 48.95051607115102],
                            [3.118356037172339, 48.95047880705511],
                            [3.11937238606898, 48.95046019309725],
                            [3.119852731638431, 48.95045023942411],
                            [3.120520409928101, 48.95045232628279],
                            [3.120968117863072, 48.95045758289322],
                            [3.121426100081013, 48.950472761382535],
                            [3.122393058777563, 48.95052941163141],
                            [3.122856415399733, 48.95056453520726],
                            [3.123439016891862, 48.95062382107558],
                            [3.124103346364604, 48.95070058178538],
                            [3.124909020747328, 48.95081998757722],
                        ],
                    },
                },
                37: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.819380272260695, 2.195423262875548],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1940.22611855,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.188259860000294,
                            48.81257171717766,
                            2.200721257947835,
                            48.8272387754095,
                        ),
                        "coordinates": [
                            [2.188259860000294, 48.81257171717766],
                            [2.18977173089294, 48.81447792661163],
                            [2.189817854884192, 48.814536438585144],
                            [2.189880267957558, 48.814612058709386],
                            [2.190284571652338, 48.81511257772727],
                            [2.190527497518925, 48.81538986762242],
                            [2.190691712957203, 48.81557712747344],
                            [2.190853279230943, 48.815739204791704],
                            [2.190918445474538, 48.81580583450609],
                            [2.191009444196634, 48.81588598697984],
                            [2.191078696426578, 48.81595262175729],
                            [2.191165605292646, 48.81603456771417],
                            [2.191514647029684, 48.816348861240286],
                            [2.191794485413418, 48.81658033139004],
                            [2.192138224509382, 48.81684785422946],
                            [2.192414098347767, 48.81703975029532],
                            [2.192805540364206, 48.81729474083723],
                            [2.192855834424884, 48.81732627963286],
                            [2.192893897575333, 48.81734880930482],
                            [2.193312595117685, 48.817598437267954],
                            [2.193729974448492, 48.817834572803044],
                            [2.194971361017204, 48.81850069086825],
                            [2.196381503666261, 48.81923166825301],
                            [2.196910272897255, 48.81954639257153],
                            [2.197231024107471, 48.819776987004445],
                            [2.197574853164364, 48.820040767528695],
                            [2.197934923038173, 48.82033167379007],
                            [2.198174690283779, 48.82055047437471],
                            [2.198313907605619, 48.820678356718965],
                            [2.198752519384207, 48.82113302449515],
                            [2.198838023237781, 48.82123834372864],
                            [2.199055191565388, 48.82150119528909],
                            [2.199333237856536, 48.821911601361165],
                            [2.199532563556481, 48.82222658902717],
                            [2.19958265460223, 48.82233456299452],
                            [2.1997298831254, 48.82262274037754],
                            [2.199854742676403, 48.82293380849898],
                            [2.199943941533043, 48.82317547081763],
                            [2.200026192789215, 48.82348347348516],
                            [2.200124394198703, 48.82392693510873],
                            [2.200140507601999, 48.82401058753482],
                            [2.200155270760345, 48.824089741149876],
                            [2.200267917081906, 48.82472926231235],
                            [2.200305389839422, 48.82497031358611],
                            [2.200478604419895, 48.82587429509449],
                            [2.200486644086928, 48.82592286563294],
                            [2.200498723526633, 48.82598762794323],
                            [2.200530897228218, 48.82617561531387],
                            [2.20059528646788, 48.826535403866295],
                            [2.200655619224576, 48.826885294333515],
                            [2.200674388675792, 48.82699412916455],
                            [2.20068917234138, 48.82706698869271],
                            [2.200721257947835, 48.8272387754095],
                        ],
                    },
                },
                38: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.068221426069414, 2.1978835203495612],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2447.39113016,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.191244759191911,
                            49.058047811766336,
                            2.205446725524735,
                            49.07769904281828,
                        ),
                        "coordinates": [
                            [2.205446725524735, 49.07769904281828],
                            [2.204806727457009, 49.076869223928355],
                            [2.204322398107003, 49.07626255546574],
                            [2.203960892017576, 49.07579901173805],
                            [2.203532532177559, 49.07525625346355],
                            [2.202823274165091, 49.07431838432103],
                            [2.201955752901646, 49.07320047018822],
                            [2.201905277492038, 49.073138361020604],
                            [2.201551951653985, 49.072703595241045],
                            [2.201285864157705, 49.07240292447033],
                            [2.201053799286954, 49.07217513339117],
                            [2.200840933229804, 49.07199714229422],
                            [2.200585334631, 49.07180497681357],
                            [2.199721874369569, 49.07123200988989],
                            [2.199231398855944, 49.07090858371576],
                            [2.198981381682828, 49.07074371599094],
                            [2.198411674778181, 49.070368932452475],
                            [2.198201305190892, 49.07022209627837],
                            [2.197996237373011, 49.07006409660289],
                            [2.197836720840645, 49.06991590232351],
                            [2.197479085492922, 49.069573744650654],
                            [2.197339987685086, 49.069393720721195],
                            [2.197237709526699, 49.06926140263168],
                            [2.197018298629368, 49.06892660566757],
                            [2.196791150255154, 49.06849227104825],
                            [2.196597907141723, 49.068034912117156],
                            [2.196364166987325, 49.06744740008892],
                            [2.196182006672561, 49.06701282765043],
                            [2.19570086437753, 49.065838684046795],
                            [2.195464448275426, 49.065237678375695],
                            [2.194906996078088, 49.06396091947925],
                            [2.194683838791784, 49.0635146037255],
                            [2.194418348118311, 49.06303855851216],
                            [2.194090139366126, 49.0624832980704],
                            [2.193606484260956, 49.06173719645499],
                            [2.193211377727299, 49.06113418879083],
                            [2.192827330256025, 49.0604961220893],
                            [2.192339642569011, 49.05973831951797],
                            [2.191980077380003, 49.059158732968434],
                            [2.191557772949955, 49.05851162012874],
                            [2.191283914193455, 49.05810839809772],
                            [2.191244759191911, 49.058047811766336],
                        ],
                    },
                },
                39: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [49.02582179995458, 2.0854330285425045],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 3199.48278728,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.078284568034463,
                            49.014133684983044,
                            2.091284826714122,
                            49.03646398072535,
                        ),
                        "coordinates": [
                            [2.079534939997374, 49.03646398072535],
                            [2.080630001149099, 49.035737394307],
                            [2.080866042491933, 49.03558504482191],
                            [2.082089687714947, 49.03488273695746],
                            [2.082608216810195, 49.03458532855274],
                            [2.083715127867986, 49.03396727747421],
                            [2.085266399054012, 49.03310199153051],
                            [2.086471977933504, 49.032431971975036],
                            [2.087653404473906, 49.03182396298089],
                            [2.088109707639061, 49.03157842727302],
                            [2.088577135965932, 49.03133606941406],
                            [2.088909010527916, 49.03115659802896],
                            [2.089230299877848, 49.03095838270194],
                            [2.089540462554628, 49.03074865824792],
                            [2.089860131583701, 49.03049951689638],
                            [2.090190951038185, 49.0301909135544],
                            [2.090503909471019, 49.02983468530743],
                            [2.090729820570972, 49.02951871767404],
                            [2.090915940711826, 49.02920028563079],
                            [2.091102600190946, 49.02877240220407],
                            [2.09120916929756, 49.02844190295927],
                            [2.091257649225088, 49.028151727236015],
                            [2.091284826714122, 49.027778226909874],
                            [2.09126486096519, 49.02742604039942],
                            [2.09123328898478, 49.0272261076615],
                            [2.091169575734375, 49.0269404500029],
                            [2.091069790340119, 49.026633298933156],
                            [2.090948286030414, 49.02632848133386],
                            [2.09080509517082, 49.02601885922264],
                            [2.090622451782062, 49.025640150706785],
                            [2.0897081715483, 49.0239678770201],
                            [2.089367338866619, 49.02339133901145],
                            [2.08915179808744, 49.02308393661535],
                            [2.088939651991842, 49.022821749101894],
                            [2.088720081508918, 49.02259761557288],
                            [2.088467998049307, 49.022363891604115],
                            [2.088259011867006, 49.02219450423433],
                            [2.088028330661265, 49.022022690971745],
                            [2.087743454737624, 49.021836481311986],
                            [2.087440481655731, 49.02165261348585],
                            [2.087112127813076, 49.02148058373926],
                            [2.086697126961103, 49.02127267595191],
                            [2.086238788952715, 49.02105039333346],
                            [2.085859890840416, 49.02085921436126],
                            [2.085488264964706, 49.02066091356204],
                            [2.084914668611982, 49.020340820748515],
                            [2.08427264509612, 49.019961090340075],
                            [2.081239292224347, 49.01818888125132],
                            [2.080748757798128, 49.01790702035803],
                            [2.080373766846072, 49.017668246014985],
                            [2.080020509629092, 49.01742476035577],
                            [2.079743134769261, 49.01719809931921],
                            [2.079487493825301, 49.01696672850629],
                            [2.079293140001917, 49.01677594262866],
                            [2.079084567036572, 49.016537539993905],
                            [2.078872676435314, 49.01624202174061],
                            [2.078718306011328, 49.01601563543059],
                            [2.078578678793434, 49.01573693577666],
                            [2.07846081767029, 49.01544639168923],
                            [2.078379108064912, 49.01516068325311],
                            [2.078326163420755, 49.014908353596375],
                            [2.078284568034463, 49.01456087315983],
                            [2.078289810937325, 49.014249190822],
                            [2.078306591409993, 49.014133684983044],
                        ],
                    },
                },
                40: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.80811669921215, 2.182660361141946],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1251.67386034,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.175926961285955,
                            48.80565394221556,
                            2.188259860000294,
                            48.81257171717766,
                        ),
                        "coordinates": [
                            [2.175926961285955, 48.80565394221556],
                            [2.176244638619483, 48.805679292531046],
                            [2.17656767040842, 48.805715322509414],
                            [2.17689606892237, 48.80575669508684],
                            [2.177326734230471, 48.80581777695293],
                            [2.177638972296932, 48.805860904333926],
                            [2.178005026800091, 48.80591655560105],
                            [2.178361930196951, 48.80597628912136],
                            [2.178674146174967, 48.806039175468044],
                            [2.179190473531706, 48.80615097582032],
                            [2.179753287461502, 48.80630031318024],
                            [2.180502944889887, 48.80652909207602],
                            [2.181168601358515, 48.80676793712481],
                            [2.181952907942329, 48.80708449884279],
                            [2.182283280876487, 48.807233327760564],
                            [2.182570148964991, 48.807363212613986],
                            [2.182654420360782, 48.807408290671304],
                            [2.183077167195768, 48.80762558765231],
                            [2.183673794332594, 48.807970814262994],
                            [2.183866752034676, 48.80809247613725],
                            [2.184095040000431, 48.80823666704375],
                            [2.184445568997908, 48.808477243660235],
                            [2.184800126216717, 48.808737608421566],
                            [2.184900651661447, 48.808811483142634],
                            [2.184948188647466, 48.80884931613252],
                            [2.185184526909117, 48.809034882060224],
                            [2.185188603857815, 48.80903758558408],
                            [2.185350196212467, 48.80917808774469],
                            [2.18570591159766, 48.809508595010904],
                            [2.185944795589196, 48.809754414369046],
                            [2.186011303512924, 48.80982284705895],
                            [2.186081874321824, 48.809898480132325],
                            [2.18618366436315, 48.810005628614604],
                            [2.186374967047272, 48.810228902338324],
                            [2.186994866749312, 48.811002198597095],
                            [2.187059974091799, 48.81108501696183],
                            [2.187663595616336, 48.811844799010636],
                            [2.18772599747772, 48.811922219215646],
                            [2.187763981332981, 48.81196903135119],
                            [2.187880677253543, 48.81210317609318],
                            [2.187978376784385, 48.81221571300756],
                            [2.187994650228365, 48.81223731749701],
                            [2.188259860000294, 48.81257171717766],
                        ],
                    },
                },
                41: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.87217992809245, 2.8679179775721435],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3142.65038893,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.854315926463895,
                            48.8632902390859,
                            2.883201728539714,
                            48.88268104666967,
                        ),
                        "coordinates": [
                            [2.854315926463895, 48.88268104666967],
                            [2.856644668363824, 48.879458828545886],
                            [2.856802549398204, 48.879233090773596],
                            [2.856967915321395, 48.878981746810574],
                            [2.857125472733312, 48.878725324765526],
                            [2.857300441789926, 48.87840404647633],
                            [2.857541207895059, 48.87794949901487],
                            [2.858091106318945, 48.87690712689522],
                            [2.858261485896771, 48.876642122518],
                            [2.858447525942609, 48.87639238679099],
                            [2.858654364811935, 48.87615448946868],
                            [2.858856356248211, 48.87594729824542],
                            [2.859117480361318, 48.875710857049796],
                            [2.859409754393366, 48.87548790905373],
                            [2.859725372881151, 48.87527337729556],
                            [2.860046392311225, 48.87508098203457],
                            [2.860390773514688, 48.87489870605718],
                            [2.860768874931072, 48.87472820604863],
                            [2.861201273422776, 48.874560866805496],
                            [2.861543767572944, 48.87444507736772],
                            [2.861876136110965, 48.874349792066305],
                            [2.862254946805611, 48.87424747273815],
                            [2.864206011614499, 48.87375264082796],
                            [2.867131344306717, 48.87301971093815],
                            [2.867510153847908, 48.87291907816883],
                            [2.867925082625485, 48.872813162839556],
                            [2.86826776444696, 48.872717809901225],
                            [2.868641236798737, 48.872601856018726],
                            [2.868957877339857, 48.87248787119745],
                            [2.869274366675177, 48.87236024823657],
                            [2.869696145252711, 48.87217076407481],
                            [2.870081668388279, 48.87197462912744],
                            [2.87041811238854, 48.87178042726096],
                            [2.870726073705668, 48.871581242958904],
                            [2.871018454882052, 48.87137531150639],
                            [2.871274675236126, 48.87117125415404],
                            [2.871479563927353, 48.870999825651765],
                            [2.871730337336006, 48.870770220090506],
                            [2.872022029269046, 48.87050121664161],
                            [2.873173454380311, 48.86944231164542],
                            [2.874693250766208, 48.86804412933708],
                            [2.874962026773236, 48.86780932015138],
                            [2.875215647262726, 48.8676069687116],
                            [2.875436174813149, 48.8674508033667],
                            [2.875728662957316, 48.86725849608329],
                            [2.875993129543531, 48.86710382587176],
                            [2.876314198417295, 48.86692672442582],
                            [2.8767303650063, 48.86670314641096],
                            [2.880709417232306, 48.864561911953444],
                            [2.88200910774739, 48.86385849111414],
                            [2.882355912784986, 48.86367613555402],
                            [2.882646253346079, 48.863528144039876],
                            [2.882916183764921, 48.86340411480701],
                            [2.883201728539714, 48.8632902390859],
                        ],
                    },
                },
                42: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.80649829543364, 1.790761244746442],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 3874.20161566,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.765056756557643,
                            48.802601980906694,
                            1.816466794198607,
                            48.810402464358575,
                        ),
                        "coordinates": [
                            [1.765056756557643, 48.810402464358575],
                            [1.765578236059365, 48.810323677235814],
                            [1.765713281789975, 48.81030187078084],
                            [1.765848307990154, 48.81028186290839],
                            [1.766470284250454, 48.81018605076781],
                            [1.768641544773686, 48.80986774332251],
                            [1.77007917532504, 48.80964467439468],
                            [1.771833154563744, 48.809379089216684],
                            [1.773430251888483, 48.809138781783844],
                            [1.773917160261275, 48.80906474508711],
                            [1.774770941992939, 48.80893585884246],
                            [1.776433481161241, 48.808685040501096],
                            [1.776871278469499, 48.808618844288524],
                            [1.777864224791863, 48.808462739754354],
                            [1.778652645643295, 48.80833260449746],
                            [1.779678145884585, 48.80818653631542],
                            [1.781373460149095, 48.80792231677589],
                            [1.782849117272393, 48.80769747415338],
                            [1.786176728211459, 48.80719648992155],
                            [1.787248628854193, 48.80703618853358],
                            [1.788013718981526, 48.80691846639314],
                            [1.788687414065552, 48.806816488476215],
                            [1.792529115569641, 48.80622965725163],
                            [1.794120702736462, 48.805976444484706],
                            [1.795612481892875, 48.805760507001644],
                            [1.79650032088141, 48.8056190298184],
                            [1.797236759662873, 48.80550290959039],
                            [1.798199454722226, 48.80536267314405],
                            [1.799949019458404, 48.80509933317677],
                            [1.801256760021642, 48.804902240135576],
                            [1.801804956732735, 48.8048184807739],
                            [1.805334043340158, 48.804284610275445],
                            [1.805668159186067, 48.804231309839885],
                            [1.805902723407634, 48.80419373236873],
                            [1.806559956126206, 48.80409696747534],
                            [1.808209923841685, 48.803846528157784],
                            [1.808962630493156, 48.80373220630825],
                            [1.809861235881343, 48.80359607145867],
                            [1.811511169217694, 48.80334558463799],
                            [1.811673432507989, 48.80332115122481],
                            [1.812423429741043, 48.803204096739385],
                            [1.814014735411301, 48.80295959867648],
                            [1.814272459255679, 48.8029194121295],
                            [1.814841106180383, 48.8028284897656],
                            [1.816193615172426, 48.80263502755033],
                            [1.816466794198607, 48.802601980906694],
                        ],
                    },
                },
                43: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.89551351886699, 2.2422495430436404],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1050.51970801,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.2370182854985,
                            48.89218735760208,
                            2.247942846959712,
                            48.89811887571271,
                        ),
                        "coordinates": [
                            [2.247942846959712, 48.89811887571271],
                            [2.247501505955844, 48.89793615150407],
                            [2.247330562755172, 48.89787248944589],
                            [2.247231037616134, 48.897829582896506],
                            [2.244893808778216, 48.89683332546334],
                            [2.243141192416398, 48.89609449731615],
                            [2.242429809476499, 48.89579085594544],
                            [2.241882838939987, 48.895539677576956],
                            [2.241142058577106, 48.89520345819289],
                            [2.240928124576816, 48.89510166055526],
                            [2.240857267511158, 48.895068328256485],
                            [2.240790507593676, 48.89503230141264],
                            [2.240569785983877, 48.89491521011794],
                            [2.240462154103692, 48.89485666633074],
                            [2.240228040174852, 48.89473526437658],
                            [2.240019334521322, 48.89461659618253],
                            [2.239812820131014, 48.8944857960416],
                            [2.239607400369969, 48.89434857135113],
                            [2.239504700452058, 48.89427496268965],
                            [2.239047879130221, 48.893965889413174],
                            [2.23872266732821, 48.89375357381493],
                            [2.23829909095892, 48.89346184470364],
                            [2.23818972662415, 48.8933807675495],
                            [2.237954082843688, 48.89319687272099],
                            [2.237855181060364, 48.89311074281137],
                            [2.237781663427691, 48.89304593119936],
                            [2.237604726501907, 48.89286592296902],
                            [2.237459652277581, 48.89270857369787],
                            [2.237325753581405, 48.89256172497171],
                            [2.237211465993576, 48.892425834369206],
                            [2.237189697469287, 48.89239973643503],
                            [2.23716385274458, 48.89236644124214],
                            [2.237076774452764, 48.892263847177276],
                            [2.2370182854985, 48.89218735760208],
                        ],
                    },
                },
                44: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.820684400843895, 2.222425201633709],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 1149.81956414,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.21485979543755,
                            48.818947800937735,
                            2.229808003729513,
                            48.821353445618726,
                        ),
                        "coordinates": [
                            [2.21485979543755, 48.82121703789382],
                            [2.215385136870361, 48.82125565245838],
                            [2.216548842138161, 48.82131636844021],
                            [2.217518042257242, 48.82134831766572],
                            [2.217871150812068, 48.821353445618726],
                            [2.218361203741479, 48.821349196707054],
                            [2.218865693458763, 48.82133544357092],
                            [2.219986456226751, 48.82127235524613],
                            [2.220627968190282, 48.8212159056292],
                            [2.22115416995627, 48.82116171543497],
                            [2.221683989790666, 48.82110038820959],
                            [2.222451736509177, 48.820989332514486],
                            [2.223050090805913, 48.820894756311176],
                            [2.223677321435976, 48.820776413758495],
                            [2.224268528603829, 48.820653273404055],
                            [2.224960685761454, 48.820501675635285],
                            [2.225656469550867, 48.82033818128925],
                            [2.226287392891662, 48.82017462028862],
                            [2.226846242163563, 48.820013364582856],
                            [2.227372684543435, 48.81984017957013],
                            [2.227798163343908, 48.81970020601756],
                            [2.22874653871935, 48.819356103927056],
                            [2.229808003729513, 48.818947800937735],
                        ],
                    },
                },
                45: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.80525162147042, 2.479503811457814],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1027.10039316,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.472720403802171,
                            48.80487260701215,
                            2.486349748779074,
                            48.80620002476371,
                        ),
                        "coordinates": [
                            [2.472720403802171, 48.80620002476371],
                            [2.473065026260363, 48.80608340069781],
                            [2.47349332755808, 48.805954403578276],
                            [2.473957661296933, 48.8058301188538],
                            [2.474452172676266, 48.80571323380122],
                            [2.474713421687063, 48.80566076003578],
                            [2.475419643647813, 48.805532205253655],
                            [2.476100051816, 48.80542346167181],
                            [2.477848753350977, 48.80516861205552],
                            [2.47837541157962, 48.80509511685007],
                            [2.479261395857102, 48.80499239393389],
                            [2.479937852704598, 48.80493579074812],
                            [2.480588482675403, 48.80489360373159],
                            [2.481545489406977, 48.80487260701215],
                            [2.482081920192518, 48.80488541377393],
                            [2.482457729663807, 48.80490651574335],
                            [2.482956104641132, 48.804940949425834],
                            [2.483551235134649, 48.80500762999487],
                            [2.483970731085068, 48.80506913807007],
                            [2.484307119737713, 48.80511006987396],
                            [2.484764741791449, 48.80517332522905],
                            [2.485174689159024, 48.80522764771423],
                            [2.486349748779074, 48.80537766216148],
                        ],
                    },
                },
                46: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.955492897625206, 2.119900937702748],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4353.42380922,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.093521901580612,
                            48.945795934518046,
                            2.144558756800802,
                            48.95942081579221,
                        ),
                        "coordinates": [
                            [2.093521901580612, 48.95540224453111],
                            [2.095275119180811, 48.955654064388554],
                            [2.096018815220241, 48.95577460055809],
                            [2.096618009515849, 48.95589244985157],
                            [2.097199058945369, 48.956026914310016],
                            [2.097718688332133, 48.95616124466473],
                            [2.098281520495417, 48.95632897650449],
                            [2.098880347475981, 48.956525331014426],
                            [2.099544077984347, 48.956750368259605],
                            [2.100608189393563, 48.95711899271907],
                            [2.101315248701186, 48.95735362746025],
                            [2.101924995466158, 48.95753809210881],
                            [2.102520396662549, 48.9577011077294],
                            [2.103123116157908, 48.957845103723315],
                            [2.10378009657946, 48.95797730778482],
                            [2.105895487496369, 48.958393226526475],
                            [2.106750946297849, 48.95858172935578],
                            [2.107656871894758, 48.9587976901254],
                            [2.10843651616127, 48.95897532140973],
                            [2.109136849052834, 48.959114719293304],
                            [2.109956464466103, 48.959244833795324],
                            [2.110639000414662, 48.959327083613374],
                            [2.111484219680787, 48.95939061488035],
                            [2.112322369032908, 48.95942081579221],
                            [2.113048645423283, 48.95941985921476],
                            [2.113803934326044, 48.95939516179983],
                            [2.114483473045252, 48.959341760471695],
                            [2.115260661327089, 48.95926713041187],
                            [2.1162728894209, 48.959152498848795],
                            [2.117111658406051, 48.95904228229965],
                            [2.118178295502507, 48.95887777293547],
                            [2.11932823883308, 48.95866582398323],
                            [2.120514540667297, 48.958412715591315],
                            [2.121747998698349, 48.95815101361782],
                            [2.124008480816989, 48.95763495050819],
                            [2.124915992428352, 48.957424777452],
                            [2.12539347128279, 48.957297175832075],
                            [2.126178595154797, 48.95704403509915],
                            [2.126703321605904, 48.95684989304958],
                            [2.127304104646893, 48.956610682942866],
                            [2.127894166345738, 48.95634289591625],
                            [2.128563966706861, 48.95601338786181],
                            [2.129363096573621, 48.95558242610153],
                            [2.129364252725261, 48.95558180229322],
                            [2.130186393825507, 48.95510504093087],
                            [2.130918026939952, 48.954668561787386],
                            [2.1323489735282, 48.95373842337728],
                            [2.134018912585963, 48.9526611748752],
                            [2.134996935419867, 48.95202999852488],
                            [2.13705434703725, 48.95069641978865],
                            [2.139423112433903, 48.94916585477055],
                            [2.141654189842415, 48.94770400653005],
                            [2.14260315743467, 48.94706319950211],
                            [2.143302133117028, 48.94660517253894],
                            [2.144558756800802, 48.945795934518046],
                        ],
                    },
                },
                47: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.53264201027134, 2.039154529180674],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 4574.23576267,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.008771813873437,
                            48.531057764508006,
                            2.069381524887472,
                            48.535806509243706,
                        ),
                        "coordinates": [
                            [2.008771813873437, 48.533732833977226],
                            [2.009746723385014, 48.53358378240689],
                            [2.011869678074811, 48.53325916163322],
                            [2.015236933939557, 48.532745314411315],
                            [2.019354185981668, 48.53211398400631],
                            [2.022193845468613, 48.5316778888953],
                            [2.02260723095999, 48.53161130087928],
                            [2.023214673083323, 48.5315184892104],
                            [2.023670815982834, 48.53145954217455],
                            [2.024043762041415, 48.53141625145539],
                            [2.024650979608317, 48.53135855339382],
                            [2.025259341134543, 48.531319251116294],
                            [2.026418113602109, 48.53127563808936],
                            [2.028202574348773, 48.53120199200792],
                            [2.02917633428576, 48.531167155766155],
                            [2.030399106889527, 48.531110397103575],
                            [2.031467828521446, 48.53106723654237],
                            [2.032058045877617, 48.531057764508006],
                            [2.032624002192012, 48.531066422234225],
                            [2.033010784651196, 48.5310841133706],
                            [2.033440498993227, 48.53111143655763],
                            [2.033820046760105, 48.53114100351547],
                            [2.034307006004498, 48.53118037160835],
                            [2.034880059997846, 48.53124453523164],
                            [2.037253168215208, 48.53153081143649],
                            [2.03928303293862, 48.531755050901516],
                            [2.041627626351697, 48.53202307463431],
                            [2.043452979452916, 48.53222025369867],
                            [2.045450314709484, 48.53241514656364],
                            [2.047512600058372, 48.53262006222356],
                            [2.050392546171845, 48.532906684239336],
                            [2.054463524084015, 48.533309477590954],
                            [2.057123821747188, 48.53357541338937],
                            [2.06013862941511, 48.53387546257729],
                            [2.062637892602588, 48.5341194627232],
                            [2.063786840836441, 48.53422519456175],
                            [2.064764729226511, 48.534338720800676],
                            [2.065090490805462, 48.53438470895088],
                            [2.065455572632191, 48.534447445125856],
                            [2.066010244684644, 48.534562976503615],
                            [2.066597006980077, 48.53470713422527],
                            [2.067151427027445, 48.53487024594024],
                            [2.06772718091878, 48.535064336412646],
                            [2.068267037200189, 48.535272615052605],
                            [2.068781704386639, 48.53550224539504],
                            [2.069234232328339, 48.53573177922848],
                            [2.069381524887472, 48.535806509243706],
                        ],
                    },
                },
                48: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.051930246401426, 2.1937179114595176],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1574.56425035,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.190262803121982,
                            49.04543025423756,
                            2.197087678318264,
                            49.058047811766336,
                        ),
                        "coordinates": [
                            [2.191244759191911, 49.058047811766336],
                            [2.190861645779191, 49.05745498788427],
                            [2.190548507695725, 49.05691952085123],
                            [2.190426094756453, 49.05667026589281],
                            [2.190320376514518, 49.05632840667057],
                            [2.190263903331224, 49.05599200549049],
                            [2.190262803121982, 49.05590117696955],
                            [2.190263384294123, 49.05570513614451],
                            [2.190286147146323, 49.05541110233548],
                            [2.190352253199126, 49.055143299819605],
                            [2.190476334369092, 49.054807972036606],
                            [2.190614746975041, 49.05452262832335],
                            [2.190767510816821, 49.05428013093477],
                            [2.190974640742354, 49.05401628817903],
                            [2.191239618929525, 49.05377631174804],
                            [2.191575177113631, 49.05351257614192],
                            [2.191838411525413, 49.05333125598555],
                            [2.192000148508365, 49.05323343873634],
                            [2.194354839966382, 49.05182093168787],
                            [2.194905705559385, 49.05139610171207],
                            [2.195268133108681, 49.05109544958792],
                            [2.195399875872445, 49.050956224249795],
                            [2.19560848076081, 49.05073076355253],
                            [2.195835107841015, 49.05042169181413],
                            [2.196012428182078, 49.050130545255556],
                            [2.196167887446513, 49.04982857941369],
                            [2.196558872161905, 49.0489346749638],
                            [2.196687457682791, 49.04858591982278],
                            [2.19678936158777, 49.04825740882277],
                            [2.196870196580013, 49.047732331233604],
                            [2.196987368693518, 49.04645010849869],
                            [2.197074722862676, 49.04555183964988],
                            [2.197087678318264, 49.04543025423756],
                        ],
                    },
                },
                49: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.06552067854783, 2.13588724561283],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1279.48780983,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.13087413699018,
                            49.06059168305009,
                            2.141696932779959,
                            49.06931413549863,
                        ),
                        "coordinates": [
                            [2.13087413699018, 49.06059168305009],
                            [2.131207137954742, 49.0608580302238],
                            [2.131565206928057, 49.06117616736091],
                            [2.132278407878558, 49.061896716213184],
                            [2.132609946293323, 49.06227800164913],
                            [2.132746809746462, 49.062454316054904],
                            [2.132880023166548, 49.06263776157711],
                            [2.133070945750251, 49.062876034902864],
                            [2.133708530825932, 49.06368138396556],
                            [2.13394625988483, 49.06398635946666],
                            [2.13411554609956, 49.06420555832268],
                            [2.134428911716054, 49.06461059938328],
                            [2.13479658586036, 49.06501811482306],
                            [2.1350978641201, 49.06535061371402],
                            [2.13539857733161, 49.065685388917764],
                            [2.135842281765689, 49.066100172749735],
                            [2.136477439580163, 49.06663187674777],
                            [2.136665138389196, 49.066779723669],
                            [2.136935885407915, 49.0669871982046],
                            [2.13713442397544, 49.06714220065981],
                            [2.137282447389924, 49.06725190810256],
                            [2.137499064429621, 49.06741408040418],
                            [2.137791543933161, 49.067621590122286],
                            [2.138152685966862, 49.06786490928907],
                            [2.13856092738341, 49.06810354920741],
                            [2.139005410894167, 49.068335113479456],
                            [2.139507839109402, 49.068566774436114],
                            [2.140169494514747, 49.06882725791799],
                            [2.140798364833166, 49.06905112808556],
                            [2.141481883794477, 49.069258227748065],
                            [2.141696932779959, 49.06931413549863],
                        ],
                    },
                },
                50: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.980362122696086, 2.2823083362410497],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1506.99009239,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272084772747633,
                            48.9794479829515,
                            2.292477128819507,
                            48.980646100425986,
                        ),
                        "coordinates": [
                            [2.292477128819507, 48.9794479829515],
                            [2.291789698218523, 48.979589155286604],
                            [2.290222213839165, 48.979863539420045],
                            [2.289567691458342, 48.97997747994914],
                            [2.288836657909453, 48.98009048584478],
                            [2.288119301114432, 48.9801864052716],
                            [2.287041234559017, 48.980307345441915],
                            [2.285992792470875, 48.98040960927644],
                            [2.285262248269383, 48.98046663029194],
                            [2.283920717443852, 48.980544858469564],
                            [2.282988168044092, 48.98057511540684],
                            [2.282271280009533, 48.98058820378442],
                            [2.28159811695532, 48.98058979917034],
                            [2.28027131584125, 48.98056499761469],
                            [2.277954290835895, 48.98048379678582],
                            [2.2771755585253, 48.98046990494057],
                            [2.276747150227587, 48.98046968153068],
                            [2.276251981472504, 48.9804775149285],
                            [2.276096224327892, 48.980483726890874],
                            [2.27545269804132, 48.98051036253481],
                            [2.274714898034236, 48.98054054067926],
                            [2.272084772747633, 48.980646100425986],
                        ],
                    },
                },
                51: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.58026466261715, 2.207151105654557],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2336.13386759,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192063068770897,
                            48.577508489431835,
                            2.22243331383282,
                            48.58248559694799,
                        ),
                        "coordinates": [
                            [2.192063068770897, 48.577508489431835],
                            [2.192959101978819, 48.577940754354735],
                            [2.193738645120984, 48.5783105414072],
                            [2.194079557396226, 48.57846752761568],
                            [2.194362844473483, 48.57858780027418],
                            [2.194776529693579, 48.57875153818035],
                            [2.195210332229236, 48.57890364143992],
                            [2.195651709922428, 48.5790407631797],
                            [2.196105677460959, 48.57916457353781],
                            [2.196559681979031, 48.57927505959016],
                            [2.197028785416625, 48.5793739035409],
                            [2.19751048415598, 48.57945610465408],
                            [2.197977176339137, 48.57951996726035],
                            [2.198474010372151, 48.57957720053478],
                            [2.198954985641293, 48.57962177042589],
                            [2.200637204591428, 48.57975302973528],
                            [2.20187803585503, 48.579854541363716],
                            [2.205739140858419, 48.580157092631076],
                            [2.208261283472879, 48.58035484105673],
                            [2.20911203386415, 48.580424086753055],
                            [2.212507550208399, 48.58069267208359],
                            [2.213365830271464, 48.58076689108147],
                            [2.213830097177527, 48.580810697383036],
                            [2.214214044964871, 48.58085275081135],
                            [2.214868993876325, 48.580933401084366],
                            [2.215298088048602, 48.58099048842931],
                            [2.215870193574709, 48.581076040105486],
                            [2.216700715035429, 48.58121682408262],
                            [2.217511122508184, 48.58137257116665],
                            [2.218341565999359, 48.58154998555617],
                            [2.219954744507211, 48.58191806856227],
                            [2.222157533987902, 48.582421632240035],
                            [2.22243331383282, 48.58248559694799],
                        ],
                    },
                },
                52: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.0061833642051, 2.2514035041850473],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2513.46718163,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.242479108496568,
                            48.99609884257494,
                            2.259655619057618,
                            49.015584975459475,
                        ),
                        "coordinates": [
                            [2.242479108496568, 49.015584975459475],
                            [2.243891923138443, 49.01453029274929],
                            [2.244324528878944, 49.01421859449099],
                            [2.245137802949952, 49.01357896361903],
                            [2.245465000925462, 49.013333722204244],
                            [2.245951107650513, 49.012911449182134],
                            [2.246345489125486, 49.01255474932075],
                            [2.246694770052406, 49.01218811988461],
                            [2.246812588856645, 49.0120515230458],
                            [2.246976992433265, 49.01185740846296],
                            [2.247440086972719, 49.01129302540317],
                            [2.247818247749802, 49.010821200356936],
                            [2.248055304932615, 49.01052498448478],
                            [2.248261937282807, 49.01026579592635],
                            [2.248831076252792, 49.00955005446084],
                            [2.249102926643525, 49.00922191352898],
                            [2.249342175503082, 49.00891992099268],
                            [2.250233936549223, 49.00777137844844],
                            [2.250918944239741, 49.006946263171656],
                            [2.251419125522458, 49.006325630150876],
                            [2.252872474242901, 49.00452316574334],
                            [2.253923911874838, 49.00325118153558],
                            [2.255407261307396, 49.00139613999132],
                            [2.255753769687276, 49.00096383377891],
                            [2.256620708454428, 48.99987632037915],
                            [2.257083614594808, 48.99929211501987],
                            [2.258113442257416, 48.998010460210544],
                            [2.259025444872625, 48.99688069384329],
                            [2.259655619057618, 48.99609884257494],
                        ],
                    },
                },
                53: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.96953947194933, 2.3118606772568446],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 994.155034711,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307137032071533,
                            48.966326544842126,
                            2.3165820711557,
                            48.972749119759264,
                        ),
                        "coordinates": [
                            [2.3165820711557, 48.966326544842126],
                            [2.316484910128924, 48.96639374526073],
                            [2.315909726745558, 48.966785727178284],
                            [2.314688285531393, 48.96762002714814],
                            [2.313242728158259, 48.96859725303137],
                            [2.312868353708528, 48.96884357757444],
                            [2.311414516053476, 48.96984595844002],
                            [2.310403360643432, 48.97053097845368],
                            [2.309758391346334, 48.97097057431772],
                            [2.308411024472593, 48.971888410684016],
                            [2.307137032071533, 48.972749119759264],
                        ],
                    },
                },
                54: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.83958973645683, 2.3847591913129182],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 733.108842178,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.379911271454398,
                            48.838969569169585,
                            2.389620014061439,
                            48.84038874809586,
                        ),
                        "coordinates": [
                            [2.379911271454398, 48.84038874809586],
                            [2.380044954129417, 48.840377697125106],
                            [2.380176797741775, 48.8403593966142],
                            [2.380184929183669, 48.84035801955395],
                            [2.38097671147078, 48.840222476483426],
                            [2.385724719441183, 48.83940954129745],
                            [2.387659931190602, 48.83905316937965],
                            [2.387674949465731, 48.839050403374316],
                            [2.387853778521485, 48.83902095798647],
                            [2.388042746548228, 48.8389972238873],
                            [2.38823347028698, 48.83898071495085],
                            [2.388425322443565, 48.83897148552068],
                            [2.388617658257711, 48.838969569169585],
                            [2.388809840151649, 48.83897496803334],
                            [2.389001234824099, 48.83898766808508],
                            [2.389005167019794, 48.838988006544206],
                            [2.389620014061439, 48.83904114371397],
                        ],
                    },
                },
                55: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.18700825046705, 2.3672096790769412],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 4459.06423684,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362303528565357,
                            49.166775039807895,
                            2.376601177324503,
                            49.20326573346356,
                        ),
                        "coordinates": [
                            [2.362303528565357, 49.166775039807895],
                            [2.362649382468536, 49.167287545801706],
                            [2.362967793672144, 49.167757791319666],
                            [2.363197003377784, 49.16810485617761],
                            [2.364233101446112, 49.16966974128223],
                            [2.365565516625801, 49.17399735517902],
                            [2.366316858529152, 49.18024681686752],
                            [2.366136105256711, 49.19066294162191],
                            [2.366513203521723, 49.195932151988366],
                            [2.367262656547948, 49.19838279749573],
                            [2.369133976409839, 49.20046550287917],
                            [2.376601177324503, 49.20326573346356],
                        ],
                    },
                },
                56: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.97675212855222, 2.2649559103886157],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1389.9858931,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.262935722791332,
                            48.97051992210463,
                            2.270035426257897,
                            48.980377556311645,
                        ),
                        "coordinates": [
                            [2.270035426257897, 48.980377556311645],
                            [2.269081199987407, 48.980237598400976],
                            [2.268398152677566, 48.9801301234452],
                            [2.268033150235689, 48.98006566282356],
                            [2.267538065876373, 48.97996305262211],
                            [2.267180319859156, 48.9798819389715],
                            [2.266802722503067, 48.979771230636224],
                            [2.266421558315122, 48.97964116253644],
                            [2.266154222341803, 48.97953392843443],
                            [2.265843556403992, 48.97939335562487],
                            [2.265536517149731, 48.97924326665335],
                            [2.265272845884962, 48.979102721946525],
                            [2.26501643663722, 48.97894076571651],
                            [2.264741989672952, 48.97875500467351],
                            [2.26453256734434, 48.97859783791925],
                            [2.264272625131723, 48.9783835331386],
                            [2.264059665491615, 48.978174015887724],
                            [2.263897256079431, 48.97800498014507],
                            [2.263691593327449, 48.97775263831284],
                            [2.263561710145016, 48.977588382515464],
                            [2.263421081252494, 48.977359876771],
                            [2.263291310966419, 48.97712185947384],
                            [2.263165215872408, 48.97684101568385],
                            [2.263086014920816, 48.97662682343224],
                            [2.2630176916121, 48.97639122715924],
                            [2.26295666875579, 48.97610566593455],
                            [2.262938928509338, 48.975881997856966],
                            [2.262935722791332, 48.975608371534236],
                            [2.262946885926966, 48.97539423777607],
                            [2.262976140104324, 48.975168219881205],
                            [2.26302713927824, 48.97489938767443],
                            [2.263358352013193, 48.973348272954006],
                            [2.263557622576995, 48.972443461278715],
                            [2.263883026060117, 48.97072420004332],
                            [2.263924959788352, 48.97051992210463],
                        ],
                    },
                },
                57: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.79158199287345, 2.4067137131838674],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2038.29308463,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.40271281718153,
                            48.78250543550023,
                            2.409541656460374,
                            48.80020939834459,
                        ),
                        "coordinates": [
                            [2.409541656460374, 48.78250543550023],
                            [2.409504545391541, 48.782718760102725],
                            [2.409361654715678, 48.783492133803456],
                            [2.409272266165194, 48.78392047034458],
                            [2.409129272495981, 48.78462722365056],
                            [2.408971892768101, 48.78534826148277],
                            [2.408782174655474, 48.78611928576211],
                            [2.408538710867583, 48.787078310521714],
                            [2.408298656866495, 48.78791122789415],
                            [2.408169660018592, 48.78835148622518],
                            [2.408033457741617, 48.78879174723824],
                            [2.407760975044736, 48.78962230537667],
                            [2.407509982849522, 48.79037670972165],
                            [2.407208650101571, 48.79119062841646],
                            [2.40682834752396, 48.79219256245235],
                            [2.406412029096415, 48.79320165556693],
                            [2.406027942625695, 48.79409413977865],
                            [2.405733554601532, 48.79475577413811],
                            [2.405543241199632, 48.7951579962248],
                            [2.405349291749823, 48.795536427871625],
                            [2.405090645253383, 48.796012449709366],
                            [2.404609264150739, 48.796897849580674],
                            [2.404368534866408, 48.7973167562486],
                            [2.404120642832604, 48.7977689761037],
                            [2.4038655501678, 48.79822595853451],
                            [2.40357091525546, 48.79874244735021],
                            [2.402798310222541, 48.80005391144719],
                            [2.40271281718153, 48.80020939834459],
                        ],
                    },
                },
                58: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.83612245224618, 2.3709797496470864],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1633.0200525,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.36543338335276,
                            48.82987504460341,
                            2.376695892125261,
                            48.84252802768357,
                        ),
                        "coordinates": [
                            [2.376695892125261, 48.82987504460341],
                            [2.376310721393016, 48.83025845726653],
                            [2.376100014738509, 48.83046820031477],
                            [2.375626127836013, 48.83091781447308],
                            [2.375338031873506, 48.83120343387657],
                            [2.374884282692759, 48.831662798476835],
                            [2.374419729928119, 48.83214833839203],
                            [2.373872342705136, 48.83272193878771],
                            [2.37311965846401, 48.83350498377089],
                            [2.372788769485438, 48.833858984985916],
                            [2.372485827398598, 48.83420233131875],
                            [2.372262562137141, 48.83447602439655],
                            [2.372037483182515, 48.8347782794699],
                            [2.371583980405342, 48.835380689434714],
                            [2.371185475209688, 48.83587116095093],
                            [2.370504782526067, 48.8366470294828],
                            [2.370256258108027, 48.83691120950934],
                            [2.369928494955805, 48.83726582637737],
                            [2.369625807359515, 48.83760216261029],
                            [2.369382701363923, 48.8378996043211],
                            [2.369145006859776, 48.838208986095495],
                            [2.368972138117524, 48.83843507294346],
                            [2.368828076526018, 48.838620701620826],
                            [2.368485911818896, 48.83903718179771],
                            [2.36823737643977, 48.83931801243641],
                            [2.367801531073584, 48.83981303439403],
                            [2.36709924870718, 48.84064170283554],
                            [2.365581702747743, 48.842360082466925],
                            [2.36543338335276, 48.84252802768357],
                        ],
                    },
                },
                59: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.80736636380431, 2.3975493522017937],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1738.10740738,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.391686971662538,
                            48.80020939834459,
                            2.40271281718153,
                            48.813989052009454,
                        ),
                        "coordinates": [
                            [2.40271281718153, 48.80020939834459],
                            [2.402388694458657, 48.800798880907166],
                            [2.40230966399799, 48.80095834086986],
                            [2.401899980586725, 48.80166285949211],
                            [2.401529822340158, 48.80230311132965],
                            [2.401120043700234, 48.80295052291369],
                            [2.400469329429956, 48.803916898168495],
                            [2.400088253846302, 48.804497668870226],
                            [2.399678391990955, 48.80510938539171],
                            [2.399261264747814, 48.80568065601951],
                            [2.398750539869079, 48.806306699992135],
                            [2.3983656672838, 48.80676136270062],
                            [2.397829707196336, 48.80738979622354],
                            [2.397038329347954, 48.80831577895154],
                            [2.395717981668412, 48.80975834857481],
                            [2.39481129406606, 48.810724825856965],
                            [2.394174437462593, 48.81140801823558],
                            [2.393789421216613, 48.81180556107138],
                            [2.393404379955451, 48.812188826521734],
                            [2.392663105048392, 48.81295771851731],
                            [2.391686971662538, 48.813989052009454],
                        ],
                    },
                },
                60: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.96684452967871, 1.8289082795876979],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3057.11833206,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.809094508773784,
                            48.96334411275807,
                            1.848348808282502,
                            48.97214167690781,
                        ),
                        "coordinates": [
                            [1.809094508773784, 48.96334411275807],
                            [1.809279551877828, 48.963355057024316],
                            [1.811029724209674, 48.96347807079743],
                            [1.812083086767916, 48.96355179040191],
                            [1.813387699003068, 48.963666453558346],
                            [1.814911934161123, 48.963825577806084],
                            [1.815912228767559, 48.96392916180948],
                            [1.817011205202946, 48.96406699800063],
                            [1.81845413919112, 48.96428608594147],
                            [1.819749147895919, 48.96450421403665],
                            [1.821617906480417, 48.964807692299324],
                            [1.823075227894982, 48.96506170646702],
                            [1.824965022409081, 48.9654318457826],
                            [1.825801666323962, 48.96560214604815],
                            [1.827049244693739, 48.96587420600549],
                            [1.828390453363887, 48.9661799805204],
                            [1.828910683687202, 48.966303205095066],
                            [1.829485475579419, 48.966444184797844],
                            [1.830438913009603, 48.966680407696785],
                            [1.831075973547873, 48.96684621932271],
                            [1.833000461301758, 48.96737104229682],
                            [1.833548209143593, 48.967525735222495],
                            [1.834866974414407, 48.96791461233414],
                            [1.838242688052874, 48.96896679082959],
                            [1.842774902225746, 48.97039743842707],
                            [1.845322167449251, 48.97119837017101],
                            [1.848348808282502, 48.97214167690781],
                        ],
                    },
                },
                61: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.75828388309225, 2.4146475096103424],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1310.3083477,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.411386724936104,
                            48.75288655674139,
                            2.418113047325797,
                            48.76378680955171,
                        ),
                        "coordinates": [
                            [2.418113047325797, 48.75288655674139],
                            [2.416624905232636, 48.75522931882932],
                            [2.416377979117072, 48.755605388227586],
                            [2.415558496728417, 48.75686404153501],
                            [2.414869262472233, 48.75794184587288],
                            [2.414459469393249, 48.75855902867565],
                            [2.414159620449721, 48.75903584730456],
                            [2.413774240207134, 48.75962056900609],
                            [2.413452595549658, 48.7600821807872],
                            [2.412453702802303, 48.76158118009764],
                            [2.412213173520056, 48.76197630951862],
                            [2.41204088089293, 48.76227859786082],
                            [2.411893754995528, 48.762564215824064],
                            [2.41169286382455, 48.76299738578484],
                            [2.411574538640741, 48.76329250082202],
                            [2.411441863780134, 48.763618556064316],
                            [2.411386724936104, 48.76378680955171],
                        ],
                    },
                },
                62: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.982368326609844, 1.8809392022219384],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 5285.39546558,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.848348808282502,
                            48.97214167690781,
                            1.91353050809466,
                            48.99259195475149,
                        ),
                        "coordinates": [
                            [1.848348808282502, 48.97214167690781],
                            [1.851021812508963, 48.97298425217767],
                            [1.861468323330048, 48.97626411273591],
                            [1.868665313283026, 48.97852090074438],
                            [1.8821924830449, 48.98276556001553],
                            [1.896839668836701, 48.98735317831446],
                            [1.908712966964527, 48.99107198435066],
                            [1.911421019791048, 48.991922003146975],
                            [1.913213127495083, 48.99249494421094],
                            [1.91353050809466, 48.99259195475149],
                        ],
                    },
                },
                63: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93829748712154, 2.3530030860419053],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 450.708968826,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350400018540065,
                            48.93750989644162,
                            2.355902810417396,
                            48.938597775209935,
                        ),
                        "coordinates": [
                            [2.355902810417396, 48.938597775209935],
                            [2.355429159133624, 48.93856562726525],
                            [2.355258469646472, 48.93854052478991],
                            [2.35509143422872, 48.9385077474605],
                            [2.35490088364042, 48.93847776870619],
                            [2.354740480448534, 48.938463787435076],
                            [2.353153116197353, 48.938371317398385],
                            [2.352551565974967, 48.93831115019994],
                            [2.351081109470616, 48.938139858431725],
                            [2.350995984122844, 48.93812747301883],
                            [2.350911059327141, 48.93810777025535],
                            [2.350830454343144, 48.938081340799464],
                            [2.350755388637984, 48.93804858694998],
                            [2.350687004063937, 48.93801000411318],
                            [2.350626333507694, 48.93796617703506],
                            [2.350574298283401, 48.937917769894284],
                            [2.35053168912451, 48.93786551810449],
                            [2.350500596820184, 48.93781317582778],
                            [2.350400018540065, 48.93750989644162],
                        ],
                    },
                },
                64: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.8549943562229, 2.2885902008619197],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 562.948769348,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.286419448213008,
                            48.853033488503854,
                            2.290391553460649,
                            48.857293413870465,
                        ),
                        "coordinates": [
                            [2.290391553460649, 48.857293413870465],
                            [2.290233969629259, 48.857116916754364],
                            [2.290008021717807, 48.85681736577427],
                            [2.289933189343854, 48.8566878397138],
                            [2.289829784316117, 48.856507942791616],
                            [2.289555002595611, 48.85597545777357],
                            [2.289344119514535, 48.85560756696089],
                            [2.289137257007656, 48.85531431749175],
                            [2.289004555406866, 48.855147078499826],
                            [2.288856018681601, 48.85496090005867],
                            [2.288707462235874, 48.85479840769266],
                            [2.288512776337732, 48.85461220893282],
                            [2.288389863687753, 48.85451724497622],
                            [2.286419448213008, 48.853033488503854],
                        ],
                    },
                },
                65: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.937240658804505, 2.362196272409096],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 283.677242808,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.360746043772506,
                            48.93638914706169,
                            2.363640702197924,
                            48.938082614059766,
                        ),
                        "coordinates": [
                            [2.363640702197924, 48.93638914706169],
                            [2.363561035020183, 48.93642734652028],
                            [2.362231791403588, 48.93722484164956],
                            [2.361996178362627, 48.937361621489735],
                            [2.361278784107133, 48.937788181650795],
                            [2.360746043772506, 48.938082614059766],
                        ],
                    },
                },
                66: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.887813287414566, 2.0748307787991527],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1737.06225249,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.069847520729069,
                            48.88099144075079,
                            2.079456713019077,
                            48.89460762842623,
                        ),
                        "coordinates": [
                            [2.069937966816875, 48.89460762842623],
                            [2.06991966754452, 48.894534877089995],
                            [2.069891527769017, 48.894399187275944],
                            [2.06987064342096, 48.89425637785819],
                            [2.069853369479513, 48.89411357487653],
                            [2.06985037429911, 48.89399935899256],
                            [2.069847520729069, 48.89385897122795],
                            [2.06984819968959, 48.89373286652931],
                            [2.069863568180821, 48.89355920930095],
                            [2.0698861265241, 48.893390327695926],
                            [2.069912140836625, 48.893250006690934],
                            [2.06995270277894, 48.89308830500236],
                            [2.06999682330192, 48.89293612898979],
                            [2.070044499654793, 48.8927934795313],
                            [2.070121195946435, 48.89262234531926],
                            [2.070197891749862, 48.89245121013213],
                            [2.070278055773203, 48.89230625681855],
                            [2.07035091311637, 48.89217794232182],
                            [2.070452726060841, 48.892033039118395],
                            [2.070576340496737, 48.89185963361358],
                            [2.070710767794486, 48.89168863400924],
                            [2.070841483146654, 48.891536659159776],
                            [2.071001191826305, 48.89136095927614],
                            [2.071164494328247, 48.891187646044926],
                            [2.071472967099735, 48.89085763324056],
                            [2.073091417039457, 48.88913635056786],
                            [2.073319967790454, 48.888903701451184],
                            [2.073494068084003, 48.88873278958121],
                            [2.073653604469192, 48.88858563819129],
                            [2.073820372026031, 48.888436122341645],
                            [2.073990719743308, 48.88829137444549],
                            [2.07417553871531, 48.88813952085178],
                            [2.074353063159543, 48.88800192743381],
                            [2.07453418287034, 48.88786671964632],
                            [2.074715275696037, 48.887736271665894],
                            [2.07489274828989, 48.887608193118645],
                            [2.075120844302162, 48.88745881734592],
                            [2.075316403331086, 48.887321262829396],
                            [2.075631440012261, 48.88710546268762],
                            [2.076131116794027, 48.886768736106745],
                            [2.076467893183744, 48.886533948724704],
                            [2.076906038637191, 48.886232768878834],
                            [2.077329671410796, 48.88594583020795],
                            [2.077528851519817, 48.88580352249013],
                            [2.077738890542331, 48.885654099610484],
                            [2.077920017534981, 48.885514128992014],
                            [2.078061320386325, 48.88540024042471],
                            [2.078191823372506, 48.88528156848475],
                            [2.078322337880908, 48.8851605167793],
                            [2.078442053927207, 48.88503468175609],
                            [2.078536389207196, 48.88493258321174],
                            [2.078638014572018, 48.8848162246887],
                            [2.078754270012778, 48.884661829622694],
                            [2.078870535492454, 48.884505054799796],
                            [2.07895421892158, 48.884369621021825],
                            [2.079034258845166, 48.88424131624867],
                            [2.079062317300772, 48.88418794014061],
                            [2.079121709335193, 48.884074958941994],
                            [2.079191047264349, 48.883922836715456],
                            [2.079260434431367, 48.883761196883306],
                            [2.079311757559971, 48.88360427552156],
                            [2.079359582159714, 48.88342593233554],
                            [2.079400095047284, 48.883266605616164],
                            [2.079426101403818, 48.88312152380987],
                            [2.07944497851566, 48.88295977057708],
                            [2.079456713019077, 48.88278372461976],
                            [2.079453868965917, 48.88263619859128],
                            [2.079451163048076, 48.88246249950271],
                            [2.079430442252997, 48.88228400137679],
                            [2.079413376551774, 48.88209599359672],
                            [2.079381932492387, 48.88189843551811],
                            [2.079346954350523, 48.88168659533497],
                            [2.079318908253816, 48.881529493202336],
                            [2.079283757610345, 48.88135096216606],
                            [2.079227061208015, 48.88115334909614],
                            [2.079177394694269, 48.88099144075079],
                        ],
                    },
                },
                67: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.80179960145587, 2.514336734024123],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1486.89418584,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.510307237115641,
                            48.79538383561483,
                            2.516055322407369,
                            48.80698507164624,
                        ),
                        "coordinates": [
                            [2.510307237115641, 48.80698507164624],
                            [2.510433108817921, 48.80694388303423],
                            [2.510756875783678, 48.80681966433071],
                            [2.511112960186082, 48.80666684267903],
                            [2.511411441138442, 48.806523626431726],
                            [2.511763794003523, 48.806335117318085],
                            [2.512410916003271, 48.80597484312017],
                            [2.512795527211592, 48.80574345328146],
                            [2.513147701275135, 48.805507354029025],
                            [2.513492640599702, 48.80526412815709],
                            [2.51380730132132, 48.80501312348691],
                            [2.514013385930899, 48.804825519929864],
                            [2.514218424630741, 48.80463939032214],
                            [2.514497905916015, 48.80436827272576],
                            [2.514731211013731, 48.8041287007002],
                            [2.514784085570845, 48.804067466995846],
                            [2.514965728999394, 48.80384865919177],
                            [2.515254316131879, 48.80346151876775],
                            [2.515462740436494, 48.80311946594813],
                            [2.515618266557589, 48.80283235286609],
                            [2.515691159246054, 48.80265957673568],
                            [2.515750486677784, 48.802500311848256],
                            [2.515819100410527, 48.802273585954744],
                            [2.51586940785784, 48.802086374812895],
                            [2.515936936010084, 48.801834058765095],
                            [2.516004009374217, 48.801455637537735],
                            [2.516042558359053, 48.80115815839129],
                            [2.516055322407369, 48.80070130400392],
                            [2.516024641549063, 48.80018265410029],
                            [2.515969168549575, 48.79978063182778],
                            [2.515917707872099, 48.79949281227939],
                            [2.5158082778713, 48.79910991059254],
                            [2.515688287143584, 48.79879364532239],
                            [2.515539406082418, 48.79845601208553],
                            [2.515361714218506, 48.79811842362603],
                            [2.51521315444596, 48.797868825566475],
                            [2.514984995293168, 48.797517039010444],
                            [2.5147858815811, 48.797229450132846],
                            [2.514518112228261, 48.7968777238003],
                            [2.514275642284225, 48.79654975251736],
                            [2.514051258882679, 48.796243166932086],
                            [2.513754485184352, 48.79583437954277],
                            [2.51350115244816, 48.79548738868592],
                            [2.513423298184714, 48.79538383561483],
                        ],
                    },
                },
                68: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.88595335363538, 2.1643023690980323],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1262.78610384,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.155903471896523,
                            48.8851632198879,
                            2.172579447718415,
                            48.88757361863876,
                        ),
                        "coordinates": [
                            [2.172579447718415, 48.88757361863876],
                            [2.171782068873163, 48.88730926067918],
                            [2.171547749345176, 48.88723967789196],
                            [2.171095459220695, 48.88710592843942],
                            [2.170754841219728, 48.887017303748365],
                            [2.170722143203212, 48.88700826369678],
                            [2.170468726817045, 48.88694134795458],
                            [2.170378804513189, 48.88691783477343],
                            [2.170302505816086, 48.88689793956726],
                            [2.170282069136247, 48.88689251429115],
                            [2.170260272163748, 48.88688618743371],
                            [2.170098140601709, 48.886843684859144],
                            [2.169617169445956, 48.88672517539531],
                            [2.168997292545189, 48.886590907528294],
                            [2.168341791213656, 48.886464312213946],
                            [2.167281755123788, 48.886255739070805],
                            [2.166565658626493, 48.88612618802025],
                            [2.16581919395176, 48.88599382915296],
                            [2.165537072433207, 48.885950240552894],
                            [2.165167733121407, 48.885891232729264],
                            [2.164944214287959, 48.885857623073406],
                            [2.164107317113675, 48.88575114355229],
                            [2.163829252492644, 48.88571834891036],
                            [2.163282665247964, 48.885653669749175],
                            [2.162866933023696, 48.885604476102564],
                            [2.162654297171717, 48.885578972110594],
                            [2.161729724557738, 48.885463598567306],
                            [2.161197210125788, 48.885403177740585],
                            [2.160784131091873, 48.88535079103308],
                            [2.160352135576175, 48.88530025599541],
                            [2.160057696348922, 48.88527192259143],
                            [2.159736789841772, 48.88524067229263],
                            [2.15943880986495, 48.88521790466067],
                            [2.159291582349866, 48.88520598523812],
                            [2.15903662989016, 48.88519389810617],
                            [2.15876122153014, 48.88518267667336],
                            [2.158447638955908, 48.88516959714309],
                            [2.158209021057997, 48.885165627261564],
                            [2.158166755724097, 48.88516376252927],
                            [2.15806994019543, 48.885163610580435],
                            [2.157955398240381, 48.8851634310154],
                            [2.157820402501647, 48.8851632198879],
                            [2.157636312163078, 48.885163830562846],
                            [2.157603586682145, 48.88516377838592],
                            [2.157531308659708, 48.88516546423599],
                            [2.157111306442858, 48.88516840069554],
                            [2.156515332277811, 48.88518994202832],
                            [2.155903471896523, 48.88521121820845],
                        ],
                    },
                },
                69: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.5487902171526, 2.2921731814414175],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3696.92764064,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.290082513840396,
                            48.532890103244725,
                            2.293345838644037,
                            48.565593862821814,
                        ),
                        "coordinates": [
                            [2.290924468489718, 48.565593862821814],
                            [2.290972006789592, 48.56509546162683],
                            [2.291148000784847, 48.56321825008443],
                            [2.291297998710955, 48.56163874002049],
                            [2.291574827260926, 48.55879638260679],
                            [2.291716157634594, 48.557296510204196],
                            [2.291929536551554, 48.555077992546174],
                            [2.292039101985673, 48.553938393509846],
                            [2.292142942379187, 48.552808274246324],
                            [2.29223821542927, 48.55167056703662],
                            [2.292330633024033, 48.55052716981879],
                            [2.29247494684281, 48.54883198676967],
                            [2.292578771243155, 48.54769617977506],
                            [2.292737312139606, 48.54604082317767],
                            [2.292846832334936, 48.54491070670284],
                            [2.293025395188173, 48.5431984712315],
                            [2.293189658953251, 48.54149760819737],
                            [2.293299152455664, 48.540375076162796],
                            [2.293339624970796, 48.53980621955245],
                            [2.293345838644037, 48.53922976526901],
                            [2.293334903723072, 48.538670371374145],
                            [2.293286793866014, 48.5381735375931],
                            [2.293230100977195, 48.53769566383412],
                            [2.293144795015966, 48.53728793977789],
                            [2.293062266209859, 48.53697123570309],
                            [2.292954038609729, 48.536654522602966],
                            [2.292797336868192, 48.53626573277849],
                            [2.29260922842184, 48.535876931181676],
                            [2.292389711432258, 48.53549001221115],
                            [2.292144486379712, 48.535120149043685],
                            [2.291859291505608, 48.53475027028643],
                            [2.291565504082937, 48.53441451904097],
                            [2.291149043743194, 48.533970632854846],
                            [2.290826703998391, 48.53364624580547],
                            [2.290433058581351, 48.53324597882319],
                            [2.290082513840396, 48.532890103244725],
                        ],
                    },
                },
                70: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.883001467142776, 2.2657882119548045],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 4669.73856649,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.237213536457713,
                            48.874238476656075,
                            2.294490592832005,
                            48.89212336383249,
                        ),
                        "coordinates": [
                            [2.294490592832005, 48.874238476656075],
                            [2.293979630769604, 48.874304669363966],
                            [2.29358346053517, 48.87435609117054],
                            [2.292248949281205, 48.87457561694739],
                            [2.291329841196212, 48.87476923606603],
                            [2.290800759140827, 48.87489222553154],
                            [2.290123006206638, 48.875083495920784],
                            [2.283601731484298, 48.877163005675975],
                            [2.281891035520748, 48.87770842376787],
                            [2.27201728352592, 48.88083184022266],
                            [2.262191356498401, 48.88397152158327],
                            [2.260015441852841, 48.88462565428735],
                            [2.25921861809974, 48.88493626661831],
                            [2.258288006188821, 48.88533850754967],
                            [2.257519628722038, 48.885753443230065],
                            [2.256442691123083, 48.8863947753678],
                            [2.255293494466192, 48.887010866098144],
                            [2.254750354253448, 48.88725508113673],
                            [2.254104940357313, 48.88749562315546],
                            [2.253117182509752, 48.88776828510927],
                            [2.251742171747327, 48.888014572006334],
                            [2.250084903288651, 48.88823814724787],
                            [2.249619707971574, 48.88833851253028],
                            [2.243116621869925, 48.890308184070236],
                            [2.237994004180329, 48.89186771760373],
                            [2.237328035769669, 48.89208656393661],
                            [2.237213536457713, 48.89212336383249],
                        ],
                    },
                },
                71: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.60073977357278, 1.6757622440878344],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 1289.24957313,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.66971881148154,
                            48.596612809761496,
                            1.681645780403713,
                            48.60507627758083,
                        ),
                        "coordinates": [
                            [1.66971881148154, 48.596612809761496],
                            [1.670996615895592, 48.597479137279805],
                            [1.67247057276675, 48.59848418982428],
                            [1.674646464434534, 48.599933074152844],
                            [1.675689360660399, 48.60063250850369],
                            [1.677558209043181, 48.60193476225599],
                            [1.679376461179896, 48.603173741274425],
                            [1.679616957856203, 48.603342402883285],
                            [1.68014702386573, 48.60376364113057],
                            [1.680990655682556, 48.604486993660174],
                            [1.681645780403713, 48.60507627758083],
                        ],
                    },
                },
                72: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.93251347378888, 2.4652205859443646],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 1532.65028221,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.454766382765777,
                            48.93230541606912,
                            2.475674370833512,
                            48.93270621869947,
                        ),
                        "coordinates": [
                            [2.454766382765777, 48.93270621869947],
                            [2.45518364315076, 48.932700995781666],
                            [2.457598821452279, 48.93267475387125],
                            [2.459869971859382, 48.93263783496673],
                            [2.462118221556601, 48.93260520910067],
                            [2.463698639395359, 48.932580933909804],
                            [2.464275473393231, 48.93256638793979],
                            [2.466635518401334, 48.9324895754969],
                            [2.469417617732813, 48.932398319719525],
                            [2.471060166345491, 48.93235468930533],
                            [2.47238270795745, 48.932341542495124],
                            [2.475674370833512, 48.93230541606912],
                        ],
                    },
                },
                73: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.30309453632192, 2.6804725098122493],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 7769.49621604,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.675087359405762,
                            48.26775810993438,
                            2.692480190584066,
                            48.33268364471056,
                        ),
                        "coordinates": [
                            [2.692480190584066, 48.33268364471056],
                            [2.691391542696429, 48.33228253572326],
                            [2.690409659957772, 48.33188545383876],
                            [2.689891583311462, 48.33165854002862],
                            [2.689365292574413, 48.33142201410298],
                            [2.688976489120495, 48.33124160855934],
                            [2.688567755902449, 48.33105060194479],
                            [2.688224663627763, 48.330881354474236],
                            [2.687906605869653, 48.33071885864362],
                            [2.687186506511966, 48.33033712063469],
                            [2.686885963109403, 48.33016989525797],
                            [2.686326809117357, 48.32985329650773],
                            [2.685774311968423, 48.3295231863682],
                            [2.685479084020273, 48.32934335199067],
                            [2.684668996449672, 48.328813500717516],
                            [2.683713695973193, 48.32814740678432],
                            [2.683383025525658, 48.32791012344695],
                            [2.683121055646814, 48.32770777996683],
                            [2.682790452979792, 48.327452082357176],
                            [2.682153260702667, 48.32693731803789],
                            [2.681755051210831, 48.32659203543299],
                            [2.681401695730068, 48.326278674410815],
                            [2.681131622688666, 48.32602591303681],
                            [2.680477248554331, 48.325378656047334],
                            [2.680155400057916, 48.32504601765736],
                            [2.679700310292202, 48.324551919654894],
                            [2.679560783117677, 48.32439220277733],
                            [2.679167143689837, 48.323924324626525],
                            [2.678839764978314, 48.323522203512624],
                            [2.678227216244546, 48.322691027298724],
                            [2.677805255589131, 48.32208565175546],
                            [2.677553142176157, 48.3216916470262],
                            [2.677295450940819, 48.32126978275815],
                            [2.677145310799483, 48.320999362541734],
                            [2.676969236280938, 48.32068356313474],
                            [2.676847640708833, 48.3204474295201],
                            [2.676464748696359, 48.319652755993324],
                            [2.67635262448922, 48.31938531382368],
                            [2.676218087039629, 48.31906449622371],
                            [2.676042468360639, 48.318613606385675],
                            [2.675867792771375, 48.31810246423378],
                            [2.675775357664548, 48.31781570405213],
                            [2.675666409491944, 48.317445755014326],
                            [2.675604279729833, 48.31721211001296],
                            [2.675540681467895, 48.316977599876836],
                            [2.675343439648102, 48.31611672096722],
                            [2.675214788432753, 48.315230457377574],
                            [2.675151705996511, 48.31467131988922],
                            [2.675131120092048, 48.3144168974097],
                            [2.675108316409423, 48.31399898315524],
                            [2.675095519346699, 48.31373448159181],
                            [2.675087359405762, 48.313123023917676],
                            [2.675094816930023, 48.312828950667935],
                            [2.67512727420026, 48.31224344963654],
                            [2.675181590587328, 48.31170104590739],
                            [2.675252050455233, 48.311154097619095],
                            [2.675309182499671, 48.31083020105635],
                            [2.67537031673438, 48.310499996574585],
                            [2.675554531998818, 48.309651523900655],
                            [2.67563568576462, 48.309271740314486],
                            [2.675732306515464, 48.308807443262225],
                            [2.676145201050875, 48.30687194226511],
                            [2.67649548931721, 48.30525046147873],
                            [2.676843052150074, 48.30362809042412],
                            [2.67727174197208, 48.30164937494295],
                            [2.677545458196509, 48.300447129148516],
                            [2.677714704225114, 48.29959418052138],
                            [2.677858594165325, 48.298907658264426],
                            [2.677996551817388, 48.29823008433304],
                            [2.678371884700336, 48.29654467685652],
                            [2.67852609549913, 48.2957817440343],
                            [2.678652454175343, 48.29519587096144],
                            [2.678869395527883, 48.29420245564648],
                            [2.679083633352303, 48.293209048105716],
                            [2.67925889634775, 48.29242977727173],
                            [2.679359271467391, 48.2919330939816],
                            [2.679501832487909, 48.29129959855797],
                            [2.67960090049538, 48.29081936469478],
                            [2.679752578554305, 48.29013072910954],
                            [2.679910707559019, 48.28941152731955],
                            [2.680064927673276, 48.2887107843005],
                            [2.680577903473908, 48.28628847977151],
                            [2.68087705776792, 48.284916232946394],
                            [2.681022053102365, 48.284250356419314],
                            [2.681190351235858, 48.283446826214714],
                            [2.681451544515652, 48.28224105380438],
                            [2.68169569844899, 48.28110637158191],
                            [2.681939833803385, 48.27997079085949],
                            [2.682086054852688, 48.27929142140013],
                            [2.682183953269003, 48.278834310742916],
                            [2.682280577162314, 48.278387994324305],
                            [2.682365427510876, 48.27799297047525],
                            [2.682507199262286, 48.277343525884795],
                            [2.68258741824988, 48.276971659519575],
                            [2.682860271339749, 48.27570829790955],
                            [2.683079586109003, 48.274692390137474],
                            [2.683300225465166, 48.27367467898567],
                            [2.683520868410259, 48.27265876621789],
                            [2.683721336208414, 48.27184344425305],
                            [2.683865485817682, 48.271261197016436],
                            [2.684020252387677, 48.270712689713825],
                            [2.684114353037021, 48.270426873280144],
                            [2.684240444271282, 48.27010766946594],
                            [2.684391161337541, 48.26977983773528],
                            [2.684616347604972, 48.26932374455536],
                            [2.68486627154594, 48.268875678655775],
                            [2.685109490180194, 48.268489492910525],
                            [2.685439261376148, 48.26803259197371],
                            [2.68564708993975, 48.26775810993438],
                        ],
                    },
                },
                74: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.84318509326101, 1.8979550294451668],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 4973.64175446,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.875595590302068,
                            48.833512070590515,
                            1.924597779359982,
                            48.85999873043875,
                        ),
                        "coordinates": [
                            [1.924597779359982, 48.833512070590515],
                            [1.923194770327423, 48.8336678299516],
                            [1.921190318523971, 48.83390708528862],
                            [1.919700159752708, 48.834056324325296],
                            [1.918703550013512, 48.83415429582055],
                            [1.918185450073443, 48.83420815147946],
                            [1.917712271985488, 48.834265767155195],
                            [1.917507723534034, 48.83429109570287],
                            [1.916580250283213, 48.834427971826806],
                            [1.916093254192245, 48.834508012591954],
                            [1.915059071771255, 48.834697540693014],
                            [1.915049521137181, 48.83469930417211],
                            [1.914713855049627, 48.83476461050825],
                            [1.914315351291881, 48.83485036595376],
                            [1.913440379459775, 48.83505845562745],
                            [1.912948925994493, 48.835180733139666],
                            [1.911243513250594, 48.83564291391187],
                            [1.909382363398708, 48.83615214829706],
                            [1.908593099039535, 48.836368615725696],
                            [1.908239433593845, 48.8364653103759],
                            [1.905403226666929, 48.83724060099547],
                            [1.903368563528334, 48.83779314686094],
                            [1.901077081489615, 48.83842021676756],
                            [1.900507667949804, 48.838570020222555],
                            [1.899849395057337, 48.838754554302625],
                            [1.899424382767335, 48.83888295765245],
                            [1.898988664991143, 48.8390327328708],
                            [1.898475025416582, 48.839224402691016],
                            [1.897922117497722, 48.83947558396048],
                            [1.89771008414774, 48.83957369003812],
                            [1.897510309452956, 48.83967184306835],
                            [1.897118414863756, 48.83987661390771],
                            [1.896757918099072, 48.84007925449823],
                            [1.896431717214061, 48.840287064583684],
                            [1.896093818571919, 48.84052253545949],
                            [1.895686448907955, 48.840845898593436],
                            [1.895347895741671, 48.84115441227406],
                            [1.895101504160527, 48.84139779201599],
                            [1.894912771304306, 48.84160697994902],
                            [1.894711777059476, 48.84184091695893],
                            [1.894557405271386, 48.84204086002167],
                            [1.894442983050777, 48.84219149797927],
                            [1.894396140582562, 48.84224977023602],
                            [1.894280249967738, 48.842412092310454],
                            [1.894013749691345, 48.84281034383009],
                            [1.893179296491143, 48.84410208169784],
                            [1.893082647696013, 48.844244693385534],
                            [1.892883691705741, 48.844553275997995],
                            [1.892044938542822, 48.84586207608825],
                            [1.891800371538073, 48.84624152289608],
                            [1.891740954455565, 48.84633391831386],
                            [1.891543457631963, 48.84662991364212],
                            [1.891394259084974, 48.84685775130098],
                            [1.891184808608388, 48.84711862714696],
                            [1.891023723334837, 48.84730415165089],
                            [1.890697694876669, 48.84764910447068],
                            [1.890406339439276, 48.847925846869245],
                            [1.890255270340923, 48.84805745138342],
                            [1.889989035800739, 48.84826774298703],
                            [1.889526792071094, 48.84860586474786],
                            [1.889307542327516, 48.84874259681445],
                            [1.888833611713345, 48.849015920432066],
                            [1.887846656114627, 48.84951384686808],
                            [1.887030992758062, 48.84990362639705],
                            [1.885802010045025, 48.85048961067134],
                            [1.885644623273448, 48.850564529509974],
                            [1.885461206267309, 48.85065463242783],
                            [1.885001384395286, 48.850870442147766],
                            [1.884916533163449, 48.850910574747054],
                            [1.884114573593193, 48.8512868979541],
                            [1.883673850115235, 48.85149918048404],
                            [1.881774175736952, 48.85239990788418],
                            [1.881063508312302, 48.85277207649475],
                            [1.880789511388133, 48.85293015725882],
                            [1.880234267344406, 48.85329305004022],
                            [1.879948925488302, 48.85349874558174],
                            [1.879722433519892, 48.853676797527775],
                            [1.879519196843302, 48.85384505094054],
                            [1.879295227771028, 48.85404469541246],
                            [1.878900482159473, 48.854438800756014],
                            [1.878790236769664, 48.85457145382602],
                            [1.878616856789359, 48.85475241439242],
                            [1.878347920560391, 48.85509846201705],
                            [1.878054268363712, 48.85546419290713],
                            [1.877712091996414, 48.855918757935974],
                            [1.877197799589176, 48.856563279856786],
                            [1.876762902132102, 48.857168549597745],
                            [1.876691011294865, 48.857278872891605],
                            [1.876429417057593, 48.85771217619204],
                            [1.876237738290118, 48.8581007961128],
                            [1.876127566257983, 48.858371038954516],
                            [1.875992168270031, 48.85871582076509],
                            [1.875891533074525, 48.85898610157833],
                            [1.875595590302068, 48.85999873043875],
                        ],
                    },
                },
                75: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.837666159350825, 2.6819810280352456],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 4215.87827718,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.655130086641314,
                            48.83446493974479,
                            2.708981742262277,
                            48.8413481541083,
                        ),
                        "coordinates": [
                            [2.708981742262277, 48.83653643294522],
                            [2.708813567142168, 48.836516448562065],
                            [2.708182267381735, 48.83644116664061],
                            [2.706801043508837, 48.83627568952893],
                            [2.705749758233857, 48.83614509994105],
                            [2.702406512761462, 48.83574398915671],
                            [2.700034121348974, 48.83546289624197],
                            [2.697856681602127, 48.835200018003185],
                            [2.69651641974847, 48.83503878004973],
                            [2.693278280452719, 48.834648755447375],
                            [2.692360775304486, 48.834548199615234],
                            [2.691592073732122, 48.83449213699931],
                            [2.691183271478378, 48.83447362323637],
                            [2.690793611689558, 48.83446493974479],
                            [2.690087976809076, 48.83446532681188],
                            [2.689372997596028, 48.83449271798273],
                            [2.689008074162088, 48.83451452766953],
                            [2.688595560731638, 48.834549072996616],
                            [2.687748928649365, 48.834645204765664],
                            [2.686966462600394, 48.83476181740248],
                            [2.686547419351012, 48.83483684330322],
                            [2.686290333426266, 48.83489068853669],
                            [2.685623933020744, 48.835047404463005],
                            [2.684774174737441, 48.83528291267264],
                            [2.684480568191723, 48.83537463530411],
                            [2.683833727569369, 48.83560322350509],
                            [2.683297042248419, 48.83580539473872],
                            [2.682783665282662, 48.836029974971495],
                            [2.682281283318439, 48.83626890783278],
                            [2.681320288957892, 48.836774513381044],
                            [2.679641194486992, 48.83765457432527],
                            [2.678748101708651, 48.83813657180763],
                            [2.678259375025331, 48.838386237976756],
                            [2.676749935165873, 48.83918840958539],
                            [2.675009550379647, 48.84009466375864],
                            [2.674562805808882, 48.84031271414811],
                            [2.674166190323721, 48.840490146625235],
                            [2.673729892822907, 48.840642515515796],
                            [2.673294870701926, 48.840782288310514],
                            [2.672851657937244, 48.84092028519619],
                            [2.672342934201122, 48.84104138675611],
                            [2.671881727561581, 48.84113806537385],
                            [2.671419042316219, 48.84121766056017],
                            [2.671033769583915, 48.84126105613632],
                            [2.670753316936057, 48.841291552872576],
                            [2.670362478986721, 48.84131787586561],
                            [2.669941631173118, 48.841338888715946],
                            [2.669539779876879, 48.8413481541083],
                            [2.66895797806322, 48.84134085538224],
                            [2.668538233810415, 48.841323191084086],
                            [2.668205661058196, 48.841301674218634],
                            [2.667798005673139, 48.84125789250317],
                            [2.667332946073375, 48.841186398453395],
                            [2.666893731350832, 48.84110853167479],
                            [2.665790036811735, 48.8408815001527],
                            [2.665262148042251, 48.8407849979329],
                            [2.664869338380738, 48.8407186814545],
                            [2.664334782120697, 48.84064377661963],
                            [2.663856240359233, 48.84059209132376],
                            [2.66346359326968, 48.84055004930345],
                            [2.662997337461138, 48.84050192144581],
                            [2.662413841464426, 48.840442435931976],
                            [2.661966672709561, 48.84039604867343],
                            [2.66144452182996, 48.84034177886048],
                            [2.658580203774628, 48.8400432314194],
                            [2.657993953902379, 48.83997743632301],
                            [2.655130086641314, 48.83964551726302],
                        ],
                    },
                },
                76: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.79158199287345, 2.4067137131838674],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2038.29308463,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.40271281718153,
                            48.78250543550023,
                            2.409541656460374,
                            48.80020939834459,
                        ),
                        "coordinates": [
                            [2.409541656460374, 48.78250543550023],
                            [2.409504545391541, 48.782718760102725],
                            [2.409361654715678, 48.783492133803456],
                            [2.409272266165194, 48.78392047034458],
                            [2.409129272495981, 48.78462722365056],
                            [2.408971892768101, 48.78534826148277],
                            [2.408782174655474, 48.78611928576211],
                            [2.408538710867583, 48.787078310521714],
                            [2.408298656866495, 48.78791122789415],
                            [2.408169660018592, 48.78835148622518],
                            [2.408033457741617, 48.78879174723824],
                            [2.407760975044736, 48.78962230537667],
                            [2.407509982849522, 48.79037670972165],
                            [2.407208650101571, 48.79119062841646],
                            [2.40682834752396, 48.79219256245235],
                            [2.406412029096415, 48.79320165556693],
                            [2.406027942625695, 48.79409413977865],
                            [2.405733554601532, 48.79475577413811],
                            [2.405543241199632, 48.7951579962248],
                            [2.405349291749823, 48.795536427871625],
                            [2.405090645253383, 48.796012449709366],
                            [2.404609264150739, 48.796897849580674],
                            [2.404368534866408, 48.7973167562486],
                            [2.404120642832604, 48.7977689761037],
                            [2.4038655501678, 48.79822595853451],
                            [2.40357091525546, 48.79874244735021],
                            [2.402798310222541, 48.80005391144719],
                            [2.40271281718153, 48.80020939834459],
                        ],
                    },
                },
                77: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.595604808066874, 2.2824773927647555],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2548.36843922,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.266937972614161,
                            48.591460820223375,
                            2.297950577822679,
                            48.599059348508746,
                        ),
                        "coordinates": [
                            [2.266937972614161, 48.591460820223375],
                            [2.267047525335429, 48.59151679110039],
                            [2.267393746322513, 48.591696878854286],
                            [2.268674568132321, 48.59239241779769],
                            [2.269922669670241, 48.59307077501544],
                            [2.271089898822804, 48.59370017204722],
                            [2.271525910676296, 48.59393110960185],
                            [2.272027767242565, 48.59416456845992],
                            [2.272396644934728, 48.59432799739449],
                            [2.273056651218614, 48.59459152098763],
                            [2.273601247795335, 48.59479002068213],
                            [2.274155927647354, 48.59496187494262],
                            [2.274708122737644, 48.59511374028097],
                            [2.275318074612092, 48.595263967518804],
                            [2.275717196138264, 48.59534912384036],
                            [2.276028466688033, 48.595412580583535],
                            [2.276440162842702, 48.595482751391785],
                            [2.276812599097834, 48.595538125571785],
                            [2.277128021386692, 48.59558304670883],
                            [2.277645192328033, 48.59564160986846],
                            [2.278084550472182, 48.5956801451578],
                            [2.278616804078241, 48.5957237225199],
                            [2.280698173409043, 48.59585801094676],
                            [2.282026335965663, 48.595946932759716],
                            [2.283678381982467, 48.596060972580474],
                            [2.286510473089086, 48.59626045928417],
                            [2.290291700203794, 48.59647359284977],
                            [2.291258363676342, 48.59651728825804],
                            [2.291845884000873, 48.596555828864894],
                            [2.292265183825152, 48.596582642928524],
                            [2.293081917984158, 48.596624196039],
                            [2.293298850176136, 48.59664259367458],
                            [2.293870732040014, 48.596721303727605],
                            [2.29433609656291, 48.59682351837107],
                            [2.294809322364659, 48.59695974683564],
                            [2.295325907192924, 48.597135235767595],
                            [2.295645308859402, 48.59726093930767],
                            [2.295921330104468, 48.597378776049474],
                            [2.296398449704391, 48.597590875344935],
                            [2.296779144063657, 48.59777501519646],
                            [2.2970529826857, 48.59792338887908],
                            [2.297269789044134, 48.598106612298714],
                            [2.297490499523158, 48.598344780730265],
                            [2.297597336598059, 48.59850367185756],
                            [2.297950577822679, 48.599059348508746],
                        ],
                    },
                },
                78: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.02829819019747, 2.098743182460937],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2638.64991952,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.090906063354292,
                            49.01834916361145,
                            2.10385269644926,
                            49.03998130935,
                        ),
                        "coordinates": [
                            [2.090906063354292, 49.01834916361145],
                            [2.091144308072323, 49.018564409763925],
                            [2.09122053522454, 49.0186329185302],
                            [2.091279070152425, 49.018685202224916],
                            [2.091615197276309, 49.01900696553482],
                            [2.092114719567505, 49.01946756597293],
                            [2.094352501318781, 49.02152538299336],
                            [2.09533537133959, 49.022421343284144],
                            [2.096228347382347, 49.02325145976882],
                            [2.0985454164078, 49.02538579820293],
                            [2.098719477388619, 49.02558849839749],
                            [2.099135570053817, 49.026079470408554],
                            [2.09915597037364, 49.026102893950906],
                            [2.099192680202592, 49.026147034200044],
                            [2.09921442601375, 49.02617495682095],
                            [2.099275578719204, 49.02625511954155],
                            [2.09934353862269, 49.026341591980604],
                            [2.09957568245288, 49.026696389079795],
                            [2.099878297436992, 49.027185324342724],
                            [2.100089530867916, 49.02762460939573],
                            [2.100270687800041, 49.02806293202759],
                            [2.100401544114964, 49.02843910073451],
                            [2.100596206114226, 49.029201191740526],
                            [2.101124406699995, 49.03143428909256],
                            [2.101608255889117, 49.03351261773517],
                            [2.101675269178231, 49.03380142337698],
                            [2.101694080434523, 49.03387250533291],
                            [2.101706082080894, 49.03393727769525],
                            [2.101714147456867, 49.03396697038454],
                            [2.101716860891602, 49.0339714724487],
                            [2.101726217570092, 49.03401735465715],
                            [2.101765167831181, 49.03416761432772],
                            [2.101785197638508, 49.03427017303603],
                            [2.101802559365983, 49.03435833847271],
                            [2.101826776225532, 49.034442920480515],
                            [2.101860385628148, 49.03456619017363],
                            [2.101902098215733, 49.03471105970538],
                            [2.101972101625191, 49.034946813731096],
                            [2.102034027434305, 49.03515557352568],
                            [2.102300012578942, 49.03588633279511],
                            [2.1024649416769, 49.03629584159403],
                            [2.102609366399447, 49.0367035107185],
                            [2.10320372786693, 49.03828565546363],
                            [2.103441514816164, 49.03891203731664],
                            [2.103611874653595, 49.03933414594337],
                            [2.10385269644926, 49.03998130935],
                        ],
                    },
                },
                79: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.8520245704158, 2.3021937626521236],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 823.861672853,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.298301401728378,
                            48.84935055362092,
                            2.306097403692308,
                            48.85468215778704,
                        ),
                        "coordinates": [
                            [2.306097403692308, 48.85468215778704],
                            [2.300733125298419, 48.8510377224149],
                            [2.298862339812689, 48.84973975840741],
                            [2.298301401728378, 48.84935055362092],
                        ],
                    },
                },
                80: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.85620205355988, 2.3083328629905187],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 471.184831963,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.306097403692308,
                            48.85468215778704,
                            2.310565960946846,
                            48.85772541289345,
                        ),
                        "coordinates": [
                            [2.310565960946846, 48.85772541289345],
                            [2.308984358887443, 48.85664319884097],
                            [2.306684862664735, 48.855081223484696],
                            [2.306097403692308, 48.85468215778704],
                        ],
                    },
                },
                81: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.841907266348095, 2.2899350324017558],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 344.408599504,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.287945766487379,
                            48.84109405724891,
                            2.291912413317875,
                            48.842746779792876,
                        ),
                        "coordinates": [
                            [2.291912413317875, 48.842746779792876],
                            [2.291820756416435, 48.842697069668546],
                            [2.291665326961091, 48.84262039924946],
                            [2.291251417175003, 48.84244238468104],
                            [2.291020668107757, 48.842348270862445],
                            [2.287945766487379, 48.84109405724891],
                        ],
                    },
                },
                82: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.8592944523774, 2.3676595840324652],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 422.020021471,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.367210867785615,
                            48.857420037539946,
                            2.368108289338497,
                            48.86116886459571,
                        ),
                        "coordinates": [
                            [2.368108289338497, 48.857420037539946],
                            [2.36741171788129, 48.86032989554634],
                            [2.367210867785615, 48.86116886459571],
                        ],
                    },
                },
                83: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.99698913811343, 1.8738592005046046],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4515.99165634,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.845134443502388,
                            48.99164222314708,
                            1.901781979947734,
                            49.00576253682855,
                        ),
                        "coordinates": [
                            [1.845134443502388, 48.99224128128681],
                            [1.845339087123361, 48.99224086589612],
                            [1.845700787429356, 48.99222814250953],
                            [1.846142147031367, 48.992203862759595],
                            [1.846779077664176, 48.99214710785623],
                            [1.847506679950353, 48.99206218562052],
                            [1.848661500415534, 48.991919596860875],
                            [1.849385524748993, 48.99182988690912],
                            [1.85007691425945, 48.991749553433515],
                            [1.850608913195878, 48.99169946969111],
                            [1.851198621556033, 48.991663903258484],
                            [1.851752007198012, 48.99164483658432],
                            [1.852258232083401, 48.99164222314708],
                            [1.852847519263956, 48.991649475741035],
                            [1.853219781521623, 48.991665326061096],
                            [1.853754602460592, 48.991696138749646],
                            [1.854325374562137, 48.99174851320475],
                            [1.85484179610291, 48.99181255535857],
                            [1.855307604280293, 48.99187638040057],
                            [1.855903180377851, 48.9919812001807],
                            [1.856863101136969, 48.99217320040876],
                            [1.857757924756603, 48.99236730343216],
                            [1.860716730700712, 48.99300305412534],
                            [1.86521459617215, 48.99397224754316],
                            [1.86649912593623, 48.99425830404563],
                            [1.867516535439773, 48.994498040678145],
                            [1.868295697228804, 48.994696342855555],
                            [1.868980965812998, 48.99488235987542],
                            [1.869778014771005, 48.995102141410214],
                            [1.870542529055708, 48.995321782169064],
                            [1.871869487437434, 48.995717401946784],
                            [1.874884157415533, 48.99660760533309],
                            [1.880095191668224, 48.998144193394246],
                            [1.883564543120176, 48.99917160441385],
                            [1.885375041519575, 48.99970460772858],
                            [1.886067544090376, 48.99990482628303],
                            [1.886619497887749, 49.00005214180135],
                            [1.887200494476583, 49.000187672653006],
                            [1.888034278400627, 49.00036226040809],
                            [1.888831933160587, 49.00053432248424],
                            [1.889593448734819, 49.00070385861547],
                            [1.890149081528058, 49.00084641373231],
                            [1.890740603746297, 49.001020036597545],
                            [1.89137522315858, 49.00122713678664],
                            [1.892013120835908, 49.00147231542071],
                            [1.892524714765811, 49.00168844528113],
                            [1.893176495006172, 49.002000295681974],
                            [1.893676802220116, 49.002266345534316],
                            [1.894148097076464, 49.002541799488334],
                            [1.894727106680992, 49.00290570286618],
                            [1.895694387118233, 49.00353045452068],
                            [1.89635634216309, 49.00392322439009],
                            [1.896741463756091, 49.00413171180254],
                            [1.897396921971946, 49.004443551173836],
                            [1.898088781938588, 49.00472935218384],
                            [1.898744884645162, 49.004969804545574],
                            [1.899455286756341, 49.005205700766005],
                            [1.900176791469935, 49.00541308188115],
                            [1.900797541551485, 49.00556297174352],
                            [1.901781979947734, 49.00576253682855],
                        ],
                    },
                },
                84: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.91331566771093, 2.3182610987949297],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1812.63218865,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313835382457718,
                            48.9056549540281,
                            2.322400403166692,
                            48.92087280435657,
                        ),
                        "coordinates": [
                            [2.322400403166692, 48.9056549540281],
                            [2.322343016394903, 48.90593448954394],
                            [2.322321163367262, 48.90602351577318],
                            [2.322170935282105, 48.90659094009398],
                            [2.321997513371347, 48.90715476491949],
                            [2.321796827133725, 48.90764034846976],
                            [2.321728563122154, 48.90781120180266],
                            [2.321556521307095, 48.90813313361577],
                            [2.321330207791256, 48.90849833197662],
                            [2.321124362874009, 48.90881475654188],
                            [2.320629817828479, 48.90946752188185],
                            [2.32032954704596, 48.90985776609357],
                            [2.319924176440652, 48.91038198561147],
                            [2.319649816930623, 48.910773131270716],
                            [2.319528325280212, 48.910965558119436],
                            [2.319283957033095, 48.91140706628604],
                            [2.319120000188026, 48.91170536711489],
                            [2.318942970870801, 48.91211458694541],
                            [2.318588852132442, 48.91307578575448],
                            [2.318484080193902, 48.913306565552205],
                            [2.318422652102822, 48.91346121270532],
                            [2.318357623693711, 48.91359444478965],
                            [2.318252869329116, 48.913770499719135],
                            [2.317815825746098, 48.914389057347904],
                            [2.317255971307212, 48.9151598709375],
                            [2.316649141155665, 48.91599491534771],
                            [2.31648659391065, 48.91621854476956],
                            [2.315905032023427, 48.916998864982666],
                            [2.315649614227107, 48.9173796010488],
                            [2.315411178041731, 48.91775549361236],
                            [2.315288340981974, 48.91795533477694],
                            [2.31510882904646, 48.918283126780764],
                            [2.314389064917821, 48.91974791118154],
                            [2.313911022100327, 48.92071723734009],
                            [2.313835382457718, 48.92087280435657],
                        ],
                    },
                },
                85: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.00896242279198, 1.9414519203399303],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3356.83036109,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.919237111731365,
                            49.00670027774167,
                            1.963551770278395,
                            49.01014136865553,
                        ),
                        "coordinates": [
                            [1.919237111731365, 49.00670027774167],
                            [1.919962154609168, 49.00679272531784],
                            [1.921295728366337, 49.0069141644876],
                            [1.921917281266103, 49.00697828333089],
                            [1.922560355579283, 49.007063890677166],
                            [1.923297187488737, 49.0071831440945],
                            [1.924117049575658, 49.007321728962125],
                            [1.924846556663963, 49.007452842342346],
                            [1.925464049616322, 49.00757165350609],
                            [1.925994742073372, 49.007690148787006],
                            [1.926637184087518, 49.007854250715305],
                            [1.927214624944173, 49.008006220539585],
                            [1.927976094109237, 49.00821118913309],
                            [1.929596489074198, 49.00864763260691],
                            [1.930989538629571, 49.009023764111305],
                            [1.931574217397635, 49.00917811424799],
                            [1.932126587596815, 49.00930379648014],
                            [1.932754990057206, 49.009420226009],
                            [1.933340223667563, 49.009507948589494],
                            [1.93392203816692, 49.00957186287439],
                            [1.934395579228628, 49.009606839349885],
                            [1.934923451820828, 49.00963248768522],
                            [1.935849102513868, 49.00966904677881],
                            [1.937736598157521, 49.00973988652296],
                            [1.942788014531863, 49.009931083201096],
                            [1.945622882241175, 49.01004074089918],
                            [1.948128713562733, 49.010137316349436],
                            [1.948869672389161, 49.01014136865553],
                            [1.94950346371552, 49.010129952542655],
                            [1.950256828674234, 49.01009109804834],
                            [1.950640084387352, 49.01006383987754],
                            [1.951055767526005, 49.01002349259428],
                            [1.951439393410282, 49.00997730812208],
                            [1.951758150693537, 49.009935441674244],
                            [1.952171557073107, 49.009873412573974],
                            [1.952438995344456, 49.009825900306545],
                            [1.953108952031279, 49.00972107752833],
                            [1.954506871415831, 49.009492575522245],
                            [1.95577800368968, 49.009287431617906],
                            [1.957223007196716, 49.00904715853953],
                            [1.957567380590215, 49.008986308791485],
                            [1.957937978828172, 49.00890973085301],
                            [1.958356459105238, 49.008814750951345],
                            [1.958719285382097, 49.00872594319529],
                            [1.959020045817519, 49.00864861304148],
                            [1.959781349263777, 49.00841794487313],
                            [1.960484851548508, 49.00817756363266],
                            [1.961173862662032, 49.00793951235834],
                            [1.963512748838912, 49.00714055851738],
                            [1.963551770278395, 49.00712724722575],
                        ],
                    },
                },
                86: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84742327318669, 2.4752842544374576],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2342.93300311,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461697053166161,
                            48.843535700970456,
                            2.488187573818578,
                            48.85379557653064,
                        ),
                        "coordinates": [
                            [2.488187573818578, 48.85379557653064],
                            [2.488026151170836, 48.853700386686505],
                            [2.487710794332568, 48.85351465379882],
                            [2.486210503444546, 48.85263443581719],
                            [2.485533409726901, 48.85223693957022],
                            [2.48495734041789, 48.851897761377344],
                            [2.48376565257618, 48.851201462680834],
                            [2.483275607940306, 48.85091432345643],
                            [2.483038092901158, 48.850774340602065],
                            [2.48191783300419, 48.85017628518955],
                            [2.480971707757251, 48.84964926996462],
                            [2.480054724805599, 48.84918010801709],
                            [2.479499383003342, 48.84891641609899],
                            [2.478886748596456, 48.8486285124882],
                            [2.478667078396267, 48.848526268346454],
                            [2.478227730268892, 48.84831818139092],
                            [2.477698340004548, 48.84806973631689],
                            [2.477385889901806, 48.84792174047433],
                            [2.477137570633965, 48.84780514060543],
                            [2.476747352711748, 48.84762036877412],
                            [2.476196147110223, 48.84736115155709],
                            [2.475895983562817, 48.847218533223426],
                            [2.47551942336589, 48.84704183387312],
                            [2.475091018731824, 48.846840016371864],
                            [2.474769032778936, 48.846687528845735],
                            [2.474545282127779, 48.846581684960434],
                            [2.47428742459903, 48.846459694054694],
                            [2.473879474918706, 48.84626054488012],
                            [2.473766229315843, 48.84620402635157],
                            [2.473545198103419, 48.84609457980709],
                            [2.473277776819685, 48.84596180723225],
                            [2.472800246764779, 48.84572586757133],
                            [2.472459156848068, 48.84555720905356],
                            [2.471757883431485, 48.845210920009016],
                            [2.471340392906684, 48.845002781096326],
                            [2.470333380753157, 48.84444910962284],
                            [2.470184662276157, 48.8443719460013],
                            [2.469748053972886, 48.8441422401421],
                            [2.469506306450234, 48.844036034224786],
                            [2.46920679614395, 48.84392217346711],
                            [2.468878526048441, 48.8438368978605],
                            [2.468512637464665, 48.84376058174031],
                            [2.468090075933323, 48.84368642908167],
                            [2.467609025361742, 48.843614702805816],
                            [2.467096487269306, 48.84355267683406],
                            [2.466749207003489, 48.843535700970456],
                            [2.466381174362278, 48.84354539804679],
                            [2.465990352868966, 48.84358085763241],
                            [2.465576208259491, 48.84364163283772],
                            [2.465066853243504, 48.843722242414984],
                            [2.464298733820078, 48.843844505927976],
                            [2.46362127531146, 48.843961793805214],
                            [2.463283999721662, 48.844017369292494],
                            [2.462476869783194, 48.844162925469625],
                            [2.461697053166161, 48.844305524221596],
                        ],
                    },
                },
                87: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.9712674260537, 2.038578397804256],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1732.17472117,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.027518775677185,
                            48.969987572193546,
                            2.049083121493801,
                            48.97482086455293,
                        ),
                        "coordinates": [
                            [2.027518775677185, 48.9703669339495],
                            [2.029697735715853, 48.97014792031068],
                            [2.030373941673409, 48.97008787285684],
                            [2.031039229438515, 48.97003968591812],
                            [2.031639332769309, 48.97001273643106],
                            [2.032196021539893, 48.96999280693307],
                            [2.032911640449786, 48.969987572193546],
                            [2.033457328587801, 48.96999377966578],
                            [2.033999358836002, 48.97000711357591],
                            [2.034530503128254, 48.97002755355511],
                            [2.035216893226258, 48.97007457236039],
                            [2.03578037484953, 48.970126024583394],
                            [2.036574972096633, 48.970209011235376],
                            [2.037271934473995, 48.97030125490967],
                            [2.037874905379498, 48.970398006789445],
                            [2.038542804221758, 48.97051633938152],
                            [2.039167293932286, 48.97064169376353],
                            [2.039809727171332, 48.97078850445559],
                            [2.040462908289185, 48.970951993196294],
                            [2.041307230331253, 48.97118497667782],
                            [2.041862781201672, 48.971357723212584],
                            [2.042483183086317, 48.97156632525577],
                            [2.043060203455286, 48.97177719392779],
                            [2.043669589789665, 48.97201669316724],
                            [2.044217597282537, 48.97224651653825],
                            [2.044794323339983, 48.97250971929899],
                            [2.045219540670145, 48.97272494466729],
                            [2.045716765166938, 48.9729879424503],
                            [2.046866063316261, 48.973614253996054],
                            [2.047906545527419, 48.97417623188714],
                            [2.049083121493801, 48.97482086455293],
                        ],
                    },
                },
                88: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84134815056841, 2.5363336873994156],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1803.93829,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.525922546560017,
                            48.84069774811574,
                            2.547775189299494,
                            48.844901139612055,
                        ),
                        "coordinates": [
                            [2.547775189299494, 48.84084343185482],
                            [2.547773029603954, 48.84084344797284],
                            [2.54618117540151, 48.84083781171269],
                            [2.543440733613217, 48.840798546376256],
                            [2.541135049724195, 48.84076700317546],
                            [2.538076724435698, 48.840738170325515],
                            [2.536372354265205, 48.840718318676],
                            [2.534760990146147, 48.840699708334746],
                            [2.534244073628467, 48.84069774811574],
                            [2.533481044941964, 48.84071750860806],
                            [2.532988025695994, 48.84075972316447],
                            [2.532760605880169, 48.8407852930702],
                            [2.532518231831299, 48.84081898188953],
                            [2.532009062539633, 48.84091247945275],
                            [2.531755865658337, 48.840965969429725],
                            [2.531246841659047, 48.84109723248938],
                            [2.530751550532498, 48.84125724727861],
                            [2.530501226101306, 48.84134939808981],
                            [2.530278144570199, 48.84144060400809],
                            [2.529912301038834, 48.84160669048067],
                            [2.529667537311592, 48.84172850661931],
                            [2.529411950969205, 48.841870124705345],
                            [2.529069417115513, 48.84207663693751],
                            [2.528857455476507, 48.842226274147826],
                            [2.528694415089344, 48.84234345466786],
                            [2.52824083468265, 48.84272640983125],
                            [2.527849830056378, 48.8430858772645],
                            [2.527528107609016, 48.84339396833171],
                            [2.527194168671096, 48.84371466939725],
                            [2.526826223462014, 48.84405161206988],
                            [2.526281808823845, 48.8445615088763],
                            [2.525922546560017, 48.844901139612055],
                        ],
                    },
                },
                89: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.83874110958538, 2.6441525461550777],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1637.12771627,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.633210913417633,
                            48.83817971021005,
                            2.655130086641314,
                            48.83964551726302,
                        ),
                        "coordinates": [
                            [2.655130086641314, 48.83964551726302],
                            [2.652211455711688, 48.83930717285293],
                            [2.650693528078407, 48.83913052568535],
                            [2.649022744125503, 48.838948564239935],
                            [2.645580122660524, 48.8385581943891],
                            [2.643334027455206, 48.83831629209087],
                            [2.642555693464354, 48.83824463832884],
                            [2.641800692607114, 48.83820079415843],
                            [2.640939570114344, 48.83817971021005],
                            [2.640401456961091, 48.83818114253053],
                            [2.63958011098775, 48.83820400783997],
                            [2.638991783321358, 48.83823704108516],
                            [2.638569664272801, 48.83827053238254],
                            [2.638127306838617, 48.838307813762086],
                            [2.637604410180904, 48.83837649748911],
                            [2.637057220089383, 48.83845437747083],
                            [2.636421770609677, 48.8385673705528],
                            [2.635897791311999, 48.83866785335885],
                            [2.634568389656018, 48.83893661760156],
                            [2.634085353299929, 48.839036797533204],
                            [2.633210913417633, 48.83921929995164],
                        ],
                    },
                },
                90: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.987580197609205, 1.827066751252897],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2859.41441828,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.808907828712391,
                            48.98297976320563,
                            1.845134443502388,
                            48.992241629671234,
                        ),
                        "coordinates": [
                            [1.808907828712391, 48.98297976320563],
                            [1.814186700328448, 48.98426983899382],
                            [1.817093127672203, 48.984975485028244],
                            [1.830703012666158, 48.98830102949521],
                            [1.833822661788837, 48.9890619165253],
                            [1.834522231246966, 48.98924344293764],
                            [1.835091823233133, 48.98940774141917],
                            [1.835632348833083, 48.98958618445617],
                            [1.836215878498463, 48.98980288592875],
                            [1.836878424452741, 48.99007227475576],
                            [1.838523288626669, 48.99081468162012],
                            [1.839149631768785, 48.99109103808666],
                            [1.839617786325658, 48.99127866461101],
                            [1.840046481930515, 48.99143518747165],
                            [1.840489814688565, 48.99157511592291],
                            [1.840890015633595, 48.99168868284594],
                            [1.841431067858026, 48.99181951369095],
                            [1.841986697410191, 48.991938507597496],
                            [1.8425461638335, 48.99203610276609],
                            [1.843163547288799, 48.99212680478414],
                            [1.843683670107396, 48.99218139359167],
                            [1.844265424092584, 48.99221959223536],
                            [1.844963045003878, 48.992241629671234],
                            [1.845134443502388, 48.99224128128681],
                        ],
                    },
                },
                91: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.86785107035018, 2.2734975381145786],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 777.471132319,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272120138879799,
                            48.86446175107751,
                            2.275574526847743,
                            48.870974138193766,
                        ),
                        "coordinates": [
                            [2.272120621598503, 48.86446175107751],
                            [2.272120138879799, 48.864832008903306],
                            [2.272127086099549, 48.86516816878753],
                            [2.272163569125495, 48.86550434450914],
                            [2.272214899155489, 48.86578206710471],
                            [2.272288388108724, 48.866054931140674],
                            [2.272369331895322, 48.86627420847161],
                            [2.272457630000423, 48.86651784975745],
                            [2.272538613999333, 48.86670789551702],
                            [2.272619611938358, 48.866888198604066],
                            [2.272884906318504, 48.867317067758115],
                            [2.273400973685293, 48.86798966628254],
                            [2.273998189559551, 48.86874025664755],
                            [2.27455946771283, 48.869459209571225],
                            [2.274571714316648, 48.86947720241366],
                            [2.27497038321126, 48.870072738979324],
                            [2.275170399511087, 48.87037230540044],
                            [2.275179923655839, 48.870386699575334],
                            [2.27543166144265, 48.87075463855705],
                            [2.275574526847743, 48.870974138193766],
                        ],
                    },
                },
                92: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.93220401222064, 2.485593854073034],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 1453.79505853,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.475674370833512,
                            48.93212901293364,
                            2.495513142584314,
                            48.93230541606912,
                        ),
                        "coordinates": [
                            [2.475674370833512, 48.93230541606912],
                            [2.476163709743931, 48.93230003707236],
                            [2.477409636592118, 48.93228483173492],
                            [2.478716297186294, 48.9322688686431],
                            [2.480597999968426, 48.932242802188085],
                            [2.485909369257553, 48.93219180371595],
                            [2.488602667950408, 48.93216023242055],
                            [2.490988334468279, 48.93212901293364],
                            [2.493681829925758, 48.932162007084386],
                            [2.49440185171253, 48.932173955094534],
                            [2.495513142584314, 48.93219600596196],
                        ],
                    },
                },
                93: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.716884021644645, 2.4470935220619707],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 3717.07077233,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.438093383889102,
                            48.70823782858165,
                            2.462282244689792,
                            48.73011683142026,
                        ),
                        "coordinates": [
                            [2.462282244689792, 48.70823782858165],
                            [2.460983910433233, 48.70879460381943],
                            [2.460264468713545, 48.70910940162476],
                            [2.45989156299872, 48.70928770107002],
                            [2.459540394511254, 48.70947546745735],
                            [2.459186371898107, 48.70968137901128],
                            [2.458828870992446, 48.70990805478701],
                            [2.4581193284077, 48.710365645385814],
                            [2.45788462065311, 48.71051697335805],
                            [2.4573934369007, 48.710810659335635],
                            [2.457066390778859, 48.71098996065503],
                            [2.456146253745974, 48.71147204257776],
                            [2.455711881415892, 48.71166494265567],
                            [2.455406437124127, 48.711790260756786],
                            [2.45442359216518, 48.71220045254005],
                            [2.453762414097586, 48.71245293242585],
                            [2.451625523919498, 48.7133130196957],
                            [2.451142189484145, 48.713502354460644],
                            [2.450760658087116, 48.713643024944055],
                            [2.450474138316585, 48.713735037731645],
                            [2.45012376227197, 48.71383340884293],
                            [2.449712228421354, 48.71392914211516],
                            [2.449243587887568, 48.71401144056516],
                            [2.448787122355311, 48.71407034461838],
                            [2.448427319688785, 48.7141076013759],
                            [2.448015377294803, 48.71412506080166],
                            [2.447647093473568, 48.71411822694539],
                            [2.446926798726546, 48.71408835290434],
                            [2.446281276317311, 48.714072790965105],
                            [2.445407435106446, 48.71404755225977],
                            [2.44471845892446, 48.7140464104308],
                            [2.444150481297779, 48.714070330422494],
                            [2.443659987170575, 48.714105865696325],
                            [2.443169542254486, 48.71416477873885],
                            [2.442869323816343, 48.714213620946566],
                            [2.442552623224028, 48.71426550651059],
                            [2.442255364780425, 48.71434368775591],
                            [2.441614354305444, 48.71453582667013],
                            [2.441231430498669, 48.71467646649414],
                            [2.440803740234079, 48.714856713288114],
                            [2.440404624068385, 48.71505491884784],
                            [2.44005715933288, 48.71526026876353],
                            [2.439504846271283, 48.715639363933136],
                            [2.439275602654027, 48.715844604756086],
                            [2.439032833066198, 48.71608133259323],
                            [2.438822682066663, 48.71632072727946],
                            [2.438653267876831, 48.71654479851283],
                            [2.438431101762117, 48.716906959958216],
                            [2.438249711512178, 48.71729614086154],
                            [2.438178333422549, 48.717559518330255],
                            [2.438116704366139, 48.7179021951341],
                            [2.438093383889102, 48.71822263243712],
                            [2.438108347463893, 48.71850813798271],
                            [2.43815434831925, 48.7187313567867],
                            [2.438233522983043, 48.71911851748304],
                            [2.438364435249654, 48.7194806567947],
                            [2.43852495245468, 48.71982326862533],
                            [2.438704570856386, 48.720127660535574],
                            [2.43895095254639, 48.72041813306976],
                            [2.439645733248798, 48.72115958316324],
                            [2.43999873658582, 48.72144716199589],
                            [2.440384148210437, 48.72175374324625],
                            [2.440884786413756, 48.722131597580464],
                            [2.441352983723824, 48.722469032149334],
                            [2.441752777144327, 48.72276607883646],
                            [2.442040937787661, 48.72298946892722],
                            [2.44223548143611, 48.72315584184236],
                            [2.442469725183576, 48.72338879718654],
                            [2.442657165211647, 48.7235956239343],
                            [2.442844687405979, 48.72384051987785],
                            [2.443028625997199, 48.724090176611114],
                            [2.443194594919307, 48.72434460977975],
                            [2.4434291891175, 48.724736978193924],
                            [2.443839778338836, 48.725681117140645],
                            [2.444123624612847, 48.726203326118146],
                            [2.444202786960045, 48.7263543286648],
                            [2.444305117491671, 48.726533186922836],
                            [2.444408805593823, 48.72671114474048],
                            [2.444523377410538, 48.72689268881358],
                            [2.444943425580544, 48.72755208104018],
                            [2.44541690109799, 48.728360348361576],
                            [2.445687086449872, 48.72883670349414],
                            [2.445830415179587, 48.72911084413214],
                            [2.445921963217562, 48.72932658073056],
                            [2.446005440453732, 48.729580994507565],
                            [2.446054793282373, 48.72977069404581],
                            [2.446105500724956, 48.729957693392315],
                            [2.446135830934545, 48.73011683142026],
                        ],
                    },
                },
                94: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.4003702698243, 2.7405343694033517],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4402.83068922,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.725685583605634,
                            48.394308438758266,
                            2.764028188787889,
                            48.416377033006604,
                        ),
                        "coordinates": [
                            [2.764028188787889, 48.394308438758266],
                            [2.763126578901833, 48.394390386630114],
                            [2.762026571127661, 48.39448100457268],
                            [2.760321297610465, 48.3946230434602],
                            [2.758757356663343, 48.39474759230496],
                            [2.757649500724457, 48.394835351208386],
                            [2.753678371873878, 48.39517199467734],
                            [2.752523311883279, 48.39526886970745],
                            [2.75101743052066, 48.39539754823184],
                            [2.749543910243132, 48.395521684086276],
                            [2.748745012052305, 48.39558124961076],
                            [2.748059966033951, 48.39564154114412],
                            [2.747513063189951, 48.395690044916485],
                            [2.747003836064991, 48.39573429195899],
                            [2.746101646752111, 48.39581476324794],
                            [2.74517120107466, 48.39591275726854],
                            [2.74437895638145, 48.39602061988101],
                            [2.743765304410223, 48.396112755611945],
                            [2.742972482153477, 48.396257688308985],
                            [2.741899604358853, 48.39648365581718],
                            [2.740933356187616, 48.39671264009034],
                            [2.740403476486886, 48.3968460067594],
                            [2.739554684237278, 48.39708643592351],
                            [2.738666117220153, 48.397361251998305],
                            [2.737850994699494, 48.397650927942905],
                            [2.737066146164455, 48.397954059624844],
                            [2.736215541808712, 48.398310473739144],
                            [2.735514659130686, 48.3986465701702],
                            [2.73494568923817, 48.39893004162216],
                            [2.733783993354781, 48.39956899964746],
                            [2.732651236450351, 48.40028518015406],
                            [2.732374577850641, 48.40047948761717],
                            [2.732028077394721, 48.40072259821432],
                            [2.731342022896275, 48.40123487101453],
                            [2.730699324796302, 48.40176677257546],
                            [2.730068993722046, 48.402327403324286],
                            [2.729892050597703, 48.40249617967574],
                            [2.729666202231323, 48.402718855628486],
                            [2.729500733563992, 48.402883319327145],
                            [2.729119019656139, 48.40329020825842],
                            [2.72868944749457, 48.40379528004186],
                            [2.728181286937066, 48.40444180490654],
                            [2.727844643400242, 48.404915977642744],
                            [2.727568375879036, 48.40533958208344],
                            [2.727244435845665, 48.40588564973888],
                            [2.726944888618034, 48.406443322325785],
                            [2.726691253507572, 48.406999287830935],
                            [2.72659562693465, 48.40720889280618],
                            [2.726526744637031, 48.40738268714426],
                            [2.726336260139316, 48.407898616450986],
                            [2.726181693915671, 48.408344279214546],
                            [2.725995032288738, 48.409005874160734],
                            [2.725942750976443, 48.40923086816349],
                            [2.725909358202428, 48.409396668539735],
                            [2.725868777010266, 48.40961960137255],
                            [2.725808126471974, 48.40998490749837],
                            [2.725746424715627, 48.41038888472404],
                            [2.725685583605634, 48.41125237992094],
                            [2.725685950470871, 48.41182250615781],
                            [2.72569692547183, 48.412094060132304],
                            [2.725712845366715, 48.41232959417772],
                            [2.725730315681396, 48.41249229905219],
                            [2.725751985051398, 48.41267387404075],
                            [2.725798115494479, 48.413209447058115],
                            [2.72586359520443, 48.41381831824005],
                            [2.725942597037732, 48.41432721450449],
                            [2.726038806308719, 48.414750395910374],
                            [2.726141499049052, 48.41508790161538],
                            [2.726525245192769, 48.41605691116175],
                            [2.726661533081673, 48.416377033006604],
                        ],
                    },
                },
                95: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.878150523525754, 2.6718618432719228],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 5106.56513654,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.637590717167975,
                            48.87520826545471,
                            2.706014179759928,
                            48.8821891367053,
                        ),
                        "coordinates": [
                            [2.637590717167975, 48.87520826545471],
                            [2.639501827967145, 48.87529591500355],
                            [2.641728063574485, 48.87538206469342],
                            [2.642860912098314, 48.87542258609675],
                            [2.644592904687644, 48.875508348157425],
                            [2.645740306052573, 48.87555759715815],
                            [2.646847971766107, 48.87559742442043],
                            [2.648197452884676, 48.87565799533788],
                            [2.650239784360432, 48.875759480792986],
                            [2.651527983023901, 48.875824940472356],
                            [2.652693479845031, 48.87588120718402],
                            [2.654032184690428, 48.87594649862967],
                            [2.655002820985922, 48.87599138595938],
                            [2.658041477654103, 48.87613856290198],
                            [2.659874089851316, 48.87621802751477],
                            [2.661779253654797, 48.876298279687475],
                            [2.663781960604314, 48.87639963597834],
                            [2.66670141427873, 48.87654575534861],
                            [2.667853296516822, 48.876610948266325],
                            [2.668444902453116, 48.87665638116822],
                            [2.669067415276588, 48.87671021522502],
                            [2.669631968750593, 48.876769432162604],
                            [2.670175480945566, 48.876835662451896],
                            [2.670679473282603, 48.87690548312522],
                            [2.671257387461126, 48.876990735437936],
                            [2.671943587250825, 48.87710522699537],
                            [2.672582326610504, 48.877218115328304],
                            [2.673213265600698, 48.877346673729996],
                            [2.673828414690495, 48.877478752432765],
                            [2.674681265399872, 48.87767446280215],
                            [2.67706832449245, 48.87823598321064],
                            [2.681074115056026, 48.87917165785329],
                            [2.683553734313555, 48.879753630437634],
                            [2.684224475693452, 48.8799098281598],
                            [2.684768429176102, 48.88003163238509],
                            [2.685285925293604, 48.8801396015488],
                            [2.686001384905116, 48.88028000340225],
                            [2.686925294353807, 48.88044410523126],
                            [2.689005393083607, 48.8808080890086],
                            [2.689865839666754, 48.88094280261593],
                            [2.690623294172337, 48.88105348419797],
                            [2.691562729337255, 48.88117229023932],
                            [2.6926339902513, 48.88129067917066],
                            [2.693689288654845, 48.88138824005221],
                            [2.694607306828951, 48.88146013950243],
                            [2.696142508184224, 48.88156486880858],
                            [2.699260271915324, 48.88175846503482],
                            [2.704285183743431, 48.882078003297934],
                            [2.706014179759928, 48.8821891367053],
                        ],
                    },
                },
                96: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.876525173157034, 2.484881107387862],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1461.41150809,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.481421258690829,
                            48.86991241918608,
                            2.48624016101661,
                            48.88230400665456,
                        ),
                        "coordinates": [
                            [2.481421258690829, 48.88230400665456],
                            [2.482002110276723, 48.88167667369007],
                            [2.482400360106924, 48.88124631151913],
                            [2.482536273619913, 48.881097757575006],
                            [2.482896410749996, 48.880692622043405],
                            [2.483300285140525, 48.880235879488275],
                            [2.483961905991979, 48.87950457051255],
                            [2.484256765404425, 48.879182977480575],
                            [2.484468884423603, 48.878940011218695],
                            [2.484702474556856, 48.878639910392906],
                            [2.484878905805151, 48.87839870704009],
                            [2.485048557720638, 48.87813859564237],
                            [2.485198031495068, 48.87788025697987],
                            [2.485346909474769, 48.87760313675325],
                            [2.485459426487179, 48.87738716326004],
                            [2.485547415677536, 48.877175718432],
                            [2.485670460790816, 48.876833832459134],
                            [2.485760458163955, 48.876568504929374],
                            [2.485814032566226, 48.876389983656146],
                            [2.485906886925282, 48.8760781686341],
                            [2.485963930603088, 48.87585443509884],
                            [2.486017418568939, 48.8756473624002],
                            [2.486070768650098, 48.875395081796675],
                            [2.486120447842253, 48.87512139221512],
                            [2.486184326312482, 48.874771543890645],
                            [2.486226431624454, 48.87437889660741],
                            [2.48624016101661, 48.87414570285082],
                            [2.486239460219678, 48.87391252805102],
                            [2.486227988061312, 48.87369602184562],
                            [2.48610475195852, 48.87229474845391],
                            [2.486056305620401, 48.87177611417295],
                            [2.486011674208813, 48.8713264762644],
                            [2.485916040919188, 48.870707970752974],
                            [2.485761140611789, 48.86991241918608],
                        ],
                    },
                },
                97: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.74558913351448, 2.7283573369901104],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 253.938046092,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.727229371429766,
                            48.74472077575101,
                            2.729481333043577,
                            48.746452320704556,
                        ),
                        "coordinates": [
                            [2.727229371429766, 48.746452320704556],
                            [2.728179796656208, 48.74572975657104],
                            [2.729481333043577, 48.74472077575101],
                        ],
                    },
                },
                98: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.85533359324683, 2.368649449128164],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 460.881116057,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368108289338497,
                            48.8534394275684,
                            2.369513568156525,
                            48.857420037539946,
                        ),
                        "coordinates": [
                            [2.369513568156525, 48.8534394275684],
                            [2.369409437789544, 48.85350300354124],
                            [2.369313185593906, 48.85357177603231],
                            [2.369225406852815, 48.853645318307535],
                            [2.36914664263279, 48.85372317996379],
                            [2.369077379891992, 48.8538048779355],
                            [2.369018040392512, 48.85388991172466],
                            [2.3689689944358, 48.853977754479],
                            [2.368930547081431, 48.85406786551022],
                            [2.368904564899556, 48.85415298071665],
                            [2.368505159064627, 48.85576200323284],
                            [2.368234848429127, 48.85689131913541],
                            [2.368108289338497, 48.857420037539946],
                        ],
                    },
                },
                99: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.865296479071255, 2.2888202381938845],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 416.736921337,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.287580162529652,
                            48.86361093764567,
                            2.290058833580487,
                            48.86698310944948,
                        ),
                        "coordinates": [
                            [2.290058833580487, 48.86698310944948],
                            [2.289730290058539, 48.86653268808891],
                            [2.28795952649392, 48.864126475049915],
                            [2.287768624731509, 48.863869120171074],
                            [2.287646011085742, 48.86370114697349],
                            [2.287580162529652, 48.86361093764567],
                        ],
                    },
                },
                100: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.642800403579216, 2.3970882627789267],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2704.34749206,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.391689078843198,
                            48.63635136710195,
                            2.407796286173906,
                            48.65396975838212,
                        ),
                        "coordinates": [
                            [2.39617681244956, 48.65396975838212],
                            [2.395864101010868, 48.653518490020446],
                            [2.395458939069624, 48.65292968134022],
                            [2.395239316582994, 48.65260545624076],
                            [2.394940922720937, 48.65215837725698],
                            [2.394562949858908, 48.65158843593755],
                            [2.394156424820623, 48.65096724961034],
                            [2.393767579145324, 48.650367635322716],
                            [2.392841130134514, 48.648936312722356],
                            [2.392520884273106, 48.6484438262315],
                            [2.39231987647181, 48.64813195496308],
                            [2.392183040382199, 48.64791500761341],
                            [2.392037078500611, 48.647659555827914],
                            [2.391944853857916, 48.64745969433567],
                            [2.391844566074487, 48.64719598837524],
                            [2.391787770467719, 48.646979280642384],
                            [2.39171271573646, 48.64660252402962],
                            [2.391689078843198, 48.646088156185264],
                            [2.391703738547119, 48.64584534752414],
                            [2.391737373089843, 48.645580048025046],
                            [2.391784606952316, 48.64534082007902],
                            [2.391938706222179, 48.644793992316636],
                            [2.392055108655321, 48.64452055868223],
                            [2.392202704490011, 48.64423272177893],
                            [2.392378495723339, 48.64395832412358],
                            [2.392537313450767, 48.643717279037446],
                            [2.392762269197696, 48.64344289208505],
                            [2.393014354857973, 48.64316219605001],
                            [2.39337220921782, 48.642816700866675],
                            [2.394325141387599, 48.64192594901282],
                            [2.394605152743046, 48.641662659277436],
                            [2.394976729423956, 48.641313734056276],
                            [2.395935416001102, 48.640413455645955],
                            [2.39654675946726, 48.63988976293397],
                            [2.396900566429323, 48.63960270989555],
                            [2.397406375167309, 48.6392119269203],
                            [2.397720723104093, 48.638976384060314],
                            [2.398332148508299, 48.638548903472746],
                            [2.399088668369362, 48.63805749156287],
                            [2.399781492121971, 48.637638950269945],
                            [2.400094710694295, 48.63747151211496],
                            [2.400471679051141, 48.63729144718596],
                            [2.400807987420308, 48.63714737405335],
                            [2.401233825666714, 48.636988861142434],
                            [2.401593225070181, 48.636867254845754],
                            [2.401996052478821, 48.63675461416553],
                            [2.402397531674984, 48.63665006641713],
                            [2.402696725458449, 48.63659203943385],
                            [2.402926550812501, 48.63654724139136],
                            [2.403265675028598, 48.63648859003345],
                            [2.403523420362856, 48.636453365728094],
                            [2.403872066083513, 48.636413591725606],
                            [2.404394378400966, 48.63637191364101],
                            [2.405056478448452, 48.636357126288175],
                            [2.406261317369262, 48.63635549194504],
                            [2.407796286173906, 48.63635136710195],
                        ],
                    },
                },
                101: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.624572448151746, 2.4400913938885833],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1722.12779576,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.428738987337901,
                            48.62315996513932,
                            2.451409095593275,
                            48.62602242896445,
                        ),
                        "coordinates": [
                            [2.428738987337901, 48.62602242896445],
                            [2.428742301467787, 48.62602213092529],
                            [2.42916663667279, 48.625984041126706],
                            [2.430155386011357, 48.6259013949163],
                            [2.43099629559297, 48.6258314534492],
                            [2.431781593578669, 48.62576604962319],
                            [2.432153221002561, 48.62573606061387],
                            [2.433009043722516, 48.62566429334606],
                            [2.433615305311759, 48.625613416807894],
                            [2.434155099641001, 48.62556349337359],
                            [2.436996542166473, 48.62534248914052],
                            [2.43763669817619, 48.625286165422374],
                            [2.438209008928098, 48.62522090625164],
                            [2.438771789928664, 48.625139465578904],
                            [2.43930741900475, 48.62504815529787],
                            [2.439715550758611, 48.62496415334572],
                            [2.44030262647675, 48.62482692872933],
                            [2.440769353361479, 48.62469820342291],
                            [2.44107627687062, 48.624605715816685],
                            [2.441618915868571, 48.62441654996222],
                            [2.443183106310344, 48.62386114223498],
                            [2.443723960267897, 48.62368617448034],
                            [2.444184876614605, 48.6235562437341],
                            [2.444631595810533, 48.62345389098151],
                            [2.444988864230892, 48.623376523226035],
                            [2.445512258091159, 48.62328699364285],
                            [2.445944788251775, 48.62323704186018],
                            [2.446338377141303, 48.62320265456813],
                            [2.44668804813741, 48.62317344921166],
                            [2.447087025781402, 48.62315996513932],
                            [2.447326908237569, 48.623162035582666],
                            [2.447762367852635, 48.62318049332132],
                            [2.448049961623548, 48.62319280061602],
                            [2.448286004453629, 48.62320246040809],
                            [2.448630080129199, 48.6232166596575],
                            [2.448977856634347, 48.62323145162825],
                            [2.449340621993819, 48.62324589180375],
                            [2.449665638963876, 48.62325954388407],
                            [2.450099743361497, 48.623277994002464],
                            [2.450468732213283, 48.623292911932346],
                            [2.451409095593275, 48.62333224107223],
                        ],
                    },
                },
                102: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.66108419196308, 2.3992329530942507],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1691.41810349,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.39617681244956,
                            48.65396975838212,
                            2.401016156351858,
                            48.667915766467786,
                        ),
                        "coordinates": [
                            [2.397532093159732, 48.667915766467786],
                            [2.39888154121098, 48.666765773934685],
                            [2.399186655764104, 48.66648323608973],
                            [2.39941600821206, 48.666269946615714],
                            [2.39971820317037, 48.66597305914164],
                            [2.399865324181742, 48.66580642885111],
                            [2.40004904206656, 48.66557198602677],
                            [2.400188396378808, 48.66538058994313],
                            [2.4003936306488, 48.66505824352663],
                            [2.400575963959229, 48.6647181010123],
                            [2.400678840861131, 48.664484233643506],
                            [2.400777562284033, 48.664188318616596],
                            [2.400882976550303, 48.66381776078706],
                            [2.400953025241312, 48.66351056106398],
                            [2.400989938403034, 48.66321518322503],
                            [2.401016156351858, 48.662873455280376],
                            [2.401013098175372, 48.662607273825195],
                            [2.400975960555513, 48.662195357856845],
                            [2.400929407712837, 48.661922080086164],
                            [2.400788833236759, 48.66133583812131],
                            [2.400595318205693, 48.6607487259052],
                            [2.40036527496261, 48.66025336004428],
                            [2.400188814020248, 48.659944907763176],
                            [2.399772197466639, 48.65928248417143],
                            [2.399141142366588, 48.658318818597024],
                            [2.397741828610799, 48.65624047535344],
                            [2.397718711885923, 48.65620631502295],
                            [2.39766431784046, 48.656124511818625],
                            [2.397419550586035, 48.65575954035897],
                            [2.396905592852952, 48.655026012462905],
                            [2.39617681244956, 48.65396975838212],
                        ],
                    },
                },
                103: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.62256121614571, 2.4609490265889007],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1460.71349754,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.451409095593275,
                            48.620290259939715,
                            2.470234997616056,
                            48.62351258610026,
                        ),
                        "coordinates": [
                            [2.451409095593275, 48.62333224107223],
                            [2.453114062864075, 48.62340352973044],
                            [2.453693772210745, 48.62342684048099],
                            [2.454192545172785, 48.62344737851048],
                            [2.455228983102236, 48.62349305994019],
                            [2.455911319900418, 48.62351032928923],
                            [2.456329113521387, 48.62351258610026],
                            [2.456781489060409, 48.62350569990087],
                            [2.45721886040086, 48.62347657126055],
                            [2.457696497870699, 48.623433346227365],
                            [2.458213156556097, 48.62337093095124],
                            [2.458730833430602, 48.62328340787198],
                            [2.45950178514217, 48.623126956610925],
                            [2.461484388251039, 48.62272735838829],
                            [2.462029393479884, 48.622615248121264],
                            [2.46285367774219, 48.622447069477104],
                            [2.46387048942235, 48.62224809319325],
                            [2.46449274961663, 48.62211699941729],
                            [2.464899463272262, 48.62203470662792],
                            [2.465598997835206, 48.62188913007324],
                            [2.46637734294892, 48.6217320477142],
                            [2.46690719694398, 48.62160706321074],
                            [2.467255564999587, 48.62152033281481],
                            [2.467639513736466, 48.62140772462234],
                            [2.467940077309812, 48.62131493612504],
                            [2.468166285161286, 48.621239105511755],
                            [2.468408885208123, 48.621150298236955],
                            [2.46860069468404, 48.621079927186024],
                            [2.468786922021146, 48.6210005797618],
                            [2.46902310495756, 48.620903754830834],
                            [2.469303113917114, 48.620777857798295],
                            [2.46963498155279, 48.620611104369736],
                            [2.470234997616056, 48.620290259939715],
                        ],
                    },
                },
                104: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.89254031037891, 2.4936512587466804],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 854.883281953,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.487910986261173,
                            48.89221962480339,
                            2.499388457291095,
                            48.893094628632376,
                        ),
                        "coordinates": [
                            [2.487910986261173, 48.893094628632376],
                            [2.488874894937666, 48.89295227248385],
                            [2.490249091498063, 48.89275057105122],
                            [2.490580920786352, 48.892702539048415],
                            [2.490937998983932, 48.89265209089862],
                            [2.491251812725068, 48.89261359677553],
                            [2.49152597788434, 48.89258943306217],
                            [2.491814597004557, 48.89257238694861],
                            [2.492164577896476, 48.89256001509356],
                            [2.492640879139245, 48.89255698712453],
                            [2.493340896319599, 48.89255127349638],
                            [2.493662020000235, 48.89254369439483],
                            [2.4939181781454, 48.892531444966025],
                            [2.494242860800842, 48.89250720524032],
                            [2.494535059760832, 48.892480629610986],
                            [2.494830849293523, 48.8924492894826],
                            [2.49586241754877, 48.89231223465382],
                            [2.496219525580559, 48.89227366876907],
                            [2.496663241386505, 48.89223735893589],
                            [2.497085369617848, 48.89222011120564],
                            [2.497431773305663, 48.89221962480339],
                            [2.49776016104334, 48.89222630128547],
                            [2.49803447200481, 48.89224970938686],
                            [2.49831965180608, 48.892284996413224],
                            [2.498594028247652, 48.8923274373981],
                            [2.498875669452198, 48.892384142428924],
                            [2.499388457291095, 48.89250476140823],
                        ],
                    },
                },
                105: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.919152572940746, 2.515110202237391],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 678.653166425,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.514613744110568,
                            48.91609650409271,
                            2.516443536539131,
                            48.92192614328582,
                        ),
                        "coordinates": [
                            [2.515061446192154, 48.91609650409271],
                            [2.514786506793893, 48.91694636095778],
                            [2.514740213707818, 48.91712488455638],
                            [2.514686894357189, 48.9173581444992],
                            [2.514644499075632, 48.91761756124888],
                            [2.514620088132031, 48.91785791214176],
                            [2.514613744110568, 48.918102996280666],
                            [2.514618315540905, 48.91837185677805],
                            [2.514640938729763, 48.918640688718014],
                            [2.514666952844916, 48.91884765259214],
                            [2.514718346213276, 48.91908550809684],
                            [2.514769640574127, 48.91929481257573],
                            [2.51483902281828, 48.91951360396429],
                            [2.514919234965931, 48.919732380658914],
                            [2.515006635097069, 48.919941627838206],
                            [2.515093950629235, 48.920127080364644],
                            [2.515210270746824, 48.92034580141876],
                            [2.51534465996286, 48.920569250103604],
                            [2.515482607054773, 48.9207784188352],
                            [2.515613279952619, 48.92097094366411],
                            [2.515772859697456, 48.92117055909289],
                            [2.515975912602574, 48.92141055691074],
                            [2.516443536539131, 48.92192614328582],
                        ],
                    },
                },
                106: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.89980621144714, 2.5090421101655718],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 705.703383802,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.506408247006797,
                            48.89714381938228,
                            2.51169930327069,
                            48.902444190569966,
                        ),
                        "coordinates": [
                            [2.506408247006797, 48.89714381938228],
                            [2.507773417232102, 48.89850039620572],
                            [2.508334785347305, 48.89907773770559],
                            [2.508787509898089, 48.8995434120482],
                            [2.509830670785831, 48.90063158316465],
                            [2.510189222048285, 48.900992701644164],
                            [2.510395662200781, 48.90119939232473],
                            [2.510841156110496, 48.90165079415016],
                            [2.511116347438255, 48.90190734538039],
                            [2.51169930327069, 48.902444190569966],
                        ],
                    },
                },
                107: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.89354688729754, 2.484127164949328],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 565.011859229,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.480348871695586,
                            48.893094628632376,
                            2.487910986261173,
                            48.89404828420717,
                        ),
                        "coordinates": [
                            [2.480348871695586, 48.89404828420717],
                            [2.4836949740937, 48.89356578082677],
                            [2.484189125106957, 48.893493764010046],
                            [2.484488514781544, 48.89345530730381],
                            [2.484791542810352, 48.89342636311626],
                            [2.485148688840417, 48.89339496820445],
                            [2.48562492116048, 48.89336579789121],
                            [2.485953220372634, 48.89334157637053],
                            [2.486256259975347, 48.89331738767819],
                            [2.486562877903646, 48.89328367547997],
                            [2.486880307537121, 48.89324518852307],
                            [2.48716164566722, 48.89320437163583],
                            [2.487910986261173, 48.893094628632376],
                        ],
                    },
                },
                108: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.832532427607816, 2.2790915346706897],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 395.751175346,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.276712090531075,
                            48.831696593107,
                            2.281470444083868,
                            48.833365343840185,
                        ),
                        "coordinates": [
                            [2.281470444083868, 48.831696593107],
                            [2.28099868136585, 48.83186746926793],
                            [2.280731882060706, 48.83195775363572],
                            [2.280461485830581, 48.83204089719003],
                            [2.280158626569133, 48.83214543881969],
                            [2.278153912295457, 48.83287964041308],
                            [2.278044468341895, 48.83292088723591],
                            [2.277941181806217, 48.83295329067679],
                            [2.277786158129075, 48.83299365860412],
                            [2.277638342225036, 48.833034030290044],
                            [2.277468883965455, 48.83308866738981],
                            [2.276712090531075, 48.833365343840185],
                        ],
                    },
                },
                109: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.83261495987958, 1.8955039383782115],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 5629.25943636,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.877504204313639,
                            48.81532862049073,
                            1.924597779359982,
                            48.838772335396015,
                        ),
                        "coordinates": [
                            [1.877504204313639, 48.81532862049073],
                            [1.87787100730415, 48.815726383929736],
                            [1.878421569306398, 48.81634995032969],
                            [1.878651511889975, 48.81663394610838],
                            [1.878892811372323, 48.816964396163435],
                            [1.879045935011556, 48.81719433005968],
                            [1.879158588822934, 48.81738273390282],
                            [1.879423676068235, 48.81787660767603],
                            [1.879615417570198, 48.818350404056055],
                            [1.879892246605241, 48.819197745440434],
                            [1.879938148944577, 48.81938947853934],
                            [1.879965176819042, 48.81956045197007],
                            [1.880008917410456, 48.81983940690308],
                            [1.88004016075747, 48.82029277485367],
                            [1.880044694493354, 48.82113363025723],
                            [1.880036352548925, 48.82189349764664],
                            [1.880020603068876, 48.823311616623634],
                            [1.880015945084784, 48.82381879844969],
                            [1.879999803881867, 48.825427565803096],
                            [1.879999864901178, 48.82616228701768],
                            [1.880006738413766, 48.82645188606749],
                            [1.880001846728486, 48.827132630097005],
                            [1.880002498239201, 48.82720997142658],
                            [1.880003472730375, 48.827252242307544],
                            [1.879990284389749, 48.82794644194013],
                            [1.879981500397308, 48.82905073693857],
                            [1.879977733132066, 48.82960918141672],
                            [1.879977691009625, 48.829613678187904],
                            [1.879984030070301, 48.830702744579845],
                            [1.879995329268325, 48.83095549099647],
                            [1.880053524906276, 48.83144134152736],
                            [1.880133127308516, 48.83182116132579],
                            [1.880251927889158, 48.83223441101881],
                            [1.880291684347071, 48.832355074927676],
                            [1.880408547314741, 48.83268288448552],
                            [1.8805741008108, 48.833048658502804],
                            [1.880679738710653, 48.8332640119926],
                            [1.880952058988127, 48.833722839251514],
                            [1.881227684535757, 48.834118729329596],
                            [1.881441733725005, 48.83439656471265],
                            [1.881496989898135, 48.83446153455297],
                            [1.881544189790246, 48.83451388199198],
                            [1.881677711340868, 48.83466009957169],
                            [1.881923178747562, 48.83492906699741],
                            [1.882334990421441, 48.8353308922992],
                            [1.882627024932562, 48.83557306481658],
                            [1.883082710867936, 48.83594538571947],
                            [1.88341973156075, 48.83618503775586],
                            [1.883777230103803, 48.836420273005004],
                            [1.884134894807137, 48.836637522818314],
                            [1.884477808558082, 48.83682953182274],
                            [1.88490493763266, 48.83704885262108],
                            [1.88572449313217, 48.8374100124786],
                            [1.886046175416951, 48.83754078213053],
                            [1.886401932152393, 48.83766988579632],
                            [1.886893618010836, 48.83783279821918],
                            [1.887547118482255, 48.838029619927084],
                            [1.888210419085543, 48.83819769891052],
                            [1.888535356133755, 48.83827091884642],
                            [1.888884848174625, 48.83834063697214],
                            [1.889182713369399, 48.83839486413132],
                            [1.889477925939689, 48.83844098638236],
                            [1.890033102632028, 48.838514205256836],
                            [1.890887882379865, 48.83860028341749],
                            [1.891330354785899, 48.83863258685505],
                            [1.892768106915908, 48.83873171662893],
                            [1.892838907306756, 48.838736488650476],
                            [1.893333229945059, 48.83875999331609],
                            [1.893732288561841, 48.838772335396015],
                            [1.89415463429514, 48.8387703774405],
                            [1.894882263335759, 48.83875521118525],
                            [1.895224377263014, 48.838736751164426],
                            [1.895618354691325, 48.83870769892675],
                            [1.896036956033603, 48.838667049742455],
                            [1.896793931650778, 48.838568351558564],
                            [1.897171852980187, 48.83850595831437],
                            [1.897749136141255, 48.83839127300515],
                            [1.898240552772194, 48.83828075165187],
                            [1.898867285886277, 48.838119487402],
                            [1.899525726677632, 48.83791517559326],
                            [1.900101056534674, 48.83771144148132],
                            [1.900185809989112, 48.83767849153344],
                            [1.900254160578375, 48.837651774820735],
                            [1.90076001010163, 48.83744777195684],
                            [1.903020266980627, 48.836491449216375],
                            [1.90397433275486, 48.836125464964276],
                            [1.904485326453057, 48.83595294004234],
                            [1.904934782873284, 48.8358071587669],
                            [1.905422385419095, 48.835660620413584],
                            [1.905845727401256, 48.83554081585114],
                            [1.906729122566696, 48.83530853623562],
                            [1.907112667134727, 48.8352218507903],
                            [1.907853722425754, 48.83506546517961],
                            [1.908331301721591, 48.83497373333898],
                            [1.909118439662935, 48.834843591991586],
                            [1.909784036358162, 48.8347480628073],
                            [1.910405830827939, 48.8346766465092],
                            [1.910780743796137, 48.83464207599627],
                            [1.912754655367173, 48.834479464807124],
                            [1.913557538872308, 48.834417697473214],
                            [1.913826074508072, 48.83439711031479],
                            [1.915055662538173, 48.83429644507696],
                            [1.915648648571893, 48.834247376976585],
                            [1.915925378505783, 48.834224117065666],
                            [1.917360778064037, 48.8341088987831],
                            [1.917585712659889, 48.834089041797846],
                            [1.918688504735731, 48.83399956330741],
                            [1.919424625782274, 48.83393750925741],
                            [1.920967741035089, 48.83380825183372],
                            [1.921056342265891, 48.83380137996571],
                            [1.921894688151168, 48.83373158943451],
                            [1.923240103035626, 48.83362226587428],
                            [1.924597779359982, 48.833512070590515],
                        ],
                    },
                },
                110: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.7618874502046, 2.506610957193139],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2271.50278665,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.504559838342837,
                            48.752185720788724,
                            2.507811246902368,
                            48.77170790696431,
                        ),
                        "coordinates": [
                            [2.507482645714313, 48.77170790696431],
                            [2.507530787502072, 48.771051137643774],
                            [2.507575019194044, 48.770613698309866],
                            [2.507589224547753, 48.770392455958934],
                            [2.507574752546502, 48.770139780687096],
                            [2.507550757374261, 48.76988712006307],
                            [2.507506430534911, 48.769656072867065],
                            [2.507432013666611, 48.76937830770552],
                            [2.507330439336359, 48.76911497205392],
                            [2.50722346037568, 48.76886243563733],
                            [2.507083811860147, 48.76860365277777],
                            [2.506855347168026, 48.7682307943893],
                            [2.506565626102118, 48.76784543694536],
                            [2.50624182151027, 48.76743674829111],
                            [2.505994466577197, 48.767106181841314],
                            [2.505863226677005, 48.76691662979885],
                            [2.505720982448366, 48.76669112219029],
                            [2.505661802962114, 48.766578385350996],
                            [2.505596338910067, 48.766440409286524],
                            [2.50555243559284, 48.76633076211139],
                            [2.505478252088972, 48.766116844994755],
                            [2.505418401920174, 48.76591490972972],
                            [2.505377948454334, 48.76566038161464],
                            [2.505375234171927, 48.7654227558511],
                            [2.505378666905266, 48.76523120535594],
                            [2.505401167454085, 48.76504682025084],
                            [2.505443993996173, 48.764839024843255],
                            [2.505480285518237, 48.764710374849585],
                            [2.505561178773942, 48.764496226997565],
                            [2.505626006195953, 48.76435854173047],
                            [2.505721967314257, 48.76417584645876],
                            [2.505901876289787, 48.76387881881513],
                            [2.506533993777897, 48.76295881991824],
                            [2.507061862090788, 48.762189151936255],
                            [2.507262111543242, 48.76187770268923],
                            [2.50733375059555, 48.76174540212374],
                            [2.507416169268052, 48.76158340953246],
                            [2.507494413708713, 48.76139444420694],
                            [2.507582029003717, 48.761161401162035],
                            [2.507665499214359, 48.7609103778139],
                            [2.507720445871089, 48.760671088379134],
                            [2.507757780899108, 48.76045250816767],
                            [2.50778284615865, 48.76022585275563],
                            [2.507811246902368, 48.75978246722647],
                            [2.507800588874619, 48.75945154989539],
                            [2.507788745730873, 48.75917189339321],
                            [2.507764829916254, 48.758940815795555],
                            [2.507732721231531, 48.75870075698282],
                            [2.507699393243959, 48.75850116772497],
                            [2.507659167456201, 48.758273711242374],
                            [2.507597698565905, 48.75803605677067],
                            [2.507522864732568, 48.757792803097104],
                            [2.507436381948397, 48.75756092027852],
                            [2.507291076517386, 48.75723020413544],
                            [2.507106196364434, 48.75685997935367],
                            [2.506883115016229, 48.75645473947403],
                            [2.506669586179318, 48.756057578383974],
                            [2.506397244478356, 48.75556248331012],
                            [2.506118081080678, 48.7550593039698],
                            [2.505863454974878, 48.75457137599365],
                            [2.505766325086295, 48.75440425490308],
                            [2.505629434486417, 48.75414276835828],
                            [2.505276331913783, 48.75348771979618],
                            [2.50487542148979, 48.75276799206569],
                            [2.504559838342837, 48.752185720788724],
                        ],
                    },
                },
                111: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.80518233330807, 1.8484705402272763],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 5040.70247754,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.816466794198607,
                            48.80227950685127,
                            1.877504204313639,
                            48.81532862049073,
                        ),
                        "coordinates": [
                            [1.816466794198607, 48.802601980906694],
                            [1.817032818079235, 48.8025335043232],
                            [1.817823666604824, 48.80245720189971],
                            [1.818624898789292, 48.80238530353169],
                            [1.819086762327612, 48.802350530441245],
                            [1.82000609534681, 48.802310634074026],
                            [1.820074188137612, 48.80230824451127],
                            [1.820718350384725, 48.802285081362],
                            [1.821076445753394, 48.80227950685127],
                            [1.821441263605794, 48.80228205495915],
                            [1.821821056380993, 48.80228467041143],
                            [1.822483914054006, 48.80229665411869],
                            [1.82320791904584, 48.802319701459034],
                            [1.823538491128812, 48.802342771761175],
                            [1.823837892918126, 48.80235221246174],
                            [1.824964241420545, 48.802435511383095],
                            [1.826055303175848, 48.802508748765874],
                            [1.826271593266374, 48.80252500527546],
                            [1.827893059945599, 48.80265005864113],
                            [1.82922479761647, 48.80275221770809],
                            [1.829450618797667, 48.80276851053067],
                            [1.829554004320367, 48.8027761645971],
                            [1.830159347084805, 48.80282202154411],
                            [1.834557352977546, 48.80314993013397],
                            [1.837705248178437, 48.80338317567262],
                            [1.838303817284695, 48.80342716060231],
                            [1.838737783527716, 48.80345873373858],
                            [1.839736298611609, 48.8035332339526],
                            [1.842137252339903, 48.803724430707796],
                            [1.843440591975587, 48.8038128103879],
                            [1.844704414875316, 48.80390550164154],
                            [1.846983025185839, 48.80408167887678],
                            [1.849335182132726, 48.804256325846175],
                            [1.851690079303359, 48.80443093648833],
                            [1.854043639604491, 48.80460459368391],
                            [1.85577003475879, 48.8047332918976],
                            [1.857218832070746, 48.804849106204976],
                            [1.857331747852899, 48.80485767455522],
                            [1.858980623305471, 48.804979703596494],
                            [1.859498935581443, 48.805020542924616],
                            [1.859677163506899, 48.80503298013552],
                            [1.860264906717973, 48.805074106096555],
                            [1.861847217251214, 48.80518232598419],
                            [1.862328750917853, 48.80522569814248],
                            [1.86288904744771, 48.80529007787644],
                            [1.863170546078489, 48.80532362203207],
                            [1.863779642244063, 48.80541068270712],
                            [1.864069155035706, 48.805460445227745],
                            [1.864676620353485, 48.8055762719471],
                            [1.865268950380655, 48.80570911975499],
                            [1.865745581680614, 48.80583968759697],
                            [1.866440712724201, 48.806043997862496],
                            [1.867223772337531, 48.806308917685236],
                            [1.867496424041834, 48.80641525673903],
                            [1.868103904531152, 48.806675851831734],
                            [1.868525453291286, 48.8068745276079],
                            [1.868965887020769, 48.80709216469365],
                            [1.869272024340581, 48.80725799047664],
                            [1.86952657099664, 48.80740831568767],
                            [1.870157316082131, 48.807803888443935],
                            [1.870390018599309, 48.80796131687527],
                            [1.870742814372329, 48.808234344494004],
                            [1.871063301534588, 48.80846857023127],
                            [1.871374024220767, 48.80872793515015],
                            [1.871726326190471, 48.80905491568096],
                            [1.872075690908933, 48.809405263831835],
                            [1.872427532637042, 48.80978260058982],
                            [1.873296930715759, 48.81072769521586],
                            [1.874195865176207, 48.81172146349909],
                            [1.874594691971299, 48.81217452445748],
                            [1.874635138465118, 48.812217853840444],
                            [1.874678265947965, 48.812265691291785],
                            [1.875186346180608, 48.81283160391503],
                            [1.875763471882011, 48.8134418584178],
                            [1.876287841852475, 48.814015925602206],
                            [1.876341781856911, 48.814072799075454],
                            [1.876411886775733, 48.81414862286476],
                            [1.876564270028339, 48.814309310792474],
                            [1.877504204313639, 48.81532862049073],
                        ],
                    },
                },
                112: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.81262364872032, 2.4666046520617333],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1863.26833208,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.463640702639653,
                            48.80620002476371,
                            2.472720403802171,
                            48.82103881506317,
                        ),
                        "coordinates": [
                            [2.463856795362316, 48.82103881506317],
                            [2.463842035253322, 48.820991686635246],
                            [2.463774544495059, 48.82069320223674],
                            [2.46371376667862, 48.82035694097439],
                            [2.4636913914199, 48.82012675096497],
                            [2.463668764501629, 48.819797640631904],
                            [2.463644562959298, 48.81938489956624],
                            [2.463640702639653, 48.81893796283143],
                            [2.4636522061659, 48.8186548165587],
                            [2.463684708528003, 48.818036838970386],
                            [2.463723215995494, 48.817651006266345],
                            [2.463869367561328, 48.81675696240219],
                            [2.463929966726621, 48.816490708287986],
                            [2.464070438320374, 48.815919694925185],
                            [2.464199055775851, 48.815518234780704],
                            [2.464401440208634, 48.8150198644123],
                            [2.464475950473105, 48.81487050078451],
                            [2.464611446754479, 48.81460865911553],
                            [2.464882493231197, 48.814107457988214],
                            [2.465182081347027, 48.81358823791181],
                            [2.465371881872123, 48.81326698148805],
                            [2.465640310511219, 48.812812543885805],
                            [2.465923578510521, 48.812306829071694],
                            [2.466194683006095, 48.811837998305734],
                            [2.466445454401813, 48.81140606022196],
                            [2.466751822147863, 48.810888627245944],
                            [2.466858881292646, 48.81069516010546],
                            [2.467060835373302, 48.81034331264128],
                            [2.467119127720184, 48.81024612391507],
                            [2.467262731322083, 48.810024882697356],
                            [2.467393106990122, 48.80984383314322],
                            [2.467489445339136, 48.809717824007734],
                            [2.467596423333249, 48.80957715371977],
                            [2.467726940726905, 48.80942348777076],
                            [2.467884421904365, 48.80924974611803],
                            [2.46804869162419, 48.80906970191179],
                            [2.46822384271856, 48.80888604718312],
                            [2.46836103329865, 48.80876358714535],
                            [2.468491402111727, 48.808636638384655],
                            [2.46864898177488, 48.808502464282505],
                            [2.469060623737829, 48.808165656843634],
                            [2.469657190803659, 48.80774230263048],
                            [2.470051330131114, 48.80748374911306],
                            [2.470259304277273, 48.80736030543941],
                            [2.470729922629629, 48.80708311516568],
                            [2.471166050842005, 48.806857442559405],
                            [2.471894883210954, 48.806522049356815],
                            [2.472249827083262, 48.806376844148005],
                            [2.472720403802171, 48.80620002476371],
                        ],
                    },
                },
                113: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.902023492912264, 2.2589282740598504],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1827.03317568,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.247942846959712,
                            48.89811887571271,
                            2.269964779194514,
                            48.90576265710707,
                        ),
                        "coordinates": [
                            [2.269964779194514, 48.90576265710707],
                            [2.269170966677327, 48.905578188978794],
                            [2.26852152180131, 48.90540331885525],
                            [2.267929858450347, 48.90520944496078],
                            [2.267535462518766, 48.90504741171076],
                            [2.267150708747172, 48.904875866452095],
                            [2.266905432119463, 48.90476468079431],
                            [2.266640924246886, 48.90464079357891],
                            [2.266174398266635, 48.90444698712153],
                            [2.265499573356789, 48.90421207879283],
                            [2.264172004326552, 48.903773445984726],
                            [2.262635234622845, 48.90326328327007],
                            [2.261210320411657, 48.902791240913956],
                            [2.259210162614818, 48.9021085609344],
                            [2.258221457490604, 48.90177507346837],
                            [2.257632812606457, 48.9015765185643],
                            [2.257065954621635, 48.90138530843066],
                            [2.256571907473751, 48.901218653919045],
                            [2.256125676885577, 48.90107109020327],
                            [2.25534040722679, 48.90081603890312],
                            [2.252259406365097, 48.899805716981895],
                            [2.251159323258396, 48.89941641147634],
                            [2.251027094334288, 48.89937044922859],
                            [2.250882602014157, 48.8993181831883],
                            [2.25069585218518, 48.89925059696528],
                            [2.249880770168008, 48.89891544975923],
                            [2.249146138678088, 48.898601042413055],
                            [2.247942846959712, 48.89811887571271],
                        ],
                    },
                },
                114: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.82194275596548, 2.3842004486949167],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2081.76727457,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.376695892125261,
                            48.813989052009454,
                            2.391686971662538,
                            48.82987504460341,
                        ),
                        "coordinates": [
                            [2.391686971662538, 48.813989052009454],
                            [2.391644736066674, 48.81403367489162],
                            [2.391256089487555, 48.814445486936805],
                            [2.390734284057633, 48.81499536125855],
                            [2.390298842776883, 48.81545953803256],
                            [2.389615060350911, 48.816173659556846],
                            [2.388902483060373, 48.81693537502156],
                            [2.387675212460237, 48.818242186449375],
                            [2.386429870754618, 48.81955851019719],
                            [2.384853298547533, 48.821222344253066],
                            [2.383431420318824, 48.822726677377766],
                            [2.382729474191612, 48.823497868782205],
                            [2.382412726451002, 48.82388344932435],
                            [2.38204555869107, 48.82430711771084],
                            [2.381713885426457, 48.82464175224206],
                            [2.381462328800976, 48.824904562472305],
                            [2.381174280815445, 48.82516640174247],
                            [2.38100145262221, 48.825325884515536],
                            [2.380241787770921, 48.826111359755714],
                            [2.379957379772388, 48.826432677685865],
                            [2.379118555179876, 48.82740138296538],
                            [2.378513688223332, 48.82806544209967],
                            [2.376695892125261, 48.82987504460341],
                        ],
                    },
                },
                115: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.90170806059854, 2.2905108199356654],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1352.62497118,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.283517328323657,
                            48.89763744791706,
                            2.297419948146663,
                            48.90562211913642,
                        ),
                        "coordinates": [
                            [2.297419948146663, 48.89763744791706],
                            [2.297395280401841, 48.897650756172794],
                            [2.296393968719668, 48.89823136374865],
                            [2.295318006130621, 48.89886388299613],
                            [2.294724849962381, 48.899224388455764],
                            [2.294311359645943, 48.89946780578177],
                            [2.293698791446777, 48.89984879511778],
                            [2.292359132250744, 48.900671534563216],
                            [2.29167304108838, 48.90108765149402],
                            [2.290109474898639, 48.90199355263667],
                            [2.289546150383618, 48.902313343551604],
                            [2.289069498124001, 48.9025713045086],
                            [2.288661449960847, 48.90279241218691],
                            [2.286371892257679, 48.90413788792124],
                            [2.285796569144198, 48.90446606543778],
                            [2.285020552053906, 48.90491105086764],
                            [2.283921380883971, 48.90545270809693],
                            [2.283517328323657, 48.90562211913642],
                        ],
                    },
                },
                116: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.89835131453269, 2.205293816282843],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1622.41359122,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.195363986912902,
                            48.89512589133458,
                            2.215232347269524,
                            48.9015496742534,
                        ),
                        "coordinates": [
                            [2.215232347269524, 48.9015496742534],
                            [2.212174295892574, 48.90056448333464],
                            [2.211305634022634, 48.90029358157169],
                            [2.209260726163626, 48.899655817526394],
                            [2.20834896021813, 48.89936433027229],
                            [2.206397403793262, 48.89872183628752],
                            [2.204685711106618, 48.89817041353144],
                            [2.204084883528737, 48.89796802739981],
                            [2.20318259669091, 48.89767316529355],
                            [2.202821465831462, 48.89755583706814],
                            [2.200533461798464, 48.896803135755704],
                            [2.19766910100393, 48.895870725863396],
                            [2.196726132172626, 48.895569212869844],
                            [2.196439975386387, 48.89547713466982],
                            [2.195799552115966, 48.89526411597628],
                            [2.195363986912902, 48.89512589133458],
                        ],
                    },
                },
                117: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.732707983110366, 1.9055149546534647],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 3310.55653413,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.890004563697985,
                            48.72191596105865,
                            1.921036600039739,
                            48.74348398592533,
                        ),
                        "coordinates": [
                            [1.890004563697985, 48.72191596105865],
                            [1.890034431822112, 48.721936895367286],
                            [1.890266086137454, 48.72209856823183],
                            [1.891620949749069, 48.7230355335236],
                            [1.891785688193822, 48.7231566818875],
                            [1.892501621874721, 48.72365408454952],
                            [1.895511355051447, 48.725750332141075],
                            [1.896271931016806, 48.726280257723445],
                            [1.89783355362877, 48.72738071825863],
                            [1.898844173125484, 48.72807885787199],
                            [1.899652182529723, 48.72863322465181],
                            [1.900023645844506, 48.728901737789634],
                            [1.901184246010784, 48.729711044894486],
                            [1.902651551611075, 48.73074003762751],
                            [1.904708292188821, 48.73215344622749],
                            [1.905902813171118, 48.73298801416836],
                            [1.907447505811745, 48.73405140925048],
                            [1.908213712840531, 48.734588471514456],
                            [1.908504326461507, 48.73478381104041],
                            [1.90872465011916, 48.73493212253206],
                            [1.90884495574657, 48.73501261159476],
                            [1.910870763410868, 48.73642758928511],
                            [1.912002200183204, 48.73721797359011],
                            [1.914187243962756, 48.738732242570805],
                            [1.91661919159956, 48.74041869378139],
                            [1.91779942111266, 48.74124154398555],
                            [1.919580594358542, 48.742480594453625],
                            [1.921036600039739, 48.74348398592533],
                        ],
                    },
                },
                118: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.88939586598889, 2.349724777482816],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 449.480782327,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.349694082213971,
                            48.88737490965435,
                            2.349742536008521,
                            48.89141683421295,
                        ),
                        "coordinates": [
                            [2.349694082213971, 48.88737490965435],
                            [2.349731931153697, 48.88941178530525],
                            [2.349735137319289, 48.89007848178429],
                            [2.349737900413805, 48.8906531116933],
                            [2.349741043696849, 48.89130661760289],
                            [2.349742536008521, 48.89135158826425],
                            [2.349738407022142, 48.89141683421295],
                        ],
                    },
                },
                119: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.817893599066835, 1.734002721117619],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 4912.05823832,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.703218425476859,
                            48.810402464358575,
                            1.765056756557643,
                            48.82657842806816,
                        ),
                        "coordinates": [
                            [1.703218425476859, 48.82657842806816],
                            [1.703834706081143, 48.82646491843838],
                            [1.704440868864696, 48.826353168721774],
                            [1.705059332238571, 48.826237886526634],
                            [1.705386982651539, 48.82617764765288],
                            [1.705975387351061, 48.82606938935608],
                            [1.706640251963787, 48.82594626129542],
                            [1.7068696017519, 48.82590436112266],
                            [1.707990364636365, 48.82570280394646],
                            [1.708435472943173, 48.8256162256746],
                            [1.708836863898313, 48.82554019578124],
                            [1.709611040257465, 48.825387975302824],
                            [1.710195613521477, 48.82525809031064],
                            [1.710804866956573, 48.825114847945656],
                            [1.711348633248916, 48.82498023683586],
                            [1.712008744744395, 48.824799497119244],
                            [1.712223352927734, 48.824737720647825],
                            [1.712816613266964, 48.82456560288375],
                            [1.713334762327082, 48.82440925836364],
                            [1.713593239341642, 48.82432433778815],
                            [1.713657530608635, 48.82430220636175],
                            [1.713760098814089, 48.82426859299619],
                            [1.713947476039934, 48.82420576497837],
                            [1.714273009634636, 48.82409512880752],
                            [1.714821504639136, 48.82390746813572],
                            [1.715179820401797, 48.82378891484546],
                            [1.716881164567938, 48.823221719061586],
                            [1.71780841570151, 48.82291199699557],
                            [1.720304265419156, 48.822079267838525],
                            [1.721752435411251, 48.82160146069737],
                            [1.724410791146531, 48.82072185532163],
                            [1.725454163075655, 48.820374924638415],
                            [1.72645474936757, 48.82003775341909],
                            [1.72848322513523, 48.819349724692636],
                            [1.730612228450318, 48.818641615831204],
                            [1.732366338047564, 48.818073571818424],
                            [1.734643164394577, 48.81729422681533],
                            [1.735079370350868, 48.81714544641768],
                            [1.736558681682944, 48.816658623749824],
                            [1.737761912325528, 48.81625306855582],
                            [1.738329338511924, 48.81606179818051],
                            [1.738490705957064, 48.816005089491334],
                            [1.738671179311696, 48.81594488264169],
                            [1.739734851702543, 48.81559163425183],
                            [1.740027429514338, 48.81549424200263],
                            [1.740255687190121, 48.81542349177832],
                            [1.740618018259811, 48.81530038328331],
                            [1.741312646775495, 48.81506030140504],
                            [1.742156178047613, 48.81477962323151],
                            [1.742314739589809, 48.814729189653775],
                            [1.743851501127592, 48.814208398571],
                            [1.744212454851976, 48.81408527195248],
                            [1.74450643005247, 48.81398337892803],
                            [1.745094854012801, 48.81378116166545],
                            [1.745879825709287, 48.81355234643284],
                            [1.746817159311929, 48.813298395575416],
                            [1.747076583180959, 48.81323858451115],
                            [1.74821493818605, 48.81299425430823],
                            [1.748713261864647, 48.812896306543024],
                            [1.749087106460449, 48.81283258510359],
                            [1.750412987050746, 48.812632569203565],
                            [1.751530464204398, 48.81246657956357],
                            [1.752381300567321, 48.812337807300985],
                            [1.753630824029237, 48.81214455770408],
                            [1.754761671860952, 48.81196867441502],
                            [1.75503449631644, 48.81192600100822],
                            [1.755771042534285, 48.811817341766975],
                            [1.757926093173865, 48.811500054108166],
                            [1.759934009884037, 48.811187377382815],
                            [1.762259726740296, 48.81082500715827],
                            [1.765056756557643, 48.810402464358575],
                        ],
                    },
                },
                120: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.89048056005887, 2.306484293549573],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1651.83719007,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.29803330457685,
                            48.8854042809258,
                            2.315599220546768,
                            48.89416838621195,
                        ),
                        "coordinates": [
                            [2.29803330457685, 48.8854042809258],
                            [2.298278490321922, 48.88553700998297],
                            [2.298906871348438, 48.88585916014498],
                            [2.299499868875073, 48.886148678935285],
                            [2.300053263238162, 48.88642068160199],
                            [2.30046489801403, 48.88667170934397],
                            [2.300749769168129, 48.88684985547936],
                            [2.300974643437413, 48.88702708226512],
                            [2.301222672411993, 48.887244784124306],
                            [2.301435259014266, 48.88744718606856],
                            [2.301642390401899, 48.887653183671574],
                            [2.301771845610144, 48.88778541630017],
                            [2.301920375347839, 48.88794193488141],
                            [2.302006222792398, 48.888033687716785],
                            [2.302152025498302, 48.88819200401933],
                            [2.302191545922343, 48.88823068431048],
                            [2.302547201014362, 48.88861657975514],
                            [2.302833392748343, 48.88888554701571],
                            [2.303070541528806, 48.889087054457136],
                            [2.30340311755293, 48.889338049078965],
                            [2.303997437406768, 48.889732101675726],
                            [2.304166463946563, 48.88984635719162],
                            [2.304372305938201, 48.889970515700675],
                            [2.304586338694636, 48.890085682254366],
                            [2.304747208226468, 48.89016396405495],
                            [2.305946269516834, 48.89072521915211],
                            [2.307533920375972, 48.891474947649236],
                            [2.307772512865817, 48.89159011449711],
                            [2.30828378788212, 48.89183934154016],
                            [2.308815518190312, 48.892097563435854],
                            [2.31036847368245, 48.892857815797825],
                            [2.310843384229622, 48.893055150412785],
                            [2.31128651457019, 48.89322605440771],
                            [2.311762761774658, 48.89336415981205],
                            [2.31237612386189, 48.893521326783755],
                            [2.312827131249224, 48.8936284909725],
                            [2.313220417438781, 48.89371184914755],
                            [2.313537935800478, 48.89377377517818],
                            [2.315518841217685, 48.8941524701219],
                            [2.315599220546768, 48.89416838621195],
                        ],
                    },
                },
                121: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.83976410057666, 2.4687547126700164],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1263.28828138,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.463708038038903,
                            48.83428889889614,
                            2.471751013746376,
                            48.84372026160052,
                        ),
                        "coordinates": [
                            [2.463708038038903, 48.84372026160052],
                            [2.464072714949626, 48.84359026307213],
                            [2.464223807167134, 48.84353523846805],
                            [2.464845785868624, 48.843275550074615],
                            [2.4648675546364, 48.843263835359316],
                            [2.465138363632208, 48.84313943029574],
                            [2.465278511748215, 48.84306823002769],
                            [2.465678552381045, 48.84286723954678],
                            [2.466205052588956, 48.84257257966302],
                            [2.466784488607378, 48.842204115934166],
                            [2.467223732831621, 48.841890666220934],
                            [2.467456233548691, 48.84171054473043],
                            [2.467727971745666, 48.84149215089406],
                            [2.468066596599805, 48.84119455817351],
                            [2.468281316900039, 48.840990174101606],
                            [2.468807131305007, 48.84045000085818],
                            [2.468986417035168, 48.8402438581054],
                            [2.469312476241462, 48.8399017543085],
                            [2.469489056992771, 48.8397037082008],
                            [2.469711871023516, 48.83947413302528],
                            [2.469902017309917, 48.83925628592139],
                            [2.470044668296358, 48.83910863769832],
                            [2.47030952379091, 48.83880976785207],
                            [2.470472459133075, 48.83860634001926],
                            [2.470891883807731, 48.83803660497335],
                            [2.471076340311951, 48.837733331325275],
                            [2.471245622982843, 48.837387600873775],
                            [2.471478443430251, 48.83687308883418],
                            [2.471598766123802, 48.83646833052923],
                            [2.47168497477152, 48.83610761842296],
                            [2.471711732204699, 48.83592773107126],
                            [2.471734441754037, 48.835762237118345],
                            [2.471747673255242, 48.8356174377757],
                            [2.471751013746376, 48.835342255254716],
                            [2.471730865312358, 48.83494479827724],
                            [2.471713817584186, 48.83468582642015],
                            [2.471701476872501, 48.834432502579006],
                            [2.471681242571033, 48.83428889889614],
                        ],
                    },
                },
                122: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.99521691364474, 1.985369609018619],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4276.19533509,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.963551770278395,
                            48.98107191008835,
                            2.00593089306856,
                            49.00712724722575,
                        ),
                        "coordinates": [
                            [1.963551770278395, 49.00712724722575],
                            [1.966504229714531, 49.00612001225277],
                            [1.969169283586467, 49.00520778971877],
                            [1.969883718400177, 49.00494359496062],
                            [1.970641916885702, 49.004629566626136],
                            [1.971509280064331, 49.00422308748815],
                            [1.972351546127064, 49.00378559057962],
                            [1.97309599138091, 49.003369190331846],
                            [1.976516420966801, 49.00147957052218],
                            [1.979187413352886, 48.999984667403446],
                            [1.980383619065264, 48.999297233533895],
                            [1.980934788738326, 48.99897793357045],
                            [1.981285774062346, 48.99874632270073],
                            [1.981726285418852, 48.998435041776936],
                            [1.983292072527056, 48.997320636859996],
                            [1.986599920129499, 48.994985233047736],
                            [1.992072386069761, 48.99111444955427],
                            [1.993652914913131, 48.98999709405227],
                            [1.99458126773623, 48.989290151775776],
                            [1.995384130320824, 48.98872312763308],
                            [1.997313715319048, 48.98729411462418],
                            [1.999210479069605, 48.98589067001332],
                            [2.000143506587969, 48.985208163013866],
                            [2.000780028771487, 48.9847446304471],
                            [2.001446790197096, 48.9842983147471],
                            [2.002376770537794, 48.98373712781365],
                            [2.00351809931744, 48.98303093273212],
                            [2.004326521660503, 48.98247651381918],
                            [2.004890556772752, 48.982039676661145],
                            [2.005264894718132, 48.98174096209572],
                            [2.005683193481696, 48.98135433740403],
                            [2.00593089306856, 48.98107191008835],
                        ],
                    },
                },
                123: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.00630891359553, 1.9105019882715242],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1292.74038421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.901781979947734,
                            49.00576253682855,
                            1.919237111731365,
                            49.00670027774167,
                        ),
                        "coordinates": [
                            [1.901781979947734, 49.00576253682855],
                            [1.901790368381825, 49.00576423769356],
                            [1.902729160929524, 49.00594149584636],
                            [1.903689724174504, 49.00611169271597],
                            [1.904482276708446, 49.00624347054149],
                            [1.905071122249443, 49.00632183254277],
                            [1.905670966702997, 49.00638357875187],
                            [1.906216685650328, 49.00643084124695],
                            [1.906758955782845, 49.006459053606754],
                            [1.90735652766824, 49.006468617667586],
                            [1.907813070223567, 49.006471229968845],
                            [1.907968951258836, 49.00646551889662],
                            [1.908543235855356, 49.006446985609024],
                            [1.909184460914762, 49.00643319469682],
                            [1.909355365117211, 49.00642933689485],
                            [1.909875055716564, 49.006400702181246],
                            [1.910097972388945, 49.0063889434238],
                            [1.912091835759061, 49.00629114201759],
                            [1.912452856034925, 49.00627449575719],
                            [1.913312850695135, 49.00622294912462],
                            [1.913811458069127, 49.00619910650897],
                            [1.914310654289818, 49.006189054038025],
                            [1.914795242248773, 49.006195599436765],
                            [1.915366526181886, 49.00621436166403],
                            [1.915981031332432, 49.00625469322571],
                            [1.91657007856274, 49.006311583196954],
                            [1.917198748634746, 49.006387649694645],
                            [1.917812832804513, 49.00647793657892],
                            [1.918488239911505, 49.00658747973578],
                            [1.91917454426289, 49.00669229884557],
                            [1.919237111731365, 49.00670027774167],
                        ],
                    },
                },
                124: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.96326967418847, 2.623331986674454],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 3881.11035797,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.603135305118449,
                            48.9531483875826,
                            2.64240630231019,
                            48.97585875402045,
                        ),
                        "coordinates": [
                            [2.603135305118449, 48.9531483875826],
                            [2.605000289162331, 48.95358023622196],
                            [2.606667981536762, 48.953976045436235],
                            [2.60843332667294, 48.95438587455402],
                            [2.609996191861178, 48.954762848286016],
                            [2.610564286872323, 48.954918527856364],
                            [2.610987737600818, 48.95505075694514],
                            [2.611407665895066, 48.955199648801525],
                            [2.611737170967245, 48.9553297236263],
                            [2.612157252560272, 48.95550478508058],
                            [2.612526701935252, 48.95567044971302],
                            [2.612852742036049, 48.95582670175315],
                            [2.613182453497493, 48.95599245990038],
                            [2.613454237727346, 48.95613694387159],
                            [2.613813069025569, 48.9563407001603],
                            [2.614150249870269, 48.95654926678368],
                            [2.614560028989912, 48.95681714106856],
                            [2.61516573517021, 48.957229677317436],
                            [2.615546578415751, 48.957490478786184],
                            [2.615989121755064, 48.95779871768538],
                            [2.616384480709172, 48.95806899772281],
                            [2.616765337560406, 48.95832979781849],
                            [2.617204238868017, 48.95863090006522],
                            [2.618865618889549, 48.95977604693423],
                            [2.620848305052638, 48.96113672398326],
                            [2.623788406543668, 48.963147256113665],
                            [2.627376631213806, 48.96560559525237],
                            [2.629031207469668, 48.966743473580635],
                            [2.633236858467855, 48.969623578526125],
                            [2.633995347296979, 48.97014982880753],
                            [2.635112976436022, 48.970896419788794],
                            [2.636905798974081, 48.972125430531804],
                            [2.637998180871814, 48.97286611020394],
                            [2.639061483617493, 48.97357473575402],
                            [2.64030279661989, 48.974425640339135],
                            [2.64240630231019, 48.97585875402045],
                        ],
                    },
                },
                125: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [49.05021880665001, 2.022354526331116],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1835.11393662,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.010999760003633,
                            49.047876203368986,
                            2.034294461852662,
                            49.05104855336923,
                        ),
                        "coordinates": [
                            [2.010999760003633, 49.047876203368986],
                            [2.012824844986796, 49.049102920262555],
                            [2.013873905514164, 49.049764963802374],
                            [2.014241856975978, 49.04996110765006],
                            [2.014736320939224, 49.05018615781923],
                            [2.015353789518761, 49.05042344822877],
                            [2.015816177845282, 49.05057226495576],
                            [2.016285947490587, 49.05069968562204],
                            [2.016810096450205, 49.05081536046382],
                            [2.017392288051122, 49.050912158187394],
                            [2.018101285744873, 49.050992651604204],
                            [2.018770695307558, 49.05103734023598],
                            [2.019382402802194, 49.05104855336923],
                            [2.020005166842821, 49.051028862615084],
                            [2.020533875061965, 49.05099939153168],
                            [2.021033680757431, 49.05096032163714],
                            [2.023460624314959, 49.0507147734925],
                            [2.032798582030029, 49.049788186849895],
                            [2.034294461852662, 49.049647005256354],
                        ],
                    },
                },
                126: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84144211570125, 2.563956513685172],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2390.80566103,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.547775189299494,
                            48.840835907860786,
                            2.580085911974356,
                            48.8428848408236,
                        ),
                        "coordinates": [
                            [2.580085911974356, 48.8428848408236],
                            [2.579637084565441, 48.84284184523262],
                            [2.577914167028852, 48.84268182528889],
                            [2.575579252547477, 48.84246550708517],
                            [2.574559690564778, 48.84237051114792],
                            [2.574375677072554, 48.842352908428936],
                            [2.573993999525708, 48.84231233480048],
                            [2.573491000004915, 48.84225762233939],
                            [2.572932211184678, 48.842192795117704],
                            [2.572388964288188, 48.84211539851454],
                            [2.570772082019269, 48.84185604015062],
                            [2.569897621407743, 48.84171363920376],
                            [2.569288938958205, 48.84160977632782],
                            [2.568646755163735, 48.841505865086496],
                            [2.5679065355355, 48.84141384001755],
                            [2.566261374250111, 48.84125618544308],
                            [2.565834756551796, 48.84121657390359],
                            [2.563752675582071, 48.84101839425878],
                            [2.563164204872726, 48.840978160339496],
                            [2.562331359867017, 48.84094269018195],
                            [2.561574309897242, 48.840928479204024],
                            [2.560603182763992, 48.8409232469098],
                            [2.559177817735165, 48.84090747244781],
                            [2.557432384954917, 48.840898008653745],
                            [2.555014278335986, 48.84087981175414],
                            [2.553800907888681, 48.8408721299675],
                            [2.552907647796653, 48.84086811309447],
                            [2.551586119972329, 48.84085632982434],
                            [2.548761401539636, 48.840835907860786],
                            [2.547775189299494, 48.84084343185482],
                        ],
                    },
                },
                127: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.94009088399499, 2.550616210006712],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2485.82994821,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.534714974742524,
                            48.93628018565177,
                            2.566448016963,
                            48.94418106597472,
                        ),
                        "coordinates": [
                            [2.534714974742524, 48.93628018565177],
                            [2.535340370734915, 48.93642662289816],
                            [2.535962129245601, 48.93656592503689],
                            [2.537332129872436, 48.93686095462459],
                            [2.537917744457916, 48.93699079325262],
                            [2.538601003272541, 48.93715138676137],
                            [2.540918322655967, 48.93769453308393],
                            [2.543683993892404, 48.938343894483246],
                            [2.544656530410048, 48.93857531034312],
                            [2.545538668164763, 48.93878071039493],
                            [2.54620751804285, 48.93893890513631],
                            [2.548626257665795, 48.93951026287049],
                            [2.549765126932029, 48.93977463943],
                            [2.550694334226996, 48.93999656709117],
                            [2.5514427700577, 48.940175997923625],
                            [2.551959857044305, 48.94031065011705],
                            [2.552824110079801, 48.94054220031732],
                            [2.554205472265827, 48.9409083884766],
                            [2.556928501227496, 48.94163602933851],
                            [2.559405672499717, 48.94229270450478],
                            [2.560599066535213, 48.94260683298388],
                            [2.561441695287231, 48.942831221353366],
                            [2.562157770590603, 48.943024923588446],
                            [2.563249943759487, 48.94331305085653],
                            [2.564117913392034, 48.94354450877578],
                            [2.564797843137347, 48.94372874544],
                            [2.566448016963, 48.94418106597472],
                        ],
                    },
                },
                128: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.94876873710224, 2.584765994787457],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2866.56229588,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.566448016963,
                            48.94418106597472,
                            2.603135305118449,
                            48.9531483875826,
                        ),
                        "coordinates": [
                            [2.566448016963, 48.94418106597472],
                            [2.566891948596433, 48.94430274383506],
                            [2.568060084076771, 48.944602570357915],
                            [2.569195661927715, 48.944888173339194],
                            [2.569817732203788, 48.94505108464606],
                            [2.570754486773528, 48.94530138872618],
                            [2.571557405897602, 48.94551150926684],
                            [2.573604556880427, 48.94605454643058],
                            [2.576045849572909, 48.94667048694143],
                            [2.578678916716112, 48.94733831537988],
                            [2.58119625510733, 48.94796588262504],
                            [2.58410432923042, 48.94869724276722],
                            [2.585019430124057, 48.948923681494264],
                            [2.586169571382587, 48.949192430824624],
                            [2.588419224238586, 48.94971334949363],
                            [2.591652740358425, 48.95046283702698],
                            [2.592202519073878, 48.950590098723566],
                            [2.59297655268225, 48.95076920162161],
                            [2.594032738515728, 48.951016666970744],
                            [2.59547956323488, 48.95135127815666],
                            [2.596702132176895, 48.95163165419941],
                            [2.601719329292711, 48.95281697296261],
                            [2.60283348429561, 48.95307849550037],
                            [2.603135305118449, 48.9531483875826],
                        ],
                    },
                },
                129: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.78330278836103, 1.557959721404166],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 7349.53843059,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.513333052350337,
                            48.76842177662328,
                            1.602701692990599,
                            48.796318150417065,
                        ),
                        "coordinates": [
                            [1.513333052350337, 48.76842177662328],
                            [1.530235391978185, 48.77355432460681],
                            [1.548384785396549, 48.7799301986718],
                            [1.548581052360553, 48.779996308995685],
                            [1.550562845284013, 48.78065482392585],
                            [1.550985183639332, 48.780796235375085],
                            [1.552213053017217, 48.781201302830844],
                            [1.55292207986148, 48.781457996539615],
                            [1.552941015866866, 48.781465321406884],
                            [1.554481626185669, 48.781975039422214],
                            [1.55524096565038, 48.78223566042545],
                            [1.558308845210969, 48.783245928793306],
                            [1.563495662375764, 48.78496389642468],
                            [1.563781347824285, 48.78505846645894],
                            [1.56647704875338, 48.78595626675818],
                            [1.56798694158851, 48.786445807471836],
                            [1.570828906068965, 48.78740024841214],
                            [1.572135447622024, 48.787843399636664],
                            [1.572515694509206, 48.787986245521914],
                            [1.572937907797496, 48.78814376065562],
                            [1.573374818740625, 48.78831935921934],
                            [1.574083518199571, 48.78861098999951],
                            [1.574713458738051, 48.788891297403204],
                            [1.575178451031452, 48.789100350739645],
                            [1.576076172015337, 48.78949305698947],
                            [1.578127899112504, 48.7904330385426],
                            [1.580698743112527, 48.791611151214994],
                            [1.583271095586056, 48.79278741673831],
                            [1.585842223194829, 48.79396271478883],
                            [1.58638430500226, 48.79421090102901],
                            [1.586558697510138, 48.79429029063243],
                            [1.58684122951289, 48.79441985373194],
                            [1.58703862574551, 48.79450838654141],
                            [1.587586204255666, 48.79475390563928],
                            [1.58795123795239, 48.794919082250885],
                            [1.588319251915359, 48.79506718954354],
                            [1.588546651767766, 48.7951523196056],
                            [1.588852628956593, 48.79526224750694],
                            [1.589196621972004, 48.79537871850116],
                            [1.58948109556084, 48.79547051664924],
                            [1.589711491353154, 48.79553767782329],
                            [1.589851101653075, 48.79557726406157],
                            [1.590095149936224, 48.79564181687393],
                            [1.590482946172726, 48.79574238292753],
                            [1.590903463973901, 48.79583956546203],
                            [1.590978040427842, 48.79585893965311],
                            [1.591147650107343, 48.79589512347828],
                            [1.591318566381321, 48.79593491241535],
                            [1.59149364842103, 48.795969333336735],
                            [1.591721703950386, 48.79601129460757],
                            [1.591933507502587, 48.79604775323074],
                            [1.592168410282592, 48.796087059796946],
                            [1.592415617063088, 48.79612284980171],
                            [1.592707712963614, 48.79616073125764],
                            [1.593266275556596, 48.79622103534825],
                            [1.59355039323903, 48.79624627172361],
                            [1.593868527257183, 48.79627262907262],
                            [1.594186781687725, 48.796290892280346],
                            [1.594428895203967, 48.79630326235087],
                            [1.59474047827648, 48.79631248737807],
                            [1.595018101366116, 48.79631699379198],
                            [1.595316195758208, 48.79631803509326],
                            [1.59533388976602, 48.796318150417065],
                            [1.595608911590666, 48.79631454457132],
                            [1.595882640009979, 48.79630643343509],
                            [1.596157754895825, 48.79629653174077],
                            [1.596441064020632, 48.7962848834532],
                            [1.596825119805168, 48.79627209130351],
                            [1.597246045650499, 48.79625144350542],
                            [1.598700603848344, 48.79619972510762],
                            [1.599284885850794, 48.7961783301367],
                            [1.599630844288678, 48.796164381731614],
                            [1.600215216871904, 48.79613668580825],
                            [1.601238148944774, 48.79609202985972],
                            [1.601894695267072, 48.79606209055192],
                            [1.602559407145686, 48.79603220085211],
                            [1.602701692990599, 48.79602536780062],
                        ],
                    },
                },
                130: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.93056577715358, 2.018818905070078],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3875.60340782,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.999603609660236,
                            48.92749432052858,
                            2.041072289675926,
                            48.93948681080073,
                        ),
                        "coordinates": [
                            [1.999603609660236, 48.93948681080073],
                            [1.999745478814779, 48.93880673258692],
                            [1.999860332839626, 48.938381164256135],
                            [1.999956433436328, 48.938057853551705],
                            [2.000088777529168, 48.93771561386505],
                            [2.000217299794479, 48.93740429598073],
                            [2.000367538745524, 48.93708590414306],
                            [2.00052498252498, 48.936769910372384],
                            [2.000766180951774, 48.936351852996204],
                            [2.001061921934988, 48.93587922875607],
                            [2.001258908111934, 48.93558952511411],
                            [2.001492180159692, 48.93527375240844],
                            [2.001772641436504, 48.93492242967672],
                            [2.002074845731686, 48.93455927312396],
                            [2.002369585781313, 48.93423178392727],
                            [2.002762339087557, 48.93382843904429],
                            [2.003191250370267, 48.9334180621935],
                            [2.003539951811205, 48.933119281041144],
                            [2.003928485189991, 48.93280395666924],
                            [2.004367667103087, 48.93247450241822],
                            [2.004817502139509, 48.93217125332143],
                            [2.005361478288389, 48.93183020440016],
                            [2.005858137663208, 48.93154373923018],
                            [2.006340173391652, 48.93128340488281],
                            [2.006890970120898, 48.9309994725025],
                            [2.007405446844218, 48.93074636618486],
                            [2.007945165016606, 48.93049808646754],
                            [2.008513780312058, 48.93024750997885],
                            [2.009259712665592, 48.929940332446385],
                            [2.009983778343435, 48.92966163940012],
                            [2.010790986660044, 48.929368904471005],
                            [2.011558213243689, 48.92911411977606],
                            [2.012325340075177, 48.9288736071436],
                            [2.01305972765501, 48.928668685330386],
                            [2.013830172796917, 48.92847099771639],
                            [2.014705358833772, 48.92826884327863],
                            [2.015403277938154, 48.92811614985625],
                            [2.016166128380683, 48.9279731523932],
                            [2.017178270840227, 48.927809432896616],
                            [2.01813232326213, 48.927693130038854],
                            [2.019035633850587, 48.92760522962063],
                            [2.019953220732404, 48.92754353509037],
                            [2.021011493040057, 48.927503637068874],
                            [2.021946797439078, 48.92749432052858],
                            [2.022661654665784, 48.92751294519864],
                            [2.023361994446083, 48.92754342097989],
                            [2.024062214136317, 48.927592926031316],
                            [2.024733503113487, 48.927649486895945],
                            [2.025462388942178, 48.92773475231132],
                            [2.026162359721935, 48.927824694025766],
                            [2.026894640334668, 48.92794565111718],
                            [2.027554718119948, 48.928064028457506],
                            [2.028265175235255, 48.928211090112995],
                            [2.028957480750428, 48.92837475493428],
                            [2.029682109026624, 48.928567052182764],
                            [2.030323752556166, 48.92874960735206],
                            [2.031062604959402, 48.92898000696472],
                            [2.031783243750481, 48.929236524159506],
                            [2.032417330717282, 48.92947615106812],
                            [2.033202606317243, 48.92979469453686],
                            [2.033800465418992, 48.93005563156655],
                            [2.034358695409448, 48.930302185188765],
                            [2.035133032821583, 48.93064210246535],
                            [2.03703827540336, 48.93148465053155],
                            [2.038615843263528, 48.93217879336028],
                            [2.041072289675926, 48.93326540612854],
                        ],
                    },
                },
                131: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.82949284193254, 1.9771930768514645],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 2719.75448517,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.960026560248269,
                            48.82365326874927,
                            1.992864535155556,
                            48.83095952864679,
                        ),
                        "coordinates": [
                            [1.960026560248269, 48.83095952864679],
                            [1.960935037637888, 48.8309379250036],
                            [1.962093061398932, 48.83091025970915],
                            [1.963721094929362, 48.83087243058366],
                            [1.963757878332537, 48.830871652009066],
                            [1.966582072810431, 48.83080531245419],
                            [1.969404903416691, 48.83073800049453],
                            [1.971730451228169, 48.8306843159905],
                            [1.974054625266235, 48.83063147843705],
                            [1.97455188070673, 48.8306204691827],
                            [1.976381517728135, 48.83057860283449],
                            [1.977309278389815, 48.830557249532816],
                            [1.97944692409613, 48.83049112489424],
                            [1.980105181229709, 48.83044192528568],
                            [1.980684545473023, 48.83037718861256],
                            [1.981573604029977, 48.83024326924754],
                            [1.981914547415635, 48.83018497848945],
                            [1.982507918347994, 48.83006541945888],
                            [1.982889947928216, 48.82997577732718],
                            [1.983445473163384, 48.82983171815846],
                            [1.984110075155704, 48.82963692860319],
                            [1.985080954442035, 48.829293702141804],
                            [1.985893753053863, 48.828959872761175],
                            [1.986162995461228, 48.82883030457826],
                            [1.986708414721469, 48.828553201710655],
                            [1.987065343057734, 48.828350158970814],
                            [1.987578284775649, 48.82804147726763],
                            [1.987929990763962, 48.82780514161545],
                            [1.988274960049601, 48.82755799357086],
                            [1.988536414014613, 48.8273717411227],
                            [1.988870612356766, 48.82710567358642],
                            [1.989320163455206, 48.826704164316794],
                            [1.991813433196942, 48.82443294496405],
                            [1.991988781901201, 48.82428599279434],
                            [1.992248912743041, 48.824089835255215],
                            [1.992864535155556, 48.82365326874927],
                        ],
                    },
                },
                132: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.07807574390078, 2.0143100562528713],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1636.96989927,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.003715373018928,
                            49.07584288482138,
                            2.024952931375388,
                            49.08049370702575,
                        ),
                        "coordinates": [
                            [2.024952931375388, 49.07584288482138],
                            [2.023876796508751, 49.0760735064212],
                            [2.022097690787036, 49.07643644322721],
                            [2.021382177249325, 49.0765864552848],
                            [2.02088872097804, 49.07668941305134],
                            [2.020829778358793, 49.07670184095788],
                            [2.019291810340124, 49.077024930744074],
                            [2.017753820460642, 49.07734799892939],
                            [2.016214442683926, 49.077671044223536],
                            [2.014134975889603, 49.07810316119402],
                            [2.013620932385088, 49.07820962686544],
                            [2.012845053373147, 49.078372006317174],
                            [2.012052723256836, 49.0785370312914],
                            [2.009970453092824, 49.078968165865255],
                            [2.006277297645017, 49.07974535050034],
                            [2.005510793293748, 49.07993266371232],
                            [2.004783856294224, 49.08013672002951],
                            [2.00394695756873, 49.080406775960846],
                            [2.003715373018928, 49.08049370702575],
                        ],
                    },
                },
                133: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.9016978943315, 2.290539692171141],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1351.92438677,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.283628702682815,
                            48.89763744791706,
                            2.297419948146663,
                            48.90570604953261,
                        ),
                        "coordinates": [
                            [2.297419948146663, 48.89763744791706],
                            [2.297395280401841, 48.897650756172794],
                            [2.296393968719668, 48.89823136374865],
                            [2.295318006130621, 48.89886388299613],
                            [2.294724849962381, 48.899224388455764],
                            [2.294311359645943, 48.89946780578177],
                            [2.293698791446777, 48.89984879511778],
                            [2.292359132250744, 48.900671534563216],
                            [2.29167304108838, 48.90108765149402],
                            [2.290109474898639, 48.90199355263667],
                            [2.289546150383618, 48.902313343551604],
                            [2.289069498124001, 48.9025713045086],
                            [2.288661449960847, 48.90279241218691],
                            [2.286371892257679, 48.90413788792124],
                            [2.285796569144198, 48.90446606543778],
                            [2.285020552053906, 48.90491105086764],
                            [2.284279755159278, 48.9053356067742],
                            [2.283628702682815, 48.90570604953261],
                        ],
                    },
                },
                134: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.962002055426225, 1.9940103249898837],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4929.3745197,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.983143352086498,
                            48.93948681080073,
                            1.999603609660236,
                            48.98144596941029,
                        ),
                        "coordinates": [
                            [1.983143352086498, 48.98144596941029],
                            [1.985340988872836, 48.97994898514042],
                            [1.98739040784258, 48.97843485119064],
                            [1.987862935756174, 48.97806273195275],
                            [1.988441100695305, 48.977574346080175],
                            [1.988950423817492, 48.97710716156023],
                            [1.989591011343472, 48.97647619566364],
                            [1.990239311090215, 48.97577387075046],
                            [1.99074231896534, 48.97517103625501],
                            [1.991176409229675, 48.97460130023088],
                            [1.991563389677002, 48.97404807761586],
                            [1.991928790942554, 48.97347813228685],
                            [1.992269163858888, 48.97286766158834],
                            [1.992521945842703, 48.97237827467398],
                            [1.9927567681866, 48.971872175628135],
                            [1.992955248295027, 48.97139452047125],
                            [1.99311723636855, 48.97096672227368],
                            [1.993272060286449, 48.97052938315263],
                            [1.993408975130323, 48.970068197702645],
                            [1.993512786240843, 48.969690190999394],
                            [1.993628292576129, 48.969188491657484],
                            [1.993729243048589, 48.96870102540323],
                            [1.99398738330238, 48.967431218555205],
                            [1.994118454353673, 48.96676776752097],
                            [1.994286758732096, 48.96594501173718],
                            [1.994507830980454, 48.964805958086565],
                            [1.99482946101371, 48.9632317804725],
                            [1.995888335689857, 48.957959889931864],
                            [1.9992371126774, 48.94132973750179],
                            [1.999603609660236, 48.93948681080073],
                        ],
                    },
                },
                135: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.918807223348814, 2.2652069343553594],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1410.3565588,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25934570305215,
                            48.91424647429558,
                            2.271598750389755,
                            48.923918626560365,
                        ),
                        "coordinates": [
                            [2.271598750389755, 48.91424647429558],
                            [2.270532945876196, 48.91500938112961],
                            [2.270139074361969, 48.915287536801934],
                            [2.269723507352697, 48.91559184934864],
                            [2.269235674719603, 48.91593656632342],
                            [2.268101078561584, 48.91667110755421],
                            [2.266174994851476, 48.91797857288676],
                            [2.26402825131479, 48.919509524027916],
                            [2.262242762116137, 48.92081463095848],
                            [2.261671656306205, 48.92124492007583],
                            [2.261266744071509, 48.92159679535038],
                            [2.260916014822611, 48.92192729234508],
                            [2.260362777223492, 48.922462274479905],
                            [2.25988531362348, 48.9230187198303],
                            [2.259639252488354, 48.92336593882241],
                            [2.25942563414716, 48.92374410948801],
                            [2.25934570305215, 48.923918626560365],
                        ],
                    },
                },
                136: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.98493952737166, 2.265570823626869],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1261.36486082,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263182622862856,
                            48.98091190326584,
                            2.269851993930268,
                            48.99065124967573,
                        ),
                        "coordinates": [
                            [2.263182622862856, 48.99065124967573],
                            [2.263828000159767, 48.98850080746261],
                            [2.264569558116951, 48.98598060907531],
                            [2.264938987091222, 48.98468948165153],
                            [2.265151782845797, 48.98398907934167],
                            [2.265217628725084, 48.98380746726178],
                            [2.265299862717603, 48.98363126018516],
                            [2.265387535529786, 48.98347214339544],
                            [2.265506693029483, 48.983271679108135],
                            [2.265639465883045, 48.983103597459554],
                            [2.265798227785891, 48.98291484795068],
                            [2.265967910562413, 48.98273150030918],
                            [2.266218262553732, 48.98250593661489],
                            [2.266449404173173, 48.982337015015496],
                            [2.266783082822401, 48.98211959515766],
                            [2.267241126077733, 48.98187527114086],
                            [2.267625294850131, 48.98169744667459],
                            [2.268508390037164, 48.98134096418717],
                            [2.268870637837192, 48.98120179144643],
                            [2.269185026292536, 48.98108956812498],
                            [2.269851993930268, 48.98091190326584],
                        ],
                    },
                },
                137: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.98791766527209, 1.9696860535955014],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2400.43254417,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.955479247534605,
                            48.98144596941029,
                            1.983143352086498,
                            48.992613881639144,
                        ),
                        "coordinates": [
                            [1.955479247534605, 48.992613881639144],
                            [1.958410208905752, 48.99185031963231],
                            [1.959493512426805, 48.99155885623629],
                            [1.960660072257731, 48.99125337848831],
                            [1.961823005469121, 48.990947879632216],
                            [1.96358732940907, 48.99048015461005],
                            [1.964826506702233, 48.99012728583892],
                            [1.966297780375974, 48.9896776003621],
                            [1.967337946717621, 48.98934071587559],
                            [1.96833111582847, 48.9890012887529],
                            [1.96919027253338, 48.9886923570231],
                            [1.970093117239252, 48.988340729064085],
                            [1.971137547301475, 48.98790864868745],
                            [1.972330708894163, 48.987405650985686],
                            [1.973948342561463, 48.98669698356846],
                            [1.974996768279388, 48.98620301726783],
                            [1.97661871831096, 48.985387255040436],
                            [1.97832460287864, 48.98445514381108],
                            [1.979243090830599, 48.98392028118249],
                            [1.980368620212517, 48.98324567510205],
                            [1.981472547679287, 48.98255433420734],
                            [1.983143352086498, 48.98144596941029],
                        ],
                    },
                },
                138: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.84515192477183, 2.400015910245531],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 187.988448097,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.398743260868829,
                            48.8450615799449,
                            2.401289019827348,
                            48.84524823225362,
                        ),
                        "coordinates": [
                            [2.401289019827348, 48.8450615799449],
                            [2.400072430374568, 48.845146472296896],
                            [2.39902509865528, 48.845223418649965],
                            [2.398743260868829, 48.84524823225362],
                        ],
                    },
                },
                139: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.66709106514783, 1.84695431729289],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 5803.08638244,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.832935470348963,
                            48.644221953457865,
                            1.85659206528713,
                            48.69309659121679,
                        ),
                        "coordinates": [
                            [1.832935470348963, 48.644221953457865],
                            [1.833897742269862, 48.64483970101746],
                            [1.835324124189156, 48.64581915998322],
                            [1.837193509659841, 48.647087998505334],
                            [1.837546513719914, 48.64734404631596],
                            [1.837880828061444, 48.64756943559603],
                            [1.838592317774448, 48.648077952894106],
                            [1.839019356772323, 48.64839637123526],
                            [1.839398873945023, 48.648717278382605],
                            [1.839692151481013, 48.64897665520306],
                            [1.840174788476924, 48.64943739944275],
                            [1.840632878565732, 48.64991062359412],
                            [1.840973934304241, 48.650279918877594],
                            [1.84136941477331, 48.65077265161532],
                            [1.841696257529263, 48.651207530340436],
                            [1.841780606608487, 48.65132390458805],
                            [1.84212318915172, 48.651814606109895],
                            [1.842467448349342, 48.65241053000372],
                            [1.842700474059629, 48.65286388334804],
                            [1.842881098071016, 48.65326394998563],
                            [1.843184643382457, 48.653998184763765],
                            [1.843497540193419, 48.65488533688768],
                            [1.843637183017852, 48.65531310298988],
                            [1.843757091376512, 48.65567783303002],
                            [1.843855995510116, 48.6559705289699],
                            [1.844004976773792, 48.65641542091583],
                            [1.844318665800132, 48.65736282719837],
                            [1.844397785343592, 48.65759788274752],
                            [1.844863599274432, 48.658949724640365],
                            [1.845328071822014, 48.66030245851917],
                            [1.845792578715679, 48.66165429048384],
                            [1.845941424720584, 48.662116266278225],
                            [1.846145666036338, 48.662743049090736],
                            [1.846531023941065, 48.66386521919959],
                            [1.846669758325678, 48.66425250942441],
                            [1.847209896930332, 48.66578991522906],
                            [1.847784738395138, 48.66752980553356],
                            [1.847842821808982, 48.6676982212138],
                            [1.84819155495819, 48.66868623537434],
                            [1.849019203452952, 48.67109897112784],
                            [1.849326236649587, 48.67205173070517],
                            [1.849676484314482, 48.67302985490711],
                            [1.850197493462145, 48.67459863843122],
                            [1.850333551960932, 48.67498771165959],
                            [1.850452338978258, 48.675338041394504],
                            [1.850614680494159, 48.675817155022685],
                            [1.851188007576962, 48.6774573760777],
                            [1.851490623368341, 48.67831461180392],
                            [1.851726601402419, 48.67904314001343],
                            [1.85217323906696, 48.680313034994754],
                            [1.852618550278436, 48.681582023410364],
                            [1.853062524695244, 48.682851004731404],
                            [1.853326603331995, 48.683627311174284],
                            [1.853672770973487, 48.68464887205584],
                            [1.854165322260302, 48.68606973363427],
                            [1.854458800034756, 48.686899219198416],
                            [1.854710960338351, 48.68764889444398],
                            [1.854862228152567, 48.68801694176579],
                            [1.854986597374976, 48.6883582972875],
                            [1.855143765850118, 48.68881939675369],
                            [1.855344426080367, 48.68941827137432],
                            [1.855428977361471, 48.68966413381634],
                            [1.855925175448971, 48.69116623973367],
                            [1.856240942407902, 48.69208484429995],
                            [1.85659206528713, 48.69309659121679],
                        ],
                    },
                },
                140: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.857420161219245, 2.3360102898696686],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1738.6722232,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325620298740735,
                            48.85333579289227,
                            2.346034985851638,
                            48.86070823076494,
                        ),
                        "coordinates": [
                            [2.346034985851638, 48.85333579289227],
                            [2.345907892957767, 48.85336873855313],
                            [2.344887247687885, 48.853635003555446],
                            [2.344233164905792, 48.85386076766378],
                            [2.342986280062955, 48.85445464936386],
                            [2.342285594334723, 48.85487256895882],
                            [2.34189481858839, 48.85515855701591],
                            [2.341713582367341, 48.85530244861159],
                            [2.34141924098911, 48.85553537397197],
                            [2.341049948552972, 48.855826754792744],
                            [2.340521208490326, 48.85619907437647],
                            [2.340267736690628, 48.856380736777844],
                            [2.340259560796243, 48.8563852334311],
                            [2.339927731137451, 48.85657838396466],
                            [2.33948141502974, 48.85683399481777],
                            [2.339263367994021, 48.85694640978577],
                            [2.338716531799063, 48.857227920693774],
                            [2.338280628507666, 48.85742758098966],
                            [2.338071533441895, 48.85750010934028],
                            [2.337896005383008, 48.85755617695443],
                            [2.337692158261464, 48.85761260290408],
                            [2.33743958324096, 48.85767461979302],
                            [2.336937003020826, 48.85777275678894],
                            [2.336275440182249, 48.85788781174538],
                            [2.335462398875377, 48.85800578572366],
                            [2.334967677481534, 48.85808042027029],
                            [2.334543823481463, 48.85815145646423],
                            [2.334055912776827, 48.85824497193187],
                            [2.333829171919461, 48.85828708741927],
                            [2.333627966903686, 48.8583267959171],
                            [2.333381282555507, 48.85838614169282],
                            [2.333224550472934, 48.858423007975766],
                            [2.332518565338944, 48.858616329624276],
                            [2.331613586685024, 48.85887708436926],
                            [2.330469928217356, 48.85920739385645],
                            [2.329262505065705, 48.859560409663246],
                            [2.325974952816833, 48.86059971663194],
                            [2.325620298740735, 48.86070823076494],
                        ],
                    },
                },
                141: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.77314071828095, 2.4104429502163347],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2086.48660115,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.409541656460374,
                            48.76378680955171,
                            2.411386724936104,
                            48.78250543550023,
                        ),
                        "coordinates": [
                            [2.411386724936104, 48.76378680955171],
                            [2.411327217835018, 48.763968394246305],
                            [2.411255717612045, 48.76428964998598],
                            [2.411184339710723, 48.76469418252225],
                            [2.411148752220556, 48.76496544994747],
                            [2.410981564960481, 48.766288466990666],
                            [2.410943269257952, 48.76660807062959],
                            [2.410810783113312, 48.76807936723669],
                            [2.410672871619905, 48.769567753651664],
                            [2.41063709737736, 48.77021255492548],
                            [2.410606989875543, 48.77101023025481],
                            [2.41058061315596, 48.771572292333126],
                            [2.410562142373555, 48.77196079016195],
                            [2.410519442718912, 48.77252466268932],
                            [2.410463428132036, 48.77328638315034],
                            [2.41041910536067, 48.773674897608615],
                            [2.410332529397457, 48.774933035940535],
                            [2.410261693083095, 48.77579638421732],
                            [2.410163806074753, 48.7767712590885],
                            [2.410151755115293, 48.77690256107511],
                            [2.410070299183182, 48.77795026655007],
                            [2.410032922058886, 48.778440394601496],
                            [2.4099848371692, 48.77905193190946],
                            [2.409937977507461, 48.77957174165585],
                            [2.4098076829105, 48.780743720800345],
                            [2.409732889392154, 48.78129815197806],
                            [2.409679415371185, 48.78165984567194],
                            [2.40964018779611, 48.78191683785356],
                            [2.409590234985702, 48.782226183530135],
                            [2.409541656460374, 48.78250543550023],
                        ],
                    },
                },
                142: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80736636380431, 2.3975493522017937],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 1738.10740738,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.391686971662538,
                            48.80020939834459,
                            2.40271281718153,
                            48.813989052009454,
                        ),
                        "coordinates": [
                            [2.40271281718153, 48.80020939834459],
                            [2.402388694458657, 48.800798880907166],
                            [2.40230966399799, 48.80095834086986],
                            [2.401899980586725, 48.80166285949211],
                            [2.401529822340158, 48.80230311132965],
                            [2.401120043700234, 48.80295052291369],
                            [2.400469329429956, 48.803916898168495],
                            [2.400088253846302, 48.804497668870226],
                            [2.399678391990955, 48.80510938539171],
                            [2.399261264747814, 48.80568065601951],
                            [2.398750539869079, 48.806306699992135],
                            [2.3983656672838, 48.80676136270062],
                            [2.397829707196336, 48.80738979622354],
                            [2.397038329347954, 48.80831577895154],
                            [2.395717981668412, 48.80975834857481],
                            [2.39481129406606, 48.810724825856965],
                            [2.394174437462593, 48.81140801823558],
                            [2.393789421216613, 48.81180556107138],
                            [2.393404379955451, 48.812188826521734],
                            [2.392663105048392, 48.81295771851731],
                            [2.391686971662538, 48.813989052009454],
                        ],
                    },
                },
                143: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.86470601092518, 2.3184037491343963],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 756.725929834,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.315138432191171,
                            48.86232532909372,
                            2.32208284867617,
                            48.86681836985008,
                        ),
                        "coordinates": [
                            [2.32208284867617, 48.86681836985008],
                            [2.321774360384874, 48.866399729418816],
                            [2.321774146036822, 48.86639944041338],
                            [2.321683429134978, 48.8662847435189],
                            [2.321583020231526, 48.86617361686905],
                            [2.321473243278932, 48.86606641482068],
                            [2.321354449598869, 48.8659634828914],
                            [2.321227020713149, 48.865865149682094],
                            [2.321091362855634, 48.86577172954391],
                            [2.32094791106153, 48.865683522602176],
                            [2.32079712648788, 48.86560081114407],
                            [2.320639490961498, 48.86552385958815],
                            [2.320475509705399, 48.86545291450024],
                            [2.320305707249787, 48.865388204570586],
                            [2.320203485083617, 48.86535318889153],
                            [2.316739953588707, 48.86421451610631],
                            [2.3166895278863, 48.86419751741929],
                            [2.316536680018167, 48.86414064670694],
                            [2.316389487160845, 48.86407761608152],
                            [2.316248520017697, 48.86400866984854],
                            [2.316114321726438, 48.86393407464166],
                            [2.315987413322851, 48.8638541185539],
                            [2.315868285550733, 48.86376911198985],
                            [2.315757397545608, 48.86367938406026],
                            [2.315655180947798, 48.86358528080652],
                            [2.315562030349788, 48.86348716604486],
                            [2.315478303296491, 48.863385421365955],
                            [2.31540432720746, 48.863280438079975],
                            [2.315340387015807, 48.86317262434035],
                            [2.315286729388407, 48.86306239527469],
                            [2.315243562643898, 48.862950179279366],
                            [2.315211052771303, 48.862836409902485],
                            [2.315189328871536, 48.862721526774095],
                            [2.315187166455062, 48.86270549518221],
                            [2.315138432191171, 48.86232532909372],
                        ],
                    },
                },
                144: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.58026466261715, 2.207151105654557],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2336.13386759,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192063068770897,
                            48.577508489431835,
                            2.22243331383282,
                            48.58248559694799,
                        ),
                        "coordinates": [
                            [2.192063068770897, 48.577508489431835],
                            [2.192959101978819, 48.577940754354735],
                            [2.193738645120984, 48.5783105414072],
                            [2.194079557396226, 48.57846752761568],
                            [2.194362844473483, 48.57858780027418],
                            [2.194776529693579, 48.57875153818035],
                            [2.195210332229236, 48.57890364143992],
                            [2.195651709922428, 48.5790407631797],
                            [2.196105677460959, 48.57916457353781],
                            [2.196559681979031, 48.57927505959016],
                            [2.197028785416625, 48.5793739035409],
                            [2.19751048415598, 48.57945610465408],
                            [2.197977176339137, 48.57951996726035],
                            [2.198474010372151, 48.57957720053478],
                            [2.198954985641293, 48.57962177042589],
                            [2.200637204591428, 48.57975302973528],
                            [2.20187803585503, 48.579854541363716],
                            [2.205739140858419, 48.580157092631076],
                            [2.208261283472879, 48.58035484105673],
                            [2.20911203386415, 48.580424086753055],
                            [2.212507550208399, 48.58069267208359],
                            [2.213365830271464, 48.58076689108147],
                            [2.213830097177527, 48.580810697383036],
                            [2.214214044964871, 48.58085275081135],
                            [2.214868993876325, 48.580933401084366],
                            [2.215298088048602, 48.58099048842931],
                            [2.215870193574709, 48.581076040105486],
                            [2.216700715035429, 48.58121682408262],
                            [2.217511122508184, 48.58137257116665],
                            [2.218341565999359, 48.58154998555617],
                            [2.219954744507211, 48.58191806856227],
                            [2.222157533987902, 48.582421632240035],
                            [2.22243331383282, 48.58248559694799],
                        ],
                    },
                },
                145: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.75828388309225, 2.4146475096103424],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 1310.3083477,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.411386724936104,
                            48.75288655674139,
                            2.418113047325797,
                            48.76378680955171,
                        ),
                        "coordinates": [
                            [2.418113047325797, 48.75288655674139],
                            [2.416624905232636, 48.75522931882932],
                            [2.416377979117072, 48.755605388227586],
                            [2.415558496728417, 48.75686404153501],
                            [2.414869262472233, 48.75794184587288],
                            [2.414459469393249, 48.75855902867565],
                            [2.414159620449721, 48.75903584730456],
                            [2.413774240207134, 48.75962056900609],
                            [2.413452595549658, 48.7600821807872],
                            [2.412453702802303, 48.76158118009764],
                            [2.412213173520056, 48.76197630951862],
                            [2.41204088089293, 48.76227859786082],
                            [2.411893754995528, 48.762564215824064],
                            [2.41169286382455, 48.76299738578484],
                            [2.411574538640741, 48.76329250082202],
                            [2.411441863780134, 48.763618556064316],
                            [2.411386724936104, 48.76378680955171],
                        ],
                    },
                },
                146: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.852241361715436, 2.372776167893174],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 544.495585985,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.369513568156525,
                            48.85127112726454,
                            2.376118773328578,
                            48.8534394275684,
                        ),
                        "coordinates": [
                            [2.376118773328578, 48.85127112726454],
                            [2.375908557132854, 48.851317944905084],
                            [2.375191751868697, 48.8514982862211],
                            [2.373933084695514, 48.851814939795396],
                            [2.372837033454945, 48.8521349669725],
                            [2.372715849389661, 48.85216701599625],
                            [2.372464509653884, 48.85223924083999],
                            [2.372217748060535, 48.852318044557705],
                            [2.371975959916607, 48.85240330064415],
                            [2.371739532513001, 48.85249486996352],
                            [2.371508846379278, 48.852592609749315],
                            [2.37128426998515, 48.852696360985405],
                            [2.371066159632332, 48.85280595739869],
                            [2.370863988822697, 48.85291605361976],
                            [2.370773069021646, 48.852965244065004],
                            [2.370635497624539, 48.85303171654456],
                            [2.370491696820891, 48.85309217090081],
                            [2.370342266577877, 48.853146357551374],
                            [2.370187833887753, 48.85319404684388],
                            [2.370061729771435, 48.85322723643112],
                            [2.370006555778103, 48.85324150196161],
                            [2.369995405589655, 48.85324438503508],
                            [2.369866599229653, 48.853283617325744],
                            [2.369742855504854, 48.853329395548144],
                            [2.369624936886777, 48.85338143863965],
                            [2.369513568156525, 48.8534394275684],
                        ],
                    },
                },
                147: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.84372550446258, 2.29297454889573],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 273.398680196,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.291912413317875,
                            48.842746779792876,
                            2.293951963648718,
                            48.84479476371181,
                        ),
                        "coordinates": [
                            [2.293951963648718, 48.84479476371181],
                            [2.293059853120187, 48.843760295825994],
                            [2.292389913093769, 48.84311684775477],
                            [2.292351358249487, 48.843077541259106],
                            [2.292254168094726, 48.84298790818733],
                            [2.292148305749116, 48.842902666592074],
                            [2.29203422419307, 48.84282217438239],
                            [2.291912413317875, 48.842746779792876],
                        ],
                    },
                },
                148: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.83765605128395, 2.2802321062255557],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 488.304338813,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.278161671278975,
                            48.83593087919467,
                            2.282700027239131,
                            48.838960939372015,
                        ),
                        "coordinates": [
                            [2.282700027239131, 48.838960939372015],
                            [2.282143378170892, 48.838734858836744],
                            [2.281665519935401, 48.83848228922402],
                            [2.27901897375046, 48.837083382005126],
                            [2.278793008191094, 48.83696705096826],
                            [2.278649713850015, 48.836865025272594],
                            [2.278561598682571, 48.836746035444094],
                            [2.278436830892277, 48.836525072788966],
                            [2.278237951915641, 48.83609678405708],
                            [2.278161671278975, 48.83593087919467],
                        ],
                    },
                },
                149: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.35347134651465, 2.781557164066508],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 8508.41926662,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.738001618532588,
                            48.33623310392106,
                            2.810859344364383,
                            48.37952262366741,
                        ),
                        "coordinates": [
                            [2.796343615000022, 48.37952262366741],
                            [2.797248420496505, 48.37912848649691],
                            [2.79761483674829, 48.37896996051565],
                            [2.797973955717404, 48.37879480928714],
                            [2.798318622920005, 48.37862361973774],
                            [2.799191538939647, 48.37818694211936],
                            [2.802443568430986, 48.37655055536922],
                            [2.804294911566199, 48.37561578312655],
                            [2.80574475336322, 48.37491105799888],
                            [2.806264606124487, 48.374642720774425],
                            [2.806582083677722, 48.374477545049174],
                            [2.806914676593119, 48.37429920195685],
                            [2.807332151212079, 48.37405376634118],
                            [2.807450240781468, 48.37398043539133],
                            [2.807592466140204, 48.37388991820488],
                            [2.808075350904084, 48.37356777126153],
                            [2.808348295682342, 48.37336189343858],
                            [2.808623206099906, 48.37312215320578],
                            [2.808931830165427, 48.372836922046325],
                            [2.80922506782465, 48.372536023384804],
                            [2.809439843906403, 48.372291642711986],
                            [2.809657723410513, 48.37203392250013],
                            [2.80982700663255, 48.37179523043513],
                            [2.809981427449479, 48.37157875622105],
                            [2.810091674810464, 48.37140023700046],
                            [2.810242113841549, 48.371116795283534],
                            [2.810388725538886, 48.37084055635797],
                            [2.810505774582508, 48.37054569146438],
                            [2.810634809330417, 48.37017227795512],
                            [2.810752259113344, 48.369746438204864],
                            [2.810792161091127, 48.36949262452508],
                            [2.810841540066914, 48.36908748817764],
                            [2.810859344364383, 48.36879457836428],
                            [2.810857367365935, 48.36858506020063],
                            [2.810827686932018, 48.36815713970425],
                            [2.810801460987502, 48.36795221970639],
                            [2.810770031941613, 48.36773666067906],
                            [2.810721638996953, 48.36752748657377],
                            [2.810651056614941, 48.36731617889527],
                            [2.810569179592014, 48.36707731999777],
                            [2.81048727966102, 48.366863395763346],
                            [2.810351990738025, 48.36658135533083],
                            [2.810199833984077, 48.36626414411335],
                            [2.8099819127011, 48.36590895217408],
                            [2.809795861568467, 48.365641753494614],
                            [2.809566164376916, 48.36532527774554],
                            [2.809336925867321, 48.36505735923569],
                            [2.809072492316782, 48.36479288960506],
                            [2.808781521299228, 48.36450660856349],
                            [2.80846545793831, 48.36422530734343],
                            [2.808257872629849, 48.36406549923453],
                            [2.808004038285347, 48.363870278762185],
                            [2.807738186184881, 48.36368638238577],
                            [2.807449237970457, 48.36350143390745],
                            [2.807227972902301, 48.36336584467541],
                            [2.80700416916066, 48.363242105176944],
                            [2.806791892142428, 48.36312319377371],
                            [2.806532219331344, 48.36298997692461],
                            [2.806316854235649, 48.36288457742787],
                            [2.806087570308325, 48.3627719041596],
                            [2.805855997703855, 48.36265810567422],
                            [2.805581904502054, 48.362523612492865],
                            [2.805112847548699, 48.36229265106712],
                            [2.804444608587908, 48.36195877838189],
                            [2.802978524232097, 48.36122627750964],
                            [2.802429903403687, 48.36095215868656],
                            [2.80189983959655, 48.36068726402109],
                            [2.801444420001418, 48.36046009010383],
                            [2.800876365653938, 48.36017979634537],
                            [2.798944709176131, 48.359222813979834],
                            [2.797536386048403, 48.35852872378684],
                            [2.796832600873678, 48.35818185013968],
                            [2.796355802254994, 48.35794833965115],
                            [2.795735811807697, 48.35763369984602],
                            [2.794165334961084, 48.35685204569394],
                            [2.78979293037002, 48.35467548339257],
                            [2.787345380185906, 48.3534649848033],
                            [2.784899288019739, 48.352253529213584],
                            [2.782453322301761, 48.351042919056034],
                            [2.780007481545479, 48.34983315613476],
                            [2.779148378851981, 48.34940398307679],
                            [2.777266286282123, 48.34846622437487],
                            [2.775769173882739, 48.34773286722875],
                            [2.775168467063438, 48.34743993340582],
                            [2.774654838264852, 48.34718742553389],
                            [2.774090624224166, 48.34690842440341],
                            [2.773414465180275, 48.34657206824231],
                            [2.772391612913229, 48.346069738584816],
                            [2.771817199743027, 48.345787789019745],
                            [2.771156294979855, 48.34546168402381],
                            [2.770521636538296, 48.34512388678718],
                            [2.770141451961348, 48.34490883254907],
                            [2.769667987775808, 48.3446370323269],
                            [2.769240943266641, 48.34436743129193],
                            [2.768882041358417, 48.34413563667834],
                            [2.768271824744296, 48.34373111313951],
                            [2.767840963248556, 48.34343059188321],
                            [2.767492555918279, 48.34317258079742],
                            [2.76725535831382, 48.342980764255366],
                            [2.766982209478003, 48.34275815341179],
                            [2.766403678144707, 48.34229877768275],
                            [2.765724601045989, 48.341766022681426],
                            [2.765318588691842, 48.34144636280191],
                            [2.765063482441401, 48.34124509340032],
                            [2.764815598978347, 48.34105331254801],
                            [2.76455956609762, 48.34086244164286],
                            [2.764171475269018, 48.34058964016269],
                            [2.763778677600431, 48.34034112629955],
                            [2.763207739784304, 48.33999110208336],
                            [2.762655424206349, 48.33966960600864],
                            [2.762160615341695, 48.33939547531839],
                            [2.761705490616973, 48.33917115809785],
                            [2.761225286394286, 48.338935037461574],
                            [2.760755975484152, 48.33872028596698],
                            [2.760043243520127, 48.33841603436495],
                            [2.759040459312793, 48.3380323509091],
                            [2.758278940060271, 48.33776116412743],
                            [2.757729843734565, 48.337582462456346],
                            [2.757119159292535, 48.33740148971741],
                            [2.756523894664542, 48.3372407394336],
                            [2.755911018252329, 48.33710061432007],
                            [2.755193949527226, 48.33693846357185],
                            [2.754616217746583, 48.336808820271116],
                            [2.754005047174062, 48.33669449508738],
                            [2.753208202397128, 48.33656657584971],
                            [2.752422321989855, 48.33646954044065],
                            [2.751754945500969, 48.33639850510893],
                            [2.75095841426223, 48.33632791515356],
                            [2.750484447768678, 48.33629003128472],
                            [2.749855363300322, 48.3362646919118],
                            [2.74937002803512, 48.33624464777485],
                            [2.748837186785384, 48.33623310392106],
                            [2.747990189927628, 48.336233491807846],
                            [2.746835928354824, 48.3362637659126],
                            [2.746254755349334, 48.33627936198361],
                            [2.745486952961956, 48.3362972192121],
                            [2.744986769326461, 48.33630906395358],
                            [2.744190244502054, 48.33632729178352],
                            [2.743660305068411, 48.33634089125678],
                            [2.74310471746014, 48.33635188385259],
                            [2.740744925188887, 48.33641160247909],
                            [2.738387831447255, 48.33647216267016],
                            [2.738001618532588, 48.336481780613234],
                        ],
                    },
                },
                150: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.12137306210128, 2.7670868898131036],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 5856.19123313,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.762728388543796,
                            48.09650277877714,
                            2.774122167142249,
                            48.14721803991587,
                        ),
                        "coordinates": [
                            [2.762728388543796, 48.14721803991587],
                            [2.76273124070775, 48.14692600279808],
                            [2.762737587948206, 48.14608701359404],
                            [2.762731355484866, 48.145190522916145],
                            [2.762737017123065, 48.1442706069449],
                            [2.762732068918912, 48.143366918204336],
                            [2.762740038379433, 48.142561194296455],
                            [2.762749366108946, 48.1415981038468],
                            [2.762761928003978, 48.14069974419957],
                            [2.762767771373231, 48.13980141098956],
                            [2.762772377652811, 48.13891567061274],
                            [2.762774289639833, 48.13802904155212],
                            [2.762780581342609, 48.13718376005438],
                            [2.762787334268553, 48.136234168354456],
                            [2.762786065436448, 48.13528910318546],
                            [2.76279185536933, 48.13438447673979],
                            [2.762795723004767, 48.13341151679277],
                            [2.76279800660798, 48.132568949314575],
                            [2.762797785334969, 48.132383712904534],
                            [2.762792466697309, 48.131754286685364],
                            [2.762804865578496, 48.13083704575186],
                            [2.762810212589824, 48.12988026735892],
                            [2.762817913102712, 48.12888391545409],
                            [2.762827917607845, 48.12768343432905],
                            [2.762832292342056, 48.1266115614433],
                            [2.762836012496911, 48.12546235950826],
                            [2.762851370833684, 48.12410090014393],
                            [2.762868537246985, 48.12374834587039],
                            [2.76289268551721, 48.12342723794915],
                            [2.762916575377397, 48.12323471695812],
                            [2.762954784014198, 48.12298819005845],
                            [2.763002490295106, 48.1227533162626],
                            [2.763085704013368, 48.12242928620231],
                            [2.763185215189774, 48.12212677610113],
                            [2.763290507295784, 48.12187280062092],
                            [2.763414432253781, 48.12159897224304],
                            [2.763561048419426, 48.12130887231516],
                            [2.763766242014921, 48.12095830301011],
                            [2.764018198635113, 48.12057968062769],
                            [2.764182768967725, 48.12034885962159],
                            [2.764403459228069, 48.12008455388772],
                            [2.764634866271736, 48.11981751016425],
                            [2.76494501251472, 48.11949261621677],
                            [2.765250188618764, 48.11921539968384],
                            [2.765536821318116, 48.11896882477002],
                            [2.765879582481076, 48.11869056363751],
                            [2.766161189825298, 48.11848537094358],
                            [2.771079631821379, 48.11361145787937],
                            [2.773060532582075, 48.10992778590111],
                            [2.774122167142249, 48.10575752160171],
                            [2.773713826426943, 48.10085776549668],
                            [2.77230261766097, 48.09650277877714],
                        ],
                    },
                },
                151: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.82974976174606, 2.5009613591628375],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2304.08009043,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.494188055346116,
                            48.82484856949889,
                            2.511855553451007,
                            48.839341939180265,
                        ),
                        "coordinates": [
                            [2.494188055346116, 48.839341939180265],
                            [2.494247766895406, 48.838846953662475],
                            [2.49428634106946, 48.83850665376865],
                            [2.494335041496361, 48.83794981945879],
                            [2.49440876096613, 48.83732632879831],
                            [2.49444007068898, 48.83696938300809],
                            [2.494492824963791, 48.83655530353588],
                            [2.494553057041376, 48.83622687146399],
                            [2.494606625712022, 48.83600754436564],
                            [2.494677919395311, 48.835757614148676],
                            [2.494785088492835, 48.83545528867773],
                            [2.494874454512325, 48.83522198901582],
                            [2.494988959541596, 48.83496010230668],
                            [2.495092814994253, 48.834750575106625],
                            [2.495250507616648, 48.83446959352472],
                            [2.495401095686161, 48.83422193256743],
                            [2.496322846076571, 48.832809693311546],
                            [2.496712946261206, 48.83219844504028],
                            [2.497140330411507, 48.831552605217134],
                            [2.497320489863974, 48.83129060209894],
                            [2.49768548971296, 48.830733342726056],
                            [2.497893531093397, 48.83042849144205],
                            [2.4981267353821, 48.83010457095283],
                            [2.498321673575904, 48.82986671831846],
                            [2.498521609160343, 48.82962576369708],
                            [2.49869037660845, 48.82943755598253],
                            [2.499101887977773, 48.829023344577465],
                            [2.499323720496731, 48.828814886859284],
                            [2.499628931941801, 48.828544098368724],
                            [2.499934239976472, 48.82830409190573],
                            [2.500267467584421, 48.82804497023481],
                            [2.500646486652083, 48.82778552795893],
                            [2.501191511108631, 48.82743672379359],
                            [2.501691788944037, 48.82715003217035],
                            [2.502106461696296, 48.826926411390446],
                            [2.502574264952994, 48.82670720837081],
                            [2.502874036656867, 48.82657485091107],
                            [2.50319948682061, 48.826442221633926],
                            [2.503541299313914, 48.826302924058766],
                            [2.504073190058934, 48.826109700224784],
                            [2.504311268842221, 48.8260293155916],
                            [2.504535748512162, 48.82595929506318],
                            [2.504858178104163, 48.82586103227905],
                            [2.505331909786763, 48.825726674456156],
                            [2.505642006799357, 48.82564965816218],
                            [2.506225849975233, 48.825518398747874],
                            [2.506561054164337, 48.82545323751325],
                            [2.507099534828155, 48.82535528254552],
                            [2.50754384646785, 48.82528963736865],
                            [2.507984529348589, 48.825229805287194],
                            [2.508844977549582, 48.825138583558406],
                            [2.509435855385033, 48.82507654159762],
                            [2.509914257207523, 48.82502670696369],
                            [2.510482958774583, 48.82497528756578],
                            [2.511177234201497, 48.82491292453119],
                            [2.511855553451007, 48.82484856949889],
                        ],
                    },
                },
                152: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.87412669089637, 2.610452466832867],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3992.07205924,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.583331158055108,
                            48.873371395535315,
                            2.637590717167975,
                            48.87520826545471,
                        ),
                        "coordinates": [
                            [2.583331158055108, 48.87414408301457],
                            [2.585207558695742, 48.873954442853965],
                            [2.585510387322357, 48.873923668498286],
                            [2.586323765709928, 48.873841008135635],
                            [2.58841899418083, 48.87365331474768],
                            [2.589324219151641, 48.87358189178765],
                            [2.589854110628206, 48.8735470495907],
                            [2.590571671217689, 48.87350581800877],
                            [2.59134977905419, 48.87346725117777],
                            [2.592208167334582, 48.87343080360643],
                            [2.592735079834614, 48.87341120715678],
                            [2.59340507342645, 48.873388985527676],
                            [2.593904110134702, 48.87337865475599],
                            [2.594525981654122, 48.873371395535315],
                            [2.59531395576001, 48.873376241105404],
                            [2.596024942027703, 48.87338319679672],
                            [2.596830117163757, 48.87339849915184],
                            [2.597560626610289, 48.87341396687035],
                            [2.598430785469064, 48.87343981727825],
                            [2.599125643294948, 48.87346606367441],
                            [2.599690649112652, 48.873492603904495],
                            [2.601340211186603, 48.87357017043353],
                            [2.603622561980809, 48.873675412130865],
                            [2.607039420624726, 48.873834409481375],
                            [2.611011574659458, 48.874019276925736],
                            [2.615896285505255, 48.87424741244236],
                            [2.618256815721966, 48.87435225607318],
                            [2.623245817549538, 48.87458636034341],
                            [2.62535912649922, 48.87467809073089],
                            [2.627551798882467, 48.874754052580975],
                            [2.62981148833539, 48.87485443246263],
                            [2.631172890821067, 48.87490486500882],
                            [2.63248189675449, 48.87496461168814],
                            [2.634268630284971, 48.87505993357167],
                            [2.636043476594933, 48.87513487798265],
                            [2.637590717167975, 48.87520826545471],
                        ],
                    },
                },
                153: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.16029172996976, 3.0952712416096126],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 6051.41950253,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.075626562947475,
                            49.13547414375095,
                            3.12061291667141,
                            49.179504949934255,
                        ),
                        "coordinates": [
                            [3.075626562947475, 49.13547414375095],
                            [3.07593991650652, 49.13828659666273],
                            [3.076101032370153, 49.139069755821595],
                            [3.076317468340032, 49.13970237391073],
                            [3.076430597472889, 49.13993456608019],
                            [3.087687495154015, 49.153982716666256],
                            [3.099703478640675, 49.16733030611128],
                            [3.1116530363399, 49.17602932425011],
                            [3.12061291667141, 49.179504949934255],
                        ],
                    },
                },
                154: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.54158017398183, 3.132339202182192],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 18930.2274681,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.011769326340159,
                            48.51375459097529,
                            3.250034982583049,
                            48.562124835009335,
                        ),
                        "coordinates": [
                            [3.250034982583049, 48.51375459097529],
                            [3.249853945357546, 48.51389872290486],
                            [3.249138844995903, 48.51447015954613],
                            [3.247753636545094, 48.51563334044736],
                            [3.246758844411207, 48.51645882048767],
                            [3.246041668711754, 48.51706892450682],
                            [3.245649465686489, 48.51738683453011],
                            [3.245209903375309, 48.5177060229367],
                            [3.244929359176486, 48.51791151926874],
                            [3.244497516600703, 48.51820905850838],
                            [3.244084047518781, 48.518474973117506],
                            [3.243663593912424, 48.518729250947516],
                            [3.243276501400833, 48.51895717945212],
                            [3.24298857430668, 48.51912945551102],
                            [3.242645385238286, 48.519314425227265],
                            [3.242136961404717, 48.519571902305024],
                            [3.241798657694586, 48.5197298657957],
                            [3.241457664070075, 48.51988784905679],
                            [3.241039197446301, 48.520069650141146],
                            [3.240448496523091, 48.52030087851992],
                            [3.239557288674779, 48.520651524807924],
                            [3.238441656931013, 48.52109478124457],
                            [3.237391669432112, 48.52150063351466],
                            [3.236347255484608, 48.52191632466226],
                            [3.235285488950892, 48.522337250278],
                            [3.234365570085992, 48.52268567380888],
                            [3.233755261989401, 48.52292869057292],
                            [3.232861321848435, 48.523281240508254],
                            [3.232035885563069, 48.52360612638846],
                            [3.230844718761034, 48.524072387904965],
                            [3.229430345244032, 48.524625830772884],
                            [3.227673709987366, 48.52529554060056],
                            [3.225588891633128, 48.52611922690337],
                            [3.224679813252694, 48.52646629779769],
                            [3.223682271251082, 48.52685982209516],
                            [3.222502957180112, 48.527320603065974],
                            [3.220706679366514, 48.52803250392],
                            [3.218524096889001, 48.52887688451809],
                            [3.217145530280503, 48.52941623057007],
                            [3.216042838639051, 48.52983415663934],
                            [3.215070703394111, 48.530185567322945],
                            [3.214098824653648, 48.53052005030102],
                            [3.212262189287973, 48.531133270260696],
                            [3.211258078677476, 48.531476469914644],
                            [3.210488256671631, 48.531745010113106],
                            [3.20983147652462, 48.53197400301876],
                            [3.20773178410411, 48.532699724273094],
                            [3.20649070083182, 48.53312384273446],
                            [3.204363522912061, 48.5338631097363],
                            [3.203561324348018, 48.53414106600199],
                            [3.202600035881683, 48.53447187593961],
                            [3.201604929095662, 48.5348079771379],
                            [3.201017600239632, 48.53501227341592],
                            [3.200412362702639, 48.53522546759334],
                            [3.199789416124002, 48.53543503525303],
                            [3.199307558779785, 48.53557773570062],
                            [3.198801710715775, 48.5357139002397],
                            [3.198339811005731, 48.535838196855515],
                            [3.197922815967738, 48.535942206308],
                            [3.197436122316396, 48.53604740952538],
                            [3.196924097493987, 48.536151449072094],
                            [3.196406272389532, 48.53624408225733],
                            [3.195765166901817, 48.536346614464804],
                            [3.195154189062761, 48.536432536302236],
                            [3.194652856395575, 48.53649478781314],
                            [3.193645680817977, 48.53659323762959],
                            [3.19265693272599, 48.536660962975574],
                            [3.191890856351761, 48.53668383189958],
                            [3.190948450629059, 48.536690039423775],
                            [3.190214240283105, 48.53667578505952],
                            [3.189431985313782, 48.53663611795202],
                            [3.188763841827345, 48.53659226871273],
                            [3.188058502824284, 48.53652382458915],
                            [3.187237601817624, 48.53642836526992],
                            [3.186337789008579, 48.536311007942096],
                            [3.184403767562205, 48.53605569323023],
                            [3.182431670942092, 48.535789838231885],
                            [3.181055479998649, 48.53560764539772],
                            [3.179885618917621, 48.53545447666611],
                            [3.178502660561405, 48.5352714036136],
                            [3.177724974621389, 48.53516656072753],
                            [3.176424760047027, 48.53499094203191],
                            [3.174262802065457, 48.53470297047485],
                            [3.172870423691708, 48.534520798309735],
                            [3.169903832762767, 48.5341316587778],
                            [3.168747879502285, 48.533996260132675],
                            [3.168147771849165, 48.53393023725482],
                            [3.167499263779493, 48.53387431693945],
                            [3.16709572080642, 48.53384515129412],
                            [3.166692238389889, 48.53381955368603],
                            [3.166061993587139, 48.533791117755705],
                            [3.164978130007166, 48.53375587654628],
                            [3.16378894386412, 48.533738481320356],
                            [3.162903440036716, 48.53374314054031],
                            [3.162365255449034, 48.5337541515964],
                            [3.161656850673534, 48.533775603691815],
                            [3.160987396839414, 48.53381036193435],
                            [3.159994317769176, 48.53387375923635],
                            [3.15927218159047, 48.53393412826336],
                            [3.158919305729981, 48.533967264710874],
                            [3.158373110997732, 48.53401978891238],
                            [3.157395905592261, 48.53413028976209],
                            [3.156772959585215, 48.53420944186886],
                            [3.156363582890293, 48.53426546277316],
                            [3.155515424325035, 48.534391610763095],
                            [3.154679469972308, 48.534538430487245],
                            [3.153942756618073, 48.53467600142997],
                            [3.153329965299476, 48.53480216163728],
                            [3.152777910311315, 48.534923527803116],
                            [3.152103397177411, 48.53508668732859],
                            [3.151150991228357, 48.53530847062247],
                            [3.150469732657855, 48.53546714684498],
                            [3.149561876351572, 48.53568140262141],
                            [3.148969636321698, 48.53581874637556],
                            [3.147920107952338, 48.53606547942096],
                            [3.146858354889337, 48.53631049197145],
                            [3.146023147843207, 48.53649722008421],
                            [3.14490348682026, 48.536763311752246],
                            [3.143267193716167, 48.53715537643393],
                            [3.142208117891897, 48.537401225541814],
                            [3.141529495522832, 48.537558928598095],
                            [3.140142610581884, 48.537884425897964],
                            [3.139155122735691, 48.53812074568456],
                            [3.138359038846482, 48.53830174435092],
                            [3.138041958613676, 48.53837413300859],
                            [3.137374200647418, 48.538535331278105],
                            [3.136985653771198, 48.53862710701978],
                            [3.135090028836219, 48.53906944650952],
                            [3.13381352113094, 48.539358115573876],
                            [3.132608709487235, 48.539642669863674],
                            [3.131626512588099, 48.53987528927635],
                            [3.130605036066385, 48.54010817486039],
                            [3.129742994026311, 48.540318352680806],
                            [3.129091261897971, 48.540468598319706],
                            [3.128484070626437, 48.540609536634065],
                            [3.12787825815666, 48.54075225957793],
                            [3.127012031383058, 48.540956151111395],
                            [3.126078333061371, 48.54117579263791],
                            [3.12411768625052, 48.541629191303464],
                            [3.120941283457941, 48.54237065892662],
                            [3.117901110811394, 48.54308231959451],
                            [3.117299272649429, 48.54322316004994],
                            [3.114935025965158, 48.54377360473222],
                            [3.114287295559121, 48.54392553610051],
                            [3.112541059051712, 48.54433229721375],
                            [3.111847437449446, 48.54449532053042],
                            [3.109492578192943, 48.5450473854617],
                            [3.108365650791605, 48.545305968975626],
                            [3.105821835994189, 48.54590600648883],
                            [3.103650310548614, 48.54640994146619],
                            [3.101285845555926, 48.5469654971732],
                            [3.097734899902423, 48.54779426483861],
                            [3.095715730592144, 48.548263745542705],
                            [3.094916695703703, 48.54844985133962],
                            [3.093757252919604, 48.54871839658532],
                            [3.093282136219811, 48.54882858455425],
                            [3.091859481183006, 48.54915911963083],
                            [3.089720122314041, 48.54965986920119],
                            [3.087837150947541, 48.55009862744388],
                            [3.085271061882689, 48.55069204930398],
                            [3.08446929492454, 48.55088169636795],
                            [3.083346254485842, 48.55114629684202],
                            [3.08178987602475, 48.551510858857185],
                            [3.077856149761744, 48.55242155099415],
                            [3.077008534714337, 48.55262187856622],
                            [3.075961145805754, 48.55286784255948],
                            [3.074940598906934, 48.553111836429025],
                            [3.073909106396766, 48.55334340005444],
                            [3.072960770269283, 48.553563707860455],
                            [3.072135698142945, 48.55375822502891],
                            [3.071313045462485, 48.553934873457585],
                            [3.070610738023913, 48.554069693820395],
                            [3.069986036783935, 48.55418080703257],
                            [3.06937558422581, 48.55428617489089],
                            [3.068574371997201, 48.554398422471614],
                            [3.067865849386374, 48.55447675441995],
                            [3.067107115382745, 48.554553025317375],
                            [3.065040411280048, 48.554752837811805],
                            [3.06359014450487, 48.55488534618906],
                            [3.062009473752052, 48.555025194893716],
                            [3.061092680987014, 48.55510906501933],
                            [3.059378646121201, 48.55527018288535],
                            [3.058118125786075, 48.555385322965634],
                            [3.057165302767761, 48.55547132042359],
                            [3.055322690347238, 48.555642187254584],
                            [3.053001077492066, 48.55585292094307],
                            [3.049947482324466, 48.55612846712036],
                            [3.048252200809361, 48.556279406405196],
                            [3.045097126257802, 48.55656714974675],
                            [3.043580570400756, 48.5567133056116],
                            [3.040996384036385, 48.55694791239956],
                            [3.040103363556948, 48.55702539829785],
                            [3.038634000989672, 48.55715770568853],
                            [3.037293140737366, 48.5572766107589],
                            [3.035643838746968, 48.55742707779664],
                            [3.034163690882344, 48.55756478982158],
                            [3.033353280096604, 48.55764171458729],
                            [3.032004254794427, 48.55775970680259],
                            [3.030923125387875, 48.55785356219038],
                            [3.029524142644331, 48.55798442079056],
                            [3.025989951964486, 48.55830272366499],
                            [3.024960189425027, 48.55838991447917],
                            [3.023929242114034, 48.55848969300562],
                            [3.021603228169595, 48.55869441421202],
                            [3.021076775685551, 48.55873446394976],
                            [3.020474671050076, 48.55879025482424],
                            [3.019850997161139, 48.55884729572404],
                            [3.019292611779082, 48.558905383348964],
                            [3.018734549412604, 48.55898726138023],
                            [3.018291050030732, 48.559058929132455],
                            [3.017929953753836, 48.55912772226823],
                            [3.017590559295051, 48.55920059864839],
                            [3.017194494254066, 48.55929464055645],
                            [3.016827162414875, 48.559392548736675],
                            [3.016424028134937, 48.55951488257897],
                            [3.016056068111987, 48.55963336922651],
                            [3.015676191709057, 48.55977418039796],
                            [3.015210056313884, 48.559965050489836],
                            [3.01460137873621, 48.560258091731235],
                            [3.014123955959843, 48.56050439353964],
                            [3.013723247820952, 48.56074176193987],
                            [3.013341726240904, 48.56098145302508],
                            [3.012867991809824, 48.561315219453775],
                            [3.012291165334066, 48.561740426398096],
                            [3.011769326340159, 48.562124835009335],
                        ],
                    },
                },
                155: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.73820855442225, 2.443557312087149],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1845.03556701,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.438344239163614,
                            48.73011683142026,
                            2.446290833250972,
                            48.745230819408114,
                        ),
                        "coordinates": [
                            [2.446135830934545, 48.73011683142026],
                            [2.446160508450207, 48.730246306539605],
                            [2.446222422872905, 48.730584373317015],
                            [2.446248693104217, 48.73078578508506],
                            [2.446269528987294, 48.730988100725234],
                            [2.446269615326568, 48.73102766850042],
                            [2.446272415584877, 48.73106453614594],
                            [2.446273879119162, 48.73111219629473],
                            [2.446282312306956, 48.73123808629105],
                            [2.446290833250972, 48.73140354404188],
                            [2.446288478243837, 48.73156901247847],
                            [2.446287565201259, 48.73177224885048],
                            [2.446281302495835, 48.73201505829245],
                            [2.446276313061863, 48.73221919760409],
                            [2.446266041324861, 48.73249348589149],
                            [2.446236631618638, 48.73278306037673],
                            [2.446215780519422, 48.73300213223851],
                            [2.446167245499712, 48.73337190552676],
                            [2.446119054693386, 48.73387110074781],
                            [2.446088788355104, 48.73425220060114],
                            [2.446034357101834, 48.734706818113786],
                            [2.446017268650283, 48.734973918225386],
                            [2.446004070876241, 48.73515468476403],
                            [2.445977310335536, 48.735350751647665],
                            [2.445939762913628, 48.735587296248184],
                            [2.445860381998591, 48.73596596659345],
                            [2.445774256046163, 48.73636982210687],
                            [2.445666632296345, 48.73689060437912],
                            [2.445607303913415, 48.73711547885987],
                            [2.445570889406429, 48.73724950585651],
                            [2.445510137380059, 48.73744560510114],
                            [2.445462812981973, 48.737565253314656],
                            [2.445383029303381, 48.73776227050722],
                            [2.445289642676271, 48.73795660254881],
                            [2.445154201945167, 48.73819413957204],
                            [2.445018685233024, 48.73839750464062],
                            [2.444904842413411, 48.738563978272616],
                            [2.444744830478017, 48.738757473784304],
                            [2.444580700532257, 48.73893388758578],
                            [2.444396194167901, 48.73911841366572],
                            [2.444231998310451, 48.7392651506375],
                            [2.444055585243407, 48.739420891395646],
                            [2.44383707055715, 48.73959915370179],
                            [2.443611736536056, 48.739768429021964],
                            [2.443360601504762, 48.739953015220834],
                            [2.442567756625349, 48.74050770886944],
                            [2.441554548523095, 48.741237240206225],
                            [2.441230557603763, 48.74148465724214],
                            [2.440953696087649, 48.74172861447228],
                            [2.440766405962939, 48.74189425143231],
                            [2.440610371240031, 48.74205176693014],
                            [2.440486911126692, 48.742182274655434],
                            [2.440334983952946, 48.74235417387515],
                            [2.440150509190862, 48.7425674696153],
                            [2.439631097472172, 48.74322261156942],
                            [2.439130624977952, 48.74383726739878],
                            [2.438931269855138, 48.744093739458705],
                            [2.438784855113378, 48.744306998508705],
                            [2.438679150644873, 48.744480652452346],
                            [2.438584332826893, 48.7446596929051],
                            [2.438505805511379, 48.74482522934107],
                            [2.438443153463417, 48.744956580996465],
                            [2.438393051958888, 48.745087488858424],
                            [2.438344239163614, 48.745230819408114],
                        ],
                    },
                },
                156: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.68305239679522, 2.3676079915120343],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2706.5412615,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352481401048998,
                            48.676446656997726,
                            2.382757203082266,
                            48.68969793365298,
                        ),
                        "coordinates": [
                            [2.352481401048998, 48.676446656997726],
                            [2.352651710635371, 48.676611194955726],
                            [2.352968137765413, 48.676883253100854],
                            [2.353598371553556, 48.67736336978714],
                            [2.354080550656454, 48.67769512658065],
                            [2.354733699512631, 48.67809203212078],
                            [2.355333834707852, 48.67841314223769],
                            [2.355893769256218, 48.67867413588618],
                            [2.356466925031537, 48.67891773907016],
                            [2.356770974291829, 48.679041341532646],
                            [2.357072676012722, 48.67915503885028],
                            [2.357351910387353, 48.679254329499415],
                            [2.357633701449175, 48.67935257185632],
                            [2.358043358131362, 48.67948335743325],
                            [2.358302089057277, 48.67956420652395],
                            [2.358550040447846, 48.67963791717336],
                            [2.358866264717556, 48.67972589062563],
                            [2.359225608812028, 48.67981861398919],
                            [2.359761028415913, 48.67994461033868],
                            [2.360329534296937, 48.68007435902309],
                            [2.360932470570231, 48.68021749939525],
                            [2.361503833830279, 48.68035299737065],
                            [2.36184521812357, 48.68043619802744],
                            [2.362175820604817, 48.68051464199508],
                            [2.362409400013626, 48.68057407190389],
                            [2.36265736285523, 48.680650154000254],
                            [2.362952044943171, 48.680742880151506],
                            [2.363271883412531, 48.68084273701301],
                            [2.363523448957911, 48.68093071245555],
                            [2.363814547340856, 48.681035333723756],
                            [2.364173940603852, 48.681182764377915],
                            [2.364483016886978, 48.68130403400878],
                            [2.364971794667307, 48.68150139774188],
                            [2.36547136498358, 48.68171303144649],
                            [2.36578405258717, 48.68185333109283],
                            [2.366103925304415, 48.68199124936919],
                            [2.366466942603685, 48.68216722481026],
                            [2.366758083280973, 48.68231942448375],
                            [2.366959375894221, 48.68243833590251],
                            [2.367243339037844, 48.68260243332113],
                            [2.367469798856948, 48.68274037288902],
                            [2.367760957277161, 48.68291160412782],
                            [2.368059310811836, 48.683092350634624],
                            [2.368350488591731, 48.68328737456252],
                            [2.368612906265408, 48.68345623233758],
                            [2.368904079792835, 48.68363697817642],
                            [2.369166493762556, 48.68379393805232],
                            [2.369450472553815, 48.683958030034155],
                            [2.369730860075062, 48.68412212121583],
                            [2.370362016312544, 48.68445883056417],
                            [2.371006933646718, 48.68475940117238],
                            [2.371671910468043, 48.68504471697853],
                            [2.372390799871556, 48.68533477055899],
                            [2.373131245413605, 48.68560815673932],
                            [2.373775282734897, 48.68581978797649],
                            [2.374087336073916, 48.68592436399419],
                            [2.37434992310769, 48.6860039492812],
                            [2.374860705818699, 48.6861530574915],
                            [2.375603774728401, 48.686348846074864],
                            [2.376991511385021, 48.68672513374018],
                            [2.377465966812344, 48.686860586385485],
                            [2.377954820330918, 48.687019824363254],
                            [2.378508397119493, 48.68722424398286],
                            [2.379083571683295, 48.68746196250001],
                            [2.379601250329117, 48.687699700193626],
                            [2.380038646964371, 48.68791431984325],
                            [2.380633434791751, 48.68826138717864],
                            [2.382057704915416, 48.689197865937366],
                            [2.382407004307814, 48.689448621645965],
                            [2.382757203082266, 48.68969793365298],
                        ],
                    },
                },
                157: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.70098871594943, 2.3933781192115724],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2979.62085903,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.382757203082266,
                            48.68969793365298,
                            2.403633104908493,
                            48.71262898747625,
                        ),
                        "coordinates": [
                            [2.382757203082266, 48.68969793365298],
                            [2.383045806984474, 48.68990339294061],
                            [2.383230663352005, 48.69004540272094],
                            [2.38345493979785, 48.69021796980802],
                            [2.384025918477654, 48.69074740314599],
                            [2.384494979877404, 48.69121752392339],
                            [2.384936890498618, 48.691695748125035],
                            [2.385571844184228, 48.69232856255648],
                            [2.386115722608555, 48.69287778020683],
                            [2.388439743080135, 48.69538570681775],
                            [2.389199942623788, 48.696188405541065],
                            [2.389924826868116, 48.696972231572516],
                            [2.390523270418308, 48.69763920728414],
                            [2.390955746082016, 48.69807964382771],
                            [2.391208720371253, 48.69835020305846],
                            [2.391541944909567, 48.698706153166206],
                            [2.392333599661923, 48.699605937312384],
                            [2.393121165310217, 48.700467948296954],
                            [2.39387341168129, 48.70130928933809],
                            [2.394578044363382, 48.702075110306524],
                            [2.395354774138076, 48.702899342748864],
                            [2.395813300584402, 48.703465645033965],
                            [2.396119453143499, 48.70385127241293],
                            [2.396779365218163, 48.7046539738991],
                            [2.397523664407638, 48.70556184101406],
                            [2.397633887097888, 48.70569937009275],
                            [2.39780262031756, 48.705907910418155],
                            [2.398790582515602, 48.707147467869454],
                            [2.399143026197246, 48.70757083148948],
                            [2.399769008776976, 48.708328569929],
                            [2.400420900819729, 48.70914474331237],
                            [2.400912159347558, 48.70971730056517],
                            [2.402222690553023, 48.711156499190864],
                            [2.402568361349131, 48.71155364541476],
                            [2.402816812970916, 48.711836640859524],
                            [2.403076020967614, 48.712095835821586],
                            [2.403390114759124, 48.71239119577324],
                            [2.403633104908493, 48.71262898747625],
                        ],
                    },
                },
                158: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84605814805444, 2.31211295314543],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 812.698766286,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307402240619641,
                            48.84532666016781,
                            2.317005235737245,
                            48.84706613315245,
                        ),
                        "coordinates": [
                            [2.317005235737245, 48.846989106139524],
                            [2.316634671102764, 48.84685485575205],
                            [2.3162490013665, 48.84671315388128],
                            [2.315374875791169, 48.84644494378696],
                            [2.312067879030493, 48.84543016051683],
                            [2.311954699311265, 48.84539866505795],
                            [2.311825114563824, 48.84537008169891],
                            [2.311692461861698, 48.84534847040511],
                            [2.311557608614055, 48.84533397555995],
                            [2.311421422902659, 48.845326690290776],
                            [2.311284791149452, 48.84532666016781],
                            [2.311148597644598, 48.8453338857848],
                            [2.311013725934533, 48.84534832096804],
                            [2.310881051987304, 48.84536987453588],
                            [2.310751437512516, 48.845398400366896],
                            [2.310653537884301, 48.84542521834227],
                            [2.309724111819044, 48.8457025690233],
                            [2.309652612949601, 48.84572431139976],
                            [2.309521848519459, 48.8457698848026],
                            [2.3093966087611, 48.8458217810049],
                            [2.309277595182059, 48.84587970908208],
                            [2.309165475664999, 48.84594334554007],
                            [2.309136689723739, 48.84596131678528],
                            [2.307402240619641, 48.84706613315245],
                        ],
                    },
                },
                159: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.852237513415986, 2.3309631639692987],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 695.842044683,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.326488473969165,
                            48.851192349321856,
                            2.335502051727559,
                            48.85301676791718,
                        ),
                        "coordinates": [
                            [2.335502051727559, 48.85301676791718],
                            [2.335145283308617, 48.852942114518896],
                            [2.334697790355912, 48.85284847566291],
                            [2.334057378978815, 48.852737246682715],
                            [2.33353072296907, 48.85267513941075],
                            [2.333225963365026, 48.852670496104],
                            [2.332822899226455, 48.85261951139787],
                            [2.328769344818776, 48.851897025405954],
                            [2.327802871339836, 48.85166218976492],
                            [2.327639491233927, 48.85161900377258],
                            [2.327446888673913, 48.851560939807065],
                            [2.327259115995632, 48.85149635535886],
                            [2.327102988253409, 48.85143618275847],
                            [2.32693524339044, 48.85137882973943],
                            [2.326488473969165, 48.851192349321856],
                        ],
                    },
                },
                160: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.04534072858193, 2.106172270618482],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 155.514119079,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.105110703444507,
                            49.04530962796638,
                            2.107233059674136,
                            49.04539401994291,
                        ),
                        "coordinates": [
                            [2.107233059674136, 49.04539401994291],
                            [2.106582403517276, 49.045354551360596],
                            [2.105934758426439, 49.04532512796745],
                            [2.105610917541017, 49.04531443254045],
                            [2.105221049327595, 49.04530962796638],
                            [2.105110703444507, 49.045311648350264],
                        ],
                    },
                },
                161: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80063291553285, 2.1747611804387925],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 496.243917546,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.171389812756379,
                            48.800562566282714,
                            2.178130972336866,
                            48.800720766349464,
                        ),
                        "coordinates": [
                            [2.171389812756379, 48.80071846386355],
                            [2.171400515562385, 48.80071880338744],
                            [2.171903089010338, 48.800720766349464],
                            [2.172336889530995, 48.8007152310616],
                            [2.173064633662477, 48.800682384781815],
                            [2.174282238330508, 48.80061633996727],
                            [2.175919822294987, 48.800562566282714],
                            [2.176654529377904, 48.80057787835856],
                            [2.177065087651669, 48.80059035108217],
                            [2.177472022349711, 48.80060995499961],
                            [2.177821314060172, 48.80063423733164],
                            [2.178130972336866, 48.80066322078583],
                        ],
                    },
                },
                162: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80030825690828, 2.1809198019738107],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 424.489649532,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.178130973726579,
                            48.79972882534396,
                            2.183684109854236,
                            48.800695034197034,
                        ),
                        "coordinates": [
                            [2.183684109854236, 48.79972882534396],
                            [2.181549600534488, 48.800207172114476],
                            [2.181037401196676, 48.80032158054706],
                            [2.180435311758618, 48.80045025127266],
                            [2.180044832620709, 48.8005272873863],
                            [2.179621038661392, 48.80059951195484],
                            [2.179189058512375, 48.800664361173034],
                            [2.178993254809456, 48.80068650189317],
                            [2.178819450514283, 48.800695034197034],
                            [2.178649252405362, 48.800693040898544],
                            [2.178130973726579, 48.80066321899656],
                        ],
                    },
                },
                163: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.045431012009466, 2.1031051862686283],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 295.647988421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.101108482966614,
                            49.045311648350264,
                            2.105110703444507,
                            49.04564873988319,
                        ),
                        "coordinates": [
                            [2.105110703444507, 49.045311648350264],
                            [2.104628215681291, 49.04532047996179],
                            [2.104374559147197, 49.04533000897707],
                            [2.104086670840201, 49.04534147623432],
                            [2.103441731027953, 49.045386363089136],
                            [2.10270505892091, 49.04544511964608],
                            [2.102295453480011, 49.045478428084046],
                            [2.101824629861494, 49.0455337048508],
                            [2.101108482966614, 49.04564873988319],
                        ],
                    },
                },
                164: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.71863684646498, 2.4119979829145652],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1874.10971295,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.403633104908493,
                            48.71262898747625,
                            2.419565024387933,
                            48.72553530486119,
                        ),
                        "coordinates": [
                            [2.403633104908493, 48.71262898747625],
                            [2.403760218066728, 48.71275338036123],
                            [2.404241855357792, 48.71319103840689],
                            [2.404580737259858, 48.71346305084839],
                            [2.404929819788531, 48.71370077356364],
                            [2.405515012454503, 48.71408234846835],
                            [2.40618558384271, 48.7145297763729],
                            [2.406450802714425, 48.7146923814499],
                            [2.40727093899601, 48.71518467423468],
                            [2.408001281358155, 48.71559428453797],
                            [2.408971029364889, 48.71615211765388],
                            [2.409509679788258, 48.716490797208145],
                            [2.409953157029819, 48.71679536485506],
                            [2.410055184198932, 48.71686544136762],
                            [2.410748939013496, 48.7173137267399],
                            [2.4114739452638, 48.71775029636385],
                            [2.412359454632673, 48.71826858843303],
                            [2.412956645358633, 48.718644083809956],
                            [2.413091319321211, 48.718728524164284],
                            [2.413197428798623, 48.718795897961854],
                            [2.413898110216495, 48.71929361949754],
                            [2.41427228515168, 48.71957213772228],
                            [2.414568002899246, 48.71981418733267],
                            [2.414777186701919, 48.720009736405494],
                            [2.41517597685818, 48.720378162012075],
                            [2.415574830267373, 48.72078165881984],
                            [2.415683744313906, 48.72089938726115],
                            [2.415732769389958, 48.72096050315869],
                            [2.416036479366335, 48.72135597063324],
                            [2.416135926304154, 48.721500683507486],
                            [2.416273513368349, 48.721698426554525],
                            [2.41645742542816, 48.72196717920239],
                            [2.416627760758634, 48.72224403484902],
                            [2.416855273307344, 48.72257660457186],
                            [2.417056940391772, 48.72289480380049],
                            [2.41730288080876, 48.72327181618965],
                            [2.417569179431797, 48.72363094277449],
                            [2.417689018459523, 48.72377384131561],
                            [2.417920500127482, 48.72403176721072],
                            [2.418459628617813, 48.72457274056327],
                            [2.418853008010847, 48.72491777697031],
                            [2.419565024387933, 48.72553530486119],
                        ],
                    },
                },
                165: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.90211574537828, 1.8653499616634424],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2116.78611661,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.857227537127738,
                            48.893238595694605,
                            1.871738475714576,
                            48.90930537596191,
                        ),
                        "coordinates": [
                            [1.871738475714576, 48.893238595694605],
                            [1.871582764656284, 48.89355451252227],
                            [1.871531452566473, 48.89364513283113],
                            [1.871482943936253, 48.89372766980096],
                            [1.871346981453043, 48.89397352157298],
                            [1.871198768426265, 48.89421662607558],
                            [1.870985533794781, 48.89455748812633],
                            [1.870874731954356, 48.89473779385778],
                            [1.870657232165005, 48.895096623301164],
                            [1.870341807396979, 48.89557106134978],
                            [1.869844655939476, 48.89636940069622],
                            [1.868415110236178, 48.89869811179744],
                            [1.867753085932334, 48.89976015798868],
                            [1.867672718056363, 48.89989292341102],
                            [1.867235009858375, 48.90059886898659],
                            [1.86633874776849, 48.902047539353646],
                            [1.86575853402498, 48.902960629130874],
                            [1.865249796899448, 48.90367077059337],
                            [1.865173970170793, 48.90375499095625],
                            [1.865033313318742, 48.903914484420405],
                            [1.864851390144611, 48.90410977925254],
                            [1.864577294637015, 48.904386527911484],
                            [1.864166099684214, 48.904734652491186],
                            [1.863804546229426, 48.905026326013854],
                            [1.862979914862162, 48.905668601551],
                            [1.862412455513467, 48.90609251148615],
                            [1.861216833956546, 48.90686542982669],
                            [1.859416378378991, 48.90796764844396],
                            [1.859261366847702, 48.90805603040124],
                            [1.858042787614553, 48.90879464677143],
                            [1.857227537127738, 48.90930537596191],
                        ],
                    },
                },
                166: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.70857323368284, 1.8721225754551571],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 4084.99966675,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.85659206528713,
                            48.69309659121679,
                            1.890004563697985,
                            48.72191596105865,
                        ),
                        "coordinates": [
                            [1.85659206528713, 48.69309659121679],
                            [1.856715398503036, 48.69345196258986],
                            [1.856799946512059, 48.69369962214961],
                            [1.857277685985409, 48.69501099590093],
                            [1.857507784225903, 48.69551830749273],
                            [1.857753066602306, 48.69603948180251],
                            [1.858030526563277, 48.69653575647938],
                            [1.858262072372782, 48.696896444672134],
                            [1.858442917149364, 48.697161594401486],
                            [1.858730317708505, 48.69757590145742],
                            [1.859003393662899, 48.69796012582615],
                            [1.859244743253453, 48.69827997358976],
                            [1.859440144657987, 48.69851872870949],
                            [1.859750937344423, 48.69888292086132],
                            [1.860112396605303, 48.699299005778514],
                            [1.860648986307845, 48.69987049879539],
                            [1.861172491947406, 48.70039157634829],
                            [1.861697736142728, 48.70087398867113],
                            [1.862232750374959, 48.70133036004215],
                            [1.862781478892719, 48.701774196723605],
                            [1.864799002836341, 48.70335363345357],
                            [1.865029637383951, 48.70353264863516],
                            [1.865365446260445, 48.703796631668055],
                            [1.866569838035721, 48.70473956896716],
                            [1.867022941689387, 48.7051020537334],
                            [1.869610704020809, 48.70713140426907],
                            [1.87068369324005, 48.7079633431826],
                            [1.871297369540176, 48.70845236829666],
                            [1.872929590574994, 48.709732420126194],
                            [1.873113045264286, 48.70987705304943],
                            [1.875622239556932, 48.711846790073906],
                            [1.876220046429648, 48.71229885351404],
                            [1.876464352393001, 48.712477900387846],
                            [1.876649335188688, 48.71260634668252],
                            [1.879687442676669, 48.71472381395895],
                            [1.879841369904282, 48.71483234560751],
                            [1.881241773766145, 48.7157992943732],
                            [1.882713742400859, 48.71682316600738],
                            [1.883287686057122, 48.717222938365225],
                            [1.883992701473626, 48.71770686229569],
                            [1.884310062671973, 48.71792844860221],
                            [1.885294539118915, 48.71862031034604],
                            [1.885965690491573, 48.7190959940718],
                            [1.888508517925195, 48.720867321760046],
                            [1.890004563697985, 48.72191596105865],
                        ],
                    },
                },
                167: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.83503063630636, 2.2922410766228767],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 834.037508321,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.288022141100325,
                            48.83244909914335,
                            2.296630340533544,
                            48.83730749276759,
                        ),
                        "coordinates": [
                            [2.288022141100325, 48.83244909914335],
                            [2.288252677402633, 48.8326011933349],
                            [2.288723477978069, 48.83291179314505],
                            [2.28886558877803, 48.83300834082818],
                            [2.290286727177951, 48.833973801627714],
                            [2.291448415703456, 48.83469140677358],
                            [2.292479855202144, 48.83532289069432],
                            [2.293153058082708, 48.835688888744365],
                            [2.293728569640646, 48.835975963406916],
                            [2.294358425262617, 48.836241539702456],
                            [2.295759303930777, 48.836865959778635],
                            [2.296476020811045, 48.83721761303035],
                            [2.296630340533544, 48.83730749276759],
                        ],
                    },
                },
                168: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84531677689487, 2.2581854944662108],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 506.004972487,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.254756719786218,
                            48.845227500732506,
                            2.261623492404885,
                            48.845378500435366,
                        ),
                        "coordinates": [
                            [2.261623492404885, 48.84524756545478],
                            [2.260908453096279, 48.845264422898296],
                            [2.257948221777687, 48.845337297795155],
                            [2.25634637547889, 48.845376699742694],
                            [2.256340933866544, 48.84537683319988],
                            [2.256117255218372, 48.845378500435366],
                            [2.255893727144803, 48.84537286530566],
                            [2.255670891885798, 48.84535994107764],
                            [2.255449300960836, 48.8453397590672],
                            [2.255229489305364, 48.84531236667963],
                            [2.255012002443456, 48.84527783297483],
                            [2.254756719786218, 48.845227500732506],
                        ],
                    },
                },
                169: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84687803044527, 2.2719395508546283],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 133.414408665,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.271115349613071,
                            48.846625048719645,
                            2.272763753316159,
                            48.847131008196236,
                        ),
                        "coordinates": [
                            [2.272763753316159, 48.847131008196236],
                            [2.271816089288167, 48.84684013744314],
                            [2.271115349613071, 48.846625048719645],
                        ],
                    },
                },
                170: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.87254958447499, 2.3362977386766595],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 422.531048258,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.333479131845597,
                            48.872152352579874,
                            2.33911503790642,
                            48.872937657673795,
                        ),
                        "coordinates": [
                            [2.333479131845597, 48.872937657673795],
                            [2.334089658681054, 48.87285384040136],
                            [2.338068582821625, 48.87230749636527],
                            [2.33911503790642, 48.872152352579874],
                        ],
                    },
                },
                171: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.87183133824494, 2.341135894778504],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 305.151186671,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.33911503790642,
                            48.87149773935003,
                            2.343154773075233,
                            48.872152352579874,
                        ),
                        "coordinates": [
                            [2.33911503790642, 48.872152352579874],
                            [2.340051785735736, 48.872013463764766],
                            [2.343154773075233, 48.87149773935003],
                        ],
                    },
                },
                172: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98935751527942, 2.2458746664321008],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 1954.61314817,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.234276393996537,
                            48.98500470125915,
                            2.25747415725031,
                            48.99371348038584,
                        ),
                        "coordinates": [
                            [2.25747415725031, 48.98500470125915],
                            [2.256667529466798, 48.98530179983275],
                            [2.256537648249651, 48.98534937040701],
                            [2.256406397970248, 48.98539873895597],
                            [2.256324367152076, 48.98542925655962],
                            [2.25483957933873, 48.98598395673322],
                            [2.254752076836709, 48.98601716760732],
                            [2.254065722420399, 48.98627566499257],
                            [2.252697094129654, 48.986791752504],
                            [2.252152919385233, 48.98699548761377],
                            [2.250853987138239, 48.98748372667994],
                            [2.25052446527544, 48.98760757845762],
                            [2.250302957914854, 48.987691044437135],
                            [2.250069147044349, 48.987778097556905],
                            [2.248828968929537, 48.98824477512492],
                            [2.248735984251072, 48.98828247410205],
                            [2.248689496718009, 48.98829862493679],
                            [2.248644373466953, 48.988315676355626],
                            [2.248578741899453, 48.988339906642],
                            [2.248519944991161, 48.988362343427454],
                            [2.248182205336202, 48.9884897792397],
                            [2.247942915503344, 48.98857952129495],
                            [2.244431417603644, 48.98989778089434],
                            [2.244312450985003, 48.98994174964649],
                            [2.244241341042742, 48.98996956972559],
                            [2.244168866746831, 48.98999648911002],
                            [2.244036222252495, 48.9900476409717],
                            [2.243727181301108, 48.99016159795455],
                            [2.243554620207485, 48.99022882178484],
                            [2.242902227019158, 48.99047741455814],
                            [2.24162140823175, 48.990954603971424],
                            [2.239750755235367, 48.99166921656483],
                            [2.237898175127222, 48.99236001975328],
                            [2.23664981377814, 48.99283004478473],
                            [2.235958195596444, 48.99308036887799],
                            [2.234276393996537, 48.99371348038584],
                        ],
                    },
                },
                173: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.08353183889434, 2.2045051569201672],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1497.22432397,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.200817247554296,
                            49.07769904281828,
                            2.207404910227873,
                            49.08930709608885,
                        ),
                        "coordinates": [
                            [2.200978026879316, 49.08930709608885],
                            [2.200858886040124, 49.08883668609218],
                            [2.200817247554296, 49.08852157256377],
                            [2.200820929914095, 49.08817832299847],
                            [2.200853268621624, 49.08786991070815],
                            [2.200922459442305, 49.087603808351226],
                            [2.200994258518992, 49.08738447030166],
                            [2.201099004649961, 49.08713369754419],
                            [2.201166459457293, 49.08700068428713],
                            [2.201291697610338, 49.08676522278638],
                            [2.201537793117673, 49.0863941134586],
                            [2.201673782621026, 49.086231505541384],
                            [2.201857852021466, 49.086010501543896],
                            [2.202091248430846, 49.085774267134724],
                            [2.20250567587162, 49.08542493572345],
                            [2.202788262577688, 49.085222929541395],
                            [2.203202412396381, 49.084972515524335],
                            [2.203746714512316, 49.08468807873599],
                            [2.203889287125589, 49.08461899980039],
                            [2.204205967789653, 49.084462892250194],
                            [2.204741984239535, 49.0842009230612],
                            [2.20509293213278, 49.08402776668637],
                            [2.205705814622024, 49.08368764427291],
                            [2.205907404134456, 49.08356107744532],
                            [2.206162568612107, 49.0833653263573],
                            [2.206356035657136, 49.08320277855845],
                            [2.206570185460174, 49.08298359839493],
                            [2.20679400128443, 49.082732955594714],
                            [2.206994628678089, 49.08244811295753],
                            [2.2071817069896, 49.082109298318024],
                            [2.207312689761099, 49.08175603227995],
                            [2.207382050865224, 49.08140809192987],
                            [2.207404910227873, 49.081043013116535],
                            [2.207375646480392, 49.08071654374962],
                            [2.207331194501543, 49.08043951790937],
                            [2.207211544546548, 49.08012643533654],
                            [2.207058986093821, 49.079833999087924],
                            [2.206790397969286, 49.079415533234695],
                            [2.206437036530973, 49.07896099924466],
                            [2.20594311432761, 49.078342636482795],
                            [2.205446725524735, 49.07769904281828],
                        ],
                    },
                },
                174: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98940490744247, 2.3617927853946363],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 1756.98324336,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.353407245869684,
                            48.984315962065935,
                            2.368684562796334,
                            48.996006830493926,
                        ),
                        "coordinates": [
                            [2.353407245869684, 48.984315962065935],
                            [2.353757288256642, 48.98451021557755],
                            [2.360689271665839, 48.98834209199464],
                            [2.362765100830239, 48.98949561924234],
                            [2.363416078162131, 48.98985950816034],
                            [2.363817530110666, 48.990102106668836],
                            [2.364175590152148, 48.990330437599106],
                            [2.364544510621891, 48.99057780155343],
                            [2.364855575633539, 48.99080376191301],
                            [2.365184736257229, 48.99105826994945],
                            [2.365513909887416, 48.99132943366328],
                            [2.365922685925408, 48.991693368807674],
                            [2.366233809964462, 48.99200022371598],
                            [2.366505149146215, 48.992278536297285],
                            [2.366729466309284, 48.99252117097596],
                            [2.367008076768097, 48.99285420501942],
                            [2.36727223330656, 48.99319676052654],
                            [2.367489362082486, 48.993498877874025],
                            [2.368003310338213, 48.99431485299605],
                            [2.368191568426409, 48.994688358895914],
                            [2.368332785243835, 48.99500477160592],
                            [2.368466783972825, 48.9953378430455],
                            [2.368571835309858, 48.99563523045974],
                            [2.368669666441447, 48.99595165605619],
                            [2.368684562796334, 48.996006830493926],
                        ],
                    },
                },
                175: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.95374366552486, 2.2439538301797435],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2255.43457812,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.231110035011993,
                            48.950304353547466,
                            2.25508371139436,
                            48.95603120205498,
                        ),
                        "coordinates": [
                            [2.25508371139436, 48.95101678180594],
                            [2.254921549225827, 48.95165221283468],
                            [2.254884998865097, 48.951906775811715],
                            [2.254856445777283, 48.95207975427657],
                            [2.254801844897676, 48.9523271671612],
                            [2.254707444005894, 48.952610239990086],
                            [2.254587760587532, 48.95288853767845],
                            [2.254464522583103, 48.953131142181334],
                            [2.254290649363522, 48.953407021537714],
                            [2.254120469110216, 48.953632935219936],
                            [2.253961202977405, 48.95381127083217],
                            [2.253838151234981, 48.953939664311726],
                            [2.253548660036974, 48.954213079124514],
                            [2.253244760135622, 48.95446030992415],
                            [2.252944518815264, 48.954678988977214],
                            [2.252655176735339, 48.9548596066055],
                            [2.252336937191794, 48.955035443504244],
                            [2.252018724767871, 48.95519462504646],
                            [2.251657158006386, 48.95535139126356],
                            [2.251205249525729, 48.955517610190945],
                            [2.250731694508429, 48.955662394495256],
                            [2.250312404539619, 48.95576676897383],
                            [2.24980640731436, 48.95586631893533],
                            [2.249304063103541, 48.95594207401254],
                            [2.248769234527907, 48.95599876826722],
                            [2.248281429064058, 48.956024567042306],
                            [2.247634683629114, 48.95603120205498],
                            [2.247013302793014, 48.955997405676825],
                            [2.246475057949377, 48.95594463758255],
                            [2.245951314722693, 48.9558657055799],
                            [2.245481786619101, 48.95577491731696],
                            [2.245052029120419, 48.955672261615085],
                            [2.244629528586005, 48.955552955828374],
                            [2.244199853611307, 48.955407469307055],
                            [2.243719681661203, 48.95521911322948],
                            [2.237629727357868, 48.95265145478149],
                            [2.235416993589458, 48.951719194728554],
                            [2.234146408152569, 48.95119222987754],
                            [2.233720456589484, 48.951025294111304],
                            [2.233247537452552, 48.950863070829904],
                            [2.232691552572382, 48.950688876011085],
                            [2.232182473393724, 48.950545651828534],
                            [2.231550585693242, 48.95039279475235],
                            [2.231110035011993, 48.950304353547466],
                        ],
                    },
                },
                176: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.94166787115946, 2.150760739942237],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1284.07893555,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.144558756800802,
                            48.93773606341459,
                            2.157086496469818,
                            48.945795934518046,
                        ),
                        "coordinates": [
                            [2.144558756800802, 48.945795934518046],
                            [2.146753189057277, 48.94439103172525],
                            [2.14745577502546, 48.94391394942269],
                            [2.147933873262263, 48.94357449457276],
                            [2.148459092094536, 48.94318990649488],
                            [2.148973504613955, 48.942795781350526],
                            [2.149404596685325, 48.942463379849556],
                            [2.149911625986352, 48.94210730967307],
                            [2.150342526973852, 48.9418224908282],
                            [2.150766182551382, 48.94154241953934],
                            [2.151349105221197, 48.941169810212344],
                            [2.153087010268662, 48.940044806929784],
                            [2.153651740968178, 48.93969832985609],
                            [2.154545805962058, 48.9391715445828],
                            [2.155276891353209, 48.93876107928797],
                            [2.157086496469818, 48.93773606341459],
                        ],
                    },
                },
                177: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9447488719057, 2.0671612677018625],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 4574.55828958,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.041072289675926,
                            48.93326540612854,
                            2.093521901580612,
                            48.95540224453111,
                        ),
                        "coordinates": [
                            [2.041072289675926, 48.93326540612854],
                            [2.045668504587519, 48.93529966502182],
                            [2.048460294797077, 48.93653211266265],
                            [2.053997431953846, 48.938980034483606],
                            [2.063909453931477, 48.943358356350146],
                            [2.069404894499701, 48.94578163311858],
                            [2.072525787399531, 48.9471641609139],
                            [2.075109865164508, 48.94830505866521],
                            [2.087559970412699, 48.95376495153617],
                            [2.088475704144185, 48.9541523995623],
                            [2.089216048741711, 48.95442352812452],
                            [2.089784880943044, 48.954616830409066],
                            [2.09041982801554, 48.95480379054842],
                            [2.091033257892704, 48.954959769637476],
                            [2.091639584520061, 48.955091935833345],
                            [2.092029394089491, 48.955171289332526],
                            [2.092321810369193, 48.95521950257172],
                            [2.092971637236077, 48.95532320200608],
                            [2.093521901580612, 48.95540224453111],
                        ],
                    },
                },
                178: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.986643147363, 1.7091422868963677],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 1107.77054667,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.703016134167223,
                            48.983654507541004,
                            1.715210986447546,
                            48.989502508030505,
                        ),
                        "coordinates": [
                            [1.715210986447546, 48.983654507541004],
                            [1.714876713955381, 48.983788316553415],
                            [1.713600965108449, 48.98433101806053],
                            [1.712641222925728, 48.984754079445864],
                            [1.712284705578705, 48.98493058933371],
                            [1.711411070835274, 48.98540407886332],
                            [1.708445222531689, 48.9871303023471],
                            [1.707197842322636, 48.987799197118015],
                            [1.706378210456435, 48.98818807925704],
                            [1.705757817330407, 48.98845115279417],
                            [1.704968622676812, 48.98871963626297],
                            [1.70427599037051, 48.9889759579842],
                            [1.703016134167223, 48.989502508030505],
                        ],
                    },
                },
                179: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.02902212266669, 2.3498710263222318],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 2186.61970193,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.336829689836827,
                            49.02320637806201,
                            2.362222981011115,
                            49.03297204677151,
                        ),
                        "coordinates": [
                            [2.362222981011115, 49.02320637806201],
                            [2.362062785664122, 49.023299049476606],
                            [2.354325519588647, 49.02752619658293],
                            [2.35180402234732, 49.0289018103816],
                            [2.351080465120606, 49.029289735538576],
                            [2.350447341166052, 49.02962054047568],
                            [2.349973391976561, 49.029849011707185],
                            [2.349452396514655, 49.03007272834155],
                            [2.348963955802607, 49.03026312735066],
                            [2.348392289277997, 49.030463051266445],
                            [2.347867649231807, 49.030627276676256],
                            [2.347357476394044, 49.030767706288785],
                            [2.346894336240289, 49.03088671417556],
                            [2.346333493604799, 49.031008109096796],
                            [2.345736464135617, 49.03113426156674],
                            [2.343619700272693, 49.03157458345275],
                            [2.337526101484952, 49.03282869248634],
                            [2.336829689836827, 49.03297204677151],
                        ],
                    },
                },
                180: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.878650740007885, 2.300900760156482],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 408.652610936,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.298310373761529,
                            48.87797270141955,
                            2.303528725370108,
                            48.879214134245586,
                        ),
                        "coordinates": [
                            [2.298310373761529, 48.87797270141955],
                            [2.298430598817582, 48.87803930781454],
                            [2.298557573832707, 48.87810022124744],
                            [2.298690683767284, 48.87815514401097],
                            [2.298829276348082, 48.878203808759025],
                            [2.298972679817809, 48.87824597681242],
                            [2.299090086321498, 48.87827420652144],
                            [2.29912019193179, 48.878281445289694],
                            [2.299129264600565, 48.87828337802444],
                            [2.303528725370108, 48.879214134245586],
                        ],
                    },
                },
                181: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.88234000676494, 2.3407177164605466],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 521.013505016,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.337294790567405,
                            48.88200505537663,
                            2.344130633722553,
                            48.88286864756839,
                        ),
                        "coordinates": [
                            [2.337294790567405, 48.88239015067237],
                            [2.337532538668095, 48.882336640488255],
                            [2.338558167921224, 48.8821737315106],
                            [2.339487057216237, 48.88202617936634],
                            [2.33979203199945, 48.88200505537663],
                            [2.340077404350079, 48.882031422387364],
                            [2.341532769084847, 48.88235428883831],
                            [2.344130633722553, 48.88286864756839],
                        ],
                    },
                },
                182: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.819380272260695, 2.195423262875548],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 1940.22611855,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.188259860000294,
                            48.81257171717766,
                            2.200721257947835,
                            48.8272387754095,
                        ),
                        "coordinates": [
                            [2.188259860000294, 48.81257171717766],
                            [2.18977173089294, 48.81447792661163],
                            [2.189817854884192, 48.814536438585144],
                            [2.189880267957558, 48.814612058709386],
                            [2.190284571652338, 48.81511257772727],
                            [2.190527497518925, 48.81538986762242],
                            [2.190691712957203, 48.81557712747344],
                            [2.190853279230943, 48.815739204791704],
                            [2.190918445474538, 48.81580583450609],
                            [2.191009444196634, 48.81588598697984],
                            [2.191078696426578, 48.81595262175729],
                            [2.191165605292646, 48.81603456771417],
                            [2.191514647029684, 48.816348861240286],
                            [2.191794485413418, 48.81658033139004],
                            [2.192138224509382, 48.81684785422946],
                            [2.192414098347767, 48.81703975029532],
                            [2.192805540364206, 48.81729474083723],
                            [2.192855834424884, 48.81732627963286],
                            [2.192893897575333, 48.81734880930482],
                            [2.193312595117685, 48.817598437267954],
                            [2.193729974448492, 48.817834572803044],
                            [2.194971361017204, 48.81850069086825],
                            [2.196381503666261, 48.81923166825301],
                            [2.196910272897255, 48.81954639257153],
                            [2.197231024107471, 48.819776987004445],
                            [2.197574853164364, 48.820040767528695],
                            [2.197934923038173, 48.82033167379007],
                            [2.198174690283779, 48.82055047437471],
                            [2.198313907605619, 48.820678356718965],
                            [2.198752519384207, 48.82113302449515],
                            [2.198838023237781, 48.82123834372864],
                            [2.199055191565388, 48.82150119528909],
                            [2.199333237856536, 48.821911601361165],
                            [2.199532563556481, 48.82222658902717],
                            [2.19958265460223, 48.82233456299452],
                            [2.1997298831254, 48.82262274037754],
                            [2.199854742676403, 48.82293380849898],
                            [2.199943941533043, 48.82317547081763],
                            [2.200026192789215, 48.82348347348516],
                            [2.200124394198703, 48.82392693510873],
                            [2.200140507601999, 48.82401058753482],
                            [2.200155270760345, 48.824089741149876],
                            [2.200267917081906, 48.82472926231235],
                            [2.200305389839422, 48.82497031358611],
                            [2.200478604419895, 48.82587429509449],
                            [2.200486644086928, 48.82592286563294],
                            [2.200498723526633, 48.82598762794323],
                            [2.200530897228218, 48.82617561531387],
                            [2.20059528646788, 48.826535403866295],
                            [2.200655619224576, 48.826885294333515],
                            [2.200674388675792, 48.82699412916455],
                            [2.20068917234138, 48.82706698869271],
                            [2.200721257947835, 48.8272387754095],
                        ],
                    },
                },
                183: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84552101618076, 2.4144114236427296],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2995.39739741,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.395823588826127,
                            48.84363500495395,
                            2.433299716281995,
                            48.84823711041019,
                        ),
                        "coordinates": [
                            [2.433299716281995, 48.84730835944483],
                            [2.432718704425602, 48.84732866082917],
                            [2.432394436625349, 48.847340623021],
                            [2.431210445851776, 48.847382975904765],
                            [2.430809879368417, 48.847397695391706],
                            [2.430503317315531, 48.847406041259134],
                            [2.430263509793383, 48.84740893580813],
                            [2.429962384388675, 48.847410081687045],
                            [2.429650341389914, 48.84740224240014],
                            [2.429362815162821, 48.84738898732365],
                            [2.429120892250702, 48.84737550758445],
                            [2.428751663563904, 48.847341542997114],
                            [2.428395222713234, 48.847297142926465],
                            [2.427881528429491, 48.84722256040823],
                            [2.427392507068644, 48.84713158345431],
                            [2.427009494461212, 48.847049086798805],
                            [2.426658946025194, 48.846975127349715],
                            [2.426202327042903, 48.84685699552397],
                            [2.425682922279799, 48.84670464776007],
                            [2.425237064480452, 48.84655366822894],
                            [2.424901578713412, 48.84643258238624],
                            [2.424390749640624, 48.84623168348388],
                            [2.424096337578732, 48.846094859096716],
                            [2.423877695368279, 48.84599366700637],
                            [2.423693682189064, 48.845903867950895],
                            [2.423509669634036, 48.84581406950443],
                            [2.423334309173288, 48.84572426390438],
                            [2.422741141323987, 48.845432053258214],
                            [2.422254093904951, 48.84521399571047],
                            [2.421221541653886, 48.84473651905528],
                            [2.420587022168888, 48.84444704897725],
                            [2.420146630720783, 48.84426302068311],
                            [2.419697930336349, 48.84407962223682],
                            [2.419067992964417, 48.84385068731212],
                            [2.418798268964133, 48.843780267145824],
                            [2.418417271020609, 48.84370427536515],
                            [2.418079126537894, 48.84366497228829],
                            [2.417848007174963, 48.84364818914995],
                            [2.417344358940576, 48.84363823929585],
                            [2.416829342640422, 48.84363500495395],
                            [2.416112734727961, 48.84366608167363],
                            [2.415269512052094, 48.84375749185558],
                            [2.414930317714806, 48.84379549417043],
                            [2.414595209315051, 48.84383349303501],
                            [2.413942700569974, 48.843907677060635],
                            [2.412302562880426, 48.844092228128055],
                            [2.411693621880217, 48.8441492833327],
                            [2.411080591702227, 48.844206339594216],
                            [2.410286376090954, 48.84428149412267],
                            [2.408840922923079, 48.84437953810553],
                            [2.407004424842043, 48.84447241085893],
                            [2.406231946435997, 48.84450975367717],
                            [2.405704699739519, 48.84453705184664],
                            [2.404798761170446, 48.844622128407906],
                            [2.404128556046331, 48.84472684166804],
                            [2.40365931489003, 48.84481358657325],
                            [2.403239958311115, 48.84490967097375],
                            [2.402965799013999, 48.84500034498978],
                            [2.402546510586614, 48.845149670067435],
                            [2.40229658457625, 48.84526695048941],
                            [2.401764551584505, 48.84557074581143],
                            [2.401055086836175, 48.84603256485446],
                            [2.399620100754327, 48.84692454650537],
                            [2.399248383412272, 48.84713338316269],
                            [2.398870620387838, 48.84731875918163],
                            [2.398402945195865, 48.847510691479556],
                            [2.397857907971638, 48.847706977594974],
                            [2.397396174339602, 48.84785560494727],
                            [2.396860860964621, 48.84800606841567],
                            [2.39635411248072, 48.84811874515271],
                            [2.39634866163159, 48.84811874822868],
                            [2.395823588826127, 48.84823711041019],
                        ],
                    },
                },
                184: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.797580349605624, 2.1406320310669837],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1796.83912,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.129043867370256,
                            48.796178314273135,
                            2.152378660253372,
                            48.80021557813598,
                        ),
                        "coordinates": [
                            [2.152378660253372, 48.79652818117568],
                            [2.152338963680592, 48.79652271537383],
                            [2.151471461789258, 48.796402340222436],
                            [2.150481531964946, 48.79627699980382],
                            [2.149919278022563, 48.796234597562176],
                            [2.149386970964321, 48.79620382486479],
                            [2.148911648288609, 48.796186386585646],
                            [2.148346254825638, 48.796178314273135],
                            [2.147978893252051, 48.796182464964964],
                            [2.147139728577896, 48.79619058794475],
                            [2.14674351935253, 48.7962042040603],
                            [2.146242795216752, 48.79623667880198],
                            [2.14585733505846, 48.79626458503123],
                            [2.145259279419891, 48.79632068578173],
                            [2.144711615802071, 48.796384005867424],
                            [2.144297248504016, 48.796435651809674],
                            [2.143875642409222, 48.79649680172298],
                            [2.143468432092114, 48.796560354944475],
                            [2.143108038006966, 48.79662398431525],
                            [2.142707980272671, 48.796699442413846],
                            [2.142297099246691, 48.79677963970738],
                            [2.141752812458423, 48.796897676941086],
                            [2.141194061865006, 48.79702996254319],
                            [2.140386158644989, 48.797244135999144],
                            [2.13942061427876, 48.79750259791235],
                            [2.137527869103348, 48.798009194274506],
                            [2.136514029104777, 48.79828079712656],
                            [2.135489978018193, 48.7985608854198],
                            [2.134833786095137, 48.79873646316356],
                            [2.134247807910476, 48.79889459527487],
                            [2.133292523448711, 48.79915188493529],
                            [2.133000893591115, 48.799230500080526],
                            [2.132544631484282, 48.79934069288383],
                            [2.131751185260367, 48.79951309439427],
                            [2.131331777615874, 48.79961329329602],
                            [2.130541404082334, 48.799816001623284],
                            [2.129043867370256, 48.80021557813598],
                        ],
                    },
                },
                185: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78329741721353, 2.1782347255209875],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 567.573521082,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.176835487870611,
                            48.7819866725001,
                            2.180493750928926,
                            48.78512141332815,
                        ),
                        "coordinates": [
                            [2.178798590270473, 48.78512141332815],
                            [2.178444700311648, 48.78491614730715],
                            [2.177078738392514, 48.78412743070845],
                            [2.176976139852545, 48.78405675936703],
                            [2.176916525412981, 48.78400066335265],
                            [2.176859341153883, 48.7839274490461],
                            [2.176840933836507, 48.783861641513276],
                            [2.176835487870611, 48.78379592326814],
                            [2.176836366270744, 48.78374024303342],
                            [2.176847934928273, 48.78369177610332],
                            [2.176872464831643, 48.78364339846035],
                            [2.176905750406229, 48.78358794146537],
                            [2.176949814870061, 48.78353398699981],
                            [2.177026466533371, 48.783468834232664],
                            [2.177170811033188, 48.78335845664294],
                            [2.178412795140476, 48.78242319679481],
                            [2.178541560939034, 48.78234126723295],
                            [2.178624286169174, 48.78230185633762],
                            [2.17868729614171, 48.7822794439862],
                            [2.178767635409114, 48.78225429502489],
                            [2.178847883369435, 48.78223485675607],
                            [2.180189777209781, 48.78202957393656],
                            [2.180493750928926, 48.7819866725001],
                        ],
                    },
                },
                186: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.797160266079445, 2.277311330678508],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 911.019161344,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272650344658386,
                            48.79446888451292,
                            2.281951320169448,
                            48.79988738317761,
                        ),
                        "coordinates": [
                            [2.272650344658386, 48.79446888451292],
                            [2.273372932701242, 48.79489055701269],
                            [2.274214412245569, 48.79537636693466],
                            [2.275184922355289, 48.79590935724733],
                            [2.276101458396386, 48.7964396334752],
                            [2.277003656229638, 48.79696624493579],
                            [2.277925534820534, 48.79750367735999],
                            [2.278356136673652, 48.79775257582172],
                            [2.279640716298814, 48.79850278491174],
                            [2.280162361769861, 48.79881171725014],
                            [2.280667672862257, 48.799130066381984],
                            [2.280987333394884, 48.799328313526814],
                            [2.281546600126762, 48.79965293285739],
                            [2.281951320169448, 48.79988738317761],
                        ],
                    },
                },
                187: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.8020227985797, 2.285518024189754],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 709.325520529,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.281951320169448,
                            48.79988738317761,
                            2.289057253599707,
                            48.804204938303016,
                        ),
                        "coordinates": [
                            [2.281951320169448, 48.79988738317761],
                            [2.282641957248953, 48.800286557132466],
                            [2.283442579983374, 48.80074349747637],
                            [2.283903852273689, 48.80099255788442],
                            [2.284385941115677, 48.80130004391047],
                            [2.285553823215842, 48.80203520934738],
                            [2.286541476660883, 48.80264911454797],
                            [2.28752196352453, 48.80326177849352],
                            [2.287929245981885, 48.803510500747265],
                            [2.288472989144604, 48.8038450631493],
                            [2.289057253599707, 48.804204938303016],
                        ],
                    },
                },
                188: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.80572325035524, 2.2915530797350665],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 495.595321437,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.289057253599707,
                            48.804204938303016,
                            2.294091244318829,
                            48.807169846835585,
                        ),
                        "coordinates": [
                            [2.289057253599707, 48.804204938303016],
                            [2.289624275318297, 48.804562879492096],
                            [2.290267237472113, 48.804966482411764],
                            [2.291269168121019, 48.80559827872177],
                            [2.291789265244971, 48.80589881904611],
                            [2.294091244318829, 48.807169846835585],
                        ],
                    },
                },
                189: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.88080897399949, 2.3123125701967915],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 427.147133518,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.309451167991542,
                            48.8804494561385,
                            2.315176626220464,
                            48.881150028474686,
                        ),
                        "coordinates": [
                            [2.309451167991542, 48.8804494561385],
                            [2.309598557889442, 48.88047487696105],
                            [2.310015000027064, 48.88053925192658],
                            [2.310138996539572, 48.88055699722095],
                            [2.311925832724022, 48.88076259160808],
                            [2.313026821579926, 48.88089330230174],
                            [2.314337119452803, 48.881048856070024],
                            [2.314655633326033, 48.88108666672566],
                            [2.31495537595022, 48.8811222484903],
                            [2.315176626220464, 48.881150028474686],
                        ],
                    },
                },
                190: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.14258121193363, 1.9410021448726438],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4610.5275496,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.936404406282517,
                            49.12345185404933,
                            1.949332680280041,
                            49.16267058077503,
                        ),
                        "coordinates": [
                            [1.949332680280041, 49.12345185404933],
                            [1.949185475917967, 49.12378430761103],
                            [1.949104582604222, 49.12396569001574],
                            [1.94906001725428, 49.12405726641162],
                            [1.949008475131125, 49.12416500562504],
                            [1.948961127224009, 49.12426196888726],
                            [1.948899668364135, 49.12441104182411],
                            [1.948677644142843, 49.12494086837261],
                            [1.948354212597838, 49.125645712108835],
                            [1.947911904182227, 49.126655008666965],
                            [1.947649598670639, 49.12725124352399],
                            [1.947221212344662, 49.12822910966549],
                            [1.947170995731967, 49.12834134977251],
                            [1.946874172548261, 49.12896804154083],
                            [1.946639048125813, 49.12939342870717],
                            [1.946366049974775, 49.12980084821339],
                            [1.946088942919607, 49.13018479864618],
                            [1.945918705255562, 49.13039734908229],
                            [1.945698842510051, 49.13064660097523],
                            [1.945567556038215, 49.130785541848205],
                            [1.945383795623346, 49.130974664694975],
                            [1.945060650715532, 49.13128651195902],
                            [1.944233272120679, 49.132105629669866],
                            [1.943425187274626, 49.13290772130572],
                            [1.942731826031594, 49.13358430159307],
                            [1.942683466858274, 49.133633596070055],
                            [1.941559174675724, 49.13472505688229],
                            [1.940799244166007, 49.135493123162135],
                            [1.940462892353715, 49.13590653194088],
                            [1.939991773709939, 49.13654396173729],
                            [1.939794055794995, 49.13686703029378],
                            [1.939675695066615, 49.13708294663929],
                            [1.93950206860149, 49.137450876604255],
                            [1.939303422180774, 49.13790029980681],
                            [1.939171986740406, 49.13828101745344],
                            [1.939067200120823, 49.138692180723424],
                            [1.938971188976278, 49.13921163345045],
                            [1.938952480858631, 49.139322180491234],
                            [1.938907469990834, 49.139975803965385],
                            [1.938902856777726, 49.140378667417416],
                            [1.938882412396459, 49.14138579397961],
                            [1.938871946518622, 49.141834500165665],
                            [1.938873077029986, 49.142374973166376],
                            [1.938859597047989, 49.14302780627577],
                            [1.938847749566484, 49.14381823618507],
                            [1.938834485755011, 49.14444409105921],
                            [1.938827702825857, 49.14545666062833],
                            [1.938826732247982, 49.14557716147961],
                            [1.93882548648793, 49.145731834112986],
                            [1.938824943604575, 49.14579927771332],
                            [1.938818433317541, 49.14609691821341],
                            [1.93881922500777, 49.14616886393916],
                            [1.93881191282284, 49.14656632148197],
                            [1.938807807931568, 49.14724616512458],
                            [1.938834359853648, 49.14769410080937],
                            [1.938896987940069, 49.1480882036881],
                            [1.93898727952948, 49.14845182705083],
                            [1.939157369190831, 49.14895061918455],
                            [1.939222793991834, 49.149110044650826],
                            [1.939279729943177, 49.14924780658754],
                            [1.939480091837816, 49.14973321365721],
                            [1.939726476201954, 49.15029252129591],
                            [1.939901089203664, 49.15074186729888],
                            [1.940015729817905, 49.151147840178965],
                            [1.940038032842936, 49.15127291784952],
                            [1.9400786826006, 49.151503274961016],
                            [1.940106121473767, 49.15184239919653],
                            [1.940090758375393, 49.15221914541746],
                            [1.940038833771533, 49.152568400853],
                            [1.940006303902632, 49.152708090427254],
                            [1.939941667231574, 49.15293449354225],
                            [1.939897976356676, 49.153066786359105],
                            [1.939816421080084, 49.153260465964536],
                            [1.93969488393565, 49.15354152148326],
                            [1.939603111357302, 49.15370127590263],
                            [1.939304644659973, 49.15416067566739],
                            [1.939045589120717, 49.154492513571384],
                            [1.938764549520273, 49.1547919936153],
                            [1.938528400879658, 49.15504018217532],
                            [1.938217300127178, 49.15536374377609],
                            [1.937752709808606, 49.155847741863944],
                            [1.937322992368784, 49.156343873220585],
                            [1.936916294485169, 49.15701380522366],
                            [1.936758771024738, 49.157363352595596],
                            [1.936655536489487, 49.15765551197302],
                            [1.936572553495464, 49.1579080242288],
                            [1.936484650957162, 49.158275543933904],
                            [1.936432627481818, 49.15869027532295],
                            [1.936424846505528, 49.15880445730658],
                            [1.936420353412215, 49.158851204604794],
                            [1.936411682941337, 49.1589060306748],
                            [1.936404406282517, 49.15929629397013],
                            [1.936499035833846, 49.15997108596125],
                            [1.936542310067271, 49.160214941894736],
                            [1.936678172214937, 49.16087818725432],
                            [1.936690105717014, 49.16092858799794],
                            [1.936700645806429, 49.16098168285089],
                            [1.936716525157527, 49.16105278163155],
                            [1.936745649107598, 49.16118148045347],
                            [1.936770523474651, 49.161327250603144],
                            [1.936840510387389, 49.16165932932405],
                            [1.936908906882405, 49.16235741100266],
                            [1.936911337535203, 49.16239608835169],
                            [1.936916370461952, 49.16245186157214],
                            [1.936928635785827, 49.16267058077503],
                        ],
                    },
                },
                191: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.80738791345056, 2.973101704150685],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3429.44115718,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.953730383101934,
                            48.80417686931555,
                            2.993109893419177,
                            48.81077532178037,
                        ),
                        "coordinates": [
                            [2.993109893419177, 48.80865396493307],
                            [2.990709606822247, 48.80940829284611],
                            [2.990089916073384, 48.809602498275076],
                            [2.989480847436489, 48.80978838952263],
                            [2.988864473045204, 48.809968624489386],
                            [2.988245197662251, 48.810114631786256],
                            [2.987891785180404, 48.81018679249689],
                            [2.987520887540429, 48.8102373648395],
                            [2.987134761606885, 48.81028226034113],
                            [2.986725759013785, 48.81031045907051],
                            [2.986282833452384, 48.81032480779425],
                            [2.985882470611465, 48.81031517942641],
                            [2.985567661028314, 48.81029920161439],
                            [2.985251696674947, 48.81026970637737],
                            [2.984839242971863, 48.810212568924996],
                            [2.984445712495797, 48.81015364008926],
                            [2.983948100423079, 48.81005212669939],
                            [2.9834130139531, 48.8099052576863],
                            [2.982975192781956, 48.80975783445286],
                            [2.982569558244773, 48.80958996827341],
                            [2.98214746043456, 48.80939256149227],
                            [2.981732746472705, 48.80915865652677],
                            [2.981419358713379, 48.808970161919746],
                            [2.980968173304679, 48.80861278717678],
                            [2.980576216825366, 48.80826907973069],
                            [2.980243498359322, 48.807957883569],
                            [2.979807976707063, 48.80754935559512],
                            [2.979513852367254, 48.80730040845847],
                            [2.979128223652701, 48.80700753241476],
                            [2.978627149519647, 48.806701028033835],
                            [2.978246420167149, 48.80650805630155],
                            [2.977949275618639, 48.80637172165721],
                            [2.977540134121476, 48.80620984049273],
                            [2.977210881022343, 48.806097477614834],
                            [2.976784224105451, 48.80597376298629],
                            [2.976310834413202, 48.80585744741021],
                            [2.975826671705476, 48.805743569536304],
                            [2.974898575063514, 48.80555078891234],
                            [2.973406135639297, 48.80521019887229],
                            [2.972597936154589, 48.805036644479415],
                            [2.971795708153195, 48.80486081691203],
                            [2.971177521615658, 48.80471782280691],
                            [2.97073312389193, 48.80461322058398],
                            [2.970252799946781, 48.80451595465856],
                            [2.969653402942331, 48.80440269023666],
                            [2.969180558675533, 48.80432679254418],
                            [2.968675390323818, 48.80425821072068],
                            [2.968238960155719, 48.80421304017145],
                            [2.967870145847296, 48.804188532897285],
                            [2.967521092309976, 48.80417812197487],
                            [2.967035392795515, 48.80417686931555],
                            [2.966628273824733, 48.804200143389494],
                            [2.966092484607458, 48.80424394268387],
                            [2.96553520449233, 48.804320388350625],
                            [2.964881026457769, 48.80443859637909],
                            [2.964375535558804, 48.80455789927259],
                            [2.96383358011103, 48.80472307806971],
                            [2.963288209296099, 48.80491910506867],
                            [2.962753187627467, 48.80513787764479],
                            [2.96221627516754, 48.80542320627935],
                            [2.961768272268781, 48.80568940898927],
                            [2.961463861820348, 48.80589497100491],
                            [2.960975800883497, 48.80627715196083],
                            [2.9600237910985, 48.80712051363151],
                            [2.959656097805605, 48.80743997880412],
                            [2.959138959974744, 48.807875035101695],
                            [2.958687671282343, 48.808280720692466],
                            [2.958352074980656, 48.80855504117014],
                            [2.957948871790213, 48.808867499395575],
                            [2.957483738092628, 48.80918084252058],
                            [2.957087460944171, 48.809419053560035],
                            [2.956658508288335, 48.809664112603315],
                            [2.956234993310772, 48.80987775025719],
                            [2.95570950477239, 48.81010428231028],
                            [2.955219071460242, 48.810301442212925],
                            [2.954702600852694, 48.81047620428591],
                            [2.954203500236609, 48.81064508445913],
                            [2.953730383101934, 48.81077532178037],
                        ],
                    },
                },
                192: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.543401472036884, 2.0975435985117445],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 4563.09665636,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.069381524887472,
                            48.535806509243706,
                            2.125707269059876,
                            48.551091975575105,
                        ),
                        "coordinates": [
                            [2.069381524887472, 48.535806509243706],
                            [2.069759543359357, 48.535998299504776],
                            [2.070460925418069, 48.536369885165314],
                            [2.070989667570149, 48.536651883101214],
                            [2.072040039916783, 48.53720871623102],
                            [2.073273757490746, 48.5378560219729],
                            [2.07383404555529, 48.538140458443806],
                            [2.074244342878502, 48.5383329422697],
                            [2.074504543504812, 48.53845346124114],
                            [2.074882417699546, 48.53861255718317],
                            [2.075520628197743, 48.53886718701092],
                            [2.076148916434266, 48.53910180412147],
                            [2.076584528721693, 48.539252699498405],
                            [2.077142904990033, 48.53942885759285],
                            [2.077816578558207, 48.53962026619161],
                            [2.078492848664502, 48.53979502098793],
                            [2.07918925769334, 48.539956493749614],
                            [2.079885784087626, 48.540096310235015],
                            [2.080594929150033, 48.54022116316257],
                            [2.081259068524918, 48.54031926103049],
                            [2.082103700714306, 48.54043608076878],
                            [2.082938309794534, 48.54055120683898],
                            [2.083775407841583, 48.54067132830402],
                            [2.084610016941602, 48.54078810776433],
                            [2.085449655022675, 48.540903226017186],
                            [2.086294287222878, 48.54102334529376],
                            [2.087121402124146, 48.541136758602526],
                            [2.087963534321341, 48.54125686024295],
                            [2.088803187270259, 48.54137195477327],
                            [2.089637837299403, 48.541485365922625],
                            [2.090477481826369, 48.54160377798841],
                            [2.091289542246929, 48.54172212442475],
                            [2.092126727902933, 48.54183219167525],
                            [2.092961376831942, 48.54194890973271],
                            [2.093806044482454, 48.542068972864186],
                            [2.094630588693342, 48.54220231167277],
                            [2.095462530899476, 48.54236230816707],
                            [2.096279439256296, 48.542520601194106],
                            [2.097096303734741, 48.542688882096584],
                            [2.098923014614802, 48.543060805047304],
                            [2.105237765577978, 48.544356312859044],
                            [2.106871638908124, 48.54469107235334],
                            [2.109898878629026, 48.545310074744734],
                            [2.110374998751922, 48.54541262325007],
                            [2.11083602775469, 48.545525130891],
                            [2.111289473372245, 48.545650946541386],
                            [2.111735345169215, 48.54578840336501],
                            [2.112103473540647, 48.54592237318674],
                            [2.112531692645639, 48.546081444263166],
                            [2.112944775749895, 48.54626046947401],
                            [2.113340272653671, 48.54644611999209],
                            [2.113728165332595, 48.546650075415435],
                            [2.114090970456488, 48.54685564545722],
                            [2.114456218741776, 48.547076208413365],
                            [2.114808930623826, 48.547296747042324],
                            [2.115098771644708, 48.547477918343304],
                            [2.115589080466254, 48.547780126908684],
                            [2.115918661708137, 48.54798220358367],
                            [2.116650168299203, 48.54842788229872],
                            [2.117113052054024, 48.54869859196749],
                            [2.117688679037721, 48.54900282726212],
                            [2.118086738149973, 48.54918513555765],
                            [2.1185074053828, 48.549360823372425],
                            [2.118945678752854, 48.54952655183586],
                            [2.119381549984429, 48.54966895550533],
                            [2.119814972604467, 48.549798029663535],
                            [2.120266013129358, 48.5499138112294],
                            [2.120729628888395, 48.550022954037395],
                            [2.121193283228171, 48.55012376579669],
                            [2.122007822832604, 48.550298523815634],
                            [2.12363441164031, 48.55064801806724],
                            [2.125268550437647, 48.55099750216395],
                            [2.125707269059876, 48.551091975575105],
                        ],
                    },
                },
                193: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.08353183889434, 2.2045051569201672],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1497.22432397,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.200817247554296,
                            49.07769904281828,
                            2.207404910227873,
                            49.08930709608885,
                        ),
                        "coordinates": [
                            [2.200978026879316, 49.08930709608885],
                            [2.200858886040124, 49.08883668609218],
                            [2.200817247554296, 49.08852157256377],
                            [2.200820929914095, 49.08817832299847],
                            [2.200853268621624, 49.08786991070815],
                            [2.200922459442305, 49.087603808351226],
                            [2.200994258518992, 49.08738447030166],
                            [2.201099004649961, 49.08713369754419],
                            [2.201166459457293, 49.08700068428713],
                            [2.201291697610338, 49.08676522278638],
                            [2.201537793117673, 49.0863941134586],
                            [2.201673782621026, 49.086231505541384],
                            [2.201857852021466, 49.086010501543896],
                            [2.202091248430846, 49.085774267134724],
                            [2.20250567587162, 49.08542493572345],
                            [2.202788262577688, 49.085222929541395],
                            [2.203202412396381, 49.084972515524335],
                            [2.203746714512316, 49.08468807873599],
                            [2.203889287125589, 49.08461899980039],
                            [2.204205967789653, 49.084462892250194],
                            [2.204741984239535, 49.0842009230612],
                            [2.20509293213278, 49.08402776668637],
                            [2.205705814622024, 49.08368764427291],
                            [2.205907404134456, 49.08356107744532],
                            [2.206162568612107, 49.0833653263573],
                            [2.206356035657136, 49.08320277855845],
                            [2.206570185460174, 49.08298359839493],
                            [2.20679400128443, 49.082732955594714],
                            [2.206994628678089, 49.08244811295753],
                            [2.2071817069896, 49.082109298318024],
                            [2.207312689761099, 49.08175603227995],
                            [2.207382050865224, 49.08140809192987],
                            [2.207404910227873, 49.081043013116535],
                            [2.207375646480392, 49.08071654374962],
                            [2.207331194501543, 49.08043951790937],
                            [2.207211544546548, 49.08012643533654],
                            [2.207058986093821, 49.079833999087924],
                            [2.206790397969286, 49.079415533234695],
                            [2.206437036530973, 49.07896099924466],
                            [2.20594311432761, 49.078342636482795],
                            [2.205446725524735, 49.07769904281828],
                        ],
                    },
                },
                194: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.98532092323638, 2.1710129580525397],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1746.00734146,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.161906605592158,
                            48.98026352072714,
                            2.180012382147682,
                            48.99028999637593,
                        ),
                        "coordinates": [
                            [2.180012382147682, 48.98026352072714],
                            [2.179744028518352, 48.980534397773155],
                            [2.17943952143388, 48.9808052247129],
                            [2.179149542791524, 48.98105465508013],
                            [2.178729144981954, 48.98139194229784],
                            [2.178265330202148, 48.98173868401558],
                            [2.177888571497791, 48.98199037099218],
                            [2.177461178654776, 48.98224912582839],
                            [2.177026603469663, 48.98249121140953],
                            [2.176501567665112, 48.98275934306846],
                            [2.175944033983173, 48.983013150491665],
                            [2.17535761170449, 48.98325739537508],
                            [2.174525169018463, 48.98355839521004],
                            [2.17337421097981, 48.98397552111971],
                            [2.171919191813018, 48.98450402653379],
                            [2.171463047489131, 48.984696093955996],
                            [2.170995990963719, 48.98490718010388],
                            [2.170572318568492, 48.98511594750829],
                            [2.170134094507895, 48.985350864954775],
                            [2.169710270453896, 48.98560245836311],
                            [2.16924290881962, 48.98589919035854],
                            [2.166532546034458, 48.98769873133757],
                            [2.16506500094823, 48.98866017298146],
                            [2.164586749680049, 48.98895211373551],
                            [2.164267965424287, 48.9891324616969],
                            [2.163963686196905, 48.98929855765896],
                            [2.161906605592158, 48.99028999637593],
                        ],
                    },
                },
                195: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.95527034220546, 2.518986404402624],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1918.82335622,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.512644627819613,
                            48.947607554953485,
                            2.52471638942019,
                            48.962709513300425,
                        ),
                        "coordinates": [
                            [2.52471638942019, 48.947607554953485],
                            [2.524690195029446, 48.94792125942806],
                            [2.524649513491627, 48.94840848815528],
                            [2.52459649163621, 48.94876693576496],
                            [2.524476063686018, 48.949205736438515],
                            [2.524310989877811, 48.94957882066666],
                            [2.524167641997917, 48.94982759698238],
                            [2.524013137601642, 48.9500617706561],
                            [2.523767156932613, 48.9503957862003],
                            [2.523545274049944, 48.950681738858265],
                            [2.523325128089641, 48.95093478504357],
                            [2.523208550877416, 48.951061318519116],
                            [2.523053086052221, 48.95122217747705],
                            [2.522884687730144, 48.95140233140805],
                            [2.522725968457396, 48.95156319493269],
                            [2.521556546707297, 48.952734303009066],
                            [2.515348917598681, 48.958941410314985],
                            [2.514995757824175, 48.95930385896129],
                            [2.514804613698599, 48.95950545000867],
                            [2.514607078866195, 48.95973917213266],
                            [2.514441958488591, 48.95994286241386],
                            [2.514263938659011, 48.96017869432164],
                            [2.514144227250268, 48.96035019226891],
                            [2.513937206250479, 48.960661017939415],
                            [2.513083485356867, 48.96201999432523],
                            [2.512644627819613, 48.962709513300425],
                        ],
                    },
                },
                196: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.595604808066874, 2.2824773927647555],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2548.36843922,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.266937972614161,
                            48.591460820223375,
                            2.297950577822679,
                            48.599059348508746,
                        ),
                        "coordinates": [
                            [2.266937972614161, 48.591460820223375],
                            [2.267047525335429, 48.59151679110039],
                            [2.267393746322513, 48.591696878854286],
                            [2.268674568132321, 48.59239241779769],
                            [2.269922669670241, 48.59307077501544],
                            [2.271089898822804, 48.59370017204722],
                            [2.271525910676296, 48.59393110960185],
                            [2.272027767242565, 48.59416456845992],
                            [2.272396644934728, 48.59432799739449],
                            [2.273056651218614, 48.59459152098763],
                            [2.273601247795335, 48.59479002068213],
                            [2.274155927647354, 48.59496187494262],
                            [2.274708122737644, 48.59511374028097],
                            [2.275318074612092, 48.595263967518804],
                            [2.275717196138264, 48.59534912384036],
                            [2.276028466688033, 48.595412580583535],
                            [2.276440162842702, 48.595482751391785],
                            [2.276812599097834, 48.595538125571785],
                            [2.277128021386692, 48.59558304670883],
                            [2.277645192328033, 48.59564160986846],
                            [2.278084550472182, 48.5956801451578],
                            [2.278616804078241, 48.5957237225199],
                            [2.280698173409043, 48.59585801094676],
                            [2.282026335965663, 48.595946932759716],
                            [2.283678381982467, 48.596060972580474],
                            [2.286510473089086, 48.59626045928417],
                            [2.290291700203794, 48.59647359284977],
                            [2.291258363676342, 48.59651728825804],
                            [2.291845884000873, 48.596555828864894],
                            [2.292265183825152, 48.596582642928524],
                            [2.293081917984158, 48.596624196039],
                            [2.293298850176136, 48.59664259367458],
                            [2.293870732040014, 48.596721303727605],
                            [2.29433609656291, 48.59682351837107],
                            [2.294809322364659, 48.59695974683564],
                            [2.295325907192924, 48.597135235767595],
                            [2.295645308859402, 48.59726093930767],
                            [2.295921330104468, 48.597378776049474],
                            [2.296398449704391, 48.597590875344935],
                            [2.296779144063657, 48.59777501519646],
                            [2.2970529826857, 48.59792338887908],
                            [2.297269789044134, 48.598106612298714],
                            [2.297490499523158, 48.598344780730265],
                            [2.297597336598059, 48.59850367185756],
                            [2.297950577822679, 48.599059348508746],
                        ],
                    },
                },
                197: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.93723077211048, 2.5190146055658134],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2431.54747179,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.508038741924935,
                            48.9322501569209,
                            2.525001590830138,
                            48.947607554953485,
                        ),
                        "coordinates": [
                            [2.508038741924935, 48.9322501569209],
                            [2.509511499171653, 48.93229557999441],
                            [2.51173560303805, 48.93243328802947],
                            [2.51263144443881, 48.93249853842352],
                            [2.51331057582227, 48.93255459834294],
                            [2.513910267077514, 48.93261315685097],
                            [2.514379945622042, 48.93266953363641],
                            [2.514719588469443, 48.93271897297017],
                            [2.515055640169205, 48.93277317465532],
                            [2.515420660221266, 48.93284874689551],
                            [2.515731492880958, 48.932919641363206],
                            [2.515977302975914, 48.932985879470806],
                            [2.516293648307232, 48.93307164535643],
                            [2.516686370408892, 48.93319218044048],
                            [2.516956388598597, 48.93328060122371],
                            [2.517217230577274, 48.9333730743249],
                            [2.51744745111074, 48.93347367170414],
                            [2.517662387081816, 48.933584386902744],
                            [2.517871195325143, 48.933695113021315],
                            [2.518644888477624, 48.934183677193154],
                            [2.519030843091576, 48.93446633786969],
                            [2.519756239316235, 48.934999354911135],
                            [2.520008130137293, 48.93519859342558],
                            [2.520327810049966, 48.93551554231356],
                            [2.520562178379841, 48.93574996719751],
                            [2.520809050317273, 48.93604104624682],
                            [2.521173243846935, 48.93648577273667],
                            [2.521506573065543, 48.93689006395683],
                            [2.521926569049038, 48.937464241161464],
                            [2.522440131549308, 48.93830116409966],
                            [2.522761571252461, 48.93889361096752],
                            [2.523062190399648, 48.939436866481614],
                            [2.523380650863689, 48.94000633363021],
                            [2.523661856023293, 48.94056360046595],
                            [2.523879406807256, 48.941044865481096],
                            [2.524712006720615, 48.943256338410464],
                            [2.524822302613202, 48.94353440961144],
                            [2.524888524601425, 48.94375237351017],
                            [2.524963122453256, 48.944024169964365],
                            [2.525000855938172, 48.94427448786633],
                            [2.525001590830138, 48.94446833094366],
                            [2.524895537088352, 48.945604640268236],
                            [2.52473861279838, 48.94734141012521],
                            [2.52471638942019, 48.947607554953485],
                        ],
                    },
                },
                198: {
                    "attributes": {
                        "reseau": "CDGVAL",
                        "val": 1,
                        "metro": 0,
                        "res_com": "CDGVAL",
                        "rer": 0,
                        "extcode": "043043100:CDGVAL",
                        "geo_point_2d": [49.009533674567464, 2.5526969894618303],
                        "indice_lig": "CDG",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Navette",
                        "tramway": 0,
                        "idrefligc": "C00563",
                        "navette": 1,
                        "idrefliga": "A01516",
                        "shape_leng": 1158.03071717,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.54483189791712,
                            49.008978460950175,
                            2.560558843901876,
                            49.010067608984684,
                        ),
                        "coordinates": [
                            [2.54483189791712, 49.008978460950175],
                            [2.547162425802318, 49.0091057529518],
                            [2.547638634618383, 49.00913012321774],
                            [2.548309436247278, 49.009182424186754],
                            [2.549309098505333, 49.00925338420587],
                            [2.553503308062386, 49.00958602287308],
                            [2.554336977326103, 49.009659395056886],
                            [2.556147660844504, 49.00982940120673],
                            [2.559091939988773, 49.010042220561566],
                            [2.559398026013325, 49.01005868136568],
                            [2.559686531709368, 49.010067608984684],
                            [2.559967728802765, 49.01005520240244],
                            [2.560227196951591, 49.010021489767944],
                            [2.560558843901876, 49.01000186615112],
                        ],
                    },
                },
                199: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96272518249947, 3.27000233292206],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 9880.37555071,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.219302814192089,
                            48.9490786960231,
                            3.32188681725306,
                            48.974026580478466,
                        ),
                        "coordinates": [
                            [3.219302814192089, 48.974026580478466],
                            [3.220051124556012, 48.973955503684245],
                            [3.220748614529517, 48.973908469373825],
                            [3.221440729638185, 48.97387844981426],
                            [3.22214195202817, 48.973864367983495],
                            [3.222807354987442, 48.97386254211974],
                            [3.223303437733916, 48.97387202006249],
                            [3.2239109814487, 48.97388895744797],
                            [3.225599772920116, 48.973954119021776],
                            [3.226737198053162, 48.973986745663815],
                            [3.227657340777943, 48.97399742830987],
                            [3.228499781707588, 48.97397197080792],
                            [3.229164471386213, 48.973936329753194],
                            [3.229611866248663, 48.973899434002966],
                            [3.23072739813513, 48.97379088595276],
                            [3.231801314864924, 48.973647579038584],
                            [3.232305277789907, 48.97356448924119],
                            [3.232770993686833, 48.97348169635326],
                            [3.2337523086958, 48.97327974114177],
                            [3.234817130899744, 48.973012368163964],
                            [3.235818752485804, 48.972725697363856],
                            [3.236562942323716, 48.97248151471364],
                            [3.237126261828032, 48.97228282101101],
                            [3.237568553162295, 48.972114756556344],
                            [3.238123180014235, 48.97188914517359],
                            [3.238762986176607, 48.97161519438356],
                            [3.239238967404711, 48.971389832262524],
                            [3.239534817914093, 48.971246460204696],
                            [3.239811034464006, 48.971105086075816],
                            [3.240445560571207, 48.970767314627835],
                            [3.240805914952083, 48.970559404391665],
                            [3.241186956266989, 48.970325785573436],
                            [3.241506123201707, 48.97012129120249],
                            [3.242054037888303, 48.9697545177798],
                            [3.242543526073105, 48.96940529329134],
                            [3.242938125464083, 48.96909638895769],
                            [3.243278759940915, 48.96882478495911],
                            [3.243476458845109, 48.968655040302586],
                            [3.243672626974816, 48.96847631326666],
                            [3.244103660794766, 48.96806908865474],
                            [3.244542207704287, 48.96762492897347],
                            [3.244996230966727, 48.96713118178916],
                            [3.245676556508061, 48.96639011231234],
                            [3.246440924758489, 48.96554044944534],
                            [3.247154624625369, 48.964759533994744],
                            [3.247750549852749, 48.96411175703726],
                            [3.248043503275677, 48.96377576582863],
                            [3.248963393863972, 48.962771957246964],
                            [3.249748952592749, 48.961892423641665],
                            [3.250479746680428, 48.96107392377699],
                            [3.251488797445429, 48.9599631858926],
                            [3.252522541986071, 48.958822257197866],
                            [3.253214124279665, 48.95805717273584],
                            [3.25622809260059, 48.954729378730335],
                            [3.256979271825964, 48.95390440514789],
                            [3.257423557592575, 48.953449432815354],
                            [3.257732651159442, 48.95314713378433],
                            [3.258007680299058, 48.9528983871552],
                            [3.258244233454284, 48.95269826674022],
                            [3.258448620442044, 48.95253671371046],
                            [3.258653099287763, 48.95238015812103],
                            [3.258875062165073, 48.95221180135747],
                            [3.259178958846838, 48.95199947282635],
                            [3.259447549171697, 48.951830026757015],
                            [3.25987417354828, 48.95156756925578],
                            [3.260210706501014, 48.951380484640914],
                            [3.260572944292518, 48.95118059993728],
                            [3.260911121762154, 48.951008787928835],
                            [3.261283377886781, 48.95083400149383],
                            [3.261723460824696, 48.95063528160006],
                            [3.262129527556702, 48.95046976723937],
                            [3.262488183983621, 48.95032884991796],
                            [3.262828315918833, 48.95020543822273],
                            [3.26330740301974, 48.95004866495225],
                            [3.263713443135862, 48.94992233624862],
                            [3.263990155997988, 48.949843470102635],
                            [3.264334860494532, 48.94974906007039],
                            [3.264725077915624, 48.94965427967217],
                            [3.265075037590687, 48.94957564940334],
                            [3.265528068561412, 48.94948652853041],
                            [3.265853762604668, 48.94942523778572],
                            [3.266249496894872, 48.94935539163253],
                            [3.26657733691546, 48.949306084740904],
                            [3.266993642345201, 48.94925439209138],
                            [3.267382194622261, 48.949206253478025],
                            [3.267730477364163, 48.949168436102255],
                            [3.268159798960954, 48.94913662061608],
                            [3.268576538616538, 48.94910823723731],
                            [3.268945304869598, 48.94909625714524],
                            [3.269339751365802, 48.94908035415021],
                            [3.26974687747657, 48.9490786960231],
                            [3.270224956996792, 48.949084783711236],
                            [3.270700699442268, 48.94910088252404],
                            [3.271120874374347, 48.94912076597347],
                            [3.271579260980257, 48.94915532528342],
                            [3.272106137459299, 48.94920098242349],
                            [3.272615598960103, 48.949261769861906],
                            [3.273016208271058, 48.94931678528912],
                            [3.273451296429456, 48.949386757097066],
                            [3.273856902266804, 48.94946257235397],
                            [3.27423663727745, 48.94954219618774],
                            [3.274583504705027, 48.949616691937635],
                            [3.274931944265065, 48.9497019659792],
                            [3.275284648547881, 48.94979619832755],
                            [3.275704694831234, 48.94991325780826],
                            [3.276424447241859, 48.95013757106604],
                            [3.276898697238463, 48.95030454457533],
                            [3.277324928561055, 48.95045932014982],
                            [3.277699231217119, 48.95061182428068],
                            [3.278119101185705, 48.950790931021636],
                            [3.27847873089525, 48.950961540721366],
                            [3.278872870787224, 48.95115164929429],
                            [3.279161203701664, 48.951306656193694],
                            [3.279463208647743, 48.95146244882942],
                            [3.279705815592856, 48.9516103435911],
                            [3.280002651950996, 48.95179278172166],
                            [3.280353261724357, 48.95202348549484],
                            [3.28076440125702, 48.95231687151686],
                            [3.281084408920581, 48.95255704994441],
                            [3.281514081801471, 48.95292466315023],
                            [3.282016643457746, 48.95339127043647],
                            [3.282407700166431, 48.953780003489086],
                            [3.282811146439633, 48.95424639809517],
                            [3.283031394713747, 48.954522740079234],
                            [3.283203429673976, 48.95476179225213],
                            [3.283333943631602, 48.95494597586285],
                            [3.283558003472831, 48.95530925304632],
                            [3.283761722582123, 48.955679893194166],
                            [3.28394254172856, 48.95606691109604],
                            [3.284092328677198, 48.956402023094086],
                            [3.284141207120106, 48.95653022405892],
                            [3.284180303971511, 48.95664681464919],
                            [3.284219883275057, 48.95676320084165],
                            [3.286257479674211, 48.96092766911615],
                            [3.28847320115611, 48.96340773142829],
                            [3.290494760731977, 48.96517551599734],
                            [3.292859479997547, 48.96598858660525],
                            [3.298782001341376, 48.9669272009919],
                            [3.312418595811659, 48.968202831680195],
                            [3.32188681725306, 48.969278782071456],
                        ],
                    },
                },
                200: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.972402667181115, 1.6209521307485937],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 13649.5046806,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.541381156495169,
                            48.943236988151924,
                            1.703016134167223,
                            48.99049452612851,
                        ),
                        "coordinates": [
                            [1.541381156495169, 48.943236988151924],
                            [1.541962745194756, 48.943565823888335],
                            [1.54254334169736, 48.943884622508584],
                            [1.542562295245285, 48.94389464656514],
                            [1.54324907697493, 48.94423306517932],
                            [1.543911482816356, 48.944559619924696],
                            [1.544622022325549, 48.944864919596505],
                            [1.545368036210908, 48.945172259802774],
                            [1.546239210948517, 48.94550833896896],
                            [1.547519428603309, 48.94596594722534],
                            [1.547598180104668, 48.94599347063161],
                            [1.547758413730737, 48.9460485368756],
                            [1.547902337627978, 48.94609899286605],
                            [1.548006899319773, 48.946134787448564],
                            [1.548044924967328, 48.94614764088472],
                            [1.549952746525076, 48.94680830004222],
                            [1.550812307244833, 48.947105594027974],
                            [1.551173532112853, 48.947229485166346],
                            [1.55363420708505, 48.94807644366639],
                            [1.555333019185319, 48.94866633246041],
                            [1.555576140385528, 48.94874803398496],
                            [1.555663021738991, 48.94878010368736],
                            [1.557583417977607, 48.94943532514701],
                            [1.560633704637024, 48.95048759620734],
                            [1.563719253387407, 48.95156340583482],
                            [1.565807189852035, 48.952259190346126],
                            [1.566748177267378, 48.95260097800559],
                            [1.567018476055226, 48.95269362928425],
                            [1.567298279397954, 48.95278994161394],
                            [1.567463976189321, 48.95284771444821],
                            [1.568944512226664, 48.9533567897689],
                            [1.569877669377148, 48.953677814902576],
                            [1.571022733611183, 48.95407219703166],
                            [1.571379962902067, 48.95419599748944],
                            [1.574815293959903, 48.95537816694688],
                            [1.575758031148289, 48.955702804106146],
                            [1.576104444180637, 48.95582112188943],
                            [1.576236203363719, 48.95586696430809],
                            [1.57641279020859, 48.95592839277981],
                            [1.577159940221973, 48.956185168585826],
                            [1.577202034451363, 48.956200736434276],
                            [1.577240076063393, 48.95621357960577],
                            [1.577826794284136, 48.956424319742474],
                            [1.577871580218472, 48.956442603040244],
                            [1.578144541799151, 48.95654244070133],
                            [1.579605797102149, 48.95707642954749],
                            [1.579707686719592, 48.957111278042646],
                            [1.580307739391328, 48.95734457621661],
                            [1.580986271085755, 48.95762605281115],
                            [1.581486680164821, 48.957856887449786],
                            [1.582157849389659, 48.958174281280634],
                            [1.582954929093008, 48.95856444703446],
                            [1.583445402186658, 48.95882128718064],
                            [1.584107830176099, 48.95917638341776],
                            [1.58476456105724, 48.959547626154034],
                            [1.585202809907044, 48.959838145483644],
                            [1.586562968604124, 48.9606941609709],
                            [1.586910063111115, 48.96092010549522],
                            [1.587397209791767, 48.961204073833706],
                            [1.587906115444549, 48.96148342437678],
                            [1.588354175835437, 48.96172430222169],
                            [1.588899365619935, 48.96199436757759],
                            [1.589419629645817, 48.962240473581446],
                            [1.589968767860917, 48.962489143616544],
                            [1.590510937822693, 48.96272110952674],
                            [1.591031823948726, 48.962926761559046],
                            [1.591595896243342, 48.96314458880158],
                            [1.59257383167648, 48.9634769415565],
                            [1.593642077668292, 48.9638122528945],
                            [1.594545333484994, 48.96406558090088],
                            [1.595880431329847, 48.96444067390458],
                            [1.596984712768646, 48.96478570403875],
                            [1.597628080688679, 48.96502067153474],
                            [1.598199399344948, 48.96524089161369],
                            [1.598975168241535, 48.96556474461152],
                            [1.599556631501998, 48.96583261281742],
                            [1.600076881017257, 48.966085807008945],
                            [1.600525150390071, 48.96631950044647],
                            [1.600996209161962, 48.96657681555457],
                            [1.601475058821443, 48.966844331183985],
                            [1.602008658922043, 48.967173744588294],
                            [1.602531284577495, 48.96751260224393],
                            [1.602981958639509, 48.96782958029518],
                            [1.603471581817273, 48.96820153435026],
                            [1.603953806737483, 48.96858533739492],
                            [1.605182299627212, 48.969585429018785],
                            [1.606800130368989, 48.970902080694025],
                            [1.608446715411697, 48.972235546755456],
                            [1.614319244402173, 48.97700311606737],
                            [1.618535048506358, 48.98042274436897],
                            [1.619239035258169, 48.980986329898776],
                            [1.61968580937528, 48.981338908049544],
                            [1.620107973984369, 48.98164374320861],
                            [1.620559233267343, 48.981936859971945],
                            [1.621014491310247, 48.9822038271807],
                            [1.621487931679318, 48.98246376798808],
                            [1.622108965821046, 48.98276745870964],
                            [1.622748525804292, 48.98304032836921],
                            [1.623320268406904, 48.983253285554895],
                            [1.623787938385126, 48.98341324509759],
                            [1.6243277376094, 48.98358554795548],
                            [1.624965143230725, 48.98375845633887],
                            [1.625541644789221, 48.983892910468846],
                            [1.626053491383382, 48.98399840771947],
                            [1.626641253604478, 48.98410437348103],
                            [1.627297768850721, 48.98420600397686],
                            [1.627893276503856, 48.984276320046305],
                            [1.628499765837446, 48.98433718330214],
                            [1.629160753037861, 48.98437934460489],
                            [1.629847350046053, 48.98440024542518],
                            [1.630512598901766, 48.98439721690573],
                            [1.631192644781068, 48.984370481188115],
                            [1.63185127145934, 48.9843245732144],
                            [1.632539154803839, 48.984255048150445],
                            [1.633933529872428, 48.984078027938104],
                            [1.634810088585694, 48.98395968027273],
                            [1.636005292202547, 48.98380520663098],
                            [1.636787585370083, 48.98370530118996],
                            [1.637606023824801, 48.983605611423066],
                            [1.63842442686033, 48.98350829537596],
                            [1.639322521063671, 48.98339956293483],
                            [1.640162503920702, 48.98330950378012],
                            [1.641227040397552, 48.983189872146305],
                            [1.642139313879204, 48.98310023760408],
                            [1.642975574514153, 48.98301727462341],
                            [1.644666026247236, 48.98286095541211],
                            [1.646197049875647, 48.98272982255503],
                            [1.647091035472594, 48.982654315704245],
                            [1.648100656596277, 48.98258187718742],
                            [1.649993109827354, 48.98245524813063],
                            [1.651216028955323, 48.982381684406995],
                            [1.652713568557468, 48.98231688763237],
                            [1.65361059241172, 48.982281798450735],
                            [1.654525492038574, 48.982261084887135],
                            [1.655389522410743, 48.982259097751545],
                            [1.656275046455499, 48.98227150718231],
                            [1.656929125515478, 48.98228967299071],
                            [1.657676961347356, 48.98232504747259],
                            [1.658450005580976, 48.98236770601398],
                            [1.659175861373318, 48.982424354760376],
                            [1.660060513008304, 48.9825009748465],
                            [1.66083659101365, 48.98258646430374],
                            [1.661558450648096, 48.9826716279605],
                            [1.662276503781799, 48.982771041687435],
                            [1.663077376461642, 48.98289473281918],
                            [1.663928602278427, 48.98303774961124],
                            [1.664682264356379, 48.98317780726155],
                            [1.665360052874971, 48.98331503562577],
                            [1.666088192789255, 48.983471590219445],
                            [1.666808917157769, 48.98364237366442],
                            [1.667471838705015, 48.983810434049694],
                            [1.668199480865629, 48.98400504467882],
                            [1.66891964187714, 48.98421864015558],
                            [1.669535265417425, 48.98441020709595],
                            [1.670208409670134, 48.98462590015267],
                            [1.672126728384713, 48.98526760903823],
                            [1.680239757114454, 48.98797227330492],
                            [1.680862605127309, 48.988170958437436],
                            [1.681449588465203, 48.98834801992586],
                            [1.682094328823308, 48.988532547911646],
                            [1.682681603654369, 48.988688190521664],
                            [1.683431163547309, 48.98887568861192],
                            [1.684184469060674, 48.98905368554938],
                            [1.684880310524462, 48.98920279874365],
                            [1.685623124567352, 48.9893545529823],
                            [1.686625808719835, 48.9895410911535],
                            [1.687462817713614, 48.98967909249607],
                            [1.688412001902074, 48.989810585424145],
                            [1.689437298712309, 48.98992822418882],
                            [1.69037255819594, 48.99001917196599],
                            [1.691358652984027, 48.990093743246646],
                            [1.692232922640822, 48.99014863948858],
                            [1.693175978351185, 48.990196779060376],
                            [1.696268802939145, 48.99036404035903],
                            [1.698529593632241, 48.99048631919019],
                            [1.699147766592247, 48.99049452612851],
                            [1.699683334961162, 48.990459440130536],
                            [1.700213667819275, 48.990410889589135],
                            [1.700724909562586, 48.990309941744876],
                            [1.70126561943671, 48.99016591077427],
                            [1.701598682602702, 48.990060884515835],
                            [1.702348288564212, 48.98977924602929],
                            [1.703016134167223, 48.989502508030505],
                        ],
                    },
                },
                201: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.467862035062616, 2.7665218453153955],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 5873.52915957,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.751153658380149,
                            48.442882064226566,
                            2.773485606663736,
                            48.487222875528246,
                        ),
                        "coordinates": [
                            [2.760926733738456, 48.442882064226566],
                            [2.761595951004158, 48.44354694021371],
                            [2.763422457189777, 48.445359056860475],
                            [2.764926650505398, 48.446868994569265],
                            [2.765680142918008, 48.44761329316563],
                            [2.765951009215691, 48.447896288729545],
                            [2.766124752982382, 48.448074727769395],
                            [2.766225533085432, 48.448198865003135],
                            [2.766321623876522, 48.448339422882505],
                            [2.766421774736739, 48.44850614724888],
                            [2.766586591072239, 48.44881037152612],
                            [2.766743584332989, 48.44914789796946],
                            [2.766882983986937, 48.44948279412558],
                            [2.766986886946515, 48.44977645864304],
                            [2.767074105482878, 48.450016230276155],
                            [2.767324460026053, 48.450835406492644],
                            [2.767426846737313, 48.45113944996402],
                            [2.767532538329151, 48.45145330840755],
                            [2.767681640379815, 48.45180042278222],
                            [2.767831749205445, 48.452135609759615],
                            [2.767888189285304, 48.452241370777884],
                            [2.768350304169477, 48.45301401374466],
                            [2.768503899000985, 48.45326792043091],
                            [2.768920876041274, 48.4539650575954],
                            [2.769207590781253, 48.45444866594502],
                            [2.769811043678867, 48.45545874875412],
                            [2.77007976253259, 48.45592406519053],
                            [2.77035913428027, 48.45637982223105],
                            [2.770825994270108, 48.45712407983803],
                            [2.771222131880606, 48.4577255822222],
                            [2.77136382249737, 48.457977245511394],
                            [2.771491266504765, 48.458236101546795],
                            [2.771574140953394, 48.458429639862544],
                            [2.771817774610239, 48.45908426846817],
                            [2.771916567490021, 48.459406724335636],
                            [2.771994377541466, 48.45973789308037],
                            [2.772193108546506, 48.460735674391266],
                            [2.772316576384184, 48.46137534151357],
                            [2.772440480960773, 48.46197391068492],
                            [2.772585800884284, 48.46267028235211],
                            [2.772694172546813, 48.4631599649219],
                            [2.772807204354267, 48.46371887295381],
                            [2.772887787100706, 48.46412233250483],
                            [2.773365257537985, 48.46646937497422],
                            [2.773418655732841, 48.46683511706058],
                            [2.773447698267541, 48.46708505414123],
                            [2.773465728805673, 48.46744738915953],
                            [2.773485606663736, 48.467866370244394],
                            [2.773457057579393, 48.468469888228924],
                            [2.773404735362116, 48.46887853676099],
                            [2.773335706074937, 48.46928688966345],
                            [2.773170868595014, 48.46996202604711],
                            [2.773008668838968, 48.47055521547116],
                            [2.772648855063921, 48.471788595626215],
                            [2.772465603035616, 48.472305024023306],
                            [2.772268010049928, 48.47278005296128],
                            [2.772072691561673, 48.47318377514302],
                            [2.771789646262083, 48.47366003513115],
                            [2.771485763848649, 48.47410375294116],
                            [2.77120549910066, 48.474535071882094],
                            [2.770600178812847, 48.475400720924135],
                            [2.77031561305327, 48.47580648005272],
                            [2.770044435919698, 48.476196900727025],
                            [2.769630305275653, 48.47679199934125],
                            [2.769312517881354, 48.477268026437116],
                            [2.768677604746096, 48.478141838809755],
                            [2.768141037009027, 48.478815635470184],
                            [2.767868040105863, 48.47915569828132],
                            [2.767290401176827, 48.47975161386681],
                            [2.766793892302045, 48.480234404195315],
                            [2.766255387394773, 48.480687845353465],
                            [2.765757730570017, 48.48110688068657],
                            [2.765401072575688, 48.481382650833126],
                            [2.764881310400018, 48.481773643711556],
                            [2.764325483713099, 48.48214569697125],
                            [2.763522391228304, 48.482666701966124],
                            [2.763006955411796, 48.48297619225833],
                            [2.762367833682136, 48.48332728889813],
                            [2.761665846489327, 48.483689200513965],
                            [2.760831671652031, 48.48408015459614],
                            [2.759719510474557, 48.48461252023684],
                            [2.75928104563875, 48.484821156227184],
                            [2.758739169459785, 48.48507538313257],
                            [2.758289899490584, 48.48527691715416],
                            [2.757797697238829, 48.48548098876748],
                            [2.757415982506981, 48.485629924957514],
                            [2.756930593312749, 48.48579351918423],
                            [2.756402294189915, 48.485964157295335],
                            [2.755964682047495, 48.48610374057985],
                            [2.75552761458263, 48.48622699012184],
                            [2.755095442948047, 48.486335655639394],
                            [2.754631016848214, 48.48643967936091],
                            [2.754213016978645, 48.48653163466971],
                            [2.75273398453552, 48.48686304015041],
                            [2.751883734060254, 48.48705650403138],
                            [2.751153658380149, 48.487222875528246],
                        ],
                    },
                },
                202: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.89780707209598, 2.4293987926745437],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 4313.53099779,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.400361703159176,
                            48.896260322962334,
                            2.458363412015992,
                            48.89887033891491,
                        ),
                        "coordinates": [
                            [2.400361703159176, 48.898112306280396],
                            [2.403281547204399, 48.8983438213715],
                            [2.404876826547504, 48.89847136687579],
                            [2.405450682176829, 48.89850671463484],
                            [2.406020912342306, 48.898530163543775],
                            [2.407403173866654, 48.89858166368836],
                            [2.408521966211799, 48.898614278896304],
                            [2.409633528019113, 48.89863737105588],
                            [2.41263233951892, 48.898676559246276],
                            [2.413472391835469, 48.8986734053139],
                            [2.413883777660752, 48.898658852205685],
                            [2.414421450071567, 48.89862755761662],
                            [2.414944681641715, 48.898593891432306],
                            [2.415713296251286, 48.89854815551904],
                            [2.416146323114309, 48.89852644188184],
                            [2.416608232083264, 48.898511844231294],
                            [2.417019628566003, 48.89850441914446],
                            [2.417499613034112, 48.898508839242446],
                            [2.417947125452648, 48.898518040421095],
                            [2.419379904883467, 48.89855746392422],
                            [2.420978711081432, 48.89860864377334],
                            [2.424111357756001, 48.898699089762765],
                            [2.427846738939663, 48.89881276436524],
                            [2.42932644878034, 48.898852026787786],
                            [2.429896676332358, 48.89886584003609],
                            [2.430214265413721, 48.89887033891491],
                            [2.430578757373056, 48.89886766133943],
                            [2.430914364672341, 48.89885786856133],
                            [2.431286045461826, 48.898840905981636],
                            [2.431690180914725, 48.89880963985484],
                            [2.432025749779658, 48.898780808992264],
                            [2.432415416154168, 48.898732897522414],
                            [2.432794241858564, 48.89867785497748],
                            [2.433133358374563, 48.89861808627199],
                            [2.433458034450159, 48.89855594966109],
                            [2.433829588397613, 48.89847473819822],
                            [2.434309326591622, 48.89835298313319],
                            [2.434882797779406, 48.89818355988485],
                            [2.435607717209017, 48.89795451927382],
                            [2.437259492611106, 48.897429625227275],
                            [2.438323331177323, 48.8970622661271],
                            [2.438813792515264, 48.89690241428735],
                            [2.439087894363203, 48.89682365164865],
                            [2.439445450651772, 48.896725945649514],
                            [2.439780394912604, 48.896642199826694],
                            [2.440162745475339, 48.896558577560285],
                            [2.440678596698777, 48.896465316512106],
                            [2.441154809413359, 48.89640063993438],
                            [2.441576925802698, 48.896352666637725],
                            [2.441991858898001, 48.89632135409288],
                            [2.442421241332333, 48.896297166078696],
                            [2.442872297336787, 48.89628247245745],
                            [2.443756413206839, 48.89627688942672],
                            [2.444514209915559, 48.896264281247326],
                            [2.445448854167565, 48.89626101817673],
                            [2.446177806648478, 48.896260322962334],
                            [2.446719118883842, 48.8962645625113],
                            [2.44714858881238, 48.896280804457405],
                            [2.4476971821202, 48.89631358493711],
                            [2.448361265144072, 48.89635100837806],
                            [2.449736363934091, 48.89643293507745],
                            [2.450819069581169, 48.89647468855999],
                            [2.45599294890596, 48.89665511724568],
                            [2.458363412015992, 48.896652451144085],
                        ],
                    },
                },
                203: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.74069806140985, 2.4112039151073685],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1589.11927858,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.40290860736794,
                            48.739201399103095,
                            2.417520977896491,
                            48.745072166893884,
                        ),
                        "coordinates": [
                            [2.40290860736794, 48.74187870567889],
                            [2.404148997694423, 48.74099924519451],
                            [2.404757643217121, 48.74064726679039],
                            [2.405086455081131, 48.74048519987144],
                            [2.405426135443845, 48.74031862960775],
                            [2.405987298049764, 48.74005390302935],
                            [2.406208773621854, 48.73995035151224],
                            [2.406476476959746, 48.739847669815504],
                            [2.406710207050344, 48.73975849825125],
                            [2.407073043981454, 48.739629678050854],
                            [2.407395152591308, 48.73954494655495],
                            [2.408133187830964, 48.73937991804247],
                            [2.408564079746463, 48.73930680465609],
                            [2.408755749852512, 48.739282402478366],
                            [2.409118717043212, 48.73924889836191],
                            [2.40930495829174, 48.739231693627914],
                            [2.409787586284275, 48.73920980122712],
                            [2.4102661560042, 48.739201399103095],
                            [2.410664530200711, 48.73920833398242],
                            [2.410811379616232, 48.73921633169249],
                            [2.411019421589991, 48.739230584525146],
                            [2.411075169715351, 48.739234144303495],
                            [2.411465435589616, 48.73927255734691],
                            [2.411906039467219, 48.739332517606854],
                            [2.412392916845483, 48.73942302048742],
                            [2.412942417322595, 48.739564737557345],
                            [2.413773559218267, 48.73983395734561],
                            [2.414097365070003, 48.7399722255866],
                            [2.414456565445204, 48.74013834493735],
                            [2.414837562557761, 48.740329628350366],
                            [2.415195486350047, 48.7405452064186],
                            [2.415548012333417, 48.740784168391286],
                            [2.415793035794553, 48.74096475144346],
                            [2.416055824997396, 48.7412010771217],
                            [2.416330905349029, 48.74146886698946],
                            [2.416512065030532, 48.741671076148776],
                            [2.416878676187535, 48.742204985630586],
                            [2.416987721592861, 48.742373072345345],
                            [2.417091393483954, 48.74258073036333],
                            [2.417259384866112, 48.74304373628445],
                            [2.417316901741602, 48.74329639139475],
                            [2.417387046518704, 48.74379004150383],
                            [2.417520977896491, 48.745072166893884],
                        ],
                    },
                },
                204: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.74207585643256, 2.331916074868938],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3148.30843408,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.312711013515798,
                            48.738738654836844,
                            2.351633198171911,
                            48.74794571395915,
                        ),
                        "coordinates": [
                            [2.312711013515798, 48.747941901886946],
                            [2.312954547887192, 48.74794571395915],
                            [2.313294514565373, 48.74793589239383],
                            [2.313644005760375, 48.74791707803183],
                            [2.314200214846999, 48.74784974342829],
                            [2.314677554927342, 48.747774297536985],
                            [2.315022986980907, 48.747705119517796],
                            [2.315323428140145, 48.74762957351263],
                            [2.315681759063343, 48.747527892488726],
                            [2.315998109487221, 48.747429223182934],
                            [2.316222519001663, 48.747342034088646],
                            [2.316755662215582, 48.747121806058445],
                            [2.318526226281677, 48.746315382799565],
                            [2.319932703806598, 48.745695168838616],
                            [2.321232167678898, 48.7451102517737],
                            [2.322407582797582, 48.744577435373934],
                            [2.323420980982226, 48.744139884726955],
                            [2.324007099304466, 48.74387646405618],
                            [2.325309863984821, 48.74329477148518],
                            [2.325770855123277, 48.7430888828714],
                            [2.327099412766535, 48.74251076922499],
                            [2.327969684712783, 48.74215832374952],
                            [2.328819541864001, 48.74184363902379],
                            [2.329364803418165, 48.74165752572969],
                            [2.329891023066446, 48.741484898162824],
                            [2.331287456413227, 48.74105242209054],
                            [2.333128480757714, 48.740493145702104],
                            [2.334744798588848, 48.73999948246041],
                            [2.335783523924499, 48.73968020127323],
                            [2.336798169287619, 48.73936371305131],
                            [2.337148530683693, 48.739251792698546],
                            [2.33758020725802, 48.73911537462024],
                            [2.337992694666737, 48.73899799057319],
                            [2.338385997901208, 48.7389155016141],
                            [2.338894412684503, 48.738836181725766],
                            [2.339426807638118, 48.73877906566978],
                            [2.339986430072071, 48.73874226605257],
                            [2.340420142293865, 48.738738654836844],
                            [2.340845698587959, 48.738752129655026],
                            [2.341377306552279, 48.73879707146058],
                            [2.341900758980999, 48.73885550168947],
                            [2.34291231973197, 48.73898224707868],
                            [2.342924556277525, 48.738984044962976],
                            [2.343560862731155, 48.73906134592529],
                            [2.345544166923985, 48.739308462626816],
                            [2.346450102220287, 48.73942353922805],
                            [2.347853266372745, 48.73959517052126],
                            [2.348251647444905, 48.73964459031302],
                            [2.349091922822984, 48.73975421272648],
                            [2.349949881828628, 48.739882711273985],
                            [2.350689557679258, 48.74001121783873],
                            [2.350941103460682, 48.740060646587224],
                            [2.351203528283975, 48.74011187164995],
                            [2.351633198171911, 48.74019544820276],
                        ],
                    },
                },
                205: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.749454187881554, 2.3888211902596206],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2931.84432367,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.373111940704935,
                            48.74187870567889,
                            2.40290860736794,
                            48.753024053396466,
                        ),
                        "coordinates": [
                            [2.373111940704935, 48.74834968236464],
                            [2.375038314740253, 48.7491591776172],
                            [2.376449188498006, 48.74971704252789],
                            [2.377442593546729, 48.75012910826065],
                            [2.379664684921162, 48.75100384351047],
                            [2.381019671355158, 48.75155637531202],
                            [2.381993755078001, 48.75195346947338],
                            [2.382601886806677, 48.75220142434109],
                            [2.383398470065671, 48.752490282214346],
                            [2.384090155503829, 48.75269091714027],
                            [2.384649229971608, 48.75281748016059],
                            [2.385345647521766, 48.75292599532882],
                            [2.385964506247302, 48.75299047714941],
                            [2.386471808951518, 48.75301723437296],
                            [2.386901468057297, 48.753024053396466],
                            [2.387285085274832, 48.753016134923854],
                            [2.387702427305103, 48.752995492117215],
                            [2.388215469965258, 48.75295465938656],
                            [2.388759177761242, 48.75288851315514],
                            [2.389254438995922, 48.75280315129084],
                            [2.389771510923235, 48.752688349848135],
                            [2.390208585449726, 48.752573993937595],
                            [2.390706165210284, 48.75241548721488],
                            [2.391092238848415, 48.75226962070701],
                            [2.391623041594178, 48.75203544046033],
                            [2.391971692368281, 48.751866323511074],
                            [2.392297353788927, 48.751680020034726],
                            [2.392613732305581, 48.75148997896813],
                            [2.392914004950804, 48.75127587542633],
                            [2.393148386563563, 48.751098214001836],
                            [2.3933973598713, 48.75088870180531],
                            [2.393655008221016, 48.75066297588677],
                            [2.39390846286162, 48.75041728499207],
                            [2.394147003440079, 48.750145837266736],
                            [2.395544409175165, 48.74849945567564],
                            [2.396183265847584, 48.74773766689982],
                            [2.396737943950552, 48.74706668852121],
                            [2.397305625310963, 48.74642158935819],
                            [2.39765739209652, 48.74607120880517],
                            [2.397850268442019, 48.74589574763405],
                            [2.398208872973871, 48.74558620449429],
                            [2.399210014732709, 48.74477091897648],
                            [2.400217958361645, 48.74398529614095],
                            [2.400821071882167, 48.74351193975223],
                            [2.400952830283561, 48.743406650891515],
                            [2.401452686788605, 48.743005291899664],
                            [2.401680893640317, 48.742833400289314],
                            [2.401933544699539, 48.74263901253194],
                            [2.40290860736794, 48.74187870567889],
                        ],
                    },
                },
                206: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.102765644793315, 2.2065049546336812],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2723.15578191,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.201823484236059,
                            49.091073452190784,
                            2.210019869292197,
                            49.114783970085064,
                        ),
                        "coordinates": [
                            [2.210019869292197, 49.114783970085064],
                            [2.209905287355804, 49.11443309398685],
                            [2.209571462191194, 49.11373129263828],
                            [2.208931932224397, 49.112588506036516],
                            [2.208754877303718, 49.112191730025366],
                            [2.208690859330901, 49.112050473242945],
                            [2.20849372942117, 49.11147291984737],
                            [2.208347530096024, 49.11080189978026],
                            [2.20829376362407, 49.110407058586986],
                            [2.208251389250461, 49.10984586550507],
                            [2.208251588433557, 49.109769427217294],
                            [2.208249052626379, 49.109691187901205],
                            [2.208199239455729, 49.10883052850721],
                            [2.20818224207847, 49.10851936185565],
                            [2.208098938314571, 49.107392634374335],
                            [2.208043830023013, 49.10628856382146],
                            [2.207974382447253, 49.10512499395677],
                            [2.207943275419631, 49.104546781745384],
                            [2.207907792382327, 49.10425646391118],
                            [2.207725193781185, 49.10340683792403],
                            [2.207585024884563, 49.10296412489829],
                            [2.207432109535791, 49.1025734283271],
                            [2.207037411877319, 49.10174528981345],
                            [2.206545329911213, 49.1007415059105],
                            [2.206082236900937, 49.099816948326385],
                            [2.20567135075664, 49.098988472939396],
                            [2.205253377454526, 49.09810526328376],
                            [2.204788443360864, 49.09717441149549],
                            [2.204526779703096, 49.09658455843854],
                            [2.204306099611187, 49.09614905646674],
                            [2.203721931498399, 49.09494612675242],
                            [2.20341199452994, 49.094331900130705],
                            [2.203130863229058, 49.09378670700129],
                            [2.202641884285912, 49.09275146960124],
                            [2.202456717071126, 49.09236096837448],
                            [2.2023395836078, 49.092129718375276],
                            [2.201823484236059, 49.091073452190784],
                        ],
                    },
                },
                207: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.749008291026875, 2.4185503110281754],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 900.737445286,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.417520977896491,
                            48.745072166893884,
                            2.419295469321415,
                            48.75288655674139,
                        ),
                        "coordinates": [
                            [2.417520977896491, 48.745072166893884],
                            [2.417559694134845, 48.74544278037653],
                            [2.417595364677613, 48.74563789761012],
                            [2.417725869572168, 48.74613350845395],
                            [2.4177936903694, 48.746349079793504],
                            [2.417929698571815, 48.7466944082515],
                            [2.41812683826887, 48.74712111819496],
                            [2.418276276263958, 48.747417952017706],
                            [2.418475450665925, 48.747766142519914],
                            [2.41889971977792, 48.74846535830931],
                            [2.419038315363134, 48.748727936264515],
                            [2.41909250837702, 48.748862091012214],
                            [2.419185230450416, 48.74913495356007],
                            [2.419241479165207, 48.74939117360156],
                            [2.419278572259143, 48.74961866253804],
                            [2.41929383748868, 48.74980390156787],
                            [2.419295469321415, 48.74996756799391],
                            [2.419278185604111, 48.750178200573124],
                            [2.419235022955878, 48.75041994623721],
                            [2.419203423280662, 48.75055133411644],
                            [2.419178299335482, 48.75065739495887],
                            [2.419156643455977, 48.750719459979486],
                            [2.419099773387582, 48.75086878091593],
                            [2.419036105714618, 48.75101900504099],
                            [2.418875794858536, 48.75144249373356],
                            [2.418463407659742, 48.75226736495072],
                            [2.418113047325797, 48.75288655674139],
                        ],
                    },
                },
                208: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.872451786806316, 2.2227314972805274],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 976.053877371,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.220949328253845,
                            48.86823878484656,
                            2.22595909514488,
                            48.87600129150149,
                        ),
                        "coordinates": [
                            [2.221410602618016, 48.86823878484656],
                            [2.221244923926796, 48.86876727236577],
                            [2.221035722153108, 48.869444511777665],
                            [2.220957002185118, 48.86988148032841],
                            [2.220949328253845, 48.87024927775301],
                            [2.220986615272779, 48.87062791080432],
                            [2.221021982663541, 48.87079745951286],
                            [2.221073317384238, 48.870982337240015],
                            [2.22113088515698, 48.871133238349195],
                            [2.221223528552819, 48.87133588254776],
                            [2.22139319643104, 48.87165259971504],
                            [2.221616822355393, 48.87196029168843],
                            [2.221855326755002, 48.87224479024959],
                            [2.222054531482109, 48.8724477125608],
                            [2.223461988600421, 48.873703030148576],
                            [2.223898750639484, 48.8740849496861],
                            [2.224084764306137, 48.87425089581864],
                            [2.224700319021337, 48.87480826671129],
                            [2.22532663019438, 48.87540133588663],
                            [2.22595909514488, 48.87600129150149],
                        ],
                    },
                },
                209: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.913400103593474, 2.433349802332179],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 340.674628107,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.431278002116334,
                            48.912704975295874,
                            2.435420992985438,
                            48.914093263505734,
                        ),
                        "coordinates": [
                            [2.435420992985438, 48.912704975295874],
                            [2.434036289484119, 48.91318020978114],
                            [2.431987763248024, 48.913844713363304],
                            [2.431278002116334, 48.914093263505734],
                        ],
                    },
                },
                210: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.49598459103408, 1.897286340154126],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 18238.011361,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.796479819708098,
                            48.45590771649728,
                            1.995901990362833,
                            48.535651142265905,
                        ),
                        "coordinates": [
                            [1.796479819708098, 48.45590771649728],
                            [1.797347183384676, 48.45656095387452],
                            [1.798739683457298, 48.457657756103394],
                            [1.799322068036277, 48.458111688841825],
                            [1.799800901950759, 48.45847096960028],
                            [1.800460534878132, 48.45899297304827],
                            [1.801363188628623, 48.45967619178733],
                            [1.802049742528129, 48.46021270184216],
                            [1.802312577824452, 48.46041717794173],
                            [1.803288844944094, 48.46117626734845],
                            [1.804715931587813, 48.462268397738576],
                            [1.804858110417826, 48.462376977850674],
                            [1.805908448560783, 48.46317146469557],
                            [1.806426241885901, 48.46356417296395],
                            [1.806699901051818, 48.46377138707511],
                            [1.80744307410263, 48.46433510710486],
                            [1.808110420257153, 48.464781563459475],
                            [1.808780442767113, 48.465197490006624],
                            [1.80930327639629, 48.465492582552294],
                            [1.809822713780274, 48.46577100193898],
                            [1.81040796712989, 48.466059334700745],
                            [1.810901357768851, 48.466289948885276],
                            [1.811339419605432, 48.46648232775929],
                            [1.811865794516726, 48.46669648738058],
                            [1.812801829439585, 48.46705963015292],
                            [1.813586034136623, 48.46733033821838],
                            [1.814483823869516, 48.46760246397173],
                            [1.815024543018507, 48.467751537399906],
                            [1.81560987948991, 48.46790171199413],
                            [1.817134347146376, 48.46825223680285],
                            [1.819493981056953, 48.46879090933883],
                            [1.820611153913419, 48.46903880819246],
                            [1.822637577851106, 48.46950485338076],
                            [1.824193273242659, 48.46985272755863],
                            [1.82569096241697, 48.470188627827795],
                            [1.827262576594724, 48.47054757623165],
                            [1.828860319954941, 48.470913306641215],
                            [1.830386186052458, 48.471268241277755],
                            [1.831323830903261, 48.471502555980265],
                            [1.831737848371277, 48.47161860988495],
                            [1.832820742645258, 48.47192558688724],
                            [1.833728285893107, 48.47218771128672],
                            [1.835475880331524, 48.472701746351625],
                            [1.836887189313672, 48.47312443511973],
                            [1.840381581049273, 48.47416128066264],
                            [1.842242687714025, 48.47470639519609],
                            [1.844487991755756, 48.475369831669],
                            [1.846607972804901, 48.47599951930195],
                            [1.847622226787146, 48.47629076935788],
                            [1.849386261322481, 48.476812754213675],
                            [1.851045579216219, 48.47730462891601],
                            [1.853786209880743, 48.478111037995745],
                            [1.856196052177203, 48.47881574003382],
                            [1.858560464693356, 48.47951728251933],
                            [1.860926345697587, 48.48021338563424],
                            [1.861676404448346, 48.48042516349604],
                            [1.862975893285599, 48.48075344217077],
                            [1.863502249278825, 48.48087794317638],
                            [1.864011085392062, 48.48099607261369],
                            [1.865487642848335, 48.48134124882376],
                            [1.866970951246157, 48.481690030905774],
                            [1.868442004856799, 48.48204953316117],
                            [1.868976287705818, 48.48219742228588],
                            [1.869452402411082, 48.482345967155986],
                            [1.86987449784543, 48.4824852951019],
                            [1.871093174540894, 48.48293364976055],
                            [1.871587923622687, 48.48311643445254],
                            [1.872554711598398, 48.48345222961363],
                            [1.87302276511184, 48.483597130403126],
                            [1.873492291701562, 48.48372944485443],
                            [1.873893114269943, 48.483830901473674],
                            [1.874404725785146, 48.483947197247076],
                            [1.875073077464651, 48.48408301431888],
                            [1.875317532058818, 48.48412537659963],
                            [1.87588353725892, 48.484211312482444],
                            [1.876218631795877, 48.48425314250328],
                            [1.877042870931892, 48.4843545101753],
                            [1.877475327710981, 48.48440032868654],
                            [1.878291988984055, 48.4844990150006],
                            [1.878964283103872, 48.48459340282371],
                            [1.879492458130092, 48.48467557066152],
                            [1.879765244151144, 48.48472703047211],
                            [1.880124472502447, 48.484793225677166],
                            [1.88050762097865, 48.48487675290486],
                            [1.882279038493584, 48.485282097992126],
                            [1.883889468697054, 48.48566084268555],
                            [1.885499909668612, 48.4860413637978],
                            [1.88794041408196, 48.48660527213401],
                            [1.891076604892144, 48.48732906777998],
                            [1.893905531639184, 48.487999230066414],
                            [1.896952478616021, 48.48871537498314],
                            [1.900519077960755, 48.489556968034506],
                            [1.903585924063144, 48.49027796474703],
                            [1.905422811107824, 48.49069712484978],
                            [1.90716180892519, 48.49110660167523],
                            [1.9089021873188, 48.491516057246535],
                            [1.909702806918212, 48.49170972207141],
                            [1.910217107611719, 48.491845649449374],
                            [1.910800124834483, 48.49201510606071],
                            [1.911683430369431, 48.492300113494295],
                            [1.912343705237787, 48.49253100321779],
                            [1.912950274726099, 48.49276406529041],
                            [1.913656574740024, 48.493056980695314],
                            [1.914312770242985, 48.49334970465227],
                            [1.914950501253676, 48.49366819130454],
                            [1.915555380899235, 48.493977990369196],
                            [1.916112563891495, 48.49429860603861],
                            [1.917583668432846, 48.49517726220579],
                            [1.918050091711761, 48.495481159231325],
                            [1.918555302422936, 48.4958565765064],
                            [1.918857484966555, 48.49610989829828],
                            [1.919155873423027, 48.496389377065746],
                            [1.919429245012203, 48.496664004003655],
                            [1.919794472287263, 48.49708648633886],
                            [1.920028197196202, 48.49739427587882],
                            [1.920204905179514, 48.49767092522721],
                            [1.920356790032013, 48.49791893144977],
                            [1.920526045423771, 48.49823124221957],
                            [1.920620853835, 48.49845524598501],
                            [1.920759428304037, 48.49880182509059],
                            [1.92086236092363, 48.499122338649464],
                            [1.920955303762367, 48.49957236772101],
                            [1.920989039380547, 48.49982231887006],
                            [1.92101551337969, 48.50008414090517],
                            [1.921031552553057, 48.50043334444899],
                            [1.921052411692544, 48.50232097573657],
                            [1.921059509014802, 48.503421700863974],
                            [1.921071858591887, 48.504215795951936],
                            [1.921102961265781, 48.50464321318166],
                            [1.921150261388074, 48.50498362699153],
                            [1.921279391135521, 48.50546113876255],
                            [1.921399654107431, 48.50580869583872],
                            [1.921537952388219, 48.50615804748133],
                            [1.921682402106643, 48.50644171481881],
                            [1.921858980163159, 48.50673739523163],
                            [1.92205148973519, 48.50700530574641],
                            [1.922289711198901, 48.507327214837716],
                            [1.92249195587338, 48.50758154678044],
                            [1.922711899944923, 48.507823352531034],
                            [1.92287617474469, 48.50799976812693],
                            [1.923096401575981, 48.50821471058692],
                            [1.923359419734197, 48.50845122121825],
                            [1.923579945340111, 48.508630473704876],
                            [1.923782764435343, 48.50878586719884],
                            [1.924010551289588, 48.50895324957036],
                            [1.924288334163497, 48.50913746703831],
                            [1.924598264241474, 48.509331317803074],
                            [1.925040272757297, 48.509575614921715],
                            [1.925364707041571, 48.50974810260799],
                            [1.92570457390914, 48.50990794910282],
                            [1.926153095734525, 48.510110236802824],
                            [1.926531405976856, 48.51026388225689],
                            [1.926857798265932, 48.51038603799363],
                            [1.92727746626088, 48.51054971780896],
                            [1.928448347360359, 48.510996493307786],
                            [1.931054346632533, 48.51199088390979],
                            [1.933878196992141, 48.51307164515939],
                            [1.938614133441519, 48.51488379692858],
                            [1.940836580403704, 48.5157371954728],
                            [1.941225664037522, 48.51589796636548],
                            [1.941803746017502, 48.51616170634916],
                            [1.942139062500095, 48.51632942569386],
                            [1.942563443422539, 48.51655693627003],
                            [1.94296980866279, 48.51679865890037],
                            [1.943454424682542, 48.517109650512054],
                            [1.943831981243184, 48.5173726841502],
                            [1.944134558582695, 48.51760690545804],
                            [1.944344511226292, 48.51777894198369],
                            [1.944645072147484, 48.518034258066365],
                            [1.944989056928959, 48.518358282476875],
                            [1.945428468905822, 48.518769865220094],
                            [1.946851339822075, 48.52009552064898],
                            [1.948159893058107, 48.521313459677856],
                            [1.948995546350472, 48.52209197660334],
                            [1.950087283518154, 48.523106910473075],
                            [1.951125724566066, 48.524071688460374],
                            [1.951548892795057, 48.5244704713892],
                            [1.953163637040052, 48.52596063386107],
                            [1.953355781193922, 48.5261278357402],
                            [1.95361923757199, 48.52633810611456],
                            [1.953968371911126, 48.52658673256372],
                            [1.954278064400252, 48.526787331216795],
                            [1.954635012172937, 48.527005360587474],
                            [1.95498457297061, 48.527199262716294],
                            [1.955327191094532, 48.527364587417665],
                            [1.955848420029291, 48.52759475342328],
                            [1.956280575280522, 48.52776275637395],
                            [1.956787937585347, 48.52793338796284],
                            [1.957195348383404, 48.52805847744412],
                            [1.957667275363324, 48.52817902120314],
                            [1.958221645259116, 48.52829270063792],
                            [1.95893362854804, 48.52840690411028],
                            [1.959406047638396, 48.52846320121289],
                            [1.959721089316469, 48.52848804134776],
                            [1.960132829298217, 48.528515582529444],
                            [1.960659338497882, 48.52852446843557],
                            [1.961003253446917, 48.52852084979491],
                            [1.961365165369233, 48.52850539328064],
                            [1.961852557758751, 48.52847607579192],
                            [1.962257598284, 48.52844172451782],
                            [1.962651622586215, 48.528405168758646],
                            [1.962982188997888, 48.52837568446024],
                            [1.963354764953974, 48.52834094098841],
                            [1.964712311391007, 48.52821141340132],
                            [1.967538420040237, 48.52794997350238],
                            [1.968416358354918, 48.52786380255813],
                            [1.970218198549861, 48.52769968079375],
                            [1.971166402942377, 48.52763080114941],
                            [1.971773087346663, 48.52760937488149],
                            [1.972286562406724, 48.527601201225664],
                            [1.972906162480634, 48.52761508767053],
                            [1.973582922552961, 48.52764666121552],
                            [1.974034009589304, 48.5276853230605],
                            [1.974542257423417, 48.527741671260706],
                            [1.974997970622828, 48.52779686527808],
                            [1.975404663726265, 48.52786338893215],
                            [1.976008055495209, 48.52797004494974],
                            [1.976592266780299, 48.528093202312135],
                            [1.977228725015882, 48.528254635554134],
                            [1.9777327863755, 48.528396610958374],
                            [1.978175972311691, 48.528536013338694],
                            [1.978625349337965, 48.528688760400655],
                            [1.979047769877629, 48.52885045690475],
                            [1.979531216974234, 48.529051323641625],
                            [1.979894127681135, 48.52921715735364],
                            [1.980211868894974, 48.529368053370625],
                            [1.980604463426243, 48.52957152784054],
                            [1.981043555189483, 48.529807862310264],
                            [1.981870977700573, 48.53030118719812],
                            [1.983369266929133, 48.53118858886927],
                            [1.985117334437867, 48.53222426274626],
                            [1.9867120465048, 48.53317140201081],
                            [1.987957296873395, 48.5338937900335],
                            [1.988617567884867, 48.53425271492436],
                            [1.989246117024498, 48.5345377801789],
                            [1.989614076350927, 48.53468880335194],
                            [1.990160848724494, 48.53488557870415],
                            [1.990664882233726, 48.53504653203461],
                            [1.991233470745683, 48.53519816188031],
                            [1.991769999235982, 48.535323520199746],
                            [1.992213614470143, 48.53541528136816],
                            [1.992904314196555, 48.53552444684039],
                            [1.99367759402475, 48.535607686034794],
                            [1.994143166368439, 48.53563288694631],
                            [1.99467327654999, 48.535651142265905],
                            [1.995164104772484, 48.53565024278171],
                            [1.995901990362833, 48.535620622584574],
                        ],
                    },
                },
                211: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.52091778489184, 2.626144867080216],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4304.739207,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.599304265919263,
                            48.515049655815545,
                            2.652441044420506,
                            48.52824560466065,
                        ),
                        "coordinates": [
                            [2.652441044420506, 48.5277977343036],
                            [2.651489225559338, 48.527969506856465],
                            [2.651028031568304, 48.52804542428913],
                            [2.650278770255548, 48.52817069843449],
                            [2.649981316073498, 48.528208165835125],
                            [2.649716165376932, 48.52823352577011],
                            [2.649538660921548, 48.528244682772204],
                            [2.649358302096582, 48.52824560466065],
                            [2.649035074246412, 48.52823454856931],
                            [2.648726427197078, 48.52821445521793],
                            [2.648444406908526, 48.528181469656616],
                            [2.648139431084696, 48.52813648974451],
                            [2.64786026178536, 48.528093727393056],
                            [2.647264510565324, 48.52796105153835],
                            [2.646698173370978, 48.527801051666025],
                            [2.646335118477055, 48.52767111077758],
                            [2.645924601123552, 48.52749921217977],
                            [2.645634018619189, 48.52736061776811],
                            [2.645231967123099, 48.52714858644443],
                            [2.644847192137414, 48.52689933566662],
                            [2.644418929397711, 48.526590553226384],
                            [2.643620231995226, 48.52593985248545],
                            [2.643097233017624, 48.525565267949425],
                            [2.642794943686103, 48.52536475518051],
                            [2.642164701116606, 48.52502473435866],
                            [2.641720848717082, 48.52483438512334],
                            [2.641332734687247, 48.52468165473522],
                            [2.640954121695803, 48.524532494311885],
                            [2.640093738517779, 48.52418858234178],
                            [2.639578179588021, 48.52400291413874],
                            [2.638814625237293, 48.52377384021085],
                            [2.638390205599792, 48.52365896476726],
                            [2.637452101019002, 48.52344203591286],
                            [2.636561713918897, 48.52327982869425],
                            [2.635565866583197, 48.523138575666266],
                            [2.633511939065768, 48.52285980360623],
                            [2.631039315325018, 48.52251014020595],
                            [2.629997341086728, 48.522346476499735],
                            [2.629452934023944, 48.522245748867654],
                            [2.628836080801009, 48.52210933985746],
                            [2.62831371265814, 48.521982049844134],
                            [2.627724098599113, 48.52182176870779],
                            [2.627153256810648, 48.521661364482],
                            [2.626486181977524, 48.52143964787353],
                            [2.62585921819042, 48.52121054397652],
                            [2.62501519826064, 48.52085928363604],
                            [2.624040790557002, 48.52043011078196],
                            [2.623484417153311, 48.52019141635272],
                            [2.622032347584952, 48.51955120853955],
                            [2.621249345616701, 48.51920875899237],
                            [2.620603391664902, 48.51892261424376],
                            [2.620040243256816, 48.51867672635145],
                            [2.619171815600943, 48.518303001536346],
                            [2.61791802298259, 48.517759367107885],
                            [2.616660740923838, 48.517312848304954],
                            [2.616169892242245, 48.517160285984744],
                            [2.615524579608531, 48.51697932485183],
                            [2.614921407363884, 48.516829730492326],
                            [2.614128661603245, 48.51666620918174],
                            [2.613634089145572, 48.51657209667064],
                            [2.61294035894753, 48.516455918917835],
                            [2.612267417627047, 48.51635224625796],
                            [2.61179299513362, 48.51628072203051],
                            [2.609359994178583, 48.51591070887729],
                            [2.608749866080982, 48.515818299316734],
                            [2.608081196528596, 48.51571683890171],
                            [2.607088815154976, 48.51556594473757],
                            [2.605826148260457, 48.51537444985189],
                            [2.604851951272825, 48.515237697441115],
                            [2.604137956304632, 48.51513899311251],
                            [2.603508164506213, 48.515081455483035],
                            [2.602924740609365, 48.51505282130296],
                            [2.602357598733199, 48.515049655815545],
                            [2.600173328535484, 48.515108708645215],
                            [2.599506222005111, 48.51514263245651],
                            [2.599304265919263, 48.51515145414115],
                        ],
                    },
                },
                212: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.90585344080832, 2.46542538916796],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 772.43812341,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.460523403674419,
                            48.90470320378032,
                            2.469971544978576,
                            48.90670063080091,
                        ),
                        "coordinates": [
                            [2.469971544978576, 48.90470320378032],
                            [2.469705581429786, 48.90527670641671],
                            [2.469686018911685, 48.905307506314074],
                            [2.469648651037504, 48.9053503463571],
                            [2.469602014757477, 48.90538903733753],
                            [2.469547152945768, 48.905422713339824],
                            [2.469485288753148, 48.90545062345811],
                            [2.469417806389947, 48.90547214340331],
                            [2.469346211390938, 48.9054867924148],
                            [2.469272104593556, 48.90549424303839],
                            [2.469221039393303, 48.905495104920305],
                            [2.468180585833174, 48.905535701349926],
                            [2.468086162773788, 48.905540786702566],
                            [2.467969175013784, 48.905553696400304],
                            [2.467880769388707, 48.905567588197584],
                            [2.467815105715589, 48.90558246858462],
                            [2.467576252133193, 48.90565689986793],
                            [2.467520223304738, 48.90567461075323],
                            [2.467431243301111, 48.905696075379005],
                            [2.467339084865083, 48.9057105849973],
                            [2.467244992824449, 48.90571794369407],
                            [2.467140499291809, 48.905717649755225],
                            [2.466205370033744, 48.9057071244155],
                            [2.46546518313828, 48.905711713112225],
                            [2.465228240399152, 48.90571196577839],
                            [2.46510030436569, 48.90571579211301],
                            [2.464973361094033, 48.90572695295135],
                            [2.46484837723056, 48.90574536628228],
                            [2.464726300946452, 48.90577088976285],
                            [2.464608065940123, 48.90580332972881],
                            [2.464606102060072, 48.905803936972184],
                            [2.46433917354481, 48.9058992493938],
                            [2.464224425292458, 48.90593668939942],
                            [2.464081495867911, 48.90597590343516],
                            [2.463934687090267, 48.906008295825174],
                            [2.463812190610341, 48.906029611359614],
                            [2.462944236708066, 48.9061719340242],
                            [2.462578711499976, 48.90623418814636],
                            [2.462257207395177, 48.90629881599506],
                            [2.461855003217617, 48.90639328437512],
                            [2.46136850247316, 48.90652319063485],
                            [2.461220618119033, 48.906560989551565],
                            [2.461074048569321, 48.90659379049016],
                            [2.460523403674419, 48.90670063080091],
                        ],
                    },
                },
                213: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.52177361645987, 2.585466944622349],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2654.10401673,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.572073662735742,
                            48.51515145414115,
                            2.599304265919263,
                            48.529746918576464,
                        ),
                        "coordinates": [
                            [2.599304265919263, 48.51515145414115],
                            [2.59887562610162, 48.51517017440106],
                            [2.598245040143599, 48.51519951042084],
                            [2.597770171013025, 48.515241073895425],
                            [2.596939690274288, 48.51535269662779],
                            [2.596227049971859, 48.51548112882047],
                            [2.595353722854649, 48.51568456202822],
                            [2.594773839087644, 48.515836063059595],
                            [2.593507432400048, 48.51619774836117],
                            [2.592976457502738, 48.51638689745907],
                            [2.592568591560144, 48.51656407527451],
                            [2.592007208345519, 48.516842481208585],
                            [2.591533165786993, 48.51710416887128],
                            [2.590742306748619, 48.51756367096046],
                            [2.590329382343046, 48.51781459093654],
                            [2.590323981338558, 48.51781730078016],
                            [2.58992724196531, 48.51805739275638],
                            [2.588269986247771, 48.51904397943652],
                            [2.587862498101782, 48.51930387207674],
                            [2.587264818536509, 48.519699072431024],
                            [2.587008575186801, 48.51988848430887],
                            [2.586455845235856, 48.52034203287396],
                            [2.586074888780608, 48.52067852066144],
                            [2.585763363453361, 48.52100451524352],
                            [2.584855951388392, 48.522005585617954],
                            [2.584086927840274, 48.52280221467334],
                            [2.583798553263469, 48.52306992479124],
                            [2.583090876584879, 48.52368566300801],
                            [2.582779310415092, 48.52391924878109],
                            [2.582141330092338, 48.52439724158895],
                            [2.581822892099882, 48.52461195605406],
                            [2.581185690125076, 48.52504204958687],
                            [2.580680568601538, 48.52537752830194],
                            [2.579994681359997, 48.525809249881114],
                            [2.57960659413182, 48.52605976033186],
                            [2.578859209425171, 48.52651307624202],
                            [2.578204476999259, 48.52690541927283],
                            [2.577727879965257, 48.527171951217774],
                            [2.577085099586342, 48.52751503673576],
                            [2.576532743339013, 48.527787271103755],
                            [2.575761436809097, 48.52816620678575],
                            [2.575119723175314, 48.52845442504817],
                            [2.57426848464177, 48.52881322038668],
                            [2.572452964537946, 48.52959084623357],
                            [2.572443136513669, 48.52959505512437],
                            [2.572073662735742, 48.529746918576464],
                        ],
                    },
                },
                214: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.56911565976585, 2.485574868793531],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1341.75092707,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.479469169601778,
                            48.5661178207362,
                            2.492713002881577,
                            48.57380779355899,
                        ),
                        "coordinates": [
                            [2.492713002881577, 48.5661178207362],
                            [2.491819478699903, 48.566345662792685],
                            [2.490618651029176, 48.56666114502516],
                            [2.488962922873594, 48.567096828853785],
                            [2.488384904907827, 48.56727296080031],
                            [2.487972960925036, 48.56741009091336],
                            [2.487434736430953, 48.56760156149464],
                            [2.48691372236041, 48.5678135805795],
                            [2.486375187785103, 48.568057993210445],
                            [2.485858366782099, 48.56831586379911],
                            [2.48530374239909, 48.56862144323904],
                            [2.484772201664366, 48.568945873165646],
                            [2.484286764404232, 48.569283730352],
                            [2.482568310495115, 48.570562008657475],
                            [2.482083011867324, 48.57095830785134],
                            [2.481573562170229, 48.57144006496315],
                            [2.480938483708071, 48.572060466874255],
                            [2.480900645604948, 48.57209648477394],
                            [2.480861457132637, 48.572134303983496],
                            [2.480399334419026, 48.57258901814628],
                            [2.48013729529505, 48.57288340831681],
                            [2.479779439773886, 48.573317305298026],
                            [2.479552738788886, 48.57365121680028],
                            [2.479469169601778, 48.57380779355899],
                        ],
                    },
                },
                215: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.43712714134036, 2.756774937871566],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 1447.60649302,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.753177568842823,
                            48.430970724114694,
                            2.760926733738456,
                            48.442882064226566,
                        ),
                        "coordinates": [
                            [2.753177568842823, 48.430970724114694],
                            [2.753227367847633, 48.43108280821532],
                            [2.75339639305608, 48.431422105938125],
                            [2.754164768115173, 48.43276305632415],
                            [2.754629576730084, 48.433628840442324],
                            [2.755394865834612, 48.43497580257816],
                            [2.755929416209419, 48.43587488365372],
                            [2.756147380557123, 48.436244572186816],
                            [2.756363958669194, 48.43660976815724],
                            [2.756601118571874, 48.43701175793484],
                            [2.757408964657009, 48.43842509495271],
                            [2.757838092539092, 48.43917950611003],
                            [2.758226072944558, 48.439818093906354],
                            [2.758465072481294, 48.440174098574076],
                            [2.758744445361875, 48.44054058274868],
                            [2.759161056041372, 48.44106239900572],
                            [2.759440760725487, 48.44138390370022],
                            [2.759751457988305, 48.44171285281196],
                            [2.760926733738456, 48.442882064226566],
                        ],
                    },
                },
                216: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93266764439456, 2.3746568031244317],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 564.49835856,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37108317162386,
                            48.93173482548615,
                            2.378225490397901,
                            48.9335864037298,
                        ),
                        "coordinates": [
                            [2.378225490397901, 48.93173482548615],
                            [2.377990238522344, 48.9317608360259],
                            [2.377800559586583, 48.931784740074846],
                            [2.377624106595516, 48.931816152312585],
                            [2.377399780304581, 48.931870540581464],
                            [2.377175626954585, 48.93193199143018],
                            [2.376882129937261, 48.932022666076314],
                            [2.376507285053355, 48.93213496283342],
                            [2.376258160617174, 48.93220500243233],
                            [2.375977233618566, 48.93227181205202],
                            [2.375693535522128, 48.93233824686265],
                            [2.375471988690423, 48.93239394007178],
                            [2.375155502583231, 48.93248674429097],
                            [2.374582327641469, 48.9326815984969],
                            [2.373333985901969, 48.93310377549099],
                            [2.373017489575142, 48.93319425563207],
                            [2.372676367147772, 48.933280107805395],
                            [2.372268415246179, 48.933368296954356],
                            [2.371863972598721, 48.93344721437942],
                            [2.37108317162386, 48.9335864037298],
                        ],
                    },
                },
                217: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.07394314421013, 2.3392798008692384],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2085.12463312,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.327669570460789,
                            49.068530235211696,
                            2.35083083355881,
                            49.079470233982065,
                        ),
                        "coordinates": [
                            [2.327669570460789, 49.068530235211696],
                            [2.328714085613412, 49.068980939458065],
                            [2.331555889767361, 49.07034789591556],
                            [2.333152513976816, 49.07108456999683],
                            [2.333887987614685, 49.0714305778981],
                            [2.335303955010883, 49.072089680652134],
                            [2.338052702632552, 49.07337214662515],
                            [2.340682072555365, 49.07459268705621],
                            [2.343282596530885, 49.075801272500435],
                            [2.343619818528195, 49.07596029535128],
                            [2.344972356117883, 49.076599591564225],
                            [2.348765940056676, 49.07836543501684],
                            [2.349157498836323, 49.07854884543927],
                            [2.34971335369105, 49.07881227267111],
                            [2.3501431024938, 49.07905085497304],
                            [2.350581437189748, 49.079312529418345],
                            [2.35083083355881, 49.079470233982065],
                        ],
                    },
                },
                218: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.91673341604137, 2.4213300633444628],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 579.584518889,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.417691093337975,
                            48.915837892883054,
                            2.425009894274451,
                            48.917783725255454,
                        ),
                        "coordinates": [
                            [2.425009894274451, 48.915837892883054],
                            [2.423426826501466, 48.91615965643257],
                            [2.42263248303036, 48.91633869564315],
                            [2.422375918355764, 48.91640609231264],
                            [2.422126397139699, 48.91648043619281],
                            [2.421725787112236, 48.9166174615369],
                            [2.421481356616688, 48.91669348963934],
                            [2.421329893519381, 48.916734841614556],
                            [2.420415099354189, 48.916954392876434],
                            [2.419887606234933, 48.917089245991086],
                            [2.419254188769923, 48.91727155360557],
                            [2.418853658150199, 48.91739461532926],
                            [2.418485607907105, 48.91751194297783],
                            [2.417691093337975, 48.917783725255454],
                        ],
                    },
                },
                219: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.91998689192097, 2.4122203750888245],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 297.447108459,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.410598615094689,
                            48.919179027725846,
                            2.41383718095636,
                            48.920785969955396,
                        ),
                        "coordinates": [
                            [2.41383718095636, 48.919179027725846],
                            [2.413212194384826, 48.919493980535684],
                            [2.412774822946779, 48.91974762395063],
                            [2.412571024109022, 48.91984740791715],
                            [2.412314487720756, 48.91995417847965],
                            [2.412116330696243, 48.92002959958562],
                            [2.411935929597778, 48.92010823615369],
                            [2.410598615094689, 48.920785969955396],
                        ],
                    },
                },
                220: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.99796489265113, 2.5317061007929005],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 6430.61878118,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.514360285533493,
                            48.97342490721535,
                            2.561232695225106,
                            49.00975645213836,
                        ),
                        "coordinates": [
                            [2.514360285533493, 48.97342490721535],
                            [2.515393263594468, 48.974892772869225],
                            [2.517718185511947, 48.97819976141486],
                            [2.519467807032124, 48.980689598485725],
                            [2.519742526133311, 48.981078898219415],
                            [2.52000746380691, 48.98146178875312],
                            [2.520197220061898, 48.98174843592305],
                            [2.520347779255573, 48.98199231760475],
                            [2.520488612558998, 48.982244779314236],
                            [2.520639397545857, 48.98254861868227],
                            [2.520754205528181, 48.98280112251762],
                            [2.520856039043879, 48.98306435346333],
                            [2.520934967814882, 48.98329121775053],
                            [2.521007384332063, 48.9835180910038],
                            [2.521079917306177, 48.98377494592646],
                            [2.521139556652976, 48.98406393997992],
                            [2.521192773969197, 48.984376502331735],
                            [2.521226423432624, 48.98467624706681],
                            [2.521250223408343, 48.98495245189641],
                            [2.521257700506907, 48.98521369215792],
                            [2.521252125576408, 48.98546424686898],
                            [2.521236764089628, 48.98570839411733],
                            [2.521202055781671, 48.98599968178228],
                            [2.521132024536406, 48.98641737251204],
                            [2.521087226341204, 48.986620878243215],
                            [2.521013432482801, 48.98690152456949],
                            [2.520637630095882, 48.98822124009513],
                            [2.52026501120734, 48.98952810305979],
                            [2.520178198423098, 48.98981090908115],
                            [2.520094475495744, 48.99004873900618],
                            [2.519988065217984, 48.99031230385261],
                            [2.519881599698468, 48.99056087821723],
                            [2.519771801513882, 48.99078804470322],
                            [2.519645760767343, 48.99102380017194],
                            [2.519509967114661, 48.991261714113556],
                            [2.519367705430668, 48.991510345893296],
                            [2.518785614208525, 48.99250488862331],
                            [2.518663940651673, 48.99272850810477],
                            [2.518548743118225, 48.9929857610214],
                            [2.51841791152753, 48.99329862199918],
                            [2.518329524503683, 48.993670470474164],
                            [2.518257103208032, 48.99407703533845],
                            [2.518205809556509, 48.99448703984075],
                            [2.518212606673171, 48.99473374652227],
                            [2.518229616440271, 48.99493501325487],
                            [2.518262941514691, 48.99514910271857],
                            [2.518306022171094, 48.995361034489164],
                            [2.518378533119977, 48.99561146672925],
                            [2.518444326834417, 48.99580408969404],
                            [2.5185494980788, 48.996086590445124],
                            [2.518730602344485, 48.99643244720212],
                            [2.518907702542956, 48.99669960025212],
                            [2.51909941644108, 48.99695299230068],
                            [2.519318430901336, 48.99721603766328],
                            [2.519563499579044, 48.99748332597616],
                            [2.519841161045308, 48.99776340874519],
                            [2.520122010129798, 48.998024212563486],
                            [2.522349199686013, 49.000061403624784],
                            [2.523440048286008, 49.001070381478584],
                            [2.523629528603032, 49.00125851891976],
                            [2.523913836292266, 49.0015621364957],
                            [2.524080554783236, 49.00175459078642],
                            [2.524283246776067, 49.00199195759419],
                            [2.524505661249694, 49.00228068354199],
                            [2.524750946355387, 49.00259078669496],
                            [2.52511068855266, 49.00304203615561],
                            [2.525362458389907, 49.00334356157268],
                            [2.525623978532358, 49.0036407897875],
                            [2.525878845930051, 49.003899479488815],
                            [2.526117258765225, 49.004111087278076],
                            [2.526365400312325, 49.00431197113942],
                            [2.526704870926082, 49.004561954732495],
                            [2.527037685331536, 49.00477340312837],
                            [2.527328021725017, 49.00494209380831],
                            [2.527598736441719, 49.00508511850118],
                            [2.527980265288008, 49.005266502743225],
                            [2.528322599826032, 49.0054115482652],
                            [2.528658365219273, 49.00554161307144],
                            [2.528990821024291, 49.00565669382984],
                            [2.529310192921969, 49.00575466337127],
                            [2.529603449263512, 49.005833403443155],
                            [2.530062831188062, 49.00594184241444],
                            [2.530453732273655, 49.00601827311647],
                            [2.530867378564925, 49.006083958627585],
                            [2.531199591467566, 49.006134789793194],
                            [2.531548021234403, 49.00617060353766],
                            [2.531922456541273, 49.00619780611901],
                            [2.532251263526683, 49.00621009522694],
                            [2.532742797939719, 49.00621567947264],
                            [2.533178937282292, 49.00620636842332],
                            [2.533527155276757, 49.006188640989144],
                            [2.534152009602865, 49.00615972940619],
                            [2.535017664707053, 49.00611326798355],
                            [2.535496065945075, 49.006091025102464],
                            [2.536068827286857, 49.00606005315039],
                            [2.536583022628391, 49.00603560274131],
                            [2.537090726425559, 49.006015444010224],
                            [2.537598465651282, 49.006003850063244],
                            [2.538073723603044, 49.00600944149606],
                            [2.538594584339257, 49.00602351508457],
                            [2.538972236459689, 49.00603998223226],
                            [2.541195917989215, 49.00616024454069],
                            [2.545662837171938, 49.006398461515154],
                            [2.546847958585747, 49.00646482188928],
                            [2.547342835043416, 49.00648961105501],
                            [2.547795412657332, 49.006518760054114],
                            [2.548150329259859, 49.00654594452661],
                            [2.548550856475564, 49.00658161091718],
                            [2.548948199691394, 49.006634411953655],
                            [2.54932675403193, 49.0066822889805],
                            [2.550153074983159, 49.00683992805838],
                            [2.550737357371696, 49.00696815071972],
                            [2.551228653275078, 49.007105008684775],
                            [2.551669488697603, 49.00725975925561],
                            [2.553108599054325, 49.00781460799817],
                            [2.553866245491355, 49.00812650813554],
                            [2.555402243342059, 49.00870774249366],
                            [2.555995034400608, 49.00890535185251],
                            [2.556592116078286, 49.00907387480147],
                            [2.557115572534614, 49.00920075953147],
                            [2.557616713047839, 49.00930062303462],
                            [2.558175686612269, 49.00940598825874],
                            [2.558698933624695, 49.00948435658386],
                            [2.559235550571284, 49.009553876749614],
                            [2.559845911461627, 49.009623252208236],
                            [2.561232695225106, 49.00975645213836],
                        ],
                    },
                },
                221: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.94690104205246, 2.337943146402199],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2995.47612694,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32824501026232,
                            48.93445554506131,
                            2.345604378196291,
                            48.958269604608034,
                        ),
                        "coordinates": [
                            [2.345604378196291, 48.93445554506131],
                            [2.34552682729569, 48.934759881220835],
                            [2.345435526614926, 48.935194669214006],
                            [2.345360667089803, 48.93555115323384],
                            [2.345304141024547, 48.93586840064392],
                            [2.345187141814928, 48.936525023869564],
                            [2.345094819779337, 48.93693648596403],
                            [2.344825212527904, 48.938001662135036],
                            [2.344718752966593, 48.93841979525869],
                            [2.344611081014025, 48.93884268321627],
                            [2.34445438759634, 48.93922909944737],
                            [2.344318818865329, 48.93960593663021],
                            [2.344199675596359, 48.93993191450605],
                            [2.344073302064426, 48.9402222023237],
                            [2.343784447655979, 48.94091698912217],
                            [2.343567793834791, 48.94139287038358],
                            [2.343405297819504, 48.94170933256215],
                            [2.343188624089768, 48.94207814333833],
                            [2.342953884887095, 48.942411264627516],
                            [2.34271552642032, 48.94273486821583],
                            [2.342329083715866, 48.94316316970892],
                            [2.341888451584169, 48.943608127361564],
                            [2.341577835338476, 48.94387938653777],
                            [2.341296109545675, 48.94411733240661],
                            [2.340952975273245, 48.94439334912475],
                            [2.340382279712963, 48.944795478745384],
                            [2.339327549259685, 48.94551882780223],
                            [2.338760437553038, 48.945901914348276],
                            [2.338247501223794, 48.94624692676937],
                            [2.33785015168668, 48.94653007376765],
                            [2.337387774586994, 48.94689173748575],
                            [2.337044601839636, 48.94719629528594],
                            [2.336668912202581, 48.947557956116526],
                            [2.336418315320437, 48.94783369425153],
                            [2.336361852815723, 48.94789582213892],
                            [2.33608007716816, 48.948240824593505],
                            [2.33576578286533, 48.948645311354845],
                            [2.335559862419661, 48.948945106049166],
                            [2.335364777086415, 48.94924966000805],
                            [2.335194977619876, 48.94954469646904],
                            [2.334429046671183, 48.95092946083693],
                            [2.334259234623968, 48.9512268749831],
                            [2.334093034053209, 48.951529047154985],
                            [2.333901541167026, 48.95184549567271],
                            [2.333724500337994, 48.952126252789114],
                            [2.33246349174877, 48.95389882173151],
                            [2.332004592777578, 48.95454836445361],
                            [2.331675770706241, 48.95498852971],
                            [2.331328881441106, 48.955393000881635],
                            [2.331010897605432, 48.955735611255236],
                            [2.330743501400027, 48.95601160089214],
                            [2.330407443727636, 48.956354208445674],
                            [2.329955748658342, 48.95680863701481],
                            [2.329579937771228, 48.957148859850385],
                            [2.328972850049945, 48.957681793189806],
                            [2.328322390158605, 48.958212340049705],
                            [2.32824501026232, 48.958269604608034],
                        ],
                    },
                },
                222: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.1380598109603, 2.2723418012754895],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1901.06508262,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.267674786874433,
                            49.132577702391806,
                            2.280515369819846,
                            49.14528660789949,
                        ),
                        "coordinates": [
                            [2.280515369819846, 49.132577702391806],
                            [2.27565936485099, 49.13454062027236],
                            [2.274687083291566, 49.134932686664044],
                            [2.27412837303634, 49.13516079772366],
                            [2.273689365759236, 49.13535328260266],
                            [2.273341035287542, 49.13552678182589],
                            [2.272963638695093, 49.1357407114609],
                            [2.272607952052375, 49.13598796219108],
                            [2.272306675190137, 49.13622096790012],
                            [2.272001708776877, 49.13649917629721],
                            [2.271685798336763, 49.136824965649225],
                            [2.270029841963733, 49.13859185120883],
                            [2.268439142618548, 49.14028737212342],
                            [2.26817393733281, 49.140625077022],
                            [2.267981311096413, 49.140927135732966],
                            [2.267817627562239, 49.14127679768858],
                            [2.267737454764108, 49.14155513068775],
                            [2.267678932094973, 49.14190961473698],
                            [2.267674786874433, 49.14228078535519],
                            [2.267732310361471, 49.142640098585574],
                            [2.267837030870093, 49.14296374942959],
                            [2.267967214367085, 49.143235069968526],
                            [2.268159021828312, 49.14352784117683],
                            [2.268394369927039, 49.14380874219874],
                            [2.268687713633045, 49.14411584911734],
                            [2.268937644669891, 49.14434679097185],
                            [2.269270947505275, 49.14461109207766],
                            [2.269651444988593, 49.14484448919205],
                            [2.270039114589342, 49.14504174548885],
                            [2.270552769414137, 49.14528660789949],
                        ],
                    },
                },
                223: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.829590814229746, 2.306428691903834],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 3287.91237839,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.292061814554318,
                            48.81838763956164,
                            2.320509227539884,
                            48.841186920243864,
                        ),
                        "coordinates": [
                            [2.292061814554318, 48.81838763956164],
                            [2.292063215351291, 48.81838838895092],
                            [2.292554771060914, 48.81865161255986],
                            [2.293235393541554, 48.819056361381406],
                            [2.294139273426576, 48.81963488165732],
                            [2.294801881437852, 48.82007054623802],
                            [2.2952938573242, 48.820437987625624],
                            [2.295885726493976, 48.82091377045482],
                            [2.296321399688822, 48.82130413649662],
                            [2.296850718517542, 48.821749259187285],
                            [2.297545684405248, 48.82234195481006],
                            [2.298071434702834, 48.82277041559989],
                            [2.299465078654862, 48.82390820243954],
                            [2.300945242268247, 48.82508406607587],
                            [2.303549153206343, 48.8272238682784],
                            [2.305288812554795, 48.82866385421778],
                            [2.306380208050093, 48.829558777861976],
                            [2.307323957912953, 48.830329927679344],
                            [2.309290836804992, 48.83186270435911],
                            [2.310022123292139, 48.83246722754302],
                            [2.310436406341613, 48.832809946388],
                            [2.310857899660154, 48.833162182809986],
                            [2.311582025943372, 48.83375003926354],
                            [2.312893438726868, 48.83477819039799],
                            [2.314255341069606, 48.83586343947946],
                            [2.314568807512882, 48.83610381335719],
                            [2.31484984447211, 48.836329903848586],
                            [2.315250124707188, 48.836680150934235],
                            [2.316400888248523, 48.83771801315104],
                            [2.31680803621099, 48.83809639901349],
                            [2.318112438906453, 48.839186352114176],
                            [2.320509227539884, 48.841186920243864],
                        ],
                    },
                },
                224: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [49.008992128501205, 2.5672579152749813],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1195.36389945,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.561232695225106,
                            49.00468746180567,
                            2.57058948552452,
                            49.010323008541455,
                        ),
                        "coordinates": [
                            [2.561232695225106, 49.00975645213836],
                            [2.566933315888485, 49.01030381116595],
                            [2.566994848324108, 49.010309258439534],
                            [2.567169126287478, 49.01031974229678],
                            [2.56734406179033, 49.010323008541455],
                            [2.567518964603455, 49.010319039397665],
                            [2.567693141449908, 49.01030785484905],
                            [2.567865907067921, 49.01028949739211],
                            [2.568036580044855, 49.010264040114],
                            [2.568204486949174, 49.01023158311038],
                            [2.568368962323955, 49.01019225438452],
                            [2.568529359608517, 49.010146211684635],
                            [2.568685045768951, 49.010093630794536],
                            [2.568835405250774, 49.010034723531945],
                            [2.568979844184409, 49.00996972517399],
                            [2.569117791835329, 49.009898884571],
                            [2.569248705877909, 49.009822487544184],
                            [2.569372071230316, 49.00974083260265],
                            [2.569487398575887, 49.00965424442557],
                            [2.569594231294806, 49.00956306219702],
                            [2.56969214949691, 49.0094676477128],
                            [2.569780767355098, 49.0093683772777],
                            [2.569859734471483, 49.00926564170976],
                            [2.569928739977285, 49.009159846354734],
                            [2.569987509820637, 49.00905140837844],
                            [2.570035813570076, 49.00894076038749],
                            [2.570073460461935, 49.00882833243077],
                            [2.570100300594615, 49.00871457268526],
                            [2.570112437716692, 49.00863573405281],
                            [2.57058948552452, 49.00468746180567],
                        ],
                    },
                },
                225: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.97660283337612, 2.300035279742222],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1320.83868052,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.292477128819507,
                            48.972749119759264,
                            2.307137032071533,
                            48.9794479829515,
                        ),
                        "coordinates": [
                            [2.307137032071533, 48.972749119759264],
                            [2.306894158072118, 48.972913200039194],
                            [2.306451383665558, 48.97321434113163],
                            [2.305326661217574, 48.97397482562643],
                            [2.304248387110239, 48.974680455821535],
                            [2.303272628965902, 48.97525391322202],
                            [2.302027637899256, 48.9759531795682],
                            [2.30107647610827, 48.976444790948634],
                            [2.300390459437297, 48.97675572500292],
                            [2.299588440994141, 48.97711234527124],
                            [2.298772732575371, 48.97745327439792],
                            [2.297903298149639, 48.97779447069571],
                            [2.297140757257672, 48.97807928049051],
                            [2.296019737740486, 48.97847734767796],
                            [2.295284316545156, 48.97871406598963],
                            [2.29446429243953, 48.978962169468424],
                            [2.293514126699586, 48.9792173559293],
                            [2.292830739502113, 48.979375363324145],
                            [2.292477128819507, 48.9794479829515],
                        ],
                    },
                },
                226: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.81343684350115, 2.2576414460161507],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 2513.01998193,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.240919294866535,
                            48.8126035833289,
                            2.274489672177882,
                            48.81488431421452,
                        ),
                        "coordinates": [
                            [2.240919294866535, 48.81488431421452],
                            [2.241726748463877, 48.81466133223218],
                            [2.242339521055581, 48.814502426292414],
                            [2.242876561607956, 48.81438152371835],
                            [2.243601010146782, 48.814225082183285],
                            [2.244044311335397, 48.814137408477],
                            [2.244811968641806, 48.81399051098299],
                            [2.248041096454325, 48.81338396064823],
                            [2.24933488683262, 48.81314226835762],
                            [2.250109707258579, 48.813000099215266],
                            [2.250834043158753, 48.812884060873834],
                            [2.251551137127898, 48.81278704631829],
                            [2.252282597272691, 48.812713831706816],
                            [2.253006824031245, 48.81265726293035],
                            [2.253734617081729, 48.81261972527513],
                            [2.254440759709511, 48.8126035833289],
                            [2.255172077863239, 48.8126136261862],
                            [2.255899761086372, 48.81264269745161],
                            [2.25662740828471, 48.8126955566814],
                            [2.257481113554087, 48.812769912924445],
                            [2.258331227074339, 48.812839502753405],
                            [2.259177735732794, 48.81291146287018],
                            [2.260020642353675, 48.81298579336772],
                            [2.263165351898009, 48.81326149121986],
                            [2.265387930932504, 48.81345087413204],
                            [2.270589594529998, 48.81391560582077],
                            [2.272977807351703, 48.81411477416988],
                            [2.273475067343621, 48.81415755907355],
                            [2.274489672177882, 48.81423944550172],
                        ],
                    },
                },
                227: {
                    "attributes": {
                        "reseau": "CDGVAL",
                        "val": 1,
                        "metro": 0,
                        "res_com": "CDGVAL",
                        "rer": 0,
                        "extcode": "043043100:CDGVAL",
                        "geo_point_2d": [49.0073852922682, 2.5709674566631833],
                        "indice_lig": "CDG",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Navette",
                        "tramway": 0,
                        "idrefligc": "C00563",
                        "navette": 1,
                        "idrefliga": "A01516",
                        "shape_leng": 593.502497166,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.570640068890432,
                            49.00472562449587,
                            2.571294844435935,
                            49.01004496004053,
                        ),
                        "coordinates": [
                            [2.570640068890432, 49.01004496004053],
                            [2.571294844435935, 49.00472562449587],
                        ],
                    },
                },
                228: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.0924694061026, 2.3120933777191293],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 6794.94954186,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.287258769653332,
                            49.068530235211696,
                            2.332268008349061,
                            49.114061951542226,
                        ),
                        "coordinates": [
                            [2.327669570460789, 49.068530235211696],
                            [2.328038899836222, 49.06872774835301],
                            [2.328379264756656, 49.06892525848934],
                            [2.328676176403118, 49.0691180065254],
                            [2.328983949716981, 49.069344065005964],
                            [2.329179472928231, 49.069508251543276],
                            [2.329360515503158, 49.06966767941749],
                            [2.329570522942775, 49.06986755607332],
                            [2.329791390118977, 49.07010312444122],
                            [2.330052085913148, 49.0704053156475],
                            [2.331366468790297, 49.07199240033275],
                            [2.331598215740878, 49.07227555195412],
                            [2.331797367797573, 49.07257059859203],
                            [2.331974874701607, 49.07288350252421],
                            [2.332072550278713, 49.0731249944843],
                            [2.332152201816522, 49.07337244835855],
                            [2.332210122745445, 49.07362703948198],
                            [2.332253554719168, 49.07392445752204],
                            [2.332268008349061, 49.07427421970068],
                            [2.332249873440238, 49.07455260085012],
                            [2.332199141035724, 49.07487380898436],
                            [2.332104944450692, 49.07520691156585],
                            [2.332003508792088, 49.0754733920773],
                            [2.331891212154573, 49.07570656170569],
                            [2.331731827631216, 49.07596828054261],
                            [2.331586934681513, 49.07617051788867],
                            [2.331402195507324, 49.07641082086371],
                            [2.331173993251632, 49.076653501839004],
                            [2.330956659677541, 49.07686049282034],
                            [2.330703102629793, 49.077072238785995],
                            [2.33040245962997, 49.077298259623554],
                            [2.330032994790309, 49.07753141222436],
                            [2.329685266863023, 49.07772173705681],
                            [2.329304938153184, 49.077902542004274],
                            [2.328913740944432, 49.078080965199966],
                            [2.327544539625985, 49.07866379666528],
                            [2.326972218059813, 49.078908820056334],
                            [2.326526667687847, 49.07911578259786],
                            [2.32615718191176, 49.07930847483493],
                            [2.325769572659676, 49.07953923205923],
                            [2.325439914253079, 49.07976761573263],
                            [2.325092128031762, 49.0800554789994],
                            [2.324795044868954, 49.08035286494631],
                            [2.324555917373287, 49.08062646195659],
                            [2.324367503040595, 49.08088340951281],
                            [2.324208063182895, 49.081137980376795],
                            [2.324084847082168, 49.08138065820567],
                            [2.323961613812705, 49.081687577457664],
                            [2.32387097522335, 49.08200639774618],
                            [2.323809316133887, 49.08230618644279],
                            [2.323773011066654, 49.08262263349091],
                            [2.323776560397654, 49.082896256295385],
                            [2.323809089985613, 49.08316750370957],
                            [2.323859736651423, 49.08341496039041],
                            [2.323968307335626, 49.083793286764646],
                            [2.324304910881321, 49.084883057344186],
                            [2.324384526902926, 49.08518999925676],
                            [2.324438794128032, 49.08546600680521],
                            [2.324456849662571, 49.085699183355786],
                            [2.324449529474076, 49.08599421976928],
                            [2.324420468931485, 49.086310667915676],
                            [2.324358816301413, 49.08659142136787],
                            [2.324260928579596, 49.08689834430137],
                            [2.324141313024478, 49.087174333422304],
                            [2.323978216497334, 49.087476489767546],
                            [2.323797014644475, 49.0877453344385],
                            [2.323532472532622, 49.088073650486805],
                            [2.323286061206933, 49.088328209241745],
                            [2.323017914702043, 49.08857086967374],
                            [2.322659186377886, 49.08885396502554],
                            [2.322300466766626, 49.08908947316159],
                            [2.321909144200667, 49.08930832103963],
                            [2.321543189002131, 49.08948672189342],
                            [2.321130136024855, 49.08966749560844],
                            [2.320496066400167, 49.089917235937584],
                            [2.319909095900716, 49.09014080680531],
                            [2.319470672121568, 49.09031681137767],
                            [2.319053977121199, 49.09050947290653],
                            [2.318680751811855, 49.09070451931201],
                            [2.318314760308707, 49.090925737747284],
                            [2.317992236460335, 49.09115410084827],
                            [2.317676946315405, 49.091411015453765],
                            [2.317383377388297, 49.09169648473053],
                            [2.317136908957664, 49.09197006595916],
                            [2.316897659499486, 49.0923007507611],
                            [2.316705517562842, 49.09260765121393],
                            [2.316393703437106, 49.093178634344675],
                            [2.315944115231108, 49.09396135228037],
                            [2.31575558789445, 49.094253974798654],
                            [2.315617833207036, 49.09443239938168],
                            [2.31529159262215, 49.094796375333104],
                            [2.314990745456496, 49.09507707870352],
                            [2.314613802878118, 49.095369663231516],
                            [2.314135393244986, 49.0956883996003],
                            [2.313754856675624, 49.09589770375553],
                            [2.313309102135331, 49.09609985552999],
                            [2.312827117190319, 49.09628772234868],
                            [2.312374142862541, 49.09642324801372],
                            [2.311924795135436, 49.096544497095486],
                            [2.311431969449966, 49.09665859543148],
                            [2.310663748524728, 49.09681069934106],
                            [2.310134687678268, 49.09691764676506],
                            [2.309601992084954, 49.09704124577252],
                            [2.309112768342545, 49.09717437055678],
                            [2.308648892987908, 49.09733129218884],
                            [2.308235735716148, 49.09749536344521],
                            [2.307815309184519, 49.097695121025225],
                            [2.307423853696543, 49.09791391987519],
                            [2.307054125715642, 49.09815175628827],
                            [2.306785867107673, 49.09835630909926],
                            [2.306532099380311, 49.09856800139231],
                            [2.306300063428488, 49.098786837262374],
                            [2.306038993923108, 49.09907704603832],
                            [2.305291999580416, 49.09995243468669],
                            [2.305081680377242, 49.10019030885264],
                            [2.304798854149685, 49.1004828876242],
                            [2.304458037442235, 49.100787346106834],
                            [2.304091867467211, 49.10106800201921],
                            [2.303693105388029, 49.101312957952814],
                            [2.303239987405854, 49.10155313781977],
                            [2.302736141883567, 49.10178140392713],
                            [2.302181580935156, 49.10197872163898],
                            [2.301583534711548, 49.102171264216075],
                            [2.301047118536595, 49.102320995709675],
                            [2.30048169412737, 49.102492128441526],
                            [2.299992367569859, 49.10265852509547],
                            [2.299528387918171, 49.10284634213778],
                            [2.298999124016957, 49.103100757077414],
                            [2.298426343445829, 49.10339084484059],
                            [2.297788292845123, 49.10372373478782],
                            [2.297237256779659, 49.1039947901187],
                            [2.296805869213364, 49.10418022711995],
                            [2.296450619117983, 49.10431810433001],
                            [2.296015637627256, 49.10446070995024],
                            [2.295551675648676, 49.10458902852821],
                            [2.29509136199417, 49.10468403441923],
                            [2.294591193483939, 49.10476950760368],
                            [2.293946063870054, 49.10485730352573],
                            [2.292655796160776, 49.1050376432397],
                            [2.29210487482149, 49.10513260378288],
                            [2.291535796595178, 49.105265622732006],
                            [2.29099931184523, 49.105420066293966],
                            [2.29046751074561, 49.105616198851294],
                            [2.290089364589656, 49.105778977768985],
                            [2.289603502431451, 49.106040504616054],
                            [2.289204635662977, 49.10627827300051],
                            [2.28887461105024, 49.10652558512761],
                            [2.28860984965019, 49.106739614745834],
                            [2.288323277790877, 49.10701549549874],
                            [2.28804391394789, 49.107331826676855],
                            [2.287789876320268, 49.10768623844484],
                            [2.287608354024446, 49.10800499104566],
                            [2.28744853917153, 49.108357062918465],
                            [2.28734311246677, 49.10868298594598],
                            [2.287281163547714, 49.109020822939414],
                            [2.28725910135174, 49.10933726367102],
                            [2.287258769653332, 49.10966799009189],
                            [2.287298282229797, 49.11002014801475],
                            [2.287651213665814, 49.11227828073427],
                            [2.28782761206601, 49.11348705357541],
                            [2.287915343526005, 49.114061951542226],
                        ],
                    },
                },
                229: {
                    "attributes": {
                        "reseau": "SNCF ST LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.019346630068554, 1.6061956471845904],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 6084.48648559,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.581532102335019,
                            48.99739200091919,
                            1.63016762729846,
                            49.03894771561846,
                        ),
                        "coordinates": [
                            [1.63016762729846, 48.99739200091919],
                            [1.629615692017885, 48.997560837011484],
                            [1.629460504632378, 48.99761293770859],
                            [1.628593555301599, 48.99791173604998],
                            [1.627811844925676, 48.99820670406024],
                            [1.627051447103467, 48.998527972797795],
                            [1.626590581322135, 48.99873908518356],
                            [1.625833792703765, 48.99909141201894],
                            [1.624705919394252, 48.99968064198069],
                            [1.623875953985121, 49.00017729075291],
                            [1.623064757456155, 49.00069833229609],
                            [1.622288690439635, 49.001246566472055],
                            [1.621762115174275, 49.00164886765004],
                            [1.621161612675615, 49.0021504294707],
                            [1.620626207879674, 49.002597733912765],
                            [1.62019127016299, 49.00299430655519],
                            [1.619274705909445, 49.00389507108065],
                            [1.618877743323862, 49.00431076202242],
                            [1.618826428898806, 49.00436170069768],
                            [1.61876533818036, 49.00442696746323],
                            [1.617979797419733, 49.005244008365665],
                            [1.616819444509274, 49.00645348575051],
                            [1.615903376863251, 49.007405487999655],
                            [1.615853395871856, 49.0074582321737],
                            [1.615784030318514, 49.00752794171759],
                            [1.615416186179481, 49.007911429165254],
                            [1.614883064429518, 49.008472836913484],
                            [1.614460649988764, 49.00894141134471],
                            [1.614116641390115, 49.009376306620545],
                            [1.613716072504004, 49.00993944518545],
                            [1.612246992817986, 49.012052534321796],
                            [1.612090623412661, 49.01227457501104],
                            [1.611697670786939, 49.01287462592438],
                            [1.611476254545599, 49.01324374063732],
                            [1.611259054096735, 49.01360478717779],
                            [1.610957338419534, 49.01404173977259],
                            [1.610508517641199, 49.01462704438992],
                            [1.610494609991183, 49.01464314325722],
                            [1.610173086730092, 49.01503140489684],
                            [1.609101422182481, 49.016317810261654],
                            [1.608888430987631, 49.016576358383375],
                            [1.60834145057359, 49.01723207585954],
                            [1.608317758696369, 49.01726250150898],
                            [1.607870972987262, 49.01779834678812],
                            [1.60743113219538, 49.01832613999689],
                            [1.607244629524408, 49.0185488806476],
                            [1.607195864303764, 49.018610622852194],
                            [1.607159694354645, 49.0186526603572],
                            [1.607112348797088, 49.01871081359914],
                            [1.6070567067536, 49.0187752098984],
                            [1.60702189051834, 49.01881815519702],
                            [1.606928617176198, 49.01893087349594],
                            [1.606208332707137, 49.01974465529506],
                            [1.606052603434265, 49.01991992689994],
                            [1.605847956882135, 49.02016683069421],
                            [1.605726855871133, 49.020311746176425],
                            [1.605522206202155, 49.02055865022237],
                            [1.60489716127549, 49.02130918033011],
                            [1.60471481793337, 49.02152654747718],
                            [1.604260971283995, 49.02207222626804],
                            [1.604079950089932, 49.022292299401016],
                            [1.603655322379698, 49.022803088918664],
                            [1.603385256245901, 49.023126011369136],
                            [1.602626468474463, 49.02403844871774],
                            [1.602148917490556, 49.02461184590749],
                            [1.601075428533441, 49.025900865404694],
                            [1.600234392771734, 49.026912582232974],
                            [1.600109077139743, 49.027062860749005],
                            [1.59887813610613, 49.02854060299173],
                            [1.597534301366289, 49.03015519836505],
                            [1.595833825220453, 49.032199142506805],
                            [1.595299011081934, 49.0328413896036],
                            [1.593914566486216, 49.03450334490145],
                            [1.593839351155919, 49.034593687952174],
                            [1.59382262945704, 49.03461426361393],
                            [1.59339638389231, 49.03512770478363],
                            [1.593308615812961, 49.035234152840665],
                            [1.592990420852731, 49.03559079461748],
                            [1.592495485444969, 49.03609519244363],
                            [1.592073905054099, 49.036480675782855],
                            [1.591888497856948, 49.036621561973774],
                            [1.591625767104305, 49.03681050776459],
                            [1.591186573572399, 49.037090933978995],
                            [1.591135453970383, 49.03712477525534],
                            [1.591089872044565, 49.03715415523627],
                            [1.591025074916945, 49.03718790794046],
                            [1.590200486537125, 49.03762679694639],
                            [1.589762549291128, 49.037812807503855],
                            [1.589204173200386, 49.03804076380119],
                            [1.588571185036308, 49.038272665428934],
                            [1.587880403683471, 49.03846358777291],
                            [1.587189533526433, 49.038640444370174],
                            [1.586528302021865, 49.038766515443584],
                            [1.586413165277728, 49.0387819495076],
                            [1.585577184505887, 49.0388852866932],
                            [1.584968189887681, 49.03892915752503],
                            [1.58421529283523, 49.03894771561846],
                            [1.583631096623415, 49.0389471491973],
                            [1.583427382428863, 49.038940413527115],
                            [1.583145734183793, 49.038931365929116],
                            [1.582244135991481, 49.03885168604373],
                            [1.582147148993589, 49.03884295350847],
                            [1.582072045693136, 49.038834365064766],
                            [1.581756641855026, 49.03879631297051],
                            [1.581532102335019, 49.0387620447533],
                        ],
                    },
                },
                230: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.864825082740374, 2.064072127883049],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 2401.04694712,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.050767845333735,
                            48.86283275236239,
                            2.076719102677291,
                            48.86806442324713,
                        ),
                        "coordinates": [
                            [2.076719102677291, 48.86806442324713],
                            [2.07665881660464, 48.86802622947434],
                            [2.076608555495885, 48.867992841017724],
                            [2.07620390160699, 48.86769515474171],
                            [2.076112978215862, 48.867617608643776],
                            [2.076080405637447, 48.86759055587084],
                            [2.075895918837657, 48.86741927046852],
                            [2.075575979873753, 48.8670849047019],
                            [2.075325440262298, 48.86677407834343],
                            [2.075205067242472, 48.866594845507024],
                            [2.075005046250618, 48.86626884677418],
                            [2.074757327063351, 48.86583348538165],
                            [2.074559395102638, 48.865479152571915],
                            [2.074451182523806, 48.865321529418],
                            [2.07418711765022, 48.86499358376927],
                            [2.073997318972103, 48.86479890152741],
                            [2.073842656979287, 48.86466185397434],
                            [2.073643153145084, 48.864498624526114],
                            [2.073370200600273, 48.86430644711338],
                            [2.073322652421665, 48.86427666124253],
                            [2.073280522518526, 48.86425318236562],
                            [2.073011465247485, 48.86409788440096],
                            [2.072755911195044, 48.86396689715028],
                            [2.072611786289378, 48.86390001705266],
                            [2.072531565036953, 48.86386296071837],
                            [2.072305792996286, 48.86377071009561],
                            [2.071995611305614, 48.86366027835953],
                            [2.071731631113541, 48.86357693186826],
                            [2.071433560181984, 48.86349620278058],
                            [2.070790912357746, 48.863366108603],
                            [2.070560754322489, 48.86333049933857],
                            [2.069916555247065, 48.86323636887943],
                            [2.067988040587575, 48.86295755976663],
                            [2.067685701034707, 48.8629118826311],
                            [2.067345140060446, 48.86287690626078],
                            [2.067034511605546, 48.862851891749045],
                            [2.06674154903981, 48.86283681022662],
                            [2.066505767163426, 48.86283355386535],
                            [2.066167747786756, 48.86283275236239],
                            [2.065858282869491, 48.862844607607364],
                            [2.065546080554733, 48.86286049327951],
                            [2.065248783233793, 48.862888122628384],
                            [2.064925525015882, 48.86292961917955],
                            [2.064577648373885, 48.862986344083936],
                            [2.064244738739486, 48.863047600061435],
                            [2.063880331847427, 48.86313575739054],
                            [2.06355542582283, 48.86322850555161],
                            [2.063287819884336, 48.86331149698967],
                            [2.06302151958094, 48.86340438402286],
                            [2.062736048148904, 48.86351341076755],
                            [2.062470954850895, 48.86363417687092],
                            [2.062118310352679, 48.86381228599204],
                            [2.061894090299821, 48.86393584710576],
                            [2.06179425185358, 48.863996757324735],
                            [2.061522089934632, 48.86416246808791],
                            [2.060718918988046, 48.86471448580716],
                            [2.0604590327292, 48.86487752575733],
                            [2.060174573758996, 48.86504680092025],
                            [2.059953115252001, 48.86516227123453],
                            [2.05964150318829, 48.86531169481954],
                            [2.05929860338916, 48.86544935153863],
                            [2.058996795069521, 48.865551134919535],
                            [2.058714199183737, 48.865629583202484],
                            [2.05838252739573, 48.865708811205195],
                            [2.058124611009986, 48.86576123901306],
                            [2.057820365358938, 48.86581085524539],
                            [2.057458921244195, 48.86585133766723],
                            [2.057142558874905, 48.865873944684175],
                            [2.056774460499759, 48.86588563121387],
                            [2.056508095344468, 48.86588113840887],
                            [2.056130948627628, 48.86585846285686],
                            [2.055670669615201, 48.86581851599152],
                            [2.055253008654674, 48.865775996989505],
                            [2.055017674958524, 48.86575062482637],
                            [2.054796811587871, 48.86573204166439],
                            [2.054504765557766, 48.865717935875104],
                            [2.054218707067317, 48.86572124277896],
                            [2.053938674430305, 48.865746442525854],
                            [2.053625984286768, 48.86578401514966],
                            [2.053322001226854, 48.86584473207426],
                            [2.053054440354415, 48.86591421125467],
                            [2.052790894759253, 48.86599628952499],
                            [2.05256682711773, 48.86608745856883],
                            [2.05217180146996, 48.86627802081153],
                            [2.051697681083132, 48.86656641713413],
                            [2.051461601841635, 48.86674621252236],
                            [2.051196210713628, 48.86701770941848],
                            [2.050998065553517, 48.86727354921825],
                            [2.050852646476935, 48.867535851508414],
                            [2.050767845333735, 48.8677920976795],
                        ],
                    },
                },
                231: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.527211362206735, 2.2723040121192186],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3105.06240268,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.254739702427517,
                            48.52040359106998,
                            2.290082513840396,
                            48.532890103244725,
                        ),
                        "coordinates": [
                            [2.290082513840396, 48.532890103244725],
                            [2.289734209201174, 48.53253649789415],
                            [2.289289225210587, 48.53209828136959],
                            [2.288938355857433, 48.531775772723115],
                            [2.288553233244141, 48.531451353204254],
                            [2.288148109787515, 48.53114588601439],
                            [2.287722985367884, 48.53086316280305],
                            [2.287369179467573, 48.53064114993548],
                            [2.286847002103546, 48.53034890042888],
                            [2.286370458634132, 48.53010786720578],
                            [2.285851089074588, 48.529874397727575],
                            [2.285343113467049, 48.52966747794502],
                            [2.284686717225082, 48.52943204412497],
                            [2.284138752105517, 48.5292535453459],
                            [2.283576495678448, 48.529095894444595],
                            [2.28301137245379, 48.52895340983816],
                            [2.282403419485687, 48.52881848697852],
                            [2.281815426567638, 48.52870822108015],
                            [2.281230268100794, 48.52861881241655],
                            [2.280568024784544, 48.52853505081832],
                            [2.279922878390861, 48.52847973934412],
                            [2.279246314363187, 48.528437680333774],
                            [2.27864394885956, 48.52842220226254],
                            [2.278027290449138, 48.52842188360666],
                            [2.277410618847667, 48.528432939927164],
                            [2.2765683769011, 48.52847231666823],
                            [2.275714707034037, 48.52851547264879],
                            [2.274858185217396, 48.52855672492686],
                            [2.274127312692539, 48.52856959727176],
                            [2.273513507684554, 48.528569255542905],
                            [2.272908294357497, 48.528548058069724],
                            [2.272325935166354, 48.528515492300926],
                            [2.27172933809518, 48.528456367237986],
                            [2.271132762818213, 48.52838017460659],
                            [2.270530500533806, 48.528288803635384],
                            [2.269956816596601, 48.528178485687526],
                            [2.269257576908441, 48.52802447552144],
                            [2.268575499776866, 48.527849613071275],
                            [2.267890604016973, 48.527651989839704],
                            [2.267245695746463, 48.527444905885865],
                            [2.266615089583204, 48.52722076181568],
                            [2.265981664349252, 48.526975752926795],
                            [2.265362551577256, 48.52670799508884],
                            [2.264766303036454, 48.526426975629136],
                            [2.264198633211657, 48.526128903303935],
                            [2.263642412954147, 48.52581566684544],
                            [2.263100501568763, 48.525481577883305],
                            [2.262561462899985, 48.52514179969478],
                            [2.261962566743837, 48.52474509311154],
                            [2.261395085444001, 48.52434650672226],
                            [2.261135580428958, 48.52416808749404],
                            [2.260773422943895, 48.52391564601215],
                            [2.259008330803085, 48.52267430971919],
                            [2.25840378914813, 48.522273786699685],
                            [2.2578676525067, 48.52194536711778],
                            [2.257305829094408, 48.52161882122433],
                            [2.25674968038453, 48.521318824222746],
                            [2.256467314338979, 48.521176406814156],
                            [2.256159265451747, 48.52103017824302],
                            [2.255631585081808, 48.52078518738958],
                            [2.254912773973982, 48.520471791151905],
                            [2.254739702427517, 48.52040359106998],
                        ],
                    },
                },
                232: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.98935751527942, 2.2458746664321008],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1954.61314817,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.234276393996537,
                            48.98500470125915,
                            2.25747415725031,
                            48.99371348038584,
                        ),
                        "coordinates": [
                            [2.25747415725031, 48.98500470125915],
                            [2.256667529466798, 48.98530179983275],
                            [2.256537648249651, 48.98534937040701],
                            [2.256406397970248, 48.98539873895597],
                            [2.256324367152076, 48.98542925655962],
                            [2.25483957933873, 48.98598395673322],
                            [2.254752076836709, 48.98601716760732],
                            [2.254065722420399, 48.98627566499257],
                            [2.252697094129654, 48.986791752504],
                            [2.252152919385233, 48.98699548761377],
                            [2.250853987138239, 48.98748372667994],
                            [2.25052446527544, 48.98760757845762],
                            [2.250302957914854, 48.987691044437135],
                            [2.250069147044349, 48.987778097556905],
                            [2.248828968929537, 48.98824477512492],
                            [2.248735984251072, 48.98828247410205],
                            [2.248689496718009, 48.98829862493679],
                            [2.248644373466953, 48.988315676355626],
                            [2.248578741899453, 48.988339906642],
                            [2.248519944991161, 48.988362343427454],
                            [2.248182205336202, 48.9884897792397],
                            [2.247942915503344, 48.98857952129495],
                            [2.244431417603644, 48.98989778089434],
                            [2.244312450985003, 48.98994174964649],
                            [2.244241341042742, 48.98996956972559],
                            [2.244168866746831, 48.98999648911002],
                            [2.244036222252495, 48.9900476409717],
                            [2.243727181301108, 48.99016159795455],
                            [2.243554620207485, 48.99022882178484],
                            [2.242902227019158, 48.99047741455814],
                            [2.24162140823175, 48.990954603971424],
                            [2.239750755235367, 48.99166921656483],
                            [2.237898175127222, 48.99236001975328],
                            [2.23664981377814, 48.99283004478473],
                            [2.235958195596444, 48.99308036887799],
                            [2.234276393996537, 48.99371348038584],
                        ],
                    },
                },
                233: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.839792769296366, 2.198425985381831],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1723.99749497,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.187110711095018,
                            48.83828254600231,
                            2.209938360929272,
                            48.840517349814164,
                        ),
                        "coordinates": [
                            [2.209938360929272, 48.840517349814164],
                            [2.209378074228418, 48.84039201418087],
                            [2.208902838412542, 48.840300655727155],
                            [2.208404390561844, 48.84022995250118],
                            [2.207828259213623, 48.84016995072265],
                            [2.20731908058864, 48.840116412990525],
                            [2.206998337665408, 48.84008987616147],
                            [2.206715441592328, 48.84007696143968],
                            [2.204591654638433, 48.840019665625455],
                            [2.203492276258633, 48.83999860241443],
                            [2.202604062166013, 48.839979576370524],
                            [2.201555127130644, 48.83994596415789],
                            [2.19988086272485, 48.83991429183193],
                            [2.199691511422124, 48.83990776916452],
                            [2.199047163231645, 48.83988990640791],
                            [2.198965426291571, 48.839888009115654],
                            [2.198890503390143, 48.83988522024738],
                            [2.198218920579349, 48.83986282302237],
                            [2.198037737175246, 48.839859005654596],
                            [2.197664471878732, 48.83985135635475],
                            [2.196863450593256, 48.83983418824968],
                            [2.196185034234173, 48.839819864118596],
                            [2.195663285120399, 48.83980752863991],
                            [2.19376154628688, 48.839766489063905],
                            [2.193331918669794, 48.83975348265407],
                            [2.192826000765254, 48.839740948350496],
                            [2.192245699403402, 48.839728317060654],
                            [2.191784358015278, 48.83971226597262],
                            [2.19155009300573, 48.83970126010026],
                            [2.191368104879146, 48.8396867524227],
                            [2.190926702419407, 48.839632652252],
                            [2.190541191822519, 48.83957148628907],
                            [2.19009089305345, 48.83947930233946],
                            [2.189786505150622, 48.839412287648514],
                            [2.189574008960758, 48.8393537203063],
                            [2.189317944032969, 48.839268373203275],
                            [2.189102608376043, 48.83919490188592],
                            [2.188561008096156, 48.83898916306283],
                            [2.188242619955218, 48.83885565607613],
                            [2.188091596817663, 48.83878981167965],
                            [2.187882117313896, 48.83868342356778],
                            [2.187604615301071, 48.838545470642934],
                            [2.187187047988941, 48.83832370068622],
                            [2.187110711095018, 48.83828254600231],
                        ],
                    },
                },
                234: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.49751296476139, 2.6861985369150476],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 3017.03064454,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.678973982691401,
                            48.487076395248074,
                            2.69503731516767,
                            48.510265175268025,
                        ),
                        "coordinates": [
                            [2.69503731516767, 48.487076395248074],
                            [2.694245575197542, 48.487281572807596],
                            [2.693509532376374, 48.48749953727407],
                            [2.692867053870831, 48.4877118107041],
                            [2.692250465805759, 48.48793334259983],
                            [2.69158537619751, 48.48819261790166],
                            [2.690815269927012, 48.48852415773336],
                            [2.690522171756, 48.4886589831965],
                            [2.6900940554476, 48.4888578019078],
                            [2.689685481029043, 48.48907263631791],
                            [2.689297445758597, 48.48929686183042],
                            [2.688813966004562, 48.48960771190611],
                            [2.688355025342478, 48.48994636097858],
                            [2.687876290443878, 48.49035701010034],
                            [2.687522550803856, 48.490714384858826],
                            [2.687167445395255, 48.491137966707285],
                            [2.686875371613728, 48.491546235827855],
                            [2.686597845502224, 48.492047403255086],
                            [2.68643375205892, 48.49243247404081],
                            [2.686310821426463, 48.49284651427812],
                            [2.686186525672235, 48.49345300102005],
                            [2.686164067422796, 48.49372464797546],
                            [2.686173832219567, 48.494736288854114],
                            [2.686202135695622, 48.49607790229893],
                            [2.686236255323618, 48.497089467982434],
                            [2.686244244936598, 48.49784662348441],
                            [2.686282949245358, 48.499127055042585],
                            [2.686252432699991, 48.49979530194838],
                            [2.686157087701774, 48.50028659447774],
                            [2.686078125886153, 48.50060517747804],
                            [2.685816428867547, 48.501302913932896],
                            [2.685676440760374, 48.50160280062751],
                            [2.685496057224245, 48.50193158769325],
                            [2.685214692563314, 48.502333525747275],
                            [2.684955889151448, 48.502672444905656],
                            [2.684319767270796, 48.50343337706348],
                            [2.683529459310763, 48.504404306722705],
                            [2.683309378298592, 48.50467116206516],
                            [2.683097332682365, 48.50492630225843],
                            [2.682706756457446, 48.50539151659371],
                            [2.68146138858131, 48.506908773942925],
                            [2.681281486538678, 48.50711795093848],
                            [2.680970187146986, 48.50750558088728],
                            [2.680588914414678, 48.50795187415301],
                            [2.680175580334432, 48.50846031271878],
                            [2.679845527274557, 48.50887857128996],
                            [2.679604470085139, 48.50921099848539],
                            [2.679454774943514, 48.50941935062202],
                            [2.679257236993564, 48.50973015661758],
                            [2.679039404519952, 48.51013458460954],
                            [2.678973982691401, 48.510265175268025],
                        ],
                    },
                },
                235: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.84776004312368, 2.133318973679109],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1471.13889724,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.131100577321693,
                            48.84271995435486,
                            2.138125058777295,
                            48.85425170349275,
                        ),
                        "coordinates": [
                            [2.138125058777295, 48.84271995435486],
                            [2.137311463270128, 48.84331568166061],
                            [2.136849623168135, 48.843645808107546],
                            [2.136723907967805, 48.84373731369144],
                            [2.134342214756369, 48.84543184966389],
                            [2.134115363880631, 48.84559691507521],
                            [2.133372014083482, 48.846118971635995],
                            [2.132792552296897, 48.84654419584981],
                            [2.132453529971064, 48.84681427168019],
                            [2.132290725030947, 48.84697495115206],
                            [2.132140225290957, 48.84712486050152],
                            [2.131977354544583, 48.84730082764652],
                            [2.131821258077197, 48.84748579886223],
                            [2.131570338308711, 48.84786574313454],
                            [2.131398770773044, 48.84816669277937],
                            [2.131258400527841, 48.84850187157919],
                            [2.1311838115422, 48.8487454419496],
                            [2.131125469558153, 48.84901422116238],
                            [2.131102699979315, 48.84924799299549],
                            [2.131100577321693, 48.849431442356114],
                            [2.131119856117018, 48.849712052543694],
                            [2.131163798369543, 48.84995943336533],
                            [2.131181155475021, 48.8500457956262],
                            [2.131269515953317, 48.85042634994647],
                            [2.131679143079398, 48.852205863450294],
                            [2.132095245728708, 48.85407441555457],
                            [2.132132445251102, 48.85425170349275],
                        ],
                    },
                },
                236: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.58032014674072, 2.589409838485273],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 3494.85205435,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.58394771106125,
                            48.564949495670916,
                            2.594551816007613,
                            48.595563837991776,
                        ),
                        "coordinates": [
                            [2.594551816007613, 48.564949495670916],
                            [2.594295504436848, 48.56545677875951],
                            [2.59394493728639, 48.566297471138796],
                            [2.593513140386829, 48.567378656710105],
                            [2.592647916108226, 48.569933613348155],
                            [2.592298847202012, 48.571078849405694],
                            [2.591903749787656, 48.57234077373574],
                            [2.591473493827524, 48.57374315570742],
                            [2.591127969309865, 48.574890759355135],
                            [2.590837866272776, 48.5758674762185],
                            [2.590598102195244, 48.57666508302081],
                            [2.590238337562021, 48.57784126690704],
                            [2.589807856422505, 48.57921747191162],
                            [2.589310338910697, 48.58081509872764],
                            [2.588812824486161, 48.58241986298694],
                            [2.588347481668348, 48.584010276998],
                            [2.587987516220817, 48.58516742138348],
                            [2.587511457618529, 48.58677689070458],
                            [2.586973779293195, 48.588501098135],
                            [2.586601945524944, 48.58968840234978],
                            [2.586134388752506, 48.59086322685132],
                            [2.585694396053536, 48.59181591901776],
                            [2.585149965885586, 48.592927460295556],
                            [2.584091329784307, 48.59523255348737],
                            [2.58394771106125, 48.595563837991776],
                        ],
                    },
                },
                237: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.846564004640356, 2.3062490383617456],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 525.077197842,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.302968297817314,
                            48.845626966747176,
                            2.309531491460945,
                            48.84750708199681,
                        ),
                        "coordinates": [
                            [2.302968297817314, 48.84750708199681],
                            [2.304451820139122, 48.84708342797386],
                            [2.307571426047775, 48.84617955755766],
                            [2.308979893777096, 48.845780563609615],
                            [2.309531491460945, 48.845626966747176],
                        ],
                    },
                },
                238: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.632155809117435, 1.80325190267206],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 5090.65309918,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.771695684383177,
                            48.62599081977363,
                            1.832935470348963,
                            48.644221953457865,
                        ),
                        "coordinates": [
                            [1.771695684383177, 48.62599081977363],
                            [1.771789234910462, 48.625993714173234],
                            [1.775294766291022, 48.62609673738346],
                            [1.778253953288389, 48.62617510851936],
                            [1.778757072012567, 48.62619016941249],
                            [1.779643986849183, 48.62621520206869],
                            [1.780016931707398, 48.626225122947474],
                            [1.781089516560572, 48.62626634214707],
                            [1.781854010110753, 48.6263213352617],
                            [1.782441385377774, 48.62638164056386],
                            [1.782832091059342, 48.6264287529839],
                            [1.783188491163392, 48.626478021746394],
                            [1.783696201204207, 48.626568622499015],
                            [1.784631464432751, 48.62676111992955],
                            [1.785764159345311, 48.62701122113867],
                            [1.787960566770759, 48.62749576886527],
                            [1.788829412831479, 48.62768611221708],
                            [1.791297364301402, 48.62823517384915],
                            [1.794458063645305, 48.62892443808158],
                            [1.795995413418458, 48.629271226882615],
                            [1.798921057474979, 48.629915635146915],
                            [1.801707165774385, 48.630526004014506],
                            [1.80335088842882, 48.63089063581582],
                            [1.804844310113646, 48.63121409131256],
                            [1.808049539332668, 48.631921441843296],
                            [1.808507937878205, 48.632023506536605],
                            [1.809761253782975, 48.63231484861222],
                            [1.810498740246909, 48.632503855680014],
                            [1.81137572434654, 48.63274109035344],
                            [1.812248876046153, 48.63300209435513],
                            [1.813254253968988, 48.63332080577438],
                            [1.813780005654765, 48.63350643658823],
                            [1.814506084180801, 48.63375960875121],
                            [1.81550358979515, 48.63414726539937],
                            [1.816007394394606, 48.63434538004149],
                            [1.81654904003577, 48.63457807731161],
                            [1.816863761901163, 48.634713511391006],
                            [1.817394506830523, 48.63495154974686],
                            [1.817894106053569, 48.635184049043794],
                            [1.818270759755442, 48.635366523645764],
                            [1.819171038824418, 48.63582116894826],
                            [1.820269244742543, 48.636425088259955],
                            [1.82060912439786, 48.63662267562147],
                            [1.821037876175012, 48.63688631426458],
                            [1.821412686014929, 48.63711823056304],
                            [1.821543468233524, 48.637198860260135],
                            [1.824339366114668, 48.63897409631737],
                            [1.825841204068545, 48.639926903963996],
                            [1.826341365401625, 48.64024569882337],
                            [1.827367245483112, 48.64089657648942],
                            [1.82998973544806, 48.642560592953174],
                            [1.830340395878458, 48.6427734875547],
                            [1.830469896221011, 48.64284960438045],
                            [1.830661452617415, 48.64296196811928],
                            [1.83092441461041, 48.6431014728271],
                            [1.831299297758785, 48.643310144664596],
                            [1.83163984521822, 48.64349077942609],
                            [1.831842136363664, 48.64359808010537],
                            [1.832314856713282, 48.643846119164735],
                            [1.832935470348963, 48.644221953457865],
                        ],
                    },
                },
                239: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.699538946497306, 2.1172950111266533],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2916.87932911,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.097975858420524,
                            48.69754950085678,
                            2.136566717058361,
                            48.70121772031537,
                        ),
                        "coordinates": [
                            [2.097975858420524, 48.70121772031537],
                            [2.09860437330809, 48.701039183427106],
                            [2.099330897085727, 48.70085794718826],
                            [2.100017445405373, 48.70071929319873],
                            [2.100672897558623, 48.70059663324645],
                            [2.101300966222995, 48.70049893686537],
                            [2.101627235991346, 48.700452849309805],
                            [2.10218177323226, 48.700400037342405],
                            [2.102863176776255, 48.700337051083075],
                            [2.103553525199324, 48.700293260570405],
                            [2.104349265950277, 48.700269593146416],
                            [2.105161659531043, 48.70027304838885],
                            [2.105639770308572, 48.70029380465048],
                            [2.106146366367439, 48.70032450865369],
                            [2.106834917959957, 48.700374462341415],
                            [2.107484751152433, 48.70042556065397],
                            [2.108566427385785, 48.70051373882784],
                            [2.109517051782314, 48.700592979125496],
                            [2.109988317547961, 48.700626293113196],
                            [2.110431748559973, 48.70065215308149],
                            [2.110852995020118, 48.7006613671844],
                            [2.111349381208017, 48.70067216232582],
                            [2.112012370453761, 48.70066897708845],
                            [2.112422702665969, 48.70065809680607],
                            [2.112827669893056, 48.70063191608533],
                            [2.113265298473231, 48.700593208381285],
                            [2.113653776244, 48.70055281880377],
                            [2.114061776873859, 48.70051113735976],
                            [2.11478263117267, 48.70043701991963],
                            [2.116448477774766, 48.70026578520458],
                            [2.117904137926928, 48.70011571793081],
                            [2.118593234462253, 48.700043300882655],
                            [2.119251071038363, 48.699973517562924],
                            [2.119847927814652, 48.69989950459252],
                            [2.120173087719416, 48.699848841858845],
                            [2.120553365641245, 48.699785353874354],
                            [2.121064616936839, 48.699682908202796],
                            [2.121298508060788, 48.69963119387628],
                            [2.121959447535761, 48.69946967489261],
                            [2.123087279132641, 48.699153850965644],
                            [2.123835775935643, 48.69895301124837],
                            [2.124274805443225, 48.69883248647731],
                            [2.124792969879381, 48.69869783122564],
                            [2.12606237908847, 48.69837290394825],
                            [2.127070735959188, 48.69809770323912],
                            [2.127664455042126, 48.69794176026221],
                            [2.128186226644817, 48.69779995845076],
                            [2.128531614540134, 48.6977196941413],
                            [2.128851773855037, 48.69765603736141],
                            [2.129265372767743, 48.69759493013148],
                            [2.129635711193363, 48.69756467441329],
                            [2.129928352861774, 48.69755190739702],
                            [2.130451677419926, 48.69754950085678],
                            [2.130847928495224, 48.697577855546],
                            [2.131328605271686, 48.69763178133112],
                            [2.133241864620513, 48.69783395872046],
                            [2.136566717058361, 48.69819697630193],
                        ],
                    },
                },
                240: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.939183252148254, 2.2613697346186448],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1859.15320244,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25789748402742,
                            48.93105422781371,
                            2.263184304511326,
                            48.946796942080006,
                        ),
                        "coordinates": [
                            [2.260602314246561, 48.93105422781371],
                            [2.261339992940939, 48.93277735871654],
                            [2.26192845562579, 48.934095897822615],
                            [2.262165980863144, 48.93464568021208],
                            [2.26278593547287, 48.93607741003118],
                            [2.26287225768476, 48.93631539973921],
                            [2.262987382623659, 48.93661527153104],
                            [2.263087913842962, 48.93701506388585],
                            [2.263138048210378, 48.937302996881705],
                            [2.263177395067224, 48.93755999071292],
                            [2.263184304511326, 48.93777175654649],
                            [2.263183753703794, 48.93814293283929],
                            [2.263157862879139, 48.93855216237681],
                            [2.263103227020259, 48.93886144123741],
                            [2.263059574229614, 48.939070795209915],
                            [2.262990553880533, 48.93933723668828],
                            [2.262856372097004, 48.93970237840287],
                            [2.262769314320712, 48.93995096295791],
                            [2.262627994339127, 48.94025780692889],
                            [2.262526554468291, 48.94046236424788],
                            [2.262345516519471, 48.94075728519014],
                            [2.262019734947993, 48.941226992058596],
                            [2.261791735517665, 48.941521880947555],
                            [2.261553780255332, 48.941821366327915],
                            [2.259935982944806, 48.94390459301893],
                            [2.25924098169465, 48.944843962964256],
                            [2.258465163835001, 48.946054674714276],
                            [2.25789748402742, 48.946796942080006],
                        ],
                    },
                },
                241: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.89294686080906, 2.305586250545477],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1589.87147309,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.297419948146663,
                            48.88822016276462,
                            2.313732451520271,
                            48.89763744791706,
                        ),
                        "coordinates": [
                            [2.313732451520271, 48.88822016276462],
                            [2.312557681116819, 48.888904131906834],
                            [2.311861101364987, 48.88931322918998],
                            [2.310471156153221, 48.89009856750011],
                            [2.307915667206252, 48.89156362940108],
                            [2.305782353427846, 48.892812229255576],
                            [2.304508076579762, 48.89358040663048],
                            [2.302399845234058, 48.894833707686736],
                            [2.301472058910227, 48.89536877831059],
                            [2.300746415528593, 48.895794456467286],
                            [2.29982620296289, 48.896307637273466],
                            [2.299147473198817, 48.89669643774181],
                            [2.298473555854997, 48.89706897752753],
                            [2.297419948146663, 48.89763744791706],
                        ],
                    },
                },
                242: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.860582770308255, 2.295416613701717],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1011.36657611,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.290391553460649,
                            48.857293413870465,
                            2.300989969386769,
                            48.86266245169434,
                        ),
                        "coordinates": [
                            [2.300989969386769, 48.86266245169434],
                            [2.300489376303076, 48.86262060013306],
                            [2.300032815891246, 48.862567398790404],
                            [2.299490401215816, 48.86249438141424],
                            [2.298927572098009, 48.86238628327973],
                            [2.298494214862682, 48.86229351367372],
                            [2.29800637041118, 48.8621620556285],
                            [2.297826501717835, 48.86210623886935],
                            [2.297464042713203, 48.86199010797553],
                            [2.297153379144549, 48.861873095721656],
                            [2.296750074591071, 48.86170748768124],
                            [2.296048439329894, 48.8613538246328],
                            [2.295530772178002, 48.86104788535211],
                            [2.29518069637236, 48.86080855129745],
                            [2.294891922429404, 48.86060880715892],
                            [2.294201323231796, 48.86013373465184],
                            [2.293821293267962, 48.859873701813434],
                            [2.292941392127579, 48.85926365878662],
                            [2.291533049514775, 48.85828559758574],
                            [2.29113808270113, 48.85799857196018],
                            [2.290786737550953, 48.85770436759405],
                            [2.290694652871954, 48.857616747019215],
                            [2.290586576383536, 48.85751184216011],
                            [2.290391553460649, 48.857293413870465],
                        ],
                    },
                },
                243: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.927538935302024, 2.2594319486728183],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 812.556138388,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25890223580021,
                            48.923918626560365,
                            2.260602314246561,
                            48.93105422781371,
                        ),
                        "coordinates": [
                            [2.25934570305215, 48.923918626560365],
                            [2.259242690685924, 48.924161829185316],
                            [2.25914654050798, 48.924426791415236],
                            [2.259044843227303, 48.924807416548504],
                            [2.258968397437719, 48.92520233379846],
                            [2.258931748247874, 48.92554731403057],
                            [2.25890223580021, 48.92594464268499],
                            [2.258905290105806, 48.9262991661213],
                            [2.258930064197831, 48.92662039577116],
                            [2.258976468072476, 48.92696067231551],
                            [2.259051762539378, 48.92730334775074],
                            [2.259141518144067, 48.92763413642275],
                            [2.259234960436355, 48.927917340461626],
                            [2.259353635180461, 48.92822911553918],
                            [2.259508342731763, 48.92859325725773],
                            [2.259709849054022, 48.929050227627464],
                            [2.260602314246561, 48.93105422781371],
                        ],
                    },
                },
                244: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93858713280242, 2.358379606699589],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 379.309216488,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.355902810417396,
                            48.938082614059766,
                            2.360746043772506,
                            48.93873295309403,
                        ),
                        "coordinates": [
                            [2.360746043772506, 48.938082614059766],
                            [2.359886135989626, 48.938557853528465],
                            [2.359883879316849, 48.938558979069725],
                            [2.359784358085317, 48.93860391977967],
                            [2.359678965852863, 48.93864261949221],
                            [2.359568603561618, 48.938674748472984],
                            [2.359454212437124, 48.93870003206175],
                            [2.359336767128403, 48.93871825333391],
                            [2.359217270179924, 48.93872925846719],
                            [2.359148479387801, 48.938732267492654],
                            [2.359096742519166, 48.93873295309403],
                            [2.358976211124996, 48.93872930583298],
                            [2.358149367895832, 48.938672831319145],
                            [2.357441331957247, 48.938625530357605],
                            [2.357022710000366, 48.938597797035406],
                            [2.356787020429971, 48.93859783822363],
                            [2.356480985413449, 48.93862106700933],
                            [2.356178458600191, 48.938616483735494],
                            [2.355902810417396, 48.938597775209935],
                        ],
                    },
                },
                245: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.20283254658722, 2.716911750278763],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 6203.63706657,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.703936052961915,
                            48.18093685577102,
                            2.736249842909681,
                            48.229549937455864,
                        ),
                        "coordinates": [
                            [2.703936052961915, 48.229549937455864],
                            [2.703985765329806, 48.22946151109987],
                            [2.704101421761575, 48.229265103554084],
                            [2.704225164985404, 48.229070467980414],
                            [2.704352886364159, 48.2288677252921],
                            [2.704517841918618, 48.22860371505364],
                            [2.70467751708113, 48.22835410852025],
                            [2.704861205445985, 48.22807564906738],
                            [2.705023496755266, 48.227816141933936],
                            [2.705181874539825, 48.22757373319775],
                            [2.70536014788292, 48.22729169349031],
                            [2.70550115941089, 48.22706732563995],
                            [2.705648891838918, 48.226842035858034],
                            [2.705801892812961, 48.2266014429016],
                            [2.70595490661124, 48.22636264750474],
                            [2.706158455915499, 48.22604185629278],
                            [2.706328803153279, 48.22578142228816],
                            [2.706476514209562, 48.225554333469084],
                            [2.706601505187193, 48.2253489006608],
                            [2.706689285050819, 48.225207434414294],
                            [2.706773041571207, 48.225067780164956],
                            [2.706839500167284, 48.22495515917468],
                            [2.706921909296604, 48.22481550865272],
                            [2.707004357709474, 48.22466118810824],
                            [2.707065320270406, 48.22455336357048],
                            [2.707146269835485, 48.224398430932204],
                            [2.707225813562455, 48.22423541019387],
                            [2.707319775214898, 48.22405038312066],
                            [2.707388982455865, 48.223915649196634],
                            [2.707486973277202, 48.22369951293949],
                            [2.70762734827228, 48.22339151642417],
                            [2.707756870759499, 48.22308896802133],
                            [2.70793450292641, 48.222683029049314],
                            [2.708045672228668, 48.22242515946952],
                            [2.708147324444039, 48.22218754196321],
                            [2.708286300392824, 48.22187325501202],
                            [2.708422601763943, 48.22156167408185],
                            [2.708565517848919, 48.22123478501777],
                            [2.708706939045614, 48.22088811745996],
                            [2.708765136296709, 48.220751243513426],
                            [2.708827234973856, 48.22059637174785],
                            [2.708874746945234, 48.220470323694485],
                            [2.708971678277027, 48.220197938446205],
                            [2.709048686366518, 48.21997247819565],
                            [2.709149993140247, 48.21966101231183],
                            [2.70920526312418, 48.21949267523329],
                            [2.709264435585181, 48.21930634030446],
                            [2.709318225868206, 48.21912002267478],
                            [2.709368046736703, 48.21894271108707],
                            [2.709424486162038, 48.218750990366836],
                            [2.709502488760634, 48.218382050362464],
                            [2.709547283037827, 48.21815443899932],
                            [2.70957626777858, 48.21798794630537],
                            [2.709599974819012, 48.217736983955085],
                            [2.709613257142747, 48.21753191744798],
                            [2.709618479314898, 48.21732867566423],
                            [2.709609001286167, 48.217138970108465],
                            [2.709592448184047, 48.216902529295],
                            [2.709570927201045, 48.216721855834535],
                            [2.709532868581779, 48.21648818381126],
                            [2.709477891089822, 48.21615025674991],
                            [2.709423274324293, 48.215860887512655],
                            [2.709386955125592, 48.215680262969016],
                            [2.709347684235613, 48.21546457899056],
                            [2.709307248617781, 48.215273178280206],
                            [2.709283245178246, 48.21512038918399],
                            [2.70925925485543, 48.214969398775246],
                            [2.709232494118538, 48.21480762656162],
                            [2.709222123613283, 48.214679072563065],
                            [2.709210123097969, 48.21451185602511],
                            [2.709207760414496, 48.21437428243087],
                            [2.709203452617789, 48.214155786033146],
                            [2.709211514118181, 48.21397231733615],
                            [2.709223737121063, 48.21380592065657],
                            [2.709238491540321, 48.213617934348214],
                            [2.709270489525792, 48.2133966199641],
                            [2.709304079744115, 48.2132085710698],
                            [2.709345847307024, 48.213034883104605],
                            [2.709402221394513, 48.21283506875077],
                            [2.709469298142296, 48.21262712676873],
                            [2.709547051418953, 48.21240745971294],
                            [2.70963433368146, 48.212203047639356],
                            [2.709740084195719, 48.21197737561937],
                            [2.709830476274736, 48.211801344969054],
                            [2.709926095360049, 48.21163287450498],
                            [2.710048387780507, 48.21143284267847],
                            [2.71019605432599, 48.211207547441234],
                            [2.710350465630802, 48.2109849283053],
                            [2.71049972145941, 48.210792899988974],
                            [2.710645065964089, 48.210617968706536],
                            [2.710797171205638, 48.21044751134172],
                            [2.710941388693076, 48.210302258308516],
                            [2.711129688537949, 48.210114595051046],
                            [2.711323446157342, 48.2099377045137],
                            [2.71164295909947, 48.20966597671235],
                            [2.711970621691362, 48.209405012285714],
                            [2.712563014471554, 48.20892465443174],
                            [2.712924110789214, 48.20863839715556],
                            [2.713095290449376, 48.20850204371293],
                            [2.713212940639064, 48.20840363567997],
                            [2.7133426585274, 48.20829979236943],
                            [2.713456231273418, 48.20819600242793],
                            [2.713571156975474, 48.20809310734561],
                            [2.713714149565788, 48.207965839104226],
                            [2.713842372065293, 48.20784221685366],
                            [2.714015342792432, 48.20766332775619],
                            [2.714209396741369, 48.20745162626286],
                            [2.714293398500193, 48.207351531352224],
                            [2.71439075722646, 48.20723880318539],
                            [2.714466768441794, 48.20714952592521],
                            [2.714537363960081, 48.207055769851536],
                            [2.714629266697856, 48.20693316835028],
                            [2.714697150289967, 48.20683672423348],
                            [2.714771672675774, 48.20672856729727],
                            [2.714846114398255, 48.20660962069083],
                            [2.714923163633058, 48.20647987470275],
                            [2.714992224206144, 48.20636094559194],
                            [2.715139446658792, 48.20608169257097],
                            [2.715221518134324, 48.205904270289544],
                            [2.715335223767999, 48.205640417088524],
                            [2.715386646004452, 48.20550176398288],
                            [2.71542352624199, 48.20539733096837],
                            [2.71545897384051, 48.205281212457635],
                            [2.715494367180454, 48.20515789994235],
                            [2.715534937429664, 48.2050075934489],
                            [2.715578529584745, 48.204802037830945],
                            [2.715607562470922, 48.204654941856454],
                            [2.715638444425401, 48.20446141821218],
                            [2.715652057004335, 48.20430400851502],
                            [2.715664358442297, 48.204151099116096],
                            [2.715675132235256, 48.20397391675516],
                            [2.715674163857806, 48.20384533102925],
                            [2.715671687187926, 48.2035162241197],
                            [2.715667711929983, 48.20334538572704],
                            [2.715664020523567, 48.203212313308974],
                            [2.715652371310211, 48.20291560920674],
                            [2.715648138742553, 48.20271060038188],
                            [2.715636374214697, 48.20239861016432],
                            [2.715629560643321, 48.20220799808585],
                            [2.715621244675989, 48.20199670864886],
                            [2.715615220153311, 48.20173235831187],
                            [2.71560837174563, 48.2015372497771],
                            [2.715602869382034, 48.201342137258],
                            [2.715594283083424, 48.201094880367705],
                            [2.715585731866197, 48.20085211890368],
                            [2.715573597483122, 48.20066961807093],
                            [2.715567377369465, 48.200379190895276],
                            [2.715561813901625, 48.20017598529307],
                            [2.715556019504955, 48.19994220758914],
                            [2.715550788034258, 48.199783063109656],
                            [2.715546683432086, 48.19959513949964],
                            [2.715541506126994, 48.19944318899457],
                            [2.715533224587629, 48.199236396416836],
                            [2.715528938667036, 48.19902419484873],
                            [2.715526383355073, 48.19886324271902],
                            [2.715530099033233, 48.19864202279452],
                            [2.715538025262077, 48.19844416724339],
                            [2.715551339672104, 48.19824719384682],
                            [2.715568702222668, 48.19805200457377],
                            [2.715591470618959, 48.197860394191906],
                            [2.715615888972144, 48.19770924360806],
                            [2.715642921715625, 48.197548192512215],
                            [2.715685655367018, 48.19732863916533],
                            [2.7157350995227, 48.197107265431654],
                            [2.715786098424808, 48.19691376127032],
                            [2.715833277227634, 48.196749045950554],
                            [2.715886078114076, 48.19657493671469],
                            [2.715927866467486, 48.196450187348056],
                            [2.715969984017179, 48.19632775213296],
                            [2.716109811087196, 48.19596399694512],
                            [2.716173237249966, 48.19581361376144],
                            [2.71626314678736, 48.19560828937853],
                            [2.716365119156295, 48.19539752938364],
                            [2.716465923468639, 48.19521015227839],
                            [2.71654689758047, 48.19506870277493],
                            [2.716679693193127, 48.194843450438036],
                            [2.716890919270105, 48.1944965394436],
                            [2.717146900109505, 48.1941417206653],
                            [2.71733551274196, 48.1938862688341],
                            [2.717443455962247, 48.19375461899209],
                            [2.717551417861278, 48.19362566578977],
                            [2.717691371582509, 48.19345883803613],
                            [2.71782073401307, 48.1933145257198],
                            [2.718027451657028, 48.19308452630762],
                            [2.718224992216332, 48.19288603095799],
                            [2.718439918568245, 48.19267488590107],
                            [2.718649537943883, 48.19247365079896],
                            [2.718855265490582, 48.19229131177645],
                            [2.719153278541325, 48.19204211792696],
                            [2.719317668195639, 48.191906677310534],
                            [2.719445979104611, 48.19180193298652],
                            [2.719753522782259, 48.19156889005158],
                            [2.720054532582699, 48.19136104776338],
                            [2.720338131659676, 48.19116315486281],
                            [2.720605825797976, 48.19099588890988],
                            [2.720944378768769, 48.19077442730669],
                            [2.721311060433757, 48.1905384812761],
                            [2.721699144230601, 48.190288074289974],
                            [2.722060522154168, 48.19006293440417],
                            [2.722534251077435, 48.18975827904674],
                            [2.722915592862175, 48.189506991001714],
                            [2.72330901933349, 48.189253862013615],
                            [2.72381756593059, 48.18893199591477],
                            [2.724113287354183, 48.188740346875534],
                            [2.724981746018108, 48.18818254239143],
                            [2.725293540694679, 48.187983641133684],
                            [2.726065572709857, 48.18748011425554],
                            [2.726992930631392, 48.186893316221486],
                            [2.727976333029956, 48.18625326338009],
                            [2.728648185346315, 48.185823417241274],
                            [2.729231419941952, 48.18545129530457],
                            [2.729908422740339, 48.18501461508867],
                            [2.730719437880147, 48.1844817629396],
                            [2.731222053684885, 48.18415167853432],
                            [2.73160428289024, 48.18389576745479],
                            [2.732036222014905, 48.18362778543925],
                            [2.732482235994008, 48.18334071999235],
                            [2.733639771166605, 48.18260148272277],
                            [2.734809003672546, 48.18185555650667],
                            [2.735598311273384, 48.18135010489242],
                            [2.736249842909681, 48.18093685577102],
                        ],
                    },
                },
                246: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.35347134651465, 2.781557164066508],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 8508.41926662,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.738001618532588,
                            48.33623310392106,
                            2.810859344364383,
                            48.37952262366741,
                        ),
                        "coordinates": [
                            [2.796343615000022, 48.37952262366741],
                            [2.797248420496505, 48.37912848649691],
                            [2.79761483674829, 48.37896996051565],
                            [2.797973955717404, 48.37879480928714],
                            [2.798318622920005, 48.37862361973774],
                            [2.799191538939647, 48.37818694211936],
                            [2.802443568430986, 48.37655055536922],
                            [2.804294911566199, 48.37561578312655],
                            [2.80574475336322, 48.37491105799888],
                            [2.806264606124487, 48.374642720774425],
                            [2.806582083677722, 48.374477545049174],
                            [2.806914676593119, 48.37429920195685],
                            [2.807332151212079, 48.37405376634118],
                            [2.807450240781468, 48.37398043539133],
                            [2.807592466140204, 48.37388991820488],
                            [2.808075350904084, 48.37356777126153],
                            [2.808348295682342, 48.37336189343858],
                            [2.808623206099906, 48.37312215320578],
                            [2.808931830165427, 48.372836922046325],
                            [2.80922506782465, 48.372536023384804],
                            [2.809439843906403, 48.372291642711986],
                            [2.809657723410513, 48.37203392250013],
                            [2.80982700663255, 48.37179523043513],
                            [2.809981427449479, 48.37157875622105],
                            [2.810091674810464, 48.37140023700046],
                            [2.810242113841549, 48.371116795283534],
                            [2.810388725538886, 48.37084055635797],
                            [2.810505774582508, 48.37054569146438],
                            [2.810634809330417, 48.37017227795512],
                            [2.810752259113344, 48.369746438204864],
                            [2.810792161091127, 48.36949262452508],
                            [2.810841540066914, 48.36908748817764],
                            [2.810859344364383, 48.36879457836428],
                            [2.810857367365935, 48.36858506020063],
                            [2.810827686932018, 48.36815713970425],
                            [2.810801460987502, 48.36795221970639],
                            [2.810770031941613, 48.36773666067906],
                            [2.810721638996953, 48.36752748657377],
                            [2.810651056614941, 48.36731617889527],
                            [2.810569179592014, 48.36707731999777],
                            [2.81048727966102, 48.366863395763346],
                            [2.810351990738025, 48.36658135533083],
                            [2.810199833984077, 48.36626414411335],
                            [2.8099819127011, 48.36590895217408],
                            [2.809795861568467, 48.365641753494614],
                            [2.809566164376916, 48.36532527774554],
                            [2.809336925867321, 48.36505735923569],
                            [2.809072492316782, 48.36479288960506],
                            [2.808781521299228, 48.36450660856349],
                            [2.80846545793831, 48.36422530734343],
                            [2.808257872629849, 48.36406549923453],
                            [2.808004038285347, 48.363870278762185],
                            [2.807738186184881, 48.36368638238577],
                            [2.807449237970457, 48.36350143390745],
                            [2.807227972902301, 48.36336584467541],
                            [2.80700416916066, 48.363242105176944],
                            [2.806791892142428, 48.36312319377371],
                            [2.806532219331344, 48.36298997692461],
                            [2.806316854235649, 48.36288457742787],
                            [2.806087570308325, 48.3627719041596],
                            [2.805855997703855, 48.36265810567422],
                            [2.805581904502054, 48.362523612492865],
                            [2.805112847548699, 48.36229265106712],
                            [2.804444608587908, 48.36195877838189],
                            [2.802978524232097, 48.36122627750964],
                            [2.802429903403687, 48.36095215868656],
                            [2.80189983959655, 48.36068726402109],
                            [2.801444420001418, 48.36046009010383],
                            [2.800876365653938, 48.36017979634537],
                            [2.798944709176131, 48.359222813979834],
                            [2.797536386048403, 48.35852872378684],
                            [2.796832600873678, 48.35818185013968],
                            [2.796355802254994, 48.35794833965115],
                            [2.795735811807697, 48.35763369984602],
                            [2.794165334961084, 48.35685204569394],
                            [2.78979293037002, 48.35467548339257],
                            [2.787345380185906, 48.3534649848033],
                            [2.784899288019739, 48.352253529213584],
                            [2.782453322301761, 48.351042919056034],
                            [2.780007481545479, 48.34983315613476],
                            [2.779148378851981, 48.34940398307679],
                            [2.777266286282123, 48.34846622437487],
                            [2.775769173882739, 48.34773286722875],
                            [2.775168467063438, 48.34743993340582],
                            [2.774654838264852, 48.34718742553389],
                            [2.774090624224166, 48.34690842440341],
                            [2.773414465180275, 48.34657206824231],
                            [2.772391612913229, 48.346069738584816],
                            [2.771817199743027, 48.345787789019745],
                            [2.771156294979855, 48.34546168402381],
                            [2.770521636538296, 48.34512388678718],
                            [2.770141451961348, 48.34490883254907],
                            [2.769667987775808, 48.3446370323269],
                            [2.769240943266641, 48.34436743129193],
                            [2.768882041358417, 48.34413563667834],
                            [2.768271824744296, 48.34373111313951],
                            [2.767840963248556, 48.34343059188321],
                            [2.767492555918279, 48.34317258079742],
                            [2.76725535831382, 48.342980764255366],
                            [2.766982209478003, 48.34275815341179],
                            [2.766403678144707, 48.34229877768275],
                            [2.765724601045989, 48.341766022681426],
                            [2.765318588691842, 48.34144636280191],
                            [2.765063482441401, 48.34124509340032],
                            [2.764815598978347, 48.34105331254801],
                            [2.76455956609762, 48.34086244164286],
                            [2.764171475269018, 48.34058964016269],
                            [2.763778677600431, 48.34034112629955],
                            [2.763207739784304, 48.33999110208336],
                            [2.762655424206349, 48.33966960600864],
                            [2.762160615341695, 48.33939547531839],
                            [2.761705490616973, 48.33917115809785],
                            [2.761225286394286, 48.338935037461574],
                            [2.760755975484152, 48.33872028596698],
                            [2.760043243520127, 48.33841603436495],
                            [2.759040459312793, 48.3380323509091],
                            [2.758278940060271, 48.33776116412743],
                            [2.757729843734565, 48.337582462456346],
                            [2.757119159292535, 48.33740148971741],
                            [2.756523894664542, 48.3372407394336],
                            [2.755911018252329, 48.33710061432007],
                            [2.755193949527226, 48.33693846357185],
                            [2.754616217746583, 48.336808820271116],
                            [2.754005047174062, 48.33669449508738],
                            [2.753208202397128, 48.33656657584971],
                            [2.752422321989855, 48.33646954044065],
                            [2.751754945500969, 48.33639850510893],
                            [2.75095841426223, 48.33632791515356],
                            [2.750484447768678, 48.33629003128472],
                            [2.749855363300322, 48.3362646919118],
                            [2.74937002803512, 48.33624464777485],
                            [2.748837186785384, 48.33623310392106],
                            [2.747990189927628, 48.336233491807846],
                            [2.746835928354824, 48.3362637659126],
                            [2.746254755349334, 48.33627936198361],
                            [2.745486952961956, 48.3362972192121],
                            [2.744986769326461, 48.33630906395358],
                            [2.744190244502054, 48.33632729178352],
                            [2.743660305068411, 48.33634089125678],
                            [2.74310471746014, 48.33635188385259],
                            [2.740744925188887, 48.33641160247909],
                            [2.738387831447255, 48.33647216267016],
                            [2.738001618532588, 48.336481780613234],
                        ],
                    },
                },
                247: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.24941853311187, 2.6960834155399858],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 4520.41587191,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.68564708993975,
                            48.229549937455864,
                            2.703936052961915,
                            48.26775810993438,
                        ),
                        "coordinates": [
                            [2.68564708993975, 48.26775810993438],
                            [2.685830313827444, 48.26751612159178],
                            [2.686250497479578, 48.26704177353725],
                            [2.686487945864353, 48.266792899007015],
                            [2.686850418277224, 48.266430283037046],
                            [2.687214483540642, 48.2661036297662],
                            [2.687480836498322, 48.2658645046267],
                            [2.688033931048953, 48.265414066435994],
                            [2.689345883702873, 48.264283232575465],
                            [2.689637596632948, 48.264014349152866],
                            [2.690029433103608, 48.26362015719037],
                            [2.690543620710754, 48.26300616803842],
                            [2.690906415917873, 48.2625059557208],
                            [2.691323592449331, 48.261888670656056],
                            [2.691579048548333, 48.261521229425],
                            [2.691771555936461, 48.26124610889578],
                            [2.692007439935492, 48.260858411463346],
                            [2.692231206061809, 48.26046618762296],
                            [2.692425683451772, 48.26005076683954],
                            [2.692555293353361, 48.259716742988594],
                            [2.692701283508169, 48.259223502918275],
                            [2.692781078103009, 48.25889143481272],
                            [2.692811844394738, 48.25867192532545],
                            [2.692870613909288, 48.25803328514041],
                            [2.69290799704218, 48.256656444802864],
                            [2.692930019805266, 48.2563434430829],
                            [2.692952264601215, 48.25606191377403],
                            [2.693008742291233, 48.2556705699214],
                            [2.693069522795977, 48.255417611712566],
                            [2.693160982117407, 48.255074067474915],
                            [2.69334432729476, 48.254551420504626],
                            [2.693508380183719, 48.25416098029063],
                            [2.694330868397965, 48.252612597341724],
                            [2.694564072513331, 48.252176157958786],
                            [2.69486235977706, 48.25161546188483],
                            [2.695429696302523, 48.250549869732986],
                            [2.696274650642705, 48.24895913762218],
                            [2.69778376066048, 48.24611994270639],
                            [2.698149070659552, 48.24543445914578],
                            [2.698776103427554, 48.24426524742434],
                            [2.699068413283547, 48.243728368312304],
                            [2.699348463230589, 48.24320258187557],
                            [2.699603716600194, 48.242725804203346],
                            [2.69988266953105, 48.242206050834255],
                            [2.700214724246778, 48.24158361438647],
                            [2.700490862568579, 48.24104858382148],
                            [2.70082166331228, 48.240417410626456],
                            [2.701259953188705, 48.23962082555225],
                            [2.701428640264105, 48.2393073488037],
                            [2.701573395610863, 48.23903531428073],
                            [2.701635813601244, 48.23891821247668],
                            [2.701702184729609, 48.23878940825473],
                            [2.701772548795654, 48.23864065797963],
                            [2.701837015559999, 48.23849787986672],
                            [2.701913016850792, 48.23831222148008],
                            [2.701977508920031, 48.23814646939549],
                            [2.702033031730077, 48.23800690956407],
                            [2.70208306595699, 48.23785297906438],
                            [2.702135608613895, 48.23767386297008],
                            [2.702181486769021, 48.23750376017419],
                            [2.702216745966819, 48.237354373988694],
                            [2.702265020507399, 48.23714379900299],
                            [2.702295809761331, 48.23693507845354],
                            [2.702326129061472, 48.23666161428319],
                            [2.702356543779326, 48.23638144786916],
                            [2.702384092733924, 48.236117394549645],
                            [2.702412980668557, 48.23583224571354],
                            [2.702433163089409, 48.235646040308936],
                            [2.702456875156807, 48.235389683756416],
                            [2.702505864966412, 48.23490753893102],
                            [2.702535417656313, 48.234528868762276],
                            [2.702566752837356, 48.234210440304516],
                            [2.702595500078212, 48.233906407980136],
                            [2.702630597635736, 48.233550200908084],
                            [2.702654667420769, 48.233343300183705],
                            [2.702675050519214, 48.23318497001422],
                            [2.702695304543422, 48.23300865655287],
                            [2.702723619746322, 48.232830517899515],
                            [2.702752059365686, 48.23266946360359],
                            [2.702789736897144, 48.232483201853505],
                            [2.702824918789129, 48.232323924421344],
                            [2.702871910354836, 48.23213257798207],
                            [2.702921644607597, 48.23192885025211],
                            [2.702987381750284, 48.23171462089179],
                            [2.703082171389999, 48.23142386274446],
                            [2.703171759897397, 48.23115829959109],
                            [2.703274825426444, 48.23089539121442],
                            [2.703332996691143, 48.23075132614692],
                            [2.703377982105059, 48.23064507083379],
                            [2.703431011114985, 48.23053429359786],
                            [2.703476030130194, 48.23043253451096],
                            [2.703483967553372, 48.23041362577977],
                            [2.703543606618239, 48.23028664024834],
                            [2.703624471649865, 48.23011732292088],
                            [2.703693537471563, 48.22999120672108],
                            [2.70376785516964, 48.229847089157154],
                            [2.703883460713511, 48.22964348801119],
                            [2.703936052961915, 48.229549937455864],
                        ],
                    },
                },
                248: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.70493135584528, 2.4957550780486546],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 1905.08113329,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.484245146583624,
                            48.69973243390383,
                            2.506078153203696,
                            48.706922332733605,
                        ),
                        "coordinates": [
                            [2.506078153203696, 48.69973243390383],
                            [2.505745145320041, 48.70008364546341],
                            [2.505458169853371, 48.700389824625006],
                            [2.505268627155721, 48.700583449192436],
                            [2.504923373858342, 48.70093287779881],
                            [2.504690477500286, 48.70116343590352],
                            [2.504349185348173, 48.701481381835514],
                            [2.504033554076357, 48.70175522582166],
                            [2.503735504177569, 48.70200566164785],
                            [2.503426551468336, 48.702247119663234],
                            [2.503139227327695, 48.70245707068949],
                            [2.502870859378354, 48.7026481087932],
                            [2.50259566997229, 48.702831062265126],
                            [2.502294684711937, 48.70302034759522],
                            [2.501955710368601, 48.70322587519803],
                            [2.501596352037629, 48.70343142998489],
                            [2.501257309253161, 48.70361807021821],
                            [2.501013170580755, 48.70374432100351],
                            [2.500592689453328, 48.70395715629899],
                            [2.500187091690275, 48.704151982311856],
                            [2.499770599733922, 48.70433962943603],
                            [2.49933104756179, 48.70453989756031],
                            [2.498850738256552, 48.70474202111995],
                            [2.498272438219328, 48.70499786817003],
                            [2.497756976205028, 48.705199586691556],
                            [2.49728589292057, 48.705365688840196],
                            [2.496777778362628, 48.705524626142605],
                            [2.496357602085642, 48.705657269905046],
                            [2.495905140688834, 48.70581137085952],
                            [2.495457981017143, 48.705938695856666],
                            [2.49485182993184, 48.706093008911125],
                            [2.494230521466974, 48.70622692417664],
                            [2.49378427689202, 48.70632492264173],
                            [2.493216247547589, 48.70644415106452],
                            [2.492855962269108, 48.70651824829253],
                            [2.492530509906904, 48.70657638781094],
                            [2.492034823289559, 48.70665530328682],
                            [2.491681007662905, 48.706709014017626],
                            [2.491323151921987, 48.7067515972716],
                            [2.490713290465763, 48.70681807200212],
                            [2.490015074320439, 48.70687297221346],
                            [2.489429570721313, 48.70690793396414],
                            [2.488857580904597, 48.706919491983996],
                            [2.488077679636427, 48.706922332733605],
                            [2.487486294045567, 48.70690916840046],
                            [2.487095299173275, 48.70689541108302],
                            [2.486634171096035, 48.70687103753567],
                            [2.485930286725826, 48.70681485946992],
                            [2.485358497882252, 48.70675136788186],
                            [2.484584399759925, 48.706656015161144],
                            [2.484245146583624, 48.70661094689584],
                        ],
                    },
                },
                249: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.64156311563495, 2.443869027329093],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1998.50057011,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.435330530181305,
                            48.6344790233052,
                            2.452289891181863,
                            48.64848911258698,
                        ),
                        "coordinates": [
                            [2.452289891181863, 48.6344790233052],
                            [2.451681103319833, 48.634940776615416],
                            [2.451105500623858, 48.63538649641672],
                            [2.450436481872459, 48.635925830271965],
                            [2.449128271529372, 48.63701345012615],
                            [2.44827106084503, 48.63775439492978],
                            [2.44788512584815, 48.63809739496592],
                            [2.445158922275342, 48.64046061314106],
                            [2.444644606820706, 48.64090560603916],
                            [2.443962991703175, 48.64149590822367],
                            [2.442814451492756, 48.64250506829805],
                            [2.440853147029545, 48.644224488059194],
                            [2.439804693941363, 48.64513370726663],
                            [2.439254711060509, 48.64560811971632],
                            [2.438716924818148, 48.64607982095153],
                            [2.437966300895626, 48.64666681685766],
                            [2.437500161555934, 48.64701255129324],
                            [2.436685681736672, 48.647578012595204],
                            [2.436415983488176, 48.6477608016361],
                            [2.436212689466204, 48.64789766959624],
                            [2.435942979185049, 48.648076860349825],
                            [2.435330530181305, 48.64848911258698],
                        ],
                    },
                },
                250: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.66288259424502, 2.4060659015579193],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1654.09119408,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.397532093159732,
                            48.65897542383006,
                            2.415206841330065,
                            48.667915766467786,
                        ),
                        "coordinates": [
                            [2.415206841330065, 48.65897542383006],
                            [2.414246517759854, 48.65933193933753],
                            [2.412986189753982, 48.659804910530205],
                            [2.412317346706541, 48.660052658672925],
                            [2.411873715728293, 48.66022201585047],
                            [2.411276239164904, 48.66044952609203],
                            [2.410404419572812, 48.6607805285088],
                            [2.409205069812482, 48.66122823872121],
                            [2.40802605577232, 48.661673225963604],
                            [2.406963725824713, 48.66209025177723],
                            [2.406599910744927, 48.662233596803134],
                            [2.405979441536889, 48.66249313912472],
                            [2.405567654216158, 48.66266933893477],
                            [2.40509821178462, 48.66288789207854],
                            [2.404638348462997, 48.66310604504687],
                            [2.40402517473554, 48.663424752819054],
                            [2.403486628587555, 48.663721830059835],
                            [2.403079388137052, 48.663957185888385],
                            [2.40271070593255, 48.664171019646034],
                            [2.402150496145624, 48.66452385804356],
                            [2.401767295989742, 48.66476660319272],
                            [2.401319005511117, 48.665063896685275],
                            [2.400537739514079, 48.66561289267194],
                            [2.399973530386303, 48.66604845498859],
                            [2.398478843048005, 48.667185950490904],
                            [2.397532093159732, 48.667915766467786],
                        ],
                    },
                },
                251: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.757009712671305, 2.7075015080368647],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3959.72058976,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.690252782195758,
                            48.746452320704556,
                            2.727229371429766,
                            48.7707789170597,
                        ),
                        "coordinates": [
                            [2.690252782195758, 48.7707789170597],
                            [2.690615889290086, 48.769940835223],
                            [2.690729793084868, 48.76969677569629],
                            [2.690987161491167, 48.76915730509382],
                            [2.691269192052953, 48.76864293667765],
                            [2.691314920614938, 48.76856905329303],
                            [2.691530277414749, 48.76824464089754],
                            [2.69157602332934, 48.768173455628805],
                            [2.691873815347791, 48.767772346862145],
                            [2.692236551196859, 48.76732247367335],
                            [2.69229198639094, 48.76727463895363],
                            [2.692705248860715, 48.7668524842858],
                            [2.692898498261289, 48.7666729233405],
                            [2.693993282060074, 48.76568028549119],
                            [2.695088021496021, 48.764687637641586],
                            [2.69618272358617, 48.76369587831255],
                            [2.69649084331991, 48.76341522988909],
                            [2.696942132116895, 48.76299383857648],
                            [2.697536815646411, 48.762464078978034],
                            [2.698996254566406, 48.76113840251165],
                            [2.700456974319795, 48.759812701986746],
                            [2.701917625946819, 48.758488779995126],
                            [2.702451266301405, 48.7579960591422],
                            [2.703093193347397, 48.75743374270838],
                            [2.703319830647944, 48.75724425780272],
                            [2.703527153059137, 48.757075330793334],
                            [2.703744879687559, 48.75690556398346],
                            [2.703986718807794, 48.756724265870304],
                            [2.704204698832289, 48.7565747966186],
                            [2.704751744428931, 48.756221558238586],
                            [2.705086281766097, 48.75603162778799],
                            [2.705404615425643, 48.755857935676644],
                            [2.705800548050763, 48.755652209918416],
                            [2.706191859543786, 48.755458801428034],
                            [2.706576874852881, 48.75529118466451],
                            [2.70705152784528, 48.755107088157935],
                            [2.707453031954326, 48.75496279644915],
                            [2.708363377923608, 48.75466126871188],
                            [2.709056379573694, 48.754449502551324],
                            [2.709725747885977, 48.754244944818076],
                            [2.710680741315084, 48.75395035050859],
                            [2.711716287896599, 48.75362959572182],
                            [2.713496581181229, 48.75309404421522],
                            [2.715565775504662, 48.75246128074907],
                            [2.716406965317591, 48.752198587876734],
                            [2.717297001441261, 48.751922235623766],
                            [2.718108350606253, 48.751672219965215],
                            [2.71881928607652, 48.75145221041933],
                            [2.719348398848898, 48.7512867656579],
                            [2.719609977247488, 48.75120582612548],
                            [2.719857075515036, 48.751116889565886],
                            [2.72018120294589, 48.75099979169586],
                            [2.720501551324978, 48.75087948398938],
                            [2.720804721319064, 48.75075863158059],
                            [2.721076045181154, 48.750646954448484],
                            [2.72135792661464, 48.750519204572996],
                            [2.721623528244793, 48.75039690337546],
                            [2.721928336372062, 48.75024479376514],
                            [2.722214041839074, 48.750084653951056],
                            [2.722469946732394, 48.74993990235693],
                            [2.722935606420231, 48.74966224448177],
                            [2.723204908727744, 48.749492265079994],
                            [2.724063811154212, 48.74889582039618],
                            [2.724361236708088, 48.74867088623932],
                            [2.725539857056865, 48.747748700286664],
                            [2.725819641427011, 48.747530117477375],
                            [2.726244071081227, 48.74720222723106],
                            [2.727229371429766, 48.746452320704556],
                        ],
                    },
                },
                252: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.70493135584528, 2.4957550780486546],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1905.08113329,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.484245146583624,
                            48.69973243390383,
                            2.506078153203696,
                            48.706922332733605,
                        ),
                        "coordinates": [
                            [2.506078153203696, 48.69973243390383],
                            [2.505745145320041, 48.70008364546341],
                            [2.505458169853371, 48.700389824625006],
                            [2.505268627155721, 48.700583449192436],
                            [2.504923373858342, 48.70093287779881],
                            [2.504690477500286, 48.70116343590352],
                            [2.504349185348173, 48.701481381835514],
                            [2.504033554076357, 48.70175522582166],
                            [2.503735504177569, 48.70200566164785],
                            [2.503426551468336, 48.702247119663234],
                            [2.503139227327695, 48.70245707068949],
                            [2.502870859378354, 48.7026481087932],
                            [2.50259566997229, 48.702831062265126],
                            [2.502294684711937, 48.70302034759522],
                            [2.501955710368601, 48.70322587519803],
                            [2.501596352037629, 48.70343142998489],
                            [2.501257309253161, 48.70361807021821],
                            [2.501013170580755, 48.70374432100351],
                            [2.500592689453328, 48.70395715629899],
                            [2.500187091690275, 48.704151982311856],
                            [2.499770599733922, 48.70433962943603],
                            [2.49933104756179, 48.70453989756031],
                            [2.498850738256552, 48.70474202111995],
                            [2.498272438219328, 48.70499786817003],
                            [2.497756976205028, 48.705199586691556],
                            [2.49728589292057, 48.705365688840196],
                            [2.496777778362628, 48.705524626142605],
                            [2.496357602085642, 48.705657269905046],
                            [2.495905140688834, 48.70581137085952],
                            [2.495457981017143, 48.705938695856666],
                            [2.49485182993184, 48.706093008911125],
                            [2.494230521466974, 48.70622692417664],
                            [2.49378427689202, 48.70632492264173],
                            [2.493216247547589, 48.70644415106452],
                            [2.492855962269108, 48.70651824829253],
                            [2.492530509906904, 48.70657638781094],
                            [2.492034823289559, 48.70665530328682],
                            [2.491681007662905, 48.706709014017626],
                            [2.491323151921987, 48.7067515972716],
                            [2.490713290465763, 48.70681807200212],
                            [2.490015074320439, 48.70687297221346],
                            [2.489429570721313, 48.70690793396414],
                            [2.488857580904597, 48.706919491983996],
                            [2.488077679636427, 48.706922332733605],
                            [2.487486294045567, 48.70690916840046],
                            [2.487095299173275, 48.70689541108302],
                            [2.486634171096035, 48.70687103753567],
                            [2.485930286725826, 48.70681485946992],
                            [2.485358497882252, 48.70675136788186],
                            [2.484584399759925, 48.706656015161144],
                            [2.484245146583624, 48.70661094689584],
                        ],
                    },
                },
                253: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.87694261400015, 2.326558753794329],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 584.53788808,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.324818285061554,
                            48.87535495768347,
                            2.327022200889503,
                            48.879634760656806,
                        ),
                        "coordinates": [
                            [2.324818285061554, 48.87535495768347],
                            [2.325293331338629, 48.875411788011455],
                            [2.326324808310137, 48.87553517769411],
                            [2.326379199510944, 48.87555363602167],
                            [2.326468861339373, 48.87559065186876],
                            [2.326552051566614, 48.87563374583918],
                            [2.326627826227669, 48.87568242789238],
                            [2.326695328050678, 48.8757361455231],
                            [2.326753790430257, 48.87579429277598],
                            [2.326802549697991, 48.875856210314105],
                            [2.326841055937404, 48.875921192673594],
                            [2.326868874069634, 48.87598850985313],
                            [2.326885686756051, 48.87605739383987],
                            [2.326890919304396, 48.87610879883007],
                            [2.327022200889503, 48.879634760656806],
                        ],
                    },
                },
                254: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.894403203861, 2.41931158427487],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 914.32307849,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.41331313951059,
                            48.89325758997389,
                            2.425326890166255,
                            48.89545467305271,
                        ),
                        "coordinates": [
                            [2.41331313951059, 48.89325758997389],
                            [2.418947631999226, 48.894366477528905],
                            [2.422310142254823, 48.89497543922746],
                            [2.425326890166255, 48.89545467305271],
                        ],
                    },
                },
                255: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.88282982048951, 2.367472698999317],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 445.42752276,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.365544320525031,
                            48.88128581276483,
                            2.36939198436133,
                            48.884385145353036,
                        ),
                        "coordinates": [
                            [2.365544320525031, 48.88128581276483],
                            [2.36592103710407, 48.88158425100825],
                            [2.367114629859325, 48.88253230447147],
                            [2.368912703299249, 48.88399522136558],
                            [2.36939198436133, 48.884385145353036],
                        ],
                    },
                },
                256: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.88617033035414, 2.38331247510228],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 576.135076209,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.379662256377633,
                            48.88521596739824,
                            2.386960017135177,
                            48.887134869076554,
                        ),
                        "coordinates": [
                            [2.379662256377633, 48.88521596739824],
                            [2.381006143553434, 48.88556547379944],
                            [2.383437652705293, 48.88619778728127],
                            [2.385563640012006, 48.88676339743525],
                            [2.386960017135177, 48.887134869076554],
                        ],
                    },
                },
                257: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.86906289618113, 2.3626131609868954],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 449.435107647,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.361027462783641,
                            48.867384472882776,
                            2.364264950425284,
                            48.87080998359611,
                        ),
                        "coordinates": [
                            [2.364264950425284, 48.867384472882776],
                            [2.363837177784976, 48.86774487638099],
                            [2.363589117932534, 48.867953866740386],
                            [2.362856906552137, 48.86877922890426],
                            [2.361027462783641, 48.87080998359611],
                        ],
                    },
                },
                258: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.89510157521263, 2.3281863912809935],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 517.554273331,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.327428458503176,
                            48.89282885338917,
                            2.328942812768303,
                            48.89737479642876,
                        ),
                        "coordinates": [
                            [2.327428458503176, 48.89282885338917],
                            [2.328680046101814, 48.896581556626664],
                            [2.328845890670691, 48.89707877263906],
                            [2.328942812768303, 48.89737479642876],
                        ],
                    },
                },
                259: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.87538136220229, 2.3421632582776266],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 309.355557069,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.34019988438517,
                            48.87487434337737,
                            2.344126030464426,
                            48.87589068189371,
                        ),
                        "coordinates": [
                            [2.34019988438517, 48.87487434337737],
                            [2.340531958908012, 48.87496021364314],
                            [2.341319807738747, 48.875163937116845],
                            [2.343500449317359, 48.875725673466356],
                            [2.344126030464426, 48.87589068189371],
                        ],
                    },
                },
                260: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.85779980077802, 2.3449703541088893],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 434.997478025,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.342232759368107,
                            48.8570599654128,
                            2.347711884033997,
                            48.85855382636668,
                        ),
                        "coordinates": [
                            [2.347711884033997, 48.8570599654128],
                            [2.343413461047747, 48.858216649742396],
                            [2.342232759368107, 48.85855382636668],
                        ],
                    },
                },
                261: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.873309198340465, 2.295648549148282],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 441.713163451,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.293865549369417,
                            48.87211245133871,
                            2.296653222576586,
                            48.874748650679905,
                        ),
                        "coordinates": [
                            [2.295560256213147, 48.874748650679905],
                            [2.295684357524058, 48.87471825829944],
                            [2.295736247013006, 48.874702174885265],
                            [2.295804163738747, 48.87468112423754],
                            [2.295918841030819, 48.87463750531065],
                            [2.296027582155779, 48.87458770975673],
                            [2.296129625659995, 48.87453208835389],
                            [2.296224254602805, 48.87447102811723],
                            [2.296310806015481, 48.874404958648995],
                            [2.296388672361222, 48.87433434495202],
                            [2.29645730844907, 48.87425968027497],
                            [2.296516231384214, 48.87418148970874],
                            [2.296565027517606, 48.87410032033417],
                            [2.296603355159062, 48.87401674213666],
                            [2.296630946036221, 48.87393134081984],
                            [2.296647608019744, 48.87384471782092],
                            [2.296653222576586, 48.87375747680572],
                            [2.296647750100711, 48.873670232693],
                            [2.296631228728992, 48.87358359815739],
                            [2.296603775764084, 48.87349817914129],
                            [2.296565584981976, 48.87341457214079],
                            [2.296516921092417, 48.87333337046919],
                            [2.296458126929655, 48.873255136419765],
                            [2.296389614968223, 48.87318042369987],
                            [2.29631186489883, 48.873109754933694],
                            [2.296225424941758, 48.87304362526791],
                            [2.296130899650384, 48.87298249690443],
                            [2.296028949861675, 48.87292680269821],
                            [2.295920295641925, 48.872876929986916],
                            [2.295805694340825, 48.872833230355184],
                            [2.295685953020096, 48.87279600801696],
                            [2.29556190788367, 48.872765528688404],
                            [2.295434432713557, 48.872742000751735],
                            [2.295304420942897, 48.87272559043898],
                            [2.295240190999165, 48.87272019485073],
                            [2.295149424995051, 48.87271225161921],
                            [2.295012351412986, 48.87269421206278],
                            [2.294877844944891, 48.87266913661609],
                            [2.294746733900644, 48.87263717496165],
                            [2.294619830918895, 48.872598526156864],
                            [2.294497918103068, 48.87255342865322],
                            [2.294381744282323, 48.872502161179106],
                            [2.29427202370764, 48.872445038235085],
                            [2.294169437366277, 48.87238241369824],
                            [2.294074618094421, 48.872314672639995],
                            [2.293988147863748, 48.87224223041014],
                            [2.293910557707625, 48.872165538031766],
                            [2.293865549369417, 48.87211245133871],
                        ],
                    },
                },
                262: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.89874299462674, 2.309819846152576],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 1165.85127956,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.305924149869319,
                            48.89425226223872,
                            2.313772157405782,
                            48.903330094573725,
                        ),
                        "coordinates": [
                            [2.313772157405782, 48.89425226223872],
                            [2.313589057556231, 48.89435820365737],
                            [2.313436436311079, 48.89446065478795],
                            [2.313246620068564, 48.894597228607815],
                            [2.313065029767362, 48.89473858154394],
                            [2.312891939699884, 48.8948844975692],
                            [2.312727617432861, 48.895034754322516],
                            [2.312572308769264, 48.895189125720115],
                            [2.312426251505231, 48.895347373041],
                            [2.312289668444325, 48.89550925747729],
                            [2.312162768879632, 48.89567453114898],
                            [2.312045743042644, 48.89584294426663],
                            [2.312029806497556, 48.89586730261096],
                            [2.309771643004175, 48.89897215903452],
                            [2.309670914371376, 48.89910397465297],
                            [2.309560496655108, 48.899232373555904],
                            [2.309455203960209, 48.8993426131402],
                            [2.308132481113233, 48.90088071408153],
                            [2.3062633463325, 48.90295389034843],
                            [2.305924149869319, 48.903330094573725],
                        ],
                    },
                },
                263: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.84654843545747, 2.397203909781934],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 380.592082056,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.39546199483274,
                            48.84524823225362,
                            2.398743260868829,
                            48.84739741738337,
                        ),
                        "coordinates": [
                            [2.39546199483274, 48.84737487872934],
                            [2.395591706502862, 48.84735685898831],
                            [2.395723233632713, 48.84734596846767],
                            [2.395855670557687, 48.84734228442935],
                            [2.395988116318066, 48.847345831100924],
                            [2.396119669154599, 48.847356584144585],
                            [2.396208906107145, 48.8473680876019],
                            [2.396354600898634, 48.847384023688086],
                            [2.396536007113115, 48.84739741738337],
                            [2.396683311339714, 48.847377106403385],
                            [2.396799902200929, 48.84731191728837],
                            [2.396879010731893, 48.847235437474986],
                            [2.39710943542564, 48.846938764921845],
                            [2.397390850120347, 48.846554385471],
                            [2.39792473576165, 48.84580812436958],
                            [2.398169557219284, 48.8454552375112],
                            [2.398274205531995, 48.84537881230064],
                            [2.398418053345941, 48.845322600184986],
                            [2.398533825327414, 48.845288814290534],
                            [2.398743260868829, 48.84524823225362],
                        ],
                    },
                },
                264: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.843439482549954, 2.401579993960619],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 466.551932894,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.400918536779803,
                            48.84133824913212,
                            2.402106392197892,
                            48.8450615799449,
                        ),
                        "coordinates": [
                            [2.400918536779803, 48.84133824913212],
                            [2.401719191833961, 48.84349713988023],
                            [2.402100865047475, 48.84468019760412],
                            [2.402106392197892, 48.844727197707456],
                            [2.402100988384617, 48.84477420433508],
                            [2.402084773888216, 48.84482011367741],
                            [2.402058131611846, 48.844863853812775],
                            [2.402021686511092, 48.84490439629691],
                            [2.401976288854629, 48.84494079025535],
                            [2.401923009869594, 48.84497218574604],
                            [2.401863089841795, 48.84499784429304],
                            [2.401797941883609, 48.84501716678673],
                            [2.401729086478148, 48.84502969765407],
                            [2.40168892252062, 48.84503367340395],
                            [2.401653388217296, 48.845036152383685],
                            [2.401289019827348, 48.8450615799449],
                        ],
                    },
                },
                265: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.879374457877866, 2.2774254551607687],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 933.918654833,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.27168672106356,
                            48.87755125180425,
                            2.283162242230229,
                            48.881191519686794,
                        ),
                        "coordinates": [
                            [2.283162242230229, 48.87755125180425],
                            [2.279368629446899, 48.87875889506898],
                            [2.27653279622191, 48.87966213080884],
                            [2.273129673482071, 48.88073385765323],
                            [2.27168672106356, 48.881191519686794],
                        ],
                    },
                },
                266: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.89037730706653, 2.2425729979280087],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 876.67053742,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.237213560544146,
                            48.88863121867044,
                            2.247932435311872,
                            48.89212339546262,
                        ),
                        "coordinates": [
                            [2.247932435311872, 48.88863121867044],
                            [2.237213560544146, 48.89212339546262],
                        ],
                    },
                },
                267: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.83847207244316, 2.2988414749755055],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 411.302642048,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.296630340533544,
                            48.83730749276759,
                            2.301107516242396,
                            48.839516585402485,
                        ),
                        "coordinates": [
                            [2.296630340533544, 48.83730749276759],
                            [2.297116684049467, 48.83759074882079],
                            [2.299093113492022, 48.83862409415317],
                            [2.30035287879313, 48.83925558279368],
                            [2.301107516242396, 48.839516585402485],
                        ],
                    },
                },
                268: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.870923002836115, 2.3040178612559825],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 563.605773834,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.300560451236721,
                            48.86980822019896,
                            2.30747079344783,
                            48.87202381039972,
                        ),
                        "coordinates": [
                            [2.30747079344783, 48.86980822019896],
                            [2.303862265065382, 48.87098059537908],
                            [2.300560451236721, 48.87202381039972],
                        ],
                    },
                },
                269: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.87414788928573, 2.3172605699319284],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 401.277475315,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.314606322970783,
                            48.8737095286447,
                            2.319916077554934,
                            48.87457851276328,
                        ),
                        "coordinates": [
                            [2.314606322970783, 48.8737095286447],
                            [2.317179889881644, 48.874138268769755],
                            [2.319862488002735, 48.87457064394481],
                            [2.319916077554934, 48.87457851276328],
                        ],
                    },
                },
                270: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.840479541981814, 2.3217382913645253],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 425.571137717,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.320984834266813,
                            48.83863164623715,
                            2.322491748462238,
                            48.84232743772648,
                        ),
                        "coordinates": [
                            [2.322491748462238, 48.83863164623715],
                            [2.320984834266813, 48.84232743772648],
                        ],
                    },
                },
                271: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.86077803614268, 2.339725468211772],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 733.319297941,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.3368784003342,
                            48.85855382636668,
                            2.342232759368107,
                            48.862829671905764,
                        ),
                        "coordinates": [
                            [2.342232759368107, 48.85855382636668],
                            [2.341832163799114, 48.85862457726988],
                            [2.34103226304976, 48.85876584563426],
                            [2.340859281517207, 48.85879119895627],
                            [2.340713361652457, 48.85881830286677],
                            [2.340647344605805, 48.85883310398548],
                            [2.340585513633742, 48.85884884547226],
                            [2.340527487213716, 48.8588656259583],
                            [2.340473017682458, 48.858883521428275],
                            [2.340387142832219, 48.858917071437396],
                            [2.340311466224829, 48.858954032181586],
                            [2.340245601012422, 48.85899460030338],
                            [2.340216216598436, 48.85901630959788],
                            [2.340189137984752, 48.85903901638696],
                            [2.340164365309804, 48.85906270988068],
                            [2.34014178839254, 48.85908748030729],
                            [2.340103040507446, 48.85914047130447],
                            [2.340072535167987, 48.85919847575265],
                            [2.340049888446126, 48.8592622137181],
                            [2.340037226455193, 48.85931781995743],
                            [2.340029176030893, 48.85937844032047],
                            [2.340025603516529, 48.85944505076422],
                            [2.340026398891464, 48.85951955910177],
                            [2.340036088115457, 48.859655707559504],
                            [2.340076341913599, 48.86003686079728],
                            [2.340083859748981, 48.86014946753324],
                            [2.340087086619343, 48.86025444839501],
                            [2.340089755475065, 48.86035280066354],
                            [2.340095760060391, 48.86046188436505],
                            [2.340136174091215, 48.860941639191225],
                            [2.340143202222332, 48.86105214315075],
                            [2.340146814915093, 48.86114949058213],
                            [2.340146729331563, 48.86126063880149],
                            [2.340141408650519, 48.86136131580957],
                            [2.34013074387823, 48.8614536677523],
                            [2.340114601757877, 48.86153874343512],
                            [2.340088374031998, 48.861630617428304],
                            [2.340072264013437, 48.86167344189196],
                            [2.340054120623814, 48.86171430175468],
                            [2.34003390477438, 48.86175326964738],
                            [2.340011595482806, 48.861790387722884],
                            [2.339987166280605, 48.86182570080163],
                            [2.339960586679347, 48.86185924828566],
                            [2.339931793012368, 48.861891106267144],
                            [2.339900791026251, 48.861921251393305],
                            [2.339867559933973, 48.861949710528314],
                            [2.339832077653898, 48.861976505133015],
                            [2.339794311223695, 48.862001654809326],
                            [2.339754240016548, 48.86202517383095],
                            [2.339711840725779, 48.86204707285928],
                            [2.33966709682559, 48.86206736529099],
                            [2.339053978272387, 48.86223218933813],
                            [2.337657422412862, 48.86262176234318],
                            [2.3368784003342, 48.862829671905764],
                        ],
                    },
                },
                272: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.80044417211203, 2.3658812115212906],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 984.935653132,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.363953196602166,
                            48.79648308455052,
                            2.368269540049694,
                            48.804688120911365,
                        ),
                        "coordinates": [
                            [2.368269540049694, 48.79648308455052],
                            [2.367818552909852, 48.79769759093878],
                            [2.367797543931022, 48.79776824886],
                            [2.367748560173459, 48.7979044579314],
                            [2.367688940394623, 48.798038800214265],
                            [2.367618845376485, 48.79817092128281],
                            [2.367538467315478, 48.79830045878061],
                            [2.367448014576556, 48.798427064825106],
                            [2.367347740379815, 48.79855039806498],
                            [2.367237910074812, 48.79867012800452],
                            [2.367118818882496, 48.798785931499864],
                            [2.366990793245777, 48.79889749366623],
                            [2.366854167600135, 48.79900451495023],
                            [2.366709323885502, 48.79910670864135],
                            [2.366556639859319, 48.79920379700095],
                            [2.366434761105431, 48.79927448479919],
                            [2.366315182552787, 48.79934037739517],
                            [2.366178735487767, 48.79942419981262],
                            [2.366049969326111, 48.79951316598058],
                            [2.3659293261852, 48.799606968875906],
                            [2.365817226575126, 48.79970528787012],
                            [2.36571405580699, 48.799807786858025],
                            [2.365620166802866, 48.79991410707703],
                            [2.365535881259427, 48.80002388330209],
                            [2.365461497892375, 48.8001367375933],
                            [2.365397265175413, 48.800252281849104],
                            [2.36534340719454, 48.80037011884256],
                            [2.365300111438037, 48.80048983855874],
                            [2.365273597947147, 48.8005849706705],
                            [2.365093589373717, 48.8011011485958],
                            [2.363953196602166, 48.804688120911365],
                        ],
                    },
                },
                273: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.885900539745144, 2.295265424082023],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 467.90913174,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.292582314102913,
                            48.88489625515051,
                            2.297724346480178,
                            48.88643422513658,
                        ),
                        "coordinates": [
                            [2.297724346480178, 48.88489625515051],
                            [2.297590973087868, 48.88493710201711],
                            [2.297462666020006, 48.884984485139704],
                            [2.297362300724286, 48.885028422180405],
                            [2.297340159868234, 48.88503813095111],
                            [2.297224155581167, 48.88509773331267],
                            [2.297115317774676, 48.88516295080013],
                            [2.297014271956193, 48.885233410284094],
                            [2.296921594992621, 48.88530870597412],
                            [2.296864982662386, 48.885361126608],
                            [2.296822336471179, 48.885402793172474],
                            [2.295994911368492, 48.88621115709437],
                            [2.295990181617722, 48.88621572487351],
                            [2.295932954612715, 48.886263840812546],
                            [2.295867352342744, 48.886307057369194],
                            [2.295794328397302, 48.88634474341146],
                            [2.295714948449354, 48.88637635030658],
                            [2.295630371104325, 48.88640141630606],
                            [2.295541827309675, 48.88641957631793],
                            [2.295450612111607, 48.886430566355656],
                            [2.295358050537332, 48.88643422513658],
                            [2.295265496156075, 48.88643049946976],
                            [2.295174298361893, 48.886419443164264],
                            [2.295085785970699, 48.88640121963055],
                            [2.295075337918444, 48.88639854375891],
                            [2.293038100155434, 48.885878232887855],
                            [2.292920214123138, 48.885850546879354],
                            [2.292746155502705, 48.8858167615317],
                            [2.292582314102913, 48.885793105231],
                        ],
                    },
                },
                274: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86621893950875, 2.369424549741028],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 784.949139368,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.364247993752544,
                            48.865253786054325,
                            2.374581969996412,
                            48.867026787567816,
                        ),
                        "coordinates": [
                            [2.374581969996412, 48.865253786054325],
                            [2.369867142474703, 48.86614334716742],
                            [2.366230261716831, 48.8668404346885],
                            [2.366179375141637, 48.8668500525819],
                            [2.365909043246572, 48.86689666531324],
                            [2.365636143780071, 48.86693623996862],
                            [2.365361100178649, 48.86696871582198],
                            [2.36513509391751, 48.86698939729227],
                            [2.365084335762661, 48.86699404204314],
                            [2.364806276439408, 48.867012179510695],
                            [2.364527353428442, 48.86702310082661],
                            [2.364247993752544, 48.867026787567816],
                        ],
                    },
                },
                275: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.85257045880614, 2.3596653684491873],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 445.273177178,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.357162571618337,
                            48.851237611581645,
                            2.361985224973328,
                            48.853575472503586,
                        ),
                        "coordinates": [
                            [2.361985224973328, 48.851237611581645],
                            [2.361824483480007, 48.85137095782408],
                            [2.361174347094301, 48.851910283839565],
                            [2.361146723827081, 48.851932891811266],
                            [2.361021223395744, 48.85202853528635],
                            [2.360887653220146, 48.85211929519692],
                            [2.360746446239272, 48.852204873446],
                            [2.360598067843209, 48.85228499369495],
                            [2.360442996916304, 48.852359391369866],
                            [2.360281743387051, 48.85242782724592],
                            [2.360191329675816, 48.85246257420109],
                            [2.358658619838349, 48.85303069782985],
                            [2.357162571618337, 48.853575472503586],
                        ],
                    },
                },
                276: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.87991296670626, 2.363862077282852],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 391.374105387,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362160071922951,
                            48.878565625799595,
                            2.365544320525031,
                            48.88128581276483,
                        ),
                        "coordinates": [
                            [2.362160071922951, 48.878565625799595],
                            [2.362897328263224, 48.8791097885117],
                            [2.3648008369011, 48.88068197491969],
                            [2.365226211039481, 48.88103329171651],
                            [2.365544320525031, 48.88128581276483],
                        ],
                    },
                },
                277: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86360367781299, 2.383339985613323],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 388.094337842,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.380797986172988,
                            48.86312321464207,
                            2.385882449326147,
                            48.86408657565025,
                        ),
                        "coordinates": [
                            [2.385882449326147, 48.86312321464207],
                            [2.383096662483467, 48.863647442438825],
                            [2.381488843909462, 48.863956977886936],
                            [2.380797986172988, 48.86408657565025],
                        ],
                    },
                },
                278: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86682883508955, 2.349793112471881],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 350.903248174,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347516213290017,
                            48.86634029838925,
                            2.352068318061256,
                            48.86730947407226,
                        ),
                        "coordinates": [
                            [2.352068318061256, 48.86634029838925],
                            [2.3519614371042, 48.86636366744032],
                            [2.350626840064542, 48.86665545734059],
                            [2.347516213290017, 48.86730947407226],
                        ],
                    },
                },
                279: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.939183252148254, 2.2613697346186448],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1859.15320244,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25789748402742,
                            48.93105422781371,
                            2.263184304511326,
                            48.946796942080006,
                        ),
                        "coordinates": [
                            [2.260602314246561, 48.93105422781371],
                            [2.261339992940939, 48.93277735871654],
                            [2.26192845562579, 48.934095897822615],
                            [2.262165980863144, 48.93464568021208],
                            [2.26278593547287, 48.93607741003118],
                            [2.26287225768476, 48.93631539973921],
                            [2.262987382623659, 48.93661527153104],
                            [2.263087913842962, 48.93701506388585],
                            [2.263138048210378, 48.937302996881705],
                            [2.263177395067224, 48.93755999071292],
                            [2.263184304511326, 48.93777175654649],
                            [2.263183753703794, 48.93814293283929],
                            [2.263157862879139, 48.93855216237681],
                            [2.263103227020259, 48.93886144123741],
                            [2.263059574229614, 48.939070795209915],
                            [2.262990553880533, 48.93933723668828],
                            [2.262856372097004, 48.93970237840287],
                            [2.262769314320712, 48.93995096295791],
                            [2.262627994339127, 48.94025780692889],
                            [2.262526554468291, 48.94046236424788],
                            [2.262345516519471, 48.94075728519014],
                            [2.262019734947993, 48.941226992058596],
                            [2.261791735517665, 48.941521880947555],
                            [2.261553780255332, 48.941821366327915],
                            [2.259935982944806, 48.94390459301893],
                            [2.25924098169465, 48.944843962964256],
                            [2.258465163835001, 48.946054674714276],
                            [2.25789748402742, 48.946796942080006],
                        ],
                    },
                },
                280: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.00994974561732, 2.3654523489543666],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 3147.41079582,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362222981011115,
                            48.996006830493926,
                            2.368960279608916,
                            49.02320637806201,
                        ),
                        "coordinates": [
                            [2.368684562796334, 48.996006830493926],
                            [2.368771154667153, 48.99632756433704],
                            [2.368843693123019, 48.99666778872084],
                            [2.368898142460405, 48.99699374320308],
                            [2.368930901007874, 48.997324462727505],
                            [2.368960059428528, 48.99768135605111],
                            [2.368960279608916, 48.99802160156042],
                            [2.368949687302651, 48.998421333643044],
                            [2.368902936805866, 48.99882345442325],
                            [2.368852510363171, 48.99913278291407],
                            [2.368791217750417, 48.99941594227207],
                            [2.368722696600605, 48.99970861962811],
                            [2.368639712300396, 49.000001301709375],
                            [2.368538656135477, 49.00031302329015],
                            [2.368412313272612, 49.00066758043242],
                            [2.368249828840886, 49.001060216502275],
                            [2.36412890002287, 49.010654771111795],
                            [2.363460589499867, 49.01221101549923],
                            [2.363290809425421, 49.01263219836392],
                            [2.363160796637514, 49.01301768146685],
                            [2.363085002178378, 49.013331771585726],
                            [2.363023687387352, 49.01366965171829],
                            [2.362998514654563, 49.0139504189681],
                            [2.362991432013492, 49.014238321221946],
                            [2.362998804517702, 49.014500046513504],
                            [2.363035138474289, 49.01480459333183],
                            [2.363085922331879, 49.01507106738294],
                            [2.363169289456207, 49.01538988053047],
                            [2.363285226207473, 49.01573009859627],
                            [2.363915566816413, 49.01740738456985],
                            [2.364303204260612, 49.018428028891734],
                            [2.364462631451012, 49.01888244423293],
                            [2.364542373667896, 49.01916080731666],
                            [2.364593197039238, 49.01947486799246],
                            [2.364607814609137, 49.01973897083355],
                            [2.36459712902502, 49.020036390445995],
                            [2.364553882734649, 49.02033381748194],
                            [2.364478092166131, 49.020659805616184],
                            [2.364366119038977, 49.02097866462008],
                            [2.364232419228614, 49.021264216636695],
                            [2.364069770580538, 49.02154025969524],
                            [2.363874564248708, 49.02182344596416],
                            [2.363628708202079, 49.022111404382365],
                            [2.363343050975764, 49.02239699127758],
                            [2.363057366734686, 49.022637370318186],
                            [2.362847615767337, 49.02280159274873],
                            [2.362511274457447, 49.02303960192606],
                            [2.362222981011115, 49.02320637806201],
                        ],
                    },
                },
                281: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.842682785835095, 2.2142923298018626],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 879.10906998,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.209938360929272,
                            48.840517349814164,
                            2.217621080890435,
                            48.84610294864101,
                        ),
                        "coordinates": [
                            [2.209938360929272, 48.840517349814164],
                            [2.210369963359886, 48.84062484324707],
                            [2.210910388399633, 48.840799900212666],
                            [2.211448117694085, 48.84096505994188],
                            [2.211964048644623, 48.841131092604876],
                            [2.212515301473346, 48.841339426628714],
                            [2.212931767902024, 48.8415116417676],
                            [2.213274713370565, 48.84166578998299],
                            [2.213608080542133, 48.84183701275158],
                            [2.214042094223859, 48.84207938634378],
                            [2.214315572488567, 48.842229858850146],
                            [2.2145223451432, 48.84235867732259],
                            [2.21476992311889, 48.842515416406734],
                            [2.21517932328762, 48.84279912581654],
                            [2.215195643880415, 48.84281083394447],
                            [2.215304436685793, 48.8428936831713],
                            [2.215765438986725, 48.84325028697513],
                            [2.215852453308995, 48.8433259183952],
                            [2.215920424297969, 48.843388040419285],
                            [2.215953051889635, 48.84341775109632],
                            [2.216174630285588, 48.84362481930477],
                            [2.216352616663704, 48.84383004288921],
                            [2.216575272870219, 48.84415671534174],
                            [2.21659292824429, 48.84418011488495],
                            [2.21660921328541, 48.84420711014718],
                            [2.216874011227362, 48.84457429409696],
                            [2.216990738966391, 48.84475966741812],
                            [2.217167121783925, 48.845068304405196],
                            [2.217190197201333, 48.8451042999668],
                            [2.217312265517721, 48.845336441099015],
                            [2.217397645592972, 48.84552717770745],
                            [2.217423398941245, 48.84558295986443],
                            [2.217443706978748, 48.845636937325274],
                            [2.217621080890435, 48.84610294864101],
                        ],
                    },
                },
                282: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.06552067854783, 2.13588724561283],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1279.48780983,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.13087413699018,
                            49.06059168305009,
                            2.141696932779959,
                            49.06931413549863,
                        ),
                        "coordinates": [
                            [2.13087413699018, 49.06059168305009],
                            [2.131207137954742, 49.0608580302238],
                            [2.131565206928057, 49.06117616736091],
                            [2.132278407878558, 49.061896716213184],
                            [2.132609946293323, 49.06227800164913],
                            [2.132746809746462, 49.062454316054904],
                            [2.132880023166548, 49.06263776157711],
                            [2.133070945750251, 49.062876034902864],
                            [2.133708530825932, 49.06368138396556],
                            [2.13394625988483, 49.06398635946666],
                            [2.13411554609956, 49.06420555832268],
                            [2.134428911716054, 49.06461059938328],
                            [2.13479658586036, 49.06501811482306],
                            [2.1350978641201, 49.06535061371402],
                            [2.13539857733161, 49.065685388917764],
                            [2.135842281765689, 49.066100172749735],
                            [2.136477439580163, 49.06663187674777],
                            [2.136665138389196, 49.066779723669],
                            [2.136935885407915, 49.0669871982046],
                            [2.13713442397544, 49.06714220065981],
                            [2.137282447389924, 49.06725190810256],
                            [2.137499064429621, 49.06741408040418],
                            [2.137791543933161, 49.067621590122286],
                            [2.138152685966862, 49.06786490928907],
                            [2.13856092738341, 49.06810354920741],
                            [2.139005410894167, 49.068335113479456],
                            [2.139507839109402, 49.068566774436114],
                            [2.140169494514747, 49.06882725791799],
                            [2.140798364833166, 49.06905112808556],
                            [2.141481883794477, 49.069258227748065],
                            [2.141696932779959, 49.06931413549863],
                        ],
                    },
                },
                283: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9952497406855, 1.9344608926455718],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 3244.37487682,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.91353050809466,
                            48.99259195475149,
                            1.955479247534605,
                            48.99691260485347,
                        ),
                        "coordinates": [
                            [1.91353050809466, 48.99259195475149],
                            [1.914576327498934, 48.99291161503717],
                            [1.915593398212429, 48.99321516514029],
                            [1.916555546139149, 48.99351142624859],
                            [1.917579668505943, 48.99383877849321],
                            [1.920263019336911, 48.994741973170775],
                            [1.920984351431904, 48.994962309530834],
                            [1.921384748750244, 48.99507797624157],
                            [1.92182845850146, 48.99520331234422],
                            [1.922400355372786, 48.995350526662065],
                            [1.923482825723805, 48.995628070229905],
                            [1.92455996185554, 48.9958960667543],
                            [1.92531248088211, 48.99606652162601],
                            [1.926220369315713, 48.99625180470593],
                            [1.926910003834282, 48.996375626036155],
                            [1.927596122291052, 48.996487532344894],
                            [1.928532127221156, 48.99660895228301],
                            [1.929212208220014, 48.99668632747381],
                            [1.929933029999748, 48.996756705033796],
                            [1.931057849940289, 48.996839219235376],
                            [1.932109699192833, 48.99689112723586],
                            [1.932825555334845, 48.99690614782384],
                            [1.933644538996546, 48.99691260485347],
                            [1.934422973373977, 48.996902853489175],
                            [1.935250354420043, 48.99687720845795],
                            [1.935923210175312, 48.99684387816518],
                            [1.936669432121215, 48.99679295403667],
                            [1.937521592397335, 48.99672098118938],
                            [1.938341304558058, 48.99663639680717],
                            [1.939367496568034, 48.99650612551201],
                            [1.940108768293799, 48.99639448845814],
                            [1.941037548214503, 48.99623531262664],
                            [1.941874172375299, 48.99606867399918],
                            [1.942792434493267, 48.99586661825114],
                            [1.94365924570416, 48.99565367265234],
                            [1.944982759903459, 48.995301306452596],
                            [1.949599332851387, 48.994095515878435],
                            [1.953609858696253, 48.99308826854502],
                            [1.955479247534605, 48.992613881639144],
                        ],
                    },
                },
                284: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.06903271870311, 2.1585479773429914],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2519.94968128,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.141696932779959,
                            49.0681762438397,
                            2.17530420994616,
                            49.07046236344271,
                        ),
                        "coordinates": [
                            [2.141696932779959, 49.06931413549863],
                            [2.141894722344571, 49.06936555492483],
                            [2.142317331590504, 49.06946558238912],
                            [2.142793529079225, 49.06956324985639],
                            [2.143075005089424, 49.069613446945446],
                            [2.14367555297842, 49.06969179710713],
                            [2.143998414905505, 49.06973011001583],
                            [2.144207728686709, 49.06975474243604],
                            [2.144885032383994, 49.06980623732963],
                            [2.145511848556825, 49.06981807552708],
                            [2.146163359909774, 49.06981466383134],
                            [2.146307089686741, 49.0698104066627],
                            [2.146872422916509, 49.069783152720916],
                            [2.147444743009804, 49.06974034916665],
                            [2.147792148523682, 49.069704789924835],
                            [2.148137598548268, 49.069662354967726],
                            [2.148390924100857, 49.069631296543065],
                            [2.14928107417728, 49.069498763835306],
                            [2.150032973123, 49.0693686961187],
                            [2.151707803017233, 49.06911961458292],
                            [2.154747989715312, 49.06864966373161],
                            [2.155550110997946, 49.06853376869588],
                            [2.15615513489806, 49.06845858474576],
                            [2.156832044747036, 49.06838766797942],
                            [2.157672986566504, 49.06830630936155],
                            [2.158496830972967, 49.06824818261551],
                            [2.160242117918889, 49.0681762438397],
                            [2.161788678659724, 49.06817951317964],
                            [2.16322012508999, 49.0682248544408],
                            [2.163822196822458, 49.068263533842966],
                            [2.164878508432512, 49.06834605716377],
                            [2.165557113681162, 49.068417216112934],
                            [2.166795233059659, 49.068566539575514],
                            [2.168016779613148, 49.068761687813286],
                            [2.169364061728551, 49.06901366110011],
                            [2.170796031537739, 49.06932059741474],
                            [2.172018660404792, 49.069611927351154],
                            [2.173597198513241, 49.07000037204879],
                            [2.175280226542526, 49.070455590709585],
                            [2.17530420994616, 49.07046236344271],
                        ],
                    },
                },
                285: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98493952737166, 2.265570823626869],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1261.36486082,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263182622862856,
                            48.98091190326584,
                            2.269851993930268,
                            48.99065124967573,
                        ),
                        "coordinates": [
                            [2.263182622862856, 48.99065124967573],
                            [2.263828000159767, 48.98850080746261],
                            [2.264569558116951, 48.98598060907531],
                            [2.264938987091222, 48.98468948165153],
                            [2.265151782845797, 48.98398907934167],
                            [2.265217628725084, 48.98380746726178],
                            [2.265299862717603, 48.98363126018516],
                            [2.265387535529786, 48.98347214339544],
                            [2.265506693029483, 48.983271679108135],
                            [2.265639465883045, 48.983103597459554],
                            [2.265798227785891, 48.98291484795068],
                            [2.265967910562413, 48.98273150030918],
                            [2.266218262553732, 48.98250593661489],
                            [2.266449404173173, 48.982337015015496],
                            [2.266783082822401, 48.98211959515766],
                            [2.267241126077733, 48.98187527114086],
                            [2.267625294850131, 48.98169744667459],
                            [2.268508390037164, 48.98134096418717],
                            [2.268870637837192, 48.98120179144643],
                            [2.269185026292536, 48.98108956812498],
                            [2.269851993930268, 48.98091190326584],
                        ],
                    },
                },
                286: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96739959384889, 1.8317664564209606],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2627.68989258,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.814911934161123,
                            48.963825577806084,
                            1.848348808282502,
                            48.97214167690781,
                        ),
                        "coordinates": [
                            [1.814911934161123, 48.963825577806084],
                            [1.815912228767559, 48.96392916180948],
                            [1.817011205202946, 48.96406699800063],
                            [1.81845413919112, 48.96428608594147],
                            [1.819749147895919, 48.96450421403665],
                            [1.821617906480417, 48.964807692299324],
                            [1.823075227894982, 48.96506170646702],
                            [1.824965022409081, 48.9654318457826],
                            [1.825801666323962, 48.96560214604815],
                            [1.827049244693739, 48.96587420600549],
                            [1.828390453363887, 48.9661799805204],
                            [1.828910683687202, 48.966303205095066],
                            [1.829485475579419, 48.966444184797844],
                            [1.830438913009603, 48.966680407696785],
                            [1.831075973547873, 48.96684621932271],
                            [1.833000461301758, 48.96737104229682],
                            [1.833548209143593, 48.967525735222495],
                            [1.834866974414407, 48.96791461233414],
                            [1.838242688052874, 48.96896679082959],
                            [1.842774902225746, 48.97039743842707],
                            [1.845322167449251, 48.97119837017101],
                            [1.848348808282502, 48.97214167690781],
                        ],
                    },
                },
                287: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.94881760118019, 2.2563323665234707],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 516.027525374,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25508371139436,
                            48.946796942080006,
                            2.25789748402742,
                            48.95101678180594,
                        ),
                        "coordinates": [
                            [2.25789748402742, 48.946796942080006],
                            [2.257719474961042, 48.947029691305865],
                            [2.257223578321887, 48.947652735034254],
                            [2.25681465623077, 48.94809738662814],
                            [2.256089519497871, 48.948962950155284],
                            [2.255738023161628, 48.94949945977133],
                            [2.255532155148722, 48.949836346592356],
                            [2.255364231847696, 48.9501441322196],
                            [2.255243717775441, 48.95043531092136],
                            [2.255170564402458, 48.95063554238053],
                            [2.255135434217287, 48.950774786794724],
                            [2.25508371139436, 48.95101678180594],
                        ],
                    },
                },
                288: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.99348921556762, 2.261616972660548],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 662.260272877,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.259655619057618,
                            48.99065124967573,
                            2.263182622862856,
                            48.99609884257494,
                        ),
                        "coordinates": [
                            [2.259655619057618, 48.99609884257494],
                            [2.259936038504019, 48.995750918986936],
                            [2.26057546032276, 48.994973472504206],
                            [2.261835158362254, 48.99338618340801],
                            [2.262140515774405, 48.9929817089451],
                            [2.262417229385822, 48.992537647091815],
                            [2.262541924089943, 48.99231200999636],
                            [2.26268993446837, 48.992029733002774],
                            [2.262884447316756, 48.991526981431136],
                            [2.263150986764796, 48.99075665689007],
                            [2.263182622862856, 48.99065124967573],
                        ],
                    },
                },
                289: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.76437037389192, 1.9754262052250464],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 5114.58099421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.943835201056777,
                            48.75538926869322,
                            2.006566869057667,
                            48.77480280977951,
                        ),
                        "coordinates": [
                            [1.943835201056777, 48.75538926869322],
                            [1.944667364028943, 48.75559099755985],
                            [1.948089958754974, 48.75630451146039],
                            [1.949761965640149, 48.756630626206295],
                            [1.95098834279538, 48.756882240266435],
                            [1.952070762970246, 48.757136527119066],
                            [1.952832360409277, 48.75730723778661],
                            [1.953986601811341, 48.7575839563403],
                            [1.954719421973728, 48.75775455743983],
                            [1.955667704796042, 48.757986153882165],
                            [1.956716320331152, 48.75827518109275],
                            [1.957348324839237, 48.75845494657275],
                            [1.957817558002823, 48.75858658021936],
                            [1.958387340651808, 48.75874709874267],
                            [1.959028977802339, 48.7589237145464],
                            [1.959890836127262, 48.759167678353315],
                            [1.960465357045865, 48.75933771841221],
                            [1.961490013672851, 48.75962979542499],
                            [1.963711603908849, 48.76028110622803],
                            [1.964640567422104, 48.76054111619817],
                            [1.965665533965252, 48.760798257957504],
                            [1.966455716218026, 48.76101021319322],
                            [1.967217280111452, 48.7611998632285],
                            [1.968953232641303, 48.76164350480127],
                            [1.970096989484728, 48.761931271902014],
                            [1.972363822311808, 48.762495317178804],
                            [1.973067927450299, 48.76267363942385],
                            [1.973477410427192, 48.762784396444744],
                            [1.973861701975016, 48.762895072320156],
                            [1.974156210934549, 48.76297928689983],
                            [1.974608660204442, 48.763121108864894],
                            [1.975000051483632, 48.763246078785315],
                            [1.975477595433308, 48.76340225333082],
                            [1.976016101591305, 48.76358954949254],
                            [1.976525801437547, 48.763779131923826],
                            [1.977049780801759, 48.763985413454215],
                            [1.977548571904761, 48.76419161190875],
                            [1.978083152615097, 48.76442647291585],
                            [1.978606956344336, 48.76465891864899],
                            [1.979378354397805, 48.76499683059387],
                            [1.979963167727697, 48.765255635022584],
                            [1.980558770292436, 48.76551684829816],
                            [1.981279957062491, 48.765833176924154],
                            [1.981983210036676, 48.76614230624942],
                            [1.982568066930035, 48.76639871782676],
                            [1.983063272717583, 48.76660963986517],
                            [1.983709346963289, 48.766863855856535],
                            [1.984341132099917, 48.767103748659196],
                            [1.985030494888863, 48.7673461933727],
                            [1.98565887661744, 48.7675598945088],
                            [1.986423754093624, 48.76781446201408],
                            [1.989239064432506, 48.76876293098881],
                            [1.989673531314358, 48.768916534790684],
                            [1.990079236590753, 48.76906528943964],
                            [1.990459781456195, 48.76920920857999],
                            [1.990750473904049, 48.76933381857678],
                            [1.991134506371609, 48.76949440145146],
                            [1.991547189518956, 48.76967648375796],
                            [1.992006518777412, 48.76988011989825],
                            [1.994963320565364, 48.77122384796468],
                            [1.995709732354749, 48.771561574582485],
                            [1.996108116283379, 48.77173407956733],
                            [1.996470650399578, 48.771885062822726],
                            [1.996901436443583, 48.772057661878335],
                            [1.99727125625033, 48.772196767058944],
                            [1.997691377615981, 48.77235029773417],
                            [1.998107983785947, 48.772491918234685],
                            [1.998564203646575, 48.77263127620023],
                            [1.999006107936467, 48.772758692624365],
                            [1.999451597836565, 48.77288849759675],
                            [2.000008601457484, 48.773030528035186],
                            [2.000486510994423, 48.77315804509535],
                            [2.001219583688146, 48.773348177122166],
                            [2.005718365196384, 48.774574809731874],
                            [2.006480182944973, 48.7747792669428],
                            [2.006566869057667, 48.77480280977951],
                        ],
                    },
                },
                290: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.68223304714637, 2.3829777968501693],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1595.31402077,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.381473988012935,
                            48.67609243396569,
                            2.386783798391594,
                            48.6892154808985,
                        ),
                        "coordinates": [
                            [2.386783798391594, 48.67609243396569],
                            [2.386345221634454, 48.67643006759993],
                            [2.386113198351504, 48.676609123667845],
                            [2.385771257628163, 48.67686556279824],
                            [2.385308562793461, 48.67722816575767],
                            [2.384818811244608, 48.677627757239264],
                            [2.384430689832536, 48.677963239502716],
                            [2.384199974970554, 48.67817837691337],
                            [2.383943636275142, 48.678436457944095],
                            [2.383735159171046, 48.678659902719374],
                            [2.383444427453402, 48.678991511555445],
                            [2.383234169536574, 48.67923440028044],
                            [2.382916789098715, 48.679651789780145],
                            [2.382400137877994, 48.68046403748937],
                            [2.382158813027004, 48.68090387571348],
                            [2.381982699277741, 48.68129759824694],
                            [2.381767170349943, 48.68181948616287],
                            [2.38169828637631, 48.68208193171099],
                            [2.381630269449401, 48.6823307319715],
                            [2.381566913107474, 48.68263610064702],
                            [2.381491387349141, 48.683221553317146],
                            [2.381473988012935, 48.68350662845024],
                            [2.381495009914132, 48.68423232886164],
                            [2.381499246806555, 48.68441308051932],
                            [2.381513028124906, 48.68463609351605],
                            [2.381532232477982, 48.68484831290916],
                            [2.381552837310175, 48.68510729376149],
                            [2.381585614625279, 48.68530961627733],
                            [2.38162655558254, 48.685529021783424],
                            [2.381698856761196, 48.68588240496696],
                            [2.381792851858905, 48.68619621259869],
                            [2.381931770414198, 48.68662151163685],
                            [2.382082884063243, 48.68701173348574],
                            [2.382206721466581, 48.68727786696142],
                            [2.382472431914383, 48.687756295632084],
                            [2.382753560806087, 48.68819310246754],
                            [2.383015837025819, 48.68858645686679],
                            [2.38352086738215, 48.6892154808985],
                        ],
                    },
                },
                291: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.96326967418847, 2.623331986674454],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 3881.11035797,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.603135305118449,
                            48.9531483875826,
                            2.64240630231019,
                            48.97585875402045,
                        ),
                        "coordinates": [
                            [2.603135305118449, 48.9531483875826],
                            [2.605000289162331, 48.95358023622196],
                            [2.606667981536762, 48.953976045436235],
                            [2.60843332667294, 48.95438587455402],
                            [2.609996191861178, 48.954762848286016],
                            [2.610564286872323, 48.954918527856364],
                            [2.610987737600818, 48.95505075694514],
                            [2.611407665895066, 48.955199648801525],
                            [2.611737170967245, 48.9553297236263],
                            [2.612157252560272, 48.95550478508058],
                            [2.612526701935252, 48.95567044971302],
                            [2.612852742036049, 48.95582670175315],
                            [2.613182453497493, 48.95599245990038],
                            [2.613454237727346, 48.95613694387159],
                            [2.613813069025569, 48.9563407001603],
                            [2.614150249870269, 48.95654926678368],
                            [2.614560028989912, 48.95681714106856],
                            [2.61516573517021, 48.957229677317436],
                            [2.615546578415751, 48.957490478786184],
                            [2.615989121755064, 48.95779871768538],
                            [2.616384480709172, 48.95806899772281],
                            [2.616765337560406, 48.95832979781849],
                            [2.617204238868017, 48.95863090006522],
                            [2.618865618889549, 48.95977604693423],
                            [2.620848305052638, 48.96113672398326],
                            [2.623788406543668, 48.963147256113665],
                            [2.627376631213806, 48.96560559525237],
                            [2.629031207469668, 48.966743473580635],
                            [2.633236858467855, 48.969623578526125],
                            [2.633995347296979, 48.97014982880753],
                            [2.635112976436022, 48.970896419788794],
                            [2.636905798974081, 48.972125430531804],
                            [2.637998180871814, 48.97286611020394],
                            [2.639061483617493, 48.97357473575402],
                            [2.64030279661989, 48.974425640339135],
                            [2.64240630231019, 48.97585875402045],
                        ],
                    },
                },
                292: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.843955963352236, 2.373588223258572],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 63.1241250744,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.373259976710645,
                            48.84377257685145,
                            2.373916469806499,
                            48.84413934985302,
                        ),
                        "coordinates": [
                            [2.373916469806499, 48.84377257685145],
                            [2.373259976710645, 48.84413934985302],
                        ],
                    },
                },
                293: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.93220401222064, 2.485593854073034],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1453.79505853,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.475674370833512,
                            48.93212901293364,
                            2.495513142584314,
                            48.93230541606912,
                        ),
                        "coordinates": [
                            [2.475674370833512, 48.93230541606912],
                            [2.476163709743931, 48.93230003707236],
                            [2.477409636592118, 48.93228483173492],
                            [2.478716297186294, 48.9322688686431],
                            [2.480597999968426, 48.932242802188085],
                            [2.485909369257553, 48.93219180371595],
                            [2.488602667950408, 48.93216023242055],
                            [2.490988334468279, 48.93212901293364],
                            [2.493681829925758, 48.932162007084386],
                            [2.49440185171253, 48.932173955094534],
                            [2.495513142584314, 48.93219600596196],
                        ],
                    },
                },
                294: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.927531565634325, 2.4060922439431613],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2973.3485505,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.386388291064694,
                            48.92435387966092,
                            2.425791425559954,
                            48.93073957031752,
                        ),
                        "coordinates": [
                            [2.386388291064694, 48.92435387966092],
                            [2.389018133977532, 48.92478587365258],
                            [2.392434522542798, 48.92533388242894],
                            [2.395446508129437, 48.92582965320484],
                            [2.397133090234305, 48.92609525835423],
                            [2.398863006496915, 48.9263512970188],
                            [2.401131064422231, 48.92668553071205],
                            [2.402452937452991, 48.926901301573565],
                            [2.404948641933777, 48.927313850034764],
                            [2.410962349463101, 48.92831419740778],
                            [2.413640642494941, 48.92875601693751],
                            [2.417329632422147, 48.929355067842664],
                            [2.420180742751204, 48.929829553573626],
                            [2.421591578284466, 48.93005923482367],
                            [2.423738953800848, 48.93040693302665],
                            [2.425791425559954, 48.93073957031752],
                        ],
                    },
                },
                295: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.71465048908473, 2.4270716016464235],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2344.8011347,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.414358881169592,
                            48.70836643170258,
                            2.439645733248798,
                            48.72115958316324,
                        ),
                        "coordinates": [
                            [2.414358881169592, 48.70836643170258],
                            [2.416298141195312, 48.70937471844929],
                            [2.41845700662311, 48.71045815408885],
                            [2.419683953531602, 48.711044957247275],
                            [2.421411102385441, 48.7118812024336],
                            [2.423976791370069, 48.71314981737515],
                            [2.426157512180124, 48.71420691853891],
                            [2.432369085363183, 48.717202181841856],
                            [2.43477694898686, 48.71838741101548],
                            [2.435691178313201, 48.71883868948199],
                            [2.436601794126185, 48.71927330916396],
                            [2.437458478409873, 48.719703209759736],
                            [2.438012902875806, 48.72002630477984],
                            [2.438428138153384, 48.720272480402244],
                            [2.438687714701187, 48.72043475289553],
                            [2.439001009703108, 48.720653369804175],
                            [2.439245911962968, 48.720836356540936],
                            [2.439645733248798, 48.72115958316324],
                        ],
                    },
                },
                296: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.87225393248097, 2.3297680575416555],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 430.40100103,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.327543081726972,
                            48.8709917839485,
                            2.331989522683248,
                            48.87351338959546,
                        ),
                        "coordinates": [
                            [2.331989522683248, 48.8709917839485],
                            [2.331921186224673, 48.871044120144724],
                            [2.33185238431283, 48.87109361987756],
                            [2.331781274501569, 48.87114160658396],
                            [2.331706679665024, 48.871188869604985],
                            [2.331261073816848, 48.87143654700647],
                            [2.330800651733506, 48.87169245519094],
                            [2.330240743698651, 48.87197445691374],
                            [2.32791908118968, 48.873286184905616],
                            [2.327543081726972, 48.87351338959546],
                        ],
                    },
                },
                297: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.93221685583283, 2.5017760037516448],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 917.861437564,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.495513142584314,
                            48.93219600596196,
                            2.508038741924935,
                            48.9322501569209,
                        ),
                        "coordinates": [
                            [2.495513142584314, 48.93219600596196],
                            [2.496840135010492, 48.93222232191138],
                            [2.497785955199344, 48.932229620949464],
                            [2.498829914690119, 48.932223834707656],
                            [2.504747939281772, 48.932200278608676],
                            [2.505691099886219, 48.93220436669105],
                            [2.507153726961957, 48.93224052521622],
                            [2.508038741924935, 48.9322501569209],
                        ],
                    },
                },
                298: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.99618857335681, 2.0962089501883305],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 249.219382669,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.094643974392771,
                            48.99574683395328,
                            2.097773988463467,
                            48.996630090663984,
                        ),
                        "coordinates": [
                            [2.097773988463467, 48.996630090663984],
                            [2.097642513489375, 48.996593229550804],
                            [2.094643974392771, 48.99574683395328],
                        ],
                    },
                },
                299: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.808566746988625, 2.1434352484030113],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1282.02392276,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.135087456598118,
                            48.80637744816838,
                            2.151500117388586,
                            48.8094822639171,
                        ),
                        "coordinates": [
                            [2.135087456598118, 48.8094822639171],
                            [2.136759626151367, 48.80937479405942],
                            [2.137769031099437, 48.80930328474868],
                            [2.138775366467677, 48.809238788115856],
                            [2.139170534934302, 48.809230440219125],
                            [2.139536782450396, 48.80923408518189],
                            [2.140182699990024, 48.809228175292304],
                            [2.140516345531292, 48.80921931208333],
                            [2.140818054421012, 48.80920317062414],
                            [2.142740328987042, 48.809058247796216],
                            [2.143443488701181, 48.80899184237951],
                            [2.143824726348298, 48.80894751164658],
                            [2.144297358854954, 48.80887332318379],
                            [2.144799598111673, 48.80878267226027],
                            [2.145161889020517, 48.808709668783415],
                            [2.145677525481889, 48.80859409553139],
                            [2.146102849026783, 48.80848697074957],
                            [2.146468574935884, 48.80838763598072],
                            [2.14685468215683, 48.8082789315685],
                            [2.147226328293141, 48.80816528751164],
                            [2.147666281348462, 48.80801745519884],
                            [2.148160659494526, 48.80782130232207],
                            [2.148628992934423, 48.80762156842433],
                            [2.148972698116551, 48.80745936571731],
                            [2.149881011800267, 48.80704179512778],
                            [2.150325595226942, 48.80684288398869],
                            [2.150869671520154, 48.80661445677922],
                            [2.151135630053698, 48.80651016096883],
                            [2.151500117388586, 48.80637744816838],
                        ],
                    },
                },
                300: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.93184955690691, 2.5057045403458003],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 1400.84297671,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.496238281204935,
                            48.93093418298108,
                            2.515049661053076,
                            48.931982586397105,
                        ),
                        "coordinates": [
                            [2.515049661053076, 48.93093418298108],
                            [2.514537642999884, 48.931151501135886],
                            [2.514122923316785, 48.931311558968055],
                            [2.513809110257994, 48.93141435775375],
                            [2.513498873655156, 48.93150762980719],
                            [2.513080355721649, 48.93161772636919],
                            [2.512676205630918, 48.93170638448722],
                            [2.512279202268983, 48.931773615390085],
                            [2.511921829045716, 48.93181461082283],
                            [2.51158287668606, 48.93183791056425],
                            [2.511294015845152, 48.931850246409475],
                            [2.510835544695571, 48.9318575269965],
                            [2.509867653805882, 48.931878584955406],
                            [2.508975726266369, 48.93189658396521],
                            [2.507173729928542, 48.93190879693527],
                            [2.506238432726017, 48.93191732118667],
                            [2.505898997882351, 48.93192496085715],
                            [2.505321233994572, 48.9319377104574],
                            [2.504674837214873, 48.93194579774802],
                            [2.504046465822722, 48.93194433748425],
                            [2.503627570669617, 48.93193926331997],
                            [2.503002804860113, 48.93194585654901],
                            [2.502313075994817, 48.93195399150332],
                            [2.500539991394683, 48.93197319689826],
                            [2.498958275144382, 48.931982586397105],
                            [2.498582693643476, 48.93198073861337],
                            [2.498199862146097, 48.93196938181386],
                            [2.496238281204935, 48.931950242402564],
                        ],
                    },
                },
                301: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.89439506819343, 2.5031507148322247],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 751.005027225,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.499388457291095,
                            48.89250476140823,
                            2.506408247006797,
                            48.89714381938228,
                        ),
                        "coordinates": [
                            [2.499388457291095, 48.89250476140823],
                            [2.500753582807867, 48.89285019716361],
                            [2.501028067411648, 48.892923562024095],
                            [2.501288134574021, 48.89300170808599],
                            [2.501522941992141, 48.8930798887224],
                            [2.50183006557377, 48.89320079285336],
                            [2.502054122916287, 48.89330040320164],
                            [2.502296284901374, 48.8934190206129],
                            [2.502524047046335, 48.8935471742202],
                            [2.502730178356596, 48.89368012079999],
                            [2.502918254885254, 48.89381071231531],
                            [2.503189610414107, 48.89402445823953],
                            [2.503508157953426, 48.894321413381334],
                            [2.503815874946024, 48.894616004290945],
                            [2.50532918491629, 48.8960675689838],
                            [2.506408247006797, 48.89714381938228],
                        ],
                    },
                },
                302: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.90521864049344, 2.51447308261432],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 749.017184773,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.51169930327069,
                            48.902444190569966,
                            2.517025495287702,
                            48.90816541612633,
                        ),
                        "coordinates": [
                            [2.51169930327069, 48.902444190569966],
                            [2.512173692589334, 48.90289554275962],
                            [2.513452328658713, 48.90418794540731],
                            [2.514028287165222, 48.90477237547025],
                            [2.51468003694186, 48.90535192685482],
                            [2.515654590609167, 48.906361635157964],
                            [2.516208873146176, 48.90692705441679],
                            [2.516361073652075, 48.90709336982695],
                            [2.516516958879685, 48.90728109504663],
                            [2.516662060776261, 48.90748073265867],
                            [2.516789194027402, 48.90770181232792],
                            [2.516945439206722, 48.90798709033225],
                            [2.517025495287702, 48.90816541612633],
                        ],
                    },
                },
                303: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [49.05366743728424, 3.054256200529882],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 8665.08815973,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.031758445836778,
                            49.021757268637266,
                            3.066608008896255,
                            49.09188299627486,
                        ),
                        "coordinates": [
                            [3.062690406987056, 49.09188299627486],
                            [3.063603799028829, 49.09090972643143],
                            [3.06401175034329, 49.09049474502763],
                            [3.064512840295526, 49.089965078264925],
                            [3.064818071954384, 49.08962184771553],
                            [3.065072167646034, 49.08931043162812],
                            [3.065343024050841, 49.08896786369541],
                            [3.065561717639361, 49.08862775382952],
                            [3.065786904794956, 49.08824822941065],
                            [3.065960220269138, 49.08792163658805],
                            [3.06610425032391, 49.08758329984063],
                            [3.066241121741434, 49.087234317494435],
                            [3.066376886490948, 49.0868103887377],
                            [3.066528983863308, 49.086118194065776],
                            [3.066595698486269, 49.085483173083496],
                            [3.066608008896255, 49.08505140202872],
                            [3.066589544421756, 49.084820396383535],
                            [3.066576047468108, 49.084647813343786],
                            [3.066540973716021, 49.08435090791982],
                            [3.06649933257993, 49.084106328183026],
                            [3.066417474223486, 49.0837137666325],
                            [3.066326751064308, 49.08340787153626],
                            [3.066212744546021, 49.08307047818137],
                            [3.066065411238063, 49.0827083129937],
                            [3.065892725596543, 49.082346308855904],
                            [3.065673740638557, 49.081939626630074],
                            [3.064772929867041, 49.0802751194925],
                            [3.064100250001276, 49.07908310687664],
                            [3.063340227621834, 49.07770857121048],
                            [3.062975190825979, 49.07705653107882],
                            [3.061982853550437, 49.075257292152514],
                            [3.061300911363224, 49.07399561745078],
                            [3.060772889152478, 49.072896394351446],
                            [3.060648129961923, 49.07259972606884],
                            [3.060526933433462, 49.072263401013245],
                            [3.060411994059985, 49.07185771830223],
                            [3.060279341939041, 49.07134459510583],
                            [3.060201548833917, 49.07098793324647],
                            [3.060120109256934, 49.070445459180974],
                            [3.060038134958052, 49.06986634500941],
                            [3.059899625029979, 49.068868481168934],
                            [3.059764278397069, 49.067847714343614],
                            [3.059626212275811, 49.066827863038675],
                            [3.059490981750694, 49.06581428969889],
                            [3.059214639108601, 49.063851928742125],
                            [3.059172689706847, 49.063603083421384],
                            [3.059142605889707, 49.063417114972076],
                            [3.059029872805711, 49.06278553883761],
                            [3.058875583398004, 49.062092308175956],
                            [3.058714962790737, 49.061494376282276],
                            [3.058628482537339, 49.061157435309944],
                            [3.058578747857831, 49.06097453117885],
                            [3.058388284497723, 49.06032780957576],
                            [3.05819201453893, 49.05972942662851],
                            [3.057991400015168, 49.05917060597082],
                            [3.057853808443352, 49.05878215707284],
                            [3.057704001456914, 49.05841500026176],
                            [3.057559409442629, 49.058057803243045],
                            [3.057399348554642, 49.057682382102826],
                            [3.05725005718897, 49.05735019933928],
                            [3.057095672318054, 49.05701638134754],
                            [3.056852541946258, 49.056504902681944],
                            [3.056531869635117, 49.055888975390275],
                            [3.055799367103623, 49.05448613391184],
                            [3.055280727099677, 49.05349834902036],
                            [3.054824660415702, 49.0526300933167],
                            [3.054336886101066, 49.051654590788225],
                            [3.054085081782075, 49.05108420307554],
                            [3.053989165167662, 49.05082397585257],
                            [3.053871226190851, 49.05048839627956],
                            [3.0538025641416, 49.05028198378415],
                            [3.053637568879302, 49.049751025874585],
                            [3.053554276557624, 49.04942342100333],
                            [3.053468161808265, 49.049075847784884],
                            [3.053396830783833, 49.0486890824147],
                            [3.053323164305656, 49.04826758961478],
                            [3.053268272974603, 49.04786953120066],
                            [3.053230420829081, 49.04752998337677],
                            [3.053204879119348, 49.047165374841136],
                            [3.053184616245502, 49.04671916758694],
                            [3.053105494706221, 49.045126076978086],
                            [3.053027759038395, 49.04353387614017],
                            [3.052950001689018, 49.041939878094226],
                            [3.052930358540742, 49.04152721528851],
                            [3.052869540165152, 49.04034769417151],
                            [3.05285750466842, 49.03998804410725],
                            [3.052845962298888, 49.03966256388611],
                            [3.052785165826623, 49.03846019542045],
                            [3.052755299341463, 49.037795804192484],
                            [3.052685936301546, 49.036676947766104],
                            [3.052652123122738, 49.036440642542054],
                            [3.052596602427684, 49.03610453607607],
                            [3.052502388528324, 49.03572036949981],
                            [3.052388178775563, 49.03535464895046],
                            [3.052293358039071, 49.035103734102066],
                            [3.052151551787678, 49.034756507612705],
                            [3.051942782816169, 49.03433307886755],
                            [3.051706347588776, 49.0339231499985],
                            [3.051540610180645, 49.033672676548456],
                            [3.051333676896308, 49.03337582307692],
                            [3.051065283892919, 49.03303271574216],
                            [3.050604383585108, 49.03251425200638],
                            [3.050221637233089, 49.03214520539636],
                            [3.049982940529118, 49.03192849690118],
                            [3.049762407252088, 49.03174165544732],
                            [3.049404764134454, 49.03146292939244],
                            [3.04893965075725, 49.03112543368331],
                            [3.048424662548047, 49.030787793438016],
                            [3.0478633768862, 49.03046392763128],
                            [3.045707394664824, 49.02929338799202],
                            [3.044142640104384, 49.02844860198017],
                            [3.043310925032412, 49.028001889375766],
                            [3.041803189878661, 49.027186506581536],
                            [3.04029550481004, 49.02637110332115],
                            [3.038787856848813, 49.02555478131903],
                            [3.038612847795833, 49.025460526317325],
                            [3.036592682139192, 49.02437032516736],
                            [3.034098586842194, 49.02302307274451],
                            [3.033778900558709, 49.02284965239199],
                            [3.033008643589508, 49.02243255778861],
                            [3.031758445836778, 49.021757268637266],
                        ],
                    },
                },
                304: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.08858576614457, 2.3565459690056496],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2273.35690815,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35083083355881,
                            49.079470233982065,
                            2.361270555241057,
                            49.09840026247686,
                        ),
                        "coordinates": [
                            [2.35083083355881, 49.079470233982065],
                            [2.350972687817406, 49.07955993269019],
                            [2.351237252861799, 49.07974553747962],
                            [2.351569982228981, 49.07998290374525],
                            [2.352066795750535, 49.08037590492253],
                            [2.352483453921169, 49.08074702437984],
                            [2.352675485087074, 49.08092782728793],
                            [2.352856655735549, 49.08112290762148],
                            [2.352994346154071, 49.08127040644488],
                            [2.353213259884614, 49.081534827650366],
                            [2.353447458948779, 49.08182615887204],
                            [2.353617293706934, 49.082051851768284],
                            [2.354353296314638, 49.08307136239222],
                            [2.354800737889736, 49.08371712716377],
                            [2.354997994459554, 49.08401655470446],
                            [2.355437707103021, 49.08464687506328],
                            [2.355897274303016, 49.085350517296966],
                            [2.356162410887202, 49.08580142210274],
                            [2.3562987977645, 49.086049193304646],
                            [2.35645105824857, 49.08634182459115],
                            [2.35660117192342, 49.086692989105835],
                            [2.356766533392021, 49.08711981258591],
                            [2.356903679092715, 49.087640861930495],
                            [2.357027815885794, 49.08823472231403],
                            [2.35708009807407, 49.08852023197048],
                            [2.357369847004412, 49.09010338755587],
                            [2.357417772047567, 49.090353683962576],
                            [2.357761988303362, 49.09218237676576],
                            [2.357936245178144, 49.093013207253854],
                            [2.358053798988859, 49.093404347016744],
                            [2.358193077257261, 49.09375979380259],
                            [2.35831927793891, 49.09402958578735],
                            [2.358523808291113, 49.0943701737494],
                            [2.359082886636688, 49.095207289892414],
                            [2.360035669599188, 49.09662034401773],
                            [2.360213415890133, 49.09685992909395],
                            [2.360668734397019, 49.09752959546552],
                            [2.361108191985409, 49.09815336383457],
                            [2.361236557413978, 49.09835034471274],
                            [2.361270555241057, 49.09840026247686],
                        ],
                    },
                },
                305: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.78458470265156, 2.2863770800055465],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1229.80409605,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.281430595437461,
                            48.78023729710838,
                            2.292351691072184,
                            48.78762174773474,
                        ),
                        "coordinates": [
                            [2.281430595437461, 48.78023729710838],
                            [2.281582133498453, 48.78044088798777],
                            [2.281868740168214, 48.78090235429701],
                            [2.282039807038847, 48.78125585186316],
                            [2.282413113446111, 48.78208336350066],
                            [2.282513566068323, 48.78230823021502],
                            [2.282654760909397, 48.78260955442246],
                            [2.282866672685342, 48.782954976715615],
                            [2.28297674491521, 48.78309711467017],
                            [2.283243168271317, 48.78337241823363],
                            [2.283365535954353, 48.783471396375155],
                            [2.283487908690229, 48.783565877328684],
                            [2.283604849804961, 48.78364956496463],
                            [2.283729963494535, 48.78372786000132],
                            [2.28389588514921, 48.78382146199687],
                            [2.284059088323308, 48.78391236450434],
                            [2.284339285935198, 48.784041090057784],
                            [2.284472587563546, 48.78409780596639],
                            [2.284780023262424, 48.78420765832671],
                            [2.284933748993409, 48.78425539027462],
                            [2.285087483894973, 48.784294128819575],
                            [2.285239857900828, 48.78433376653366],
                            [2.286584045738613, 48.78461514371969],
                            [2.286929609185086, 48.78470808963253],
                            [2.287198930957116, 48.784795761576376],
                            [2.287389473876727, 48.78486079612561],
                            [2.287618000743795, 48.78495981546218],
                            [2.287862083235801, 48.785090017125086],
                            [2.288026038980263, 48.78518570881546],
                            [2.288215072312931, 48.785317083722106],
                            [2.288413595393507, 48.78548623266101],
                            [2.288565867805562, 48.78563737482507],
                            [2.288669183328528, 48.78575252579747],
                            [2.288975031560293, 48.7861177605956],
                            [2.289382864826554, 48.78657656167834],
                            [2.289556907391681, 48.78673760398659],
                            [2.289760891426588, 48.786900457313756],
                            [2.289879215232604, 48.78698054183082],
                            [2.290118603568097, 48.78712272592368],
                            [2.290264157443965, 48.78719292895717],
                            [2.290368964344747, 48.787241859766304],
                            [2.290496778052197, 48.78729823931063],
                            [2.290734734335132, 48.78738469140355],
                            [2.291004630483221, 48.787462524576355],
                            [2.291197463223349, 48.78750895216191],
                            [2.291359400114878, 48.78754042876407],
                            [2.291513144131667, 48.78757022953279],
                            [2.291766249114265, 48.78760270387891],
                            [2.291966293812107, 48.78761627155582],
                            [2.292170429711516, 48.78762174773474],
                            [2.292351691072184, 48.78761984513844],
                        ],
                    },
                },
                306: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [49.01063462363853, 3.019372072552726],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3201.06899827,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.007953055749719,
                            48.99841539320162,
                            3.031758445836778,
                            49.021757268637266,
                        ),
                        "coordinates": [
                            [3.031758445836778, 49.021757268637266],
                            [3.031192632609206, 49.021451637047775],
                            [3.02937804733439, 49.020469780313704],
                            [3.027564913344277, 49.01948878511261],
                            [3.02728111042359, 49.0193358148912],
                            [3.02663359523629, 49.0189862859137],
                            [3.025066047911244, 49.01814143261744],
                            [3.024772607323102, 49.01798163076165],
                            [3.024320414073001, 49.01772946360061],
                            [3.024030862086733, 49.017554935796205],
                            [3.023536827606953, 49.01722695089455],
                            [3.023100171713156, 49.016895023382475],
                            [3.022899041594082, 49.01672867265889],
                            [3.022629808841753, 49.01648710658191],
                            [3.022483522244274, 49.01634640667193],
                            [3.022301120954777, 49.01615761930662],
                            [3.022153265296338, 49.01599741225286],
                            [3.021938391680297, 49.01574671934196],
                            [3.021770680404929, 49.015521200120375],
                            [3.02163132744376, 49.015332153801204],
                            [3.021463228469008, 49.01507832136779],
                            [3.02126742711388, 49.01477192065155],
                            [3.02080333898293, 49.01403455861575],
                            [3.020706914916997, 49.01388314989977],
                            [3.020231597272865, 49.013123370146694],
                            [3.01915639215236, 49.011399439643824],
                            [3.018881948950972, 49.01095968816022],
                            [3.018517641772965, 49.01037359352136],
                            [3.018200391891305, 49.00987006775914],
                            [3.017175887840634, 49.00823491279709],
                            [3.016194869955983, 49.006675932294584],
                            [3.015947465032778, 49.00627810431446],
                            [3.015769944192662, 49.00599227676004],
                            [3.015307289719046, 49.005247689988494],
                            [3.01432916091712, 49.003691374475046],
                            [3.014059725863468, 49.00326489472907],
                            [3.013773452435715, 49.002835817453686],
                            [3.013461663756977, 49.00242487544922],
                            [3.01312957451806, 49.00202844149354],
                            [3.01297470197025, 49.00185554213996],
                            [3.01256631797443, 49.00142489465815],
                            [3.012451480966465, 49.001316591611705],
                            [3.012254967627573, 49.00113878768798],
                            [3.0119200580077, 49.00083499668754],
                            [3.011495428768955, 49.00049014226873],
                            [3.011226927479065, 49.000291851492186],
                            [3.010930269025352, 49.00007040730094],
                            [3.01050480379268, 48.99978573999148],
                            [3.010286490798526, 48.99963947221157],
                            [3.010005726162612, 48.99946956561279],
                            [3.00974543992512, 48.999316193900626],
                            [3.009459731780556, 48.99915464446193],
                            [3.009072232651956, 48.99895371517964],
                            [3.008726609738067, 48.99877816606785],
                            [3.007953055749719, 48.99841539320162],
                        ],
                    },
                },
                307: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.78476779106515, 2.2952865454675297],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 888.100684445,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.292492977835659,
                            48.78135672132315,
                            2.297647677794033,
                            48.78761467997086,
                        ),
                        "coordinates": [
                            [2.292492977835659, 48.78761467997086],
                            [2.292679616250388, 48.787600082031055],
                            [2.29288104489784, 48.7875814502161],
                            [2.293087761589691, 48.78755285957411],
                            [2.293258263831342, 48.787519132811205],
                            [2.293430995574591, 48.78748468866553],
                            [2.293628699094135, 48.78743612091473],
                            [2.293753393354043, 48.78739663983609],
                            [2.294066509308887, 48.7872789536328],
                            [2.294242130561358, 48.78720527862897],
                            [2.294540309897511, 48.78704531871662],
                            [2.294733131289556, 48.786932591303355],
                            [2.294890266525972, 48.78680714037315],
                            [2.295008750797257, 48.78670556635819],
                            [2.295189900687894, 48.786527576292656],
                            [2.295259380371177, 48.78644037158626],
                            [2.29530668712442, 48.78638120568621],
                            [2.295360196647731, 48.786309114902636],
                            [2.295477396231926, 48.78611221661797],
                            [2.295522385294267, 48.78601780873976],
                            [2.295605590347802, 48.78578582611702],
                            [2.295654756769304, 48.7855754139589],
                            [2.295667163820924, 48.78538297301532],
                            [2.295663194347215, 48.78524538249386],
                            [2.295618540832719, 48.78493691532291],
                            [2.295584975077274, 48.784778160644585],
                            [2.295492451943212, 48.78436672943394],
                            [2.295452892516807, 48.784152158500575],
                            [2.295422038556265, 48.7839440444778],
                            [2.295415468214076, 48.783662569814],
                            [2.295430614326407, 48.78344944737888],
                            [2.295451119733874, 48.783337045149366],
                            [2.295486623445263, 48.7831904762063],
                            [2.295533003985466, 48.78305380377409],
                            [2.295586182151358, 48.78292522655012],
                            [2.295676141934391, 48.782747202175656],
                            [2.295773048631445, 48.782603495391605],
                            [2.295884583435394, 48.78245591279106],
                            [2.295977204709325, 48.78235073132649],
                            [2.296188298117464, 48.78214037652985],
                            [2.296365313711094, 48.782001051721004],
                            [2.296568186360709, 48.78185723968117],
                            [2.296745173324406, 48.781750288611725],
                            [2.296882671657655, 48.78167659647112],
                            [2.297133364560108, 48.781552825927776],
                            [2.297379531529704, 48.78145105225056],
                            [2.297647677794033, 48.78135672132315],
                        ],
                    },
                },
                308: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.859206627137546, 2.128998127676194],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1212.30743329,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.123191095956036,
                            48.85425170349275,
                            2.13222781675411,
                            48.86121452860313,
                        ),
                        "coordinates": [
                            [2.132132445251102, 48.85425170349275],
                            [2.132211523244792, 48.854628579949164],
                            [2.132225910848351, 48.85477518826893],
                            [2.13222781675411, 48.85497393284356],
                            [2.132190973943386, 48.85531649263748],
                            [2.1321603344847, 48.85547650957962],
                            [2.132151949344838, 48.85552685429834],
                            [2.132074199412369, 48.85587473559721],
                            [2.131725003673335, 48.85727248910103],
                            [2.131706975144982, 48.857347996594626],
                            [2.131539392249747, 48.85799607573047],
                            [2.131484131343375, 48.858176731256705],
                            [2.131405612299056, 48.85837892789731],
                            [2.131318873872262, 48.8585910019674],
                            [2.131111678627425, 48.85897929070143],
                            [2.130930569620161, 48.859220697515276],
                            [2.130771743238963, 48.8593966691957],
                            [2.130596565184352, 48.85957171241241],
                            [2.130415965391015, 48.85973955155124],
                            [2.130209493226999, 48.859901047945],
                            [2.129863696842335, 48.86013603232177],
                            [2.129472980706318, 48.86035654628046],
                            [2.129209434844469, 48.86047657025232],
                            [2.128977327110828, 48.860574169077054],
                            [2.128704339856506, 48.86066989501753],
                            [2.128163880930443, 48.860845166830316],
                            [2.127910073092736, 48.86091664420526],
                            [2.127634472487542, 48.86098448520757],
                            [2.127247193163182, 48.86105601341559],
                            [2.126914344519825, 48.86110096802356],
                            [2.126660759315211, 48.8611193859138],
                            [2.126388128950213, 48.86112877574075],
                            [2.126084181897776, 48.861130912157805],
                            [2.12520791577382, 48.8611050105616],
                            [2.124676381974803, 48.861101325323176],
                            [2.124147481384198, 48.86111922574863],
                            [2.123968896718236, 48.861127885424445],
                            [2.123539397922206, 48.86116755070419],
                            [2.123191095956036, 48.86121452860313],
                        ],
                    },
                },
                309: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.11709859519964, 2.409968071982185],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1600.26786565,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.399724852518912,
                            49.11563266727845,
                            2.420107032801724,
                            49.11902482682648,
                        ),
                        "coordinates": [
                            [2.399724852518912, 49.11902264630466],
                            [2.40008734999755, 49.11902482682648],
                            [2.400500579906065, 49.11901508224722],
                            [2.400873920669871, 49.11899346156345],
                            [2.401399461678388, 49.11893606394205],
                            [2.401790892200709, 49.11888825801243],
                            [2.402146062795225, 49.1188333329668],
                            [2.40258819233905, 49.118749805125205],
                            [2.402986816247692, 49.118661541654745],
                            [2.403394980924829, 49.11856137571291],
                            [2.403776755699988, 49.11844694694775],
                            [2.405400062315582, 49.11797964398466],
                            [2.407632141340071, 49.11734213696873],
                            [2.409232999447281, 49.11687801721664],
                            [2.409634239450425, 49.116763556597185],
                            [2.411650242876779, 49.11618888064514],
                            [2.412298786824015, 49.11600287124851],
                            [2.412874885408582, 49.11585259479356],
                            [2.413302456566346, 49.11575951745221],
                            [2.4137055537204, 49.1156898800109],
                            [2.414119223945466, 49.115652733193194],
                            [2.414538400083871, 49.11563266727845],
                            [2.414982279602019, 49.11564046079079],
                            [2.4153508336342, 49.1156626915916],
                            [2.415800253071774, 49.115708247129845],
                            [2.416213128094022, 49.115781342787784],
                            [2.416651869174905, 49.115876211610875],
                            [2.417018127179638, 49.11597588943403],
                            [2.41738804421984, 49.11609697674325],
                            [2.417743480455973, 49.116227590065314],
                            [2.418378205353224, 49.116467455248426],
                            [2.420107032801724, 49.11713213147004],
                        ],
                    },
                },
                310: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.7058344929096, 2.2024834878813957],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1445.94797575,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192734884806757,
                            48.70540392478545,
                            2.212262378017492,
                            48.7060460974342,
                        ),
                        "coordinates": [
                            [2.192734884806757, 48.70540392478545],
                            [2.192780659873909, 48.70541944755166],
                            [2.192996147896904, 48.705489672116975],
                            [2.193328066179606, 48.70557574732531],
                            [2.193652546988164, 48.70564803526338],
                            [2.19411492176014, 48.70572235125837],
                            [2.19445991302407, 48.70576275650223],
                            [2.194770399463234, 48.70578912073375],
                            [2.195074589346994, 48.70580148793666],
                            [2.1952893263363, 48.70580295908448],
                            [2.196311055557053, 48.705805124284424],
                            [2.198455036128457, 48.70581764335217],
                            [2.198627587870742, 48.70581875219154],
                            [2.199035186064179, 48.705821943704244],
                            [2.200812358643543, 48.70582318353787],
                            [2.200876217960678, 48.70582325961589],
                            [2.202752558028232, 48.70583448043217],
                            [2.204349036103353, 48.70583455345437],
                            [2.204694148403721, 48.70583405543435],
                            [2.205077304500317, 48.70583360033746],
                            [2.207775700912355, 48.70582950083887],
                            [2.208336811852623, 48.70584272691146],
                            [2.209361074374797, 48.70592121648294],
                            [2.210097481551581, 48.706000806721896],
                            [2.210437828093218, 48.70603146184713],
                            [2.210641250529695, 48.70603996787977],
                            [2.210868924053524, 48.7060460974342],
                            [2.211253079669854, 48.70603955668504],
                            [2.211606778268401, 48.70602318084931],
                            [2.211896208893781, 48.70600586491976],
                            [2.212159198330013, 48.70598339683053],
                            [2.212262378017492, 48.705968984822285],
                        ],
                    },
                },
                311: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.82013930910672, 2.234705242288376],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 680.443495258,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.231323159873781,
                            48.81914377292724,
                            2.238598337792144,
                            48.82230993293686,
                        ),
                        "coordinates": [
                            [2.238598337792144, 48.819174329133155],
                            [2.238102328151296, 48.81915366473829],
                            [2.237608844443484, 48.81914377292724],
                            [2.237183530146146, 48.819157624460665],
                            [2.236831178811387, 48.8191826618598],
                            [2.236564198216579, 48.81921570019472],
                            [2.236228468230664, 48.81927575368246],
                            [2.235893215392072, 48.8193563550119],
                            [2.235579152917104, 48.819443246319445],
                            [2.235301950866264, 48.81952952261525],
                            [2.234968639054397, 48.819649536168555],
                            [2.234745110793476, 48.819742861339854],
                            [2.234494276995335, 48.81986853512326],
                            [2.234140633993603, 48.82006621275966],
                            [2.232976612072505, 48.82080690759223],
                            [2.232391567565277, 48.821193961670524],
                            [2.232217484891931, 48.821330273805934],
                            [2.232026165593603, 48.82149427337594],
                            [2.231860063217213, 48.82166067499972],
                            [2.231708379176126, 48.821824709178934],
                            [2.231504489002659, 48.82207713439633],
                            [2.231323159873781, 48.82230993293686],
                        ],
                    },
                },
                312: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.53471116759861, 2.002341357247183],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 973.286577058,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.995901990362833,
                            48.533732833977226,
                            2.008771813873437,
                            48.535620622584574,
                        ),
                        "coordinates": [
                            [1.995901990362833, 48.535620622584574],
                            [1.996149655407846, 48.53560324126843],
                            [1.996587037059659, 48.535559348810345],
                            [1.997030099120749, 48.53550456125951],
                            [1.999272807572155, 48.535186543819215],
                            [2.000910309415123, 48.53494032899217],
                            [2.0024632183799, 48.534695091273704],
                            [2.004712286620207, 48.53435707456925],
                            [2.006203528914461, 48.534126773590195],
                            [2.00703818318476, 48.53399786252292],
                            [2.008771813873437, 48.533732833977226],
                        ],
                    },
                },
                313: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.72990037025463, 2.2430211143938505],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3164.51926549,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.230961125063006,
                            48.723263625741104,
                            2.257355188147784,
                            48.74018152105127,
                        ),
                        "coordinates": [
                            [2.230961125063006, 48.74018152105127],
                            [2.23098445288411, 48.74005463486085],
                            [2.231005115304485, 48.73992875596402],
                            [2.231143956064053, 48.739213062329064],
                            [2.23133755527186, 48.73831846427792],
                            [2.231389850921934, 48.7380199544629],
                            [2.231517696441473, 48.737323953177906],
                            [2.231656540757419, 48.73663082306813],
                            [2.23175387573255, 48.73620350503682],
                            [2.231882518867669, 48.73584596590882],
                            [2.231963112276722, 48.73566438625252],
                            [2.232008167288357, 48.73557360137358],
                            [2.232162381042306, 48.7352931696553],
                            [2.232291468753221, 48.735099776012866],
                            [2.232432384928964, 48.73490133494148],
                            [2.232580970513968, 48.734709925491316],
                            [2.232719962524376, 48.734554478442746],
                            [2.233078269733759, 48.73418880198645],
                            [2.233252619656834, 48.73402619146521],
                            [2.233488217195298, 48.73382946528655],
                            [2.233493663617743, 48.73382497417502],
                            [2.233814975786007, 48.733594152285214],
                            [2.234179822176415, 48.7333462825014],
                            [2.23445747699121, 48.73318736136455],
                            [2.234524164561867, 48.7331505504603],
                            [2.234906581701936, 48.7329494569221],
                            [2.23551344429274, 48.732678418610355],
                            [2.235737927251701, 48.732591388729304],
                            [2.236144698602173, 48.73244247016402],
                            [2.236439876558312, 48.73235280349404],
                            [2.23672445339913, 48.73227419824006],
                            [2.237072339454767, 48.73218789372844],
                            [2.237458585566031, 48.73210280019247],
                            [2.238297745460487, 48.731937355844046],
                            [2.239506660869996, 48.731698998672464],
                            [2.240586452408943, 48.73148139489881],
                            [2.242645351022293, 48.73107754551703],
                            [2.243045151097771, 48.73100413558205],
                            [2.243447185337184, 48.730914953817745],
                            [2.243808099234809, 48.730826706477956],
                            [2.244069249744639, 48.73074688384464],
                            [2.24447733837877, 48.73059973516143],
                            [2.244689559924687, 48.73051357774977],
                            [2.245111320125024, 48.73032147374634],
                            [2.245474628900737, 48.730126624171746],
                            [2.245652896991881, 48.73002245093449],
                            [2.24599179193542, 48.729795206034034],
                            [2.24615921190782, 48.729674837032434],
                            [2.24635314200479, 48.72951398577489],
                            [2.246534985238619, 48.729348699990396],
                            [2.246725557382419, 48.72917050234812],
                            [2.246882206294474, 48.72902253895129],
                            [2.247004806743087, 48.72886571669419],
                            [2.247130581643116, 48.72871225582383],
                            [2.247255534698821, 48.72853812535572],
                            [2.247360508239191, 48.7283673460726],
                            [2.247455657180291, 48.728183600129476],
                            [2.247554207795166, 48.72798980423787],
                            [2.247625189110651, 48.727823493856256],
                            [2.247698952316081, 48.72762211466232],
                            [2.247816720068468, 48.72713570002597],
                            [2.247923688268346, 48.726606111991224],
                            [2.248059462612094, 48.72592816657213],
                            [2.248141523771741, 48.72565681571391],
                            [2.248253442992088, 48.72538425774568],
                            [2.248376146751459, 48.72517392331163],
                            [2.248573433319804, 48.72491324121412],
                            [2.248760285699882, 48.724701203644926],
                            [2.248977463436584, 48.72449121129155],
                            [2.249179594602076, 48.72432023624486],
                            [2.249470816715983, 48.72411902342145],
                            [2.249684426426722, 48.723995986575076],
                            [2.249831348514707, 48.723922358814995],
                            [2.250004108886166, 48.72384065683768],
                            [2.250199982988584, 48.72375447656998],
                            [2.250391756466418, 48.723680882542254],
                            [2.250590318624253, 48.72361089002413],
                            [2.250806540453934, 48.72354720536321],
                            [2.251005077441467, 48.723491599864325],
                            [2.251185929065367, 48.72344497397882],
                            [2.251381724981873, 48.72340195668006],
                            [2.251546241892341, 48.72336880703061],
                            [2.251756971269742, 48.72333659092265],
                            [2.251967689741116, 48.72330977027565],
                            [2.252167523828399, 48.72328923578491],
                            [2.252394532148593, 48.72327411688374],
                            [2.252633760854183, 48.723266201454905],
                            [2.252799584788732, 48.723263625741104],
                            [2.253034710853136, 48.72327099364352],
                            [2.253263039090381, 48.72327925579161],
                            [2.253449218798233, 48.723295579308655],
                            [2.253653057733224, 48.723318210298274],
                            [2.253923472638647, 48.72335617751241],
                            [2.254143593632019, 48.723395905764946],
                            [2.25427946238483, 48.72342567987217],
                            [2.254377288750736, 48.723446434658825],
                            [2.25465035817131, 48.723523969927996],
                            [2.254898956319499, 48.7236041841998],
                            [2.255139382657151, 48.72369608317356],
                            [2.255375729495687, 48.72378887814956],
                            [2.25556723002587, 48.723878941868506],
                            [2.255810318625587, 48.72400591273784],
                            [2.25595289990442, 48.724089647034596],
                            [2.256095466996484, 48.72418147445492],
                            [2.256247523073326, 48.724289494542674],
                            [2.256410423948143, 48.724415508337785],
                            [2.256653404848118, 48.72461352009172],
                            [2.257151574885914, 48.725027535307994],
                            [2.257355188147784, 48.725197641013786],
                        ],
                    },
                },
                314: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.62919225914879, 2.8567102938759077],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 5744.83419298,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.825169932970373,
                            48.61401524181304,
                            2.888252894073074,
                            48.64437362491682,
                        ),
                        "coordinates": [
                            [2.888252894073074, 48.61401524181304],
                            [2.886894329621075, 48.61467212955065],
                            [2.885802317321128, 48.61519792185732],
                            [2.884880059891243, 48.615639616576274],
                            [2.884159618753315, 48.61598752074155],
                            [2.883563242397453, 48.616270973318805],
                            [2.882606602077116, 48.61672612166928],
                            [2.881949900321334, 48.61704089305603],
                            [2.880835011533278, 48.61757456245426],
                            [2.879272266403292, 48.61832752838799],
                            [2.87791919514967, 48.618978801419274],
                            [2.877912453382639, 48.61898243031329],
                            [2.876548261970104, 48.61963911086706],
                            [2.875769655387975, 48.62001241831445],
                            [2.875041009341235, 48.62036569963416],
                            [2.874257033209312, 48.620746216183136],
                            [2.873541783875754, 48.621085934149065],
                            [2.872571551481486, 48.62155544986569],
                            [2.871624187098022, 48.622008662459784],
                            [2.870265275666224, 48.6226670409903],
                            [2.869701179774353, 48.62293947766398],
                            [2.868608063444103, 48.62346798988264],
                            [2.86808172890078, 48.6237213558296],
                            [2.867582412812167, 48.62396470109709],
                            [2.867068189275765, 48.62420991204925],
                            [2.866516171316349, 48.624473282519865],
                            [2.86540945176939, 48.62500452540267],
                            [2.864614544869241, 48.62539132070537],
                            [2.863802010421292, 48.62577999108498],
                            [2.862932793456428, 48.626197695762535],
                            [2.862024477801295, 48.62663985559059],
                            [2.86146834654885, 48.62690411941979],
                            [2.860789435827009, 48.62723279792947],
                            [2.860396639573331, 48.62742076289445],
                            [2.859860792860715, 48.62768042930123],
                            [2.859342498743579, 48.62793281813051],
                            [2.858756654882549, 48.62821249366439],
                            [2.858164039487893, 48.62849399677434],
                            [2.857493197231982, 48.6288199195482],
                            [2.856896526487096, 48.629104132360744],
                            [2.85629585489467, 48.62939555398004],
                            [2.855661428273114, 48.62970331328564],
                            [2.855048579863479, 48.62999928048711],
                            [2.854539659587769, 48.630244410337454],
                            [2.85396457744671, 48.63052041491203],
                            [2.853443446221091, 48.63076649467456],
                            [2.852960138199263, 48.630997112360504],
                            [2.852331050965338, 48.63130033298677],
                            [2.850974292855363, 48.63195307373588],
                            [2.847555928052476, 48.63359891203457],
                            [2.844758429879055, 48.63494600552501],
                            [2.841962128583143, 48.63629212510461],
                            [2.839165686108111, 48.63763907524106],
                            [2.837655994248148, 48.63836517449139],
                            [2.837110458282423, 48.6386292720264],
                            [2.835968161034107, 48.63919275697193],
                            [2.834989031718132, 48.63965659344312],
                            [2.83387742919385, 48.64017315956778],
                            [2.833306136576159, 48.64044364648118],
                            [2.832272303940632, 48.64094103812035],
                            [2.831580240455728, 48.64127852410644],
                            [2.829917742016724, 48.642080726200255],
                            [2.829470702230033, 48.64229579755986],
                            [2.829088472563825, 48.64247821246111],
                            [2.828280821868661, 48.642867505358204],
                            [2.827461026259217, 48.64326493795237],
                            [2.826534447300731, 48.64370689060596],
                            [2.825169932970373, 48.64437362491682],
                        ],
                    },
                },
                315: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.35699076328116, 2.3818403510076025],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 3516.34282922,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.378815443311891,
                            48.34166354461877,
                            2.3872097971981,
                            48.371383292302916,
                        ),
                        "coordinates": [
                            [2.3872097971981, 48.371383292302916],
                            [2.387102683944449, 48.37095631563566],
                            [2.38701318309263, 48.3705355127545],
                            [2.387011823776647, 48.37052562152982],
                            [2.386963008281704, 48.37029903572158],
                            [2.386945379242516, 48.370215414705314],
                            [2.386647111859777, 48.368865791727366],
                            [2.3864790098333, 48.36811050699099],
                            [2.386327319346536, 48.36756743484263],
                            [2.386196082793839, 48.367234775540126],
                            [2.386021903886005, 48.36688206928967],
                            [2.385768892527425, 48.36648589841639],
                            [2.385463534461687, 48.36610925085317],
                            [2.385128516620641, 48.36575779425017],
                            [2.384914270946655, 48.365558075522976],
                            [2.384568001560895, 48.365262555019044],
                            [2.384334367630136, 48.36508010878919],
                            [2.383918417604053, 48.36475206307369],
                            [2.382883442083556, 48.36393481458701],
                            [2.382307340319447, 48.36347941007806],
                            [2.382014303780284, 48.36324842463052],
                            [2.381605052884129, 48.36292963259905],
                            [2.381235092147973, 48.362585998897146],
                            [2.380898788735928, 48.362247120234805],
                            [2.380617827485326, 48.36192170703418],
                            [2.380371961191565, 48.36160527131465],
                            [2.380191187797442, 48.361333038417285],
                            [2.380035715002991, 48.36109890104219],
                            [2.379863901949351, 48.36080784557924],
                            [2.3797341468193, 48.36055700862452],
                            [2.379528188764548, 48.36002777917151],
                            [2.379389136597165, 48.359478057674345],
                            [2.379310362802994, 48.358879196846125],
                            [2.379292650159525, 48.358677774446434],
                            [2.379284476616894, 48.35858785441596],
                            [2.379293694099702, 48.35832167646849],
                            [2.379304247403749, 48.35804021207344],
                            [2.379375397672509, 48.35761754490497],
                            [2.379408951736457, 48.357410707356294],
                            [2.379501698693322, 48.35699972161859],
                            [2.379587809464255, 48.35671912767402],
                            [2.37970225245364, 48.35643762298574],
                            [2.381123242481836, 48.35368001526602],
                            [2.381307990807523, 48.35330203974088],
                            [2.381475250800272, 48.35291320917409],
                            [2.381589066618756, 48.35258276378483],
                            [2.381668674684915, 48.352294664976355],
                            [2.38176677470504, 48.351816404845785],
                            [2.381791755917186, 48.351445150972154],
                            [2.381795790291247, 48.3511928172501],
                            [2.381769778450427, 48.350817092691216],
                            [2.381724997563281, 48.350522393498885],
                            [2.381662533717348, 48.350273500351186],
                            [2.381590034933037, 48.34999528856714],
                            [2.381410933374099, 48.34952543786254],
                            [2.381150116287011, 48.34902196995473],
                            [2.380998758208531, 48.34872348413253],
                            [2.380529925643359, 48.347908962614135],
                            [2.380402639616366, 48.347658685585266],
                            [2.380278918661147, 48.34741569858949],
                            [2.380160058705003, 48.34714765613446],
                            [2.38008797493503, 48.34696314041009],
                            [2.379991870304709, 48.34658729748835],
                            [2.379937618157132, 48.34624920639911],
                            [2.379831473628897, 48.34518275686747],
                            [2.379785173322681, 48.34470402132215],
                            [2.379734957032885, 48.34432402623893],
                            [2.379572517708278, 48.34366225257452],
                            [2.379396661448054, 48.343133411112106],
                            [2.379123643303898, 48.34244126498024],
                            [2.378815443311891, 48.34166354461877],
                        ],
                    },
                },
                316: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.70325792943563, 2.084743768087775],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2045.04859772,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.071242846320578,
                            48.70121772031537,
                            2.097975858420524,
                            48.70404891782436,
                        ),
                        "coordinates": [
                            [2.071242846320578, 48.70275104207728],
                            [2.072053905016768, 48.702821311399966],
                            [2.073003110032174, 48.702909847303324],
                            [2.073392814368726, 48.70295121726831],
                            [2.073630432915237, 48.70297784589057],
                            [2.074151839135939, 48.703035705703826],
                            [2.075403846181076, 48.703158192406335],
                            [2.076138502009198, 48.70322732352774],
                            [2.077705536006643, 48.70338557887386],
                            [2.079848425277684, 48.70358558159166],
                            [2.081851417567684, 48.703780733380285],
                            [2.082408206744542, 48.7038305412462],
                            [2.082787086060977, 48.703866459470326],
                            [2.084418139929283, 48.7040004838145],
                            [2.084640887418912, 48.70401446689678],
                            [2.085119018507342, 48.70403710879418],
                            [2.085579540715796, 48.70404891782436],
                            [2.086185506448927, 48.70404755610668],
                            [2.086953261445827, 48.70402406517083],
                            [2.087669437115315, 48.7039905636731],
                            [2.088150793499402, 48.7039557507473],
                            [2.088658956911798, 48.70390549655373],
                            [2.089066577287838, 48.70385054616717],
                            [2.08949780081503, 48.70379311561894],
                            [2.090151962396165, 48.703689419073314],
                            [2.090751683208182, 48.703575951903744],
                            [2.091328199771092, 48.703455354534405],
                            [2.092025644726726, 48.70328604219953],
                            [2.092575650821441, 48.7031325023861],
                            [2.093608470158545, 48.70280018454701],
                            [2.094279474063904, 48.702552517568066],
                            [2.095067515819321, 48.702262829391834],
                            [2.095725545251577, 48.70201737745888],
                            [2.096352353184927, 48.70178264221469],
                            [2.096945083503258, 48.70156769469486],
                            [2.097396200779455, 48.701406249161494],
                            [2.097975858420524, 48.70121772031537],
                        ],
                    },
                },
                317: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.935266054325524, 2.367476395438841],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 655.95609457,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.363640702197924,
                            48.9335864037298,
                            2.37108317162386,
                            48.93638914706169,
                        ),
                        "coordinates": [
                            [2.37108317162386, 48.9335864037298],
                            [2.370900327950848, 48.93361899736051],
                            [2.370832164505576, 48.93363045885871],
                            [2.370731034662537, 48.933653669966674],
                            [2.370634064240749, 48.93368360790996],
                            [2.370542278010945, 48.933719957035265],
                            [2.370456651101579, 48.93376233128679],
                            [2.370400976098924, 48.933795268343104],
                            [2.370200582967197, 48.93394132426102],
                            [2.368020774592565, 48.93552241778671],
                            [2.3680085136018, 48.93552988194713],
                            [2.367915454166445, 48.935580835690764],
                            [2.367815654581574, 48.935625915651606],
                            [2.367709967228832, 48.935664735121335],
                            [2.367599294291298, 48.93569696610993],
                            [2.367484578295947, 48.935722331202705],
                            [2.367366799240526, 48.93574061523644],
                            [2.367276737560029, 48.93574960838819],
                            [2.367275196393754, 48.93574972705125],
                            [2.364869333432989, 48.9359913574374],
                            [2.364723788004321, 48.936011136525536],
                            [2.36457269926915, 48.93603872871091],
                            [2.364427534041617, 48.93607730900362],
                            [2.364303078675548, 48.936123588030014],
                            [2.364023545789006, 48.936232008460166],
                            [2.36371576946455, 48.93635315335522],
                            [2.363640702197924, 48.93638914706169],
                        ],
                    },
                },
                318: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.79377959594914, 2.0579754964503536],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 2386.69178239,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.044621987173176,
                            48.787390238280715,
                            2.071847005929401,
                            48.79870763528835,
                        ),
                        "coordinates": [
                            [2.044621987173176, 48.787390238280715],
                            [2.044851105628235, 48.78750349640637],
                            [2.046741304126305, 48.78844003846329],
                            [2.047258327554183, 48.78869832312603],
                            [2.048565214852195, 48.78936071667585],
                            [2.049383771745726, 48.78978630894997],
                            [2.051178973182095, 48.79070687265457],
                            [2.052959877315797, 48.79162023425542],
                            [2.054245460494912, 48.792256337309674],
                            [2.058741619891684, 48.794489710908344],
                            [2.061679413663929, 48.79595062396591],
                            [2.062070911434097, 48.79614191596519],
                            [2.062516342039329, 48.79634999307187],
                            [2.062907965074912, 48.79651986861153],
                            [2.063242176986505, 48.796651535583436],
                            [2.063705846985577, 48.79681920285661],
                            [2.064173185834679, 48.79697497863914],
                            [2.064637031043277, 48.797111711223465],
                            [2.066485347074011, 48.79761321151646],
                            [2.067965653930496, 48.797961639157485],
                            [2.069370074197862, 48.79828149046026],
                            [2.069903062061266, 48.79839604889063],
                            [2.070856322002004, 48.79857633553913],
                            [2.071332370669918, 48.79864848827117],
                            [2.071695582347995, 48.79869339867155],
                            [2.071847005929401, 48.79870763528835],
                        ],
                    },
                },
                319: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.90712365088222, 2.452240682286362],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 422.337607947,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.450004663029331,
                            48.90653328847081,
                            2.454352826517924,
                            48.907967202241124,
                        ),
                        "coordinates": [
                            [2.454352826517924, 48.90781254678193],
                            [2.453798692319693, 48.907945108842576],
                            [2.453698844293073, 48.90795970420636],
                            [2.453597189128823, 48.90796709773942],
                            [2.453494917421039, 48.907967202241124],
                            [2.453393227053841, 48.90796001598142],
                            [2.453293312256158, 48.90794562534897],
                            [2.453196343212233, 48.90792419756363],
                            [2.453103457827214, 48.907895985134786],
                            [2.453015744074903, 48.90786131768685],
                            [2.452934230447519, 48.90782060191506],
                            [2.452859872378375, 48.907774315227556],
                            [2.452793542748274, 48.90772300030558],
                            [2.452736019674303, 48.90766725875173],
                            [2.452696542942403, 48.90761957372287],
                            [2.452645087191625, 48.90753072420071],
                            [2.452609831360226, 48.9074427211789],
                            [2.452427881501575, 48.906877302874115],
                            [2.452405785373768, 48.906810483585964],
                            [2.452378120673296, 48.9067558378569],
                            [2.452340083170767, 48.906703973896285],
                            [2.452307209485594, 48.90666700708148],
                            [2.452258313634045, 48.90662816389161],
                            [2.452183352535916, 48.90659726551411],
                            [2.452099551123099, 48.90657105338204],
                            [2.452011632785909, 48.90655155812618],
                            [2.451920834675909, 48.90653905518926],
                            [2.451790536048414, 48.906533620679454],
                            [2.450004663029331, 48.90653328847081],
                        ],
                    },
                },
                320: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.89815162113899, 2.4629076150960576],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 626.339001699,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.460330069519439,
                            48.89591583620302,
                            2.465460481358355,
                            48.90041730406597,
                        ),
                        "coordinates": [
                            [2.460330069519439, 48.89591583620302],
                            [2.460525078440618, 48.89606602003162],
                            [2.460676545684093, 48.896200265023246],
                            [2.460799642481189, 48.896325247785185],
                            [2.460892454246844, 48.89641745633996],
                            [2.461119310778047, 48.89660443742263],
                            [2.46214544506194, 48.89748946193119],
                            [2.462726575983945, 48.89795693989776],
                            [2.463096466097705, 48.89828328660894],
                            [2.463794022699063, 48.89891284948797],
                            [2.465135793088446, 48.90012670247856],
                            [2.465460481358355, 48.90041730406597],
                        ],
                    },
                },
                321: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.54158017398183, 3.132339202182192],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 18930.2274681,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.011769326340159,
                            48.51375459097529,
                            3.250034982583049,
                            48.562124835009335,
                        ),
                        "coordinates": [
                            [3.250034982583049, 48.51375459097529],
                            [3.249853945357546, 48.51389872290486],
                            [3.249138844995903, 48.51447015954613],
                            [3.247753636545094, 48.51563334044736],
                            [3.246758844411207, 48.51645882048767],
                            [3.246041668711754, 48.51706892450682],
                            [3.245649465686489, 48.51738683453011],
                            [3.245209903375309, 48.5177060229367],
                            [3.244929359176486, 48.51791151926874],
                            [3.244497516600703, 48.51820905850838],
                            [3.244084047518781, 48.518474973117506],
                            [3.243663593912424, 48.518729250947516],
                            [3.243276501400833, 48.51895717945212],
                            [3.24298857430668, 48.51912945551102],
                            [3.242645385238286, 48.519314425227265],
                            [3.242136961404717, 48.519571902305024],
                            [3.241798657694586, 48.5197298657957],
                            [3.241457664070075, 48.51988784905679],
                            [3.241039197446301, 48.520069650141146],
                            [3.240448496523091, 48.52030087851992],
                            [3.239557288674779, 48.520651524807924],
                            [3.238441656931013, 48.52109478124457],
                            [3.237391669432112, 48.52150063351466],
                            [3.236347255484608, 48.52191632466226],
                            [3.235285488950892, 48.522337250278],
                            [3.234365570085992, 48.52268567380888],
                            [3.233755261989401, 48.52292869057292],
                            [3.232861321848435, 48.523281240508254],
                            [3.232035885563069, 48.52360612638846],
                            [3.230844718761034, 48.524072387904965],
                            [3.229430345244032, 48.524625830772884],
                            [3.227673709987366, 48.52529554060056],
                            [3.225588891633128, 48.52611922690337],
                            [3.224679813252694, 48.52646629779769],
                            [3.223682271251082, 48.52685982209516],
                            [3.222502957180112, 48.527320603065974],
                            [3.220706679366514, 48.52803250392],
                            [3.218524096889001, 48.52887688451809],
                            [3.217145530280503, 48.52941623057007],
                            [3.216042838639051, 48.52983415663934],
                            [3.215070703394111, 48.530185567322945],
                            [3.214098824653648, 48.53052005030102],
                            [3.212262189287973, 48.531133270260696],
                            [3.211258078677476, 48.531476469914644],
                            [3.210488256671631, 48.531745010113106],
                            [3.20983147652462, 48.53197400301876],
                            [3.20773178410411, 48.532699724273094],
                            [3.20649070083182, 48.53312384273446],
                            [3.204363522912061, 48.5338631097363],
                            [3.203561324348018, 48.53414106600199],
                            [3.202600035881683, 48.53447187593961],
                            [3.201604929095662, 48.5348079771379],
                            [3.201017600239632, 48.53501227341592],
                            [3.200412362702639, 48.53522546759334],
                            [3.199789416124002, 48.53543503525303],
                            [3.199307558779785, 48.53557773570062],
                            [3.198801710715775, 48.5357139002397],
                            [3.198339811005731, 48.535838196855515],
                            [3.197922815967738, 48.535942206308],
                            [3.197436122316396, 48.53604740952538],
                            [3.196924097493987, 48.536151449072094],
                            [3.196406272389532, 48.53624408225733],
                            [3.195765166901817, 48.536346614464804],
                            [3.195154189062761, 48.536432536302236],
                            [3.194652856395575, 48.53649478781314],
                            [3.193645680817977, 48.53659323762959],
                            [3.19265693272599, 48.536660962975574],
                            [3.191890856351761, 48.53668383189958],
                            [3.190948450629059, 48.536690039423775],
                            [3.190214240283105, 48.53667578505952],
                            [3.189431985313782, 48.53663611795202],
                            [3.188763841827345, 48.53659226871273],
                            [3.188058502824284, 48.53652382458915],
                            [3.187237601817624, 48.53642836526992],
                            [3.186337789008579, 48.536311007942096],
                            [3.184403767562205, 48.53605569323023],
                            [3.182431670942092, 48.535789838231885],
                            [3.181055479998649, 48.53560764539772],
                            [3.179885618917621, 48.53545447666611],
                            [3.178502660561405, 48.5352714036136],
                            [3.177724974621389, 48.53516656072753],
                            [3.176424760047027, 48.53499094203191],
                            [3.174262802065457, 48.53470297047485],
                            [3.172870423691708, 48.534520798309735],
                            [3.169903832762767, 48.5341316587778],
                            [3.168747879502285, 48.533996260132675],
                            [3.168147771849165, 48.53393023725482],
                            [3.167499263779493, 48.53387431693945],
                            [3.16709572080642, 48.53384515129412],
                            [3.166692238389889, 48.53381955368603],
                            [3.166061993587139, 48.533791117755705],
                            [3.164978130007166, 48.53375587654628],
                            [3.16378894386412, 48.533738481320356],
                            [3.162903440036716, 48.53374314054031],
                            [3.162365255449034, 48.5337541515964],
                            [3.161656850673534, 48.533775603691815],
                            [3.160987396839414, 48.53381036193435],
                            [3.159994317769176, 48.53387375923635],
                            [3.15927218159047, 48.53393412826336],
                            [3.158919305729981, 48.533967264710874],
                            [3.158373110997732, 48.53401978891238],
                            [3.157395905592261, 48.53413028976209],
                            [3.156772959585215, 48.53420944186886],
                            [3.156363582890293, 48.53426546277316],
                            [3.155515424325035, 48.534391610763095],
                            [3.154679469972308, 48.534538430487245],
                            [3.153942756618073, 48.53467600142997],
                            [3.153329965299476, 48.53480216163728],
                            [3.152777910311315, 48.534923527803116],
                            [3.152103397177411, 48.53508668732859],
                            [3.151150991228357, 48.53530847062247],
                            [3.150469732657855, 48.53546714684498],
                            [3.149561876351572, 48.53568140262141],
                            [3.148969636321698, 48.53581874637556],
                            [3.147920107952338, 48.53606547942096],
                            [3.146858354889337, 48.53631049197145],
                            [3.146023147843207, 48.53649722008421],
                            [3.14490348682026, 48.536763311752246],
                            [3.143267193716167, 48.53715537643393],
                            [3.142208117891897, 48.537401225541814],
                            [3.141529495522832, 48.537558928598095],
                            [3.140142610581884, 48.537884425897964],
                            [3.139155122735691, 48.53812074568456],
                            [3.138359038846482, 48.53830174435092],
                            [3.138041958613676, 48.53837413300859],
                            [3.137374200647418, 48.538535331278105],
                            [3.136985653771198, 48.53862710701978],
                            [3.135090028836219, 48.53906944650952],
                            [3.13381352113094, 48.539358115573876],
                            [3.132608709487235, 48.539642669863674],
                            [3.131626512588099, 48.53987528927635],
                            [3.130605036066385, 48.54010817486039],
                            [3.129742994026311, 48.540318352680806],
                            [3.129091261897971, 48.540468598319706],
                            [3.128484070626437, 48.540609536634065],
                            [3.12787825815666, 48.54075225957793],
                            [3.127012031383058, 48.540956151111395],
                            [3.126078333061371, 48.54117579263791],
                            [3.12411768625052, 48.541629191303464],
                            [3.120941283457941, 48.54237065892662],
                            [3.117901110811394, 48.54308231959451],
                            [3.117299272649429, 48.54322316004994],
                            [3.114935025965158, 48.54377360473222],
                            [3.114287295559121, 48.54392553610051],
                            [3.112541059051712, 48.54433229721375],
                            [3.111847437449446, 48.54449532053042],
                            [3.109492578192943, 48.5450473854617],
                            [3.108365650791605, 48.545305968975626],
                            [3.105821835994189, 48.54590600648883],
                            [3.103650310548614, 48.54640994146619],
                            [3.101285845555926, 48.5469654971732],
                            [3.097734899902423, 48.54779426483861],
                            [3.095715730592144, 48.548263745542705],
                            [3.094916695703703, 48.54844985133962],
                            [3.093757252919604, 48.54871839658532],
                            [3.093282136219811, 48.54882858455425],
                            [3.091859481183006, 48.54915911963083],
                            [3.089720122314041, 48.54965986920119],
                            [3.087837150947541, 48.55009862744388],
                            [3.085271061882689, 48.55069204930398],
                            [3.08446929492454, 48.55088169636795],
                            [3.083346254485842, 48.55114629684202],
                            [3.08178987602475, 48.551510858857185],
                            [3.077856149761744, 48.55242155099415],
                            [3.077008534714337, 48.55262187856622],
                            [3.075961145805754, 48.55286784255948],
                            [3.074940598906934, 48.553111836429025],
                            [3.073909106396766, 48.55334340005444],
                            [3.072960770269283, 48.553563707860455],
                            [3.072135698142945, 48.55375822502891],
                            [3.071313045462485, 48.553934873457585],
                            [3.070610738023913, 48.554069693820395],
                            [3.069986036783935, 48.55418080703257],
                            [3.06937558422581, 48.55428617489089],
                            [3.068574371997201, 48.554398422471614],
                            [3.067865849386374, 48.55447675441995],
                            [3.067107115382745, 48.554553025317375],
                            [3.065040411280048, 48.554752837811805],
                            [3.06359014450487, 48.55488534618906],
                            [3.062009473752052, 48.555025194893716],
                            [3.061092680987014, 48.55510906501933],
                            [3.059378646121201, 48.55527018288535],
                            [3.058118125786075, 48.555385322965634],
                            [3.057165302767761, 48.55547132042359],
                            [3.055322690347238, 48.555642187254584],
                            [3.053001077492066, 48.55585292094307],
                            [3.049947482324466, 48.55612846712036],
                            [3.048252200809361, 48.556279406405196],
                            [3.045097126257802, 48.55656714974675],
                            [3.043580570400756, 48.5567133056116],
                            [3.040996384036385, 48.55694791239956],
                            [3.040103363556948, 48.55702539829785],
                            [3.038634000989672, 48.55715770568853],
                            [3.037293140737366, 48.5572766107589],
                            [3.035643838746968, 48.55742707779664],
                            [3.034163690882344, 48.55756478982158],
                            [3.033353280096604, 48.55764171458729],
                            [3.032004254794427, 48.55775970680259],
                            [3.030923125387875, 48.55785356219038],
                            [3.029524142644331, 48.55798442079056],
                            [3.025989951964486, 48.55830272366499],
                            [3.024960189425027, 48.55838991447917],
                            [3.023929242114034, 48.55848969300562],
                            [3.021603228169595, 48.55869441421202],
                            [3.021076775685551, 48.55873446394976],
                            [3.020474671050076, 48.55879025482424],
                            [3.019850997161139, 48.55884729572404],
                            [3.019292611779082, 48.558905383348964],
                            [3.018734549412604, 48.55898726138023],
                            [3.018291050030732, 48.559058929132455],
                            [3.017929953753836, 48.55912772226823],
                            [3.017590559295051, 48.55920059864839],
                            [3.017194494254066, 48.55929464055645],
                            [3.016827162414875, 48.559392548736675],
                            [3.016424028134937, 48.55951488257897],
                            [3.016056068111987, 48.55963336922651],
                            [3.015676191709057, 48.55977418039796],
                            [3.015210056313884, 48.559965050489836],
                            [3.01460137873621, 48.560258091731235],
                            [3.014123955959843, 48.56050439353964],
                            [3.013723247820952, 48.56074176193987],
                            [3.013341726240904, 48.56098145302508],
                            [3.012867991809824, 48.561315219453775],
                            [3.012291165334066, 48.561740426398096],
                            [3.011769326340159, 48.562124835009335],
                        ],
                    },
                },
                322: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.76202702315821, 2.8891947127560473],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 6789.11276818,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.868955830083688,
                            48.73493929649145,
                            2.907866786241034,
                            48.78949667687371,
                        ),
                        "coordinates": [
                            [2.907387270372533, 48.78949667687371],
                            [2.907672278124837, 48.78857671836464],
                            [2.90774467243484, 48.788243613896185],
                            [2.907788550683037, 48.787916047231555],
                            [2.907814390355671, 48.787642940890585],
                            [2.907858952362596, 48.78717197069109],
                            [2.907866786241034, 48.78687855133041],
                            [2.907837649454092, 48.78661990569762],
                            [2.90777130445866, 48.78605637458288],
                            [2.907653744742842, 48.785536266942074],
                            [2.907491199073863, 48.78500919081661],
                            [2.907362568962345, 48.7846706045163],
                            [2.907163062247064, 48.78428239813506],
                            [2.906961524018084, 48.78391469196295],
                            [2.906796109871589, 48.78362649801079],
                            [2.906535279261195, 48.78329450669294],
                            [2.906198622914274, 48.782891503082645],
                            [2.905217087029088, 48.781905372237745],
                            [2.904238320683652, 48.78092011786055],
                            [2.903258222537577, 48.77993396401712],
                            [2.903064209036372, 48.77974517559402],
                            [2.902087011441527, 48.77877068744661],
                            [2.901059173085188, 48.77776676562529],
                            [2.900229060352602, 48.7769174363788],
                            [2.899104680375913, 48.77579166909271],
                            [2.898412183864179, 48.77507384495052],
                            [2.897693764563782, 48.77434805074234],
                            [2.897238381291322, 48.773901540323834],
                            [2.896877931853254, 48.77354808870332],
                            [2.895910666136787, 48.77258788938728],
                            [2.895353430141775, 48.77203395547823],
                            [2.894724667435965, 48.77140932391289],
                            [2.893732573600871, 48.7704114581142],
                            [2.893420241071258, 48.77009822880923],
                            [2.892915297693068, 48.769592590248884],
                            [2.892499481767197, 48.76914856682951],
                            [2.892145240574735, 48.768735716352914],
                            [2.891924142652818, 48.76842833370249],
                            [2.891553053963667, 48.76784559590744],
                            [2.89102230376021, 48.7669731604868],
                            [2.890682823899723, 48.766417245497955],
                            [2.890163206537758, 48.76556453635456],
                            [2.889833447988031, 48.765024758735535],
                            [2.889649177179815, 48.76472348832138],
                            [2.889300016273418, 48.764150530187564],
                            [2.888730391989809, 48.76320003384317],
                            [2.888314867743198, 48.762528470507114],
                            [2.887870034134938, 48.76178870169665],
                            [2.887439084538023, 48.76107314482548],
                            [2.887052565173101, 48.760438308503495],
                            [2.886695144025573, 48.759850993635666],
                            [2.886449995452512, 48.75945288737531],
                            [2.886064920778273, 48.75882343751583],
                            [2.885786307295673, 48.75834995036194],
                            [2.885308481863254, 48.757571660438785],
                            [2.885002304938059, 48.757064131804306],
                            [2.884632385771341, 48.75644899196209],
                            [2.884247495922932, 48.755832125464536],
                            [2.883766869645194, 48.75504215246377],
                            [2.883455274074854, 48.754533746420165],
                            [2.882992609559591, 48.75376706528362],
                            [2.882656028252816, 48.75321111387641],
                            [2.881024564387434, 48.75052372459487],
                            [2.880433240123644, 48.74954991123406],
                            [2.879792014317041, 48.74848730200429],
                            [2.879153556386817, 48.747426475554796],
                            [2.878513745435965, 48.74636385258965],
                            [2.877858868157162, 48.74528870887593],
                            [2.877204017843514, 48.74421356057026],
                            [2.876550557150757, 48.74313840278631],
                            [2.876324888405327, 48.74276626318562],
                            [2.875569790068015, 48.74155031159599],
                            [2.875145825594815, 48.740862636944534],
                            [2.874990819182418, 48.74061066671271],
                            [2.874768339670694, 48.74027987814688],
                            [2.874582794233398, 48.74000318268982],
                            [2.874250517146026, 48.73954310092453],
                            [2.873842935757708, 48.73906749822995],
                            [2.873517980601827, 48.73868862821459],
                            [2.872943552196497, 48.738121180315865],
                            [2.872481936260866, 48.73769878278018],
                            [2.871930303787981, 48.73720326941313],
                            [2.871022361279409, 48.73646651389438],
                            [2.870270076725789, 48.735916974866626],
                            [2.869692909211364, 48.735468231922106],
                            [2.868955830083688, 48.73493929649145],
                        ],
                    },
                },
                323: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.12445410755038, 2.2868201684168663],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2289.26535467,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.280515369819846,
                            49.114061951542226,
                            2.289505921794906,
                            49.132577702391806,
                        ),
                        "coordinates": [
                            [2.287915343526005, 49.114061951542226],
                            [2.28830659168989, 49.11662558755965],
                            [2.288357021538845, 49.11694681759301],
                            [2.288436428022629, 49.11729423362733],
                            [2.288530398751394, 49.11757503319891],
                            [2.288631616968672, 49.1178582150244],
                            [2.288750936667034, 49.11816757774532],
                            [2.289022194121215, 49.118795832827736],
                            [2.289166845941157, 49.119152791886634],
                            [2.289315067602379, 49.11956923508511],
                            [2.28940535844051, 49.11991665447931],
                            [2.289470277591376, 49.120261683187564],
                            [2.289502586187276, 49.12059242252884],
                            [2.289505921794906, 49.12089459871056],
                            [2.289491108991441, 49.12122055938044],
                            [2.289450948405008, 49.12151795854032],
                            [2.289396264519452, 49.12183676557945],
                            [2.289309002235829, 49.12210559329852],
                            [2.289185413794657, 49.12245054436564],
                            [2.289025560035484, 49.122807376904],
                            [2.288778564160312, 49.12330217279451],
                            [2.286573635496457, 49.12762684137346],
                            [2.285966938726975, 49.1288186157871],
                            [2.285828883434149, 49.12908979748605],
                            [2.285658151143287, 49.12940379196838],
                            [2.285491087357516, 49.12967496006374],
                            [2.285309545760705, 49.129919949243515],
                            [2.285095374180886, 49.13016254407357],
                            [2.284892118396909, 49.130364695057075],
                            [2.284616297801082, 49.13061201968683],
                            [2.284264309722811, 49.13088310223222],
                            [2.28395226881371, 49.13108995957257],
                            [2.283578579262125, 49.13130154707487],
                            [2.283226685066815, 49.131475073809455],
                            [2.28270431532732, 49.13170086459664],
                            [2.282171075949369, 49.13191475127873],
                            [2.280538684486732, 49.132568276914796],
                            [2.280515369819846, 49.132577702391806],
                        ],
                    },
                },
                324: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.04923516685733, 2.115634104154819],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1621.37120524,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.107233059674136,
                            49.04539401994291,
                            2.122735908273571,
                            49.05510176049028,
                        ),
                        "coordinates": [
                            [2.107233059674136, 49.04539401994291],
                            [2.108136477562507, 49.04551189824994],
                            [2.108740469746825, 49.04561541338749],
                            [2.109232236145258, 49.04572346070429],
                            [2.109691383926692, 49.04584096050178],
                            [2.110045600330533, 49.04595111052167],
                            [2.110262426900967, 49.0460276793396],
                            [2.110941680988262, 49.0462978858753],
                            [2.112086523335931, 49.046866418921624],
                            [2.112592143336525, 49.04711724077516],
                            [2.113378651037956, 49.047529451110684],
                            [2.115749294818896, 49.048734071786484],
                            [2.116048234886255, 49.0488857271039],
                            [2.11674795521901, 49.04924721447272],
                            [2.117195745839415, 49.04948838555114],
                            [2.117639847013364, 49.049746205520144],
                            [2.118018869659705, 49.04998724318897],
                            [2.11834727982538, 49.05021390645694],
                            [2.118685888003766, 49.05045641849523],
                            [2.119218937350977, 49.050889085065876],
                            [2.119690735073348, 49.051323309934894],
                            [2.119950270856517, 49.05157505979811],
                            [2.120051396568381, 49.051687421730406],
                            [2.12032205009989, 49.051988340151055],
                            [2.120909893430428, 49.0527960519349],
                            [2.121177645922871, 49.05320662637218],
                            [2.121400590726058, 49.05353887922251],
                            [2.121403308274942, 49.05354337986806],
                            [2.121505229437814, 49.05370364262508],
                            [2.121883523535363, 49.05418276809344],
                            [2.122051018320342, 49.05436743394621],
                            [2.122400970914177, 49.05475837514959],
                            [2.122417319959997, 49.05477459313916],
                            [2.122424126367783, 49.05478269888339],
                            [2.122735908273571, 49.05510176049028],
                        ],
                    },
                },
                325: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.59833436362864, 2.4677402019484362],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2686.51176741,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.46365049758796,
                            48.58715390715936,
                            2.473490366344224,
                            48.60904470232516,
                        ),
                        "coordinates": [
                            [2.467812581880024, 48.60904470232516],
                            [2.467259560906871, 48.60853134026008],
                            [2.466704945525497, 48.60801616735327],
                            [2.46588132594399, 48.60729373512432],
                            [2.465619027136802, 48.607065620897735],
                            [2.465432737139466, 48.606865296626566],
                            [2.46515806954535, 48.6065715487432],
                            [2.464860210693563, 48.60622297177405],
                            [2.464716267368065, 48.60602693482228],
                            [2.464611179190008, 48.60587703686077],
                            [2.464524065677236, 48.60574764178742],
                            [2.464445117931386, 48.60562992695782],
                            [2.46433746671555, 48.605422318229834],
                            [2.464207714114394, 48.60517097520503],
                            [2.464102957901666, 48.60491989381582],
                            [2.463951372239219, 48.60453598814933],
                            [2.463838045701175, 48.6041899891358],
                            [2.46376545770558, 48.603905903244126],
                            [2.463717369419082, 48.60365775977019],
                            [2.46368975473947, 48.60346265073572],
                            [2.463667458955063, 48.6032261688976],
                            [2.463653526442768, 48.60307960471047],
                            [2.46365049758796, 48.602954610170784],
                            [2.463668469366315, 48.60255711598949],
                            [2.463695916796384, 48.602346545274216],
                            [2.463723036762776, 48.6021550837382],
                            [2.463743056868722, 48.60203006339373],
                            [2.463777768634583, 48.601862876762574],
                            [2.463851730034211, 48.60157761168084],
                            [2.463902849554118, 48.6014192837425],
                            [2.463982694295215, 48.601210762176976],
                            [2.464074258166806, 48.60097252482469],
                            [2.464203124666076, 48.600692302823724],
                            [2.464384011875606, 48.60036655149375],
                            [2.464519186514138, 48.600135339156516],
                            [2.464662390244777, 48.59993464184954],
                            [2.465093456470842, 48.59937481297758],
                            [2.465547696147623, 48.598867113109414],
                            [2.466752277896092, 48.59755191374214],
                            [2.467633710346566, 48.596591386072596],
                            [2.468347434459824, 48.59579471152539],
                            [2.46922744442761, 48.59483237359307],
                            [2.470400741720214, 48.59355044564892],
                            [2.470691332374389, 48.59322546889875],
                            [2.471274980816786, 48.59248828074433],
                            [2.471536995780791, 48.59212736566556],
                            [2.471894699431132, 48.59156130314163],
                            [2.472664912188532, 48.59015393626952],
                            [2.472899382178316, 48.589641974966014],
                            [2.473122823003963, 48.58906348133528],
                            [2.473207461132328, 48.58878550717733],
                            [2.473389653854507, 48.58799663629103],
                            [2.473490366344224, 48.58715390715936],
                        ],
                    },
                },
                326: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.95374366552486, 2.2439538301797435],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2255.43457812,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.231110035011993,
                            48.950304353547466,
                            2.25508371139436,
                            48.95603120205498,
                        ),
                        "coordinates": [
                            [2.25508371139436, 48.95101678180594],
                            [2.254921549225827, 48.95165221283468],
                            [2.254884998865097, 48.951906775811715],
                            [2.254856445777283, 48.95207975427657],
                            [2.254801844897676, 48.9523271671612],
                            [2.254707444005894, 48.952610239990086],
                            [2.254587760587532, 48.95288853767845],
                            [2.254464522583103, 48.953131142181334],
                            [2.254290649363522, 48.953407021537714],
                            [2.254120469110216, 48.953632935219936],
                            [2.253961202977405, 48.95381127083217],
                            [2.253838151234981, 48.953939664311726],
                            [2.253548660036974, 48.954213079124514],
                            [2.253244760135622, 48.95446030992415],
                            [2.252944518815264, 48.954678988977214],
                            [2.252655176735339, 48.9548596066055],
                            [2.252336937191794, 48.955035443504244],
                            [2.252018724767871, 48.95519462504646],
                            [2.251657158006386, 48.95535139126356],
                            [2.251205249525729, 48.955517610190945],
                            [2.250731694508429, 48.955662394495256],
                            [2.250312404539619, 48.95576676897383],
                            [2.24980640731436, 48.95586631893533],
                            [2.249304063103541, 48.95594207401254],
                            [2.248769234527907, 48.95599876826722],
                            [2.248281429064058, 48.956024567042306],
                            [2.247634683629114, 48.95603120205498],
                            [2.247013302793014, 48.955997405676825],
                            [2.246475057949377, 48.95594463758255],
                            [2.245951314722693, 48.9558657055799],
                            [2.245481786619101, 48.95577491731696],
                            [2.245052029120419, 48.955672261615085],
                            [2.244629528586005, 48.955552955828374],
                            [2.244199853611307, 48.955407469307055],
                            [2.243719681661203, 48.95521911322948],
                            [2.237629727357868, 48.95265145478149],
                            [2.235416993589458, 48.951719194728554],
                            [2.234146408152569, 48.95119222987754],
                            [2.233720456589484, 48.951025294111304],
                            [2.233247537452552, 48.950863070829904],
                            [2.232691552572382, 48.950688876011085],
                            [2.232182473393724, 48.950545651828534],
                            [2.231550585693242, 48.95039279475235],
                            [2.231110035011993, 48.950304353547466],
                        ],
                    },
                },
                327: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.968167875718265, 2.5119952225627604],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1267.04694193,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.510794502536983,
                            48.962709513300425,
                            2.514360285533493,
                            48.97342490721535,
                        ),
                        "coordinates": [
                            [2.512644627819613, 48.962709513300425],
                            [2.51253367660992, 48.962883830758834],
                            [2.511579694576398, 48.96442282787217],
                            [2.511430964711348, 48.96467145879541],
                            [2.511311410157439, 48.96489435047717],
                            [2.511214520160336, 48.96508722483509],
                            [2.511140301276273, 48.965254367783466],
                            [2.511069388178855, 48.96543649572448],
                            [2.510998544601292, 48.96563789746363],
                            [2.5109374522591, 48.96583928313796],
                            [2.510889344088356, 48.96603208532463],
                            [2.510854219275904, 48.966218440652305],
                            [2.510822371781356, 48.96641121734397],
                            [2.510806792606764, 48.9666061106377],
                            [2.510794502536983, 48.96681170486373],
                            [2.510795131759407, 48.966991583826314],
                            [2.51080237496525, 48.967201431060694],
                            [2.510822532248843, 48.96738556211583],
                            [2.5108426780662, 48.967565410876524],
                            [2.510872574447887, 48.96774310341048],
                            [2.510918830159858, 48.96794860886313],
                            [2.510987959572485, 48.96818405979442],
                            [2.511053730193194, 48.968389535866336],
                            [2.511171844494645, 48.96868059060173],
                            [2.511325857016991, 48.969005851224594],
                            [2.51148291809776, 48.969271147914014],
                            [2.511682457417031, 48.969592056623746],
                            [2.51187860899922, 48.9698744247755],
                            [2.512365766322083, 48.97058463047277],
                            [2.514360285533493, 48.97342490721535],
                        ],
                    },
                },
                328: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.587632417399725, 2.2541755974922735],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2059.41739555,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.241070080902974,
                            48.58564905652479,
                            2.266937972614161,
                            48.591460820223375,
                        ),
                        "coordinates": [
                            [2.241070080902974, 48.58600789080001],
                            [2.242084455186498, 48.58594756803607],
                            [2.243244380386634, 48.58588191019452],
                            [2.24518763061134, 48.585766910831964],
                            [2.245980996473156, 48.58571924839891],
                            [2.246327467778501, 48.58569787421666],
                            [2.246809508060314, 48.585671609704285],
                            [2.247271452883254, 48.585651989014636],
                            [2.247778554485241, 48.58564905652479],
                            [2.248285616521396, 48.58566777339114],
                            [2.248692252093051, 48.5856930732241],
                            [2.248985920442405, 48.585719948270935],
                            [2.249246943696469, 48.58575179549462],
                            [2.249723790058498, 48.58582377888461],
                            [2.25020812668337, 48.58592074902591],
                            [2.250679882833715, 48.5860343627792],
                            [2.251118994081004, 48.58615627646565],
                            [2.251545529507748, 48.586291504017275],
                            [2.25192438989098, 48.586416700613796],
                            [2.253239129963109, 48.58684404584783],
                            [2.255933926869488, 48.58771539233423],
                            [2.26102017922893, 48.58935443041366],
                            [2.263203327353522, 48.59006037622496],
                            [2.264305584422156, 48.590417635461435],
                            [2.264839473848621, 48.59058772532614],
                            [2.265346363454804, 48.59076792003928],
                            [2.265707891162466, 48.59090682001625],
                            [2.266204508183534, 48.5911148827013],
                            [2.266704982341543, 48.59134178320871],
                            [2.266937972614161, 48.591460820223375],
                        ],
                    },
                },
                329: {
                    "attributes": {
                        "reseau": "CDGVAL",
                        "val": 1,
                        "metro": 0,
                        "res_com": "CDGVAL",
                        "rer": 0,
                        "extcode": "043043100:CDGVAL",
                        "geo_point_2d": [49.01048876935357, 2.5427309096204995],
                        "indice_lig": "CDG",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Navette",
                        "tramway": 0,
                        "idrefligc": "C00563",
                        "navette": 1,
                        "idrefliga": "A01516",
                        "shape_leng": 640.350586399,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.541951696822008,
                            49.00892721987235,
                            2.54483189791712,
                            49.01340270477389,
                        ),
                        "coordinates": [
                            [2.541951696822008, 49.01340270477389],
                            [2.542062406171343, 49.012661918980704],
                            [2.542247349694377, 49.01120352201801],
                            [2.54227510447621, 49.01091795142858],
                            [2.542291447929491, 49.01067237267566],
                            [2.542296311105748, 49.01044965741376],
                            [2.5422944660714, 49.01000424646959],
                            [2.542299574151539, 49.00980150881853],
                            [2.542321891757856, 49.0096879735104],
                            [2.542370187494764, 49.009559401749776],
                            [2.542425117837756, 49.00946079800337],
                            [2.542506090858474, 49.0093621487135],
                            [2.542596899553691, 49.00928061192198],
                            [2.542687743277034, 49.009207640156376],
                            [2.542788405764618, 49.00914750056546],
                            [2.542915109424088, 49.00908731258612],
                            [2.543051613488022, 49.00903567369461],
                            [2.543191400186782, 49.008990453105746],
                            [2.543370267710119, 49.008949443660605],
                            [2.543581774868312, 49.00892979019412],
                            [2.543819396899023, 49.00892721987235],
                            [2.544043523918503, 49.008937054563276],
                            [2.54483189791712, 49.008978460950175],
                        ],
                    },
                },
                330: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.05786014298378, 2.1267907263053805],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 853.909345945,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.122735908273571,
                            49.05510176049028,
                            2.13087413699018,
                            49.06059168305009,
                        ),
                        "coordinates": [
                            [2.122735908273571, 49.05510176049028],
                            [2.122941784839978, 49.05531244053711],
                            [2.123243573991299, 49.05558617135187],
                            [2.123556743123518, 49.05580998739711],
                            [2.124163911709783, 49.05621219293198],
                            [2.124764339066789, 49.05659369933939],
                            [2.125954403837653, 49.057326106733456],
                            [2.12806979020558, 49.058643821124825],
                            [2.129277032233856, 49.05942085308345],
                            [2.129901510006047, 49.059871677728786],
                            [2.130764207723083, 49.06050375583142],
                            [2.13087413699018, 49.06059168305009],
                        ],
                    },
                },
                331: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.61603464220723, 1.7258730224851424],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 7533.23044483,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.681645780403713,
                            48.60507627758083,
                            1.771695684383177,
                            48.62599081977363,
                        ),
                        "coordinates": [
                            [1.681645780403713, 48.60507627758083],
                            [1.682028828731405, 48.60544000348944],
                            [1.682284363875135, 48.605693671658216],
                            [1.682510478582558, 48.60593739287628],
                            [1.682652051823361, 48.60610277944176],
                            [1.68279093811972, 48.60626635209282],
                            [1.683172745899829, 48.60672629179818],
                            [1.683427721132133, 48.607034418679675],
                            [1.684095217188592, 48.60784042911831],
                            [1.684310217337543, 48.608095266228936],
                            [1.68456944987415, 48.60838992645341],
                            [1.684796834368052, 48.6086313436037],
                            [1.68502439691502, 48.60885927214996],
                            [1.685220015953271, 48.609041153074095],
                            [1.685465503475535, 48.60924670220475],
                            [1.685616125635904, 48.609372330577955],
                            [1.685783643718874, 48.60949673190765],
                            [1.686076573069341, 48.60970434887851],
                            [1.686313148349033, 48.6098657785106],
                            [1.686553946631448, 48.61001554095454],
                            [1.686812338411055, 48.61016810226736],
                            [1.687089693454511, 48.6103225688031],
                            [1.687388746874749, 48.610477159611825],
                            [1.687709498888427, 48.610631873630595],
                            [1.6880802641354, 48.610799461927535],
                            [1.688480332656467, 48.610959113146734],
                            [1.688835944500131, 48.61108975139336],
                            [1.689251898621625, 48.61122762646717],
                            [1.689527120485947, 48.61131009457629],
                            [1.689762578971609, 48.61137471384771],
                            [1.690070715538887, 48.6114574052211],
                            [1.690604698558215, 48.611589043953224],
                            [1.691060557418467, 48.61167976702397],
                            [1.691572027227322, 48.611769904723616],
                            [1.691975430085003, 48.61182705282397],
                            [1.692445328850017, 48.61188097859468],
                            [1.692914070547105, 48.6119196086165],
                            [1.69321498170572, 48.61193210485341],
                            [1.693418301785602, 48.611940450926944],
                            [1.693660947173518, 48.61194901939169],
                            [1.694116615522591, 48.611949799387006],
                            [1.694508755096942, 48.61193403137525],
                            [1.69493762479103, 48.61190708907832],
                            [1.695308250149018, 48.611879195774335],
                            [1.695719765817159, 48.61183295679801],
                            [1.695977859632853, 48.611800239159834],
                            [1.696154449998027, 48.61177785412676],
                            [1.696601510747221, 48.61170932968417],
                            [1.697085448767697, 48.61162032752128],
                            [1.697504283304654, 48.6115318563429],
                            [1.697904210075528, 48.61143698295724],
                            [1.698337015401104, 48.61131621277696],
                            [1.698580682118874, 48.61124473844383],
                            [1.698817556903938, 48.61117412591071],
                            [1.699347474535672, 48.61098824796642],
                            [1.699922769873254, 48.61075316201632],
                            [1.700354887792527, 48.61057932026233],
                            [1.700793669214985, 48.610414508206624],
                            [1.701062116133116, 48.61031348986167],
                            [1.701374036878452, 48.61020642004249],
                            [1.701666811058719, 48.61011183176037],
                            [1.701964962905463, 48.61002087023569],
                            [1.702264424452295, 48.6099335117817],
                            [1.702494303032176, 48.609879038813894],
                            [1.702777228008149, 48.60981227140796],
                            [1.703064161818002, 48.609750021778275],
                            [1.703359198062538, 48.60969051451791],
                            [1.703656899534343, 48.60963461878951],
                            [1.704052326249534, 48.609572071692114],
                            [1.704429941244427, 48.60952381267354],
                            [1.70481424530942, 48.60948278361045],
                            [1.705152295071171, 48.60945318842802],
                            [1.705457342784004, 48.60943435473924],
                            [1.70585936143521, 48.6094223112806],
                            [1.706472940463488, 48.609420956861065],
                            [1.707028846302926, 48.60944069373127],
                            [1.707394536931885, 48.609464135141444],
                            [1.707785250534227, 48.609494850646314],
                            [1.708147174192982, 48.609532543117105],
                            [1.708508947342221, 48.60958213228913],
                            [1.708902923743786, 48.609639035414254],
                            [1.709289634879034, 48.60970303483287],
                            [1.710055260914004, 48.60984004967474],
                            [1.711049676315785, 48.610027186437954],
                            [1.713569258583826, 48.61050107382789],
                            [1.716694550441582, 48.61106983023851],
                            [1.718590169412278, 48.61142909328618],
                            [1.719684712595161, 48.61163377514209],
                            [1.720802416211951, 48.61183678392124],
                            [1.722177168301598, 48.61209153197995],
                            [1.723063490237711, 48.6122563782701],
                            [1.723765083073147, 48.61239578925175],
                            [1.724459210199877, 48.612558949898734],
                            [1.725017201031443, 48.612704718204746],
                            [1.725582050129779, 48.61287669321343],
                            [1.726114435364237, 48.61306276707749],
                            [1.726643032021446, 48.613265474354925],
                            [1.727271548440353, 48.61351392359139],
                            [1.728002726349082, 48.61381355458144],
                            [1.728721147215114, 48.61411177445037],
                            [1.729446046762463, 48.61440355556277],
                            [1.730181602056709, 48.614704906193005],
                            [1.730806539263009, 48.61495569544509],
                            [1.731444387213352, 48.61519526378627],
                            [1.731697896818882, 48.615282850034596],
                            [1.732062401666669, 48.61540851842724],
                            [1.732437702103005, 48.615531862609075],
                            [1.732918700125067, 48.61566885397997],
                            [1.733487457037277, 48.615819395809275],
                            [1.73412944538327, 48.615997686776105],
                            [1.734626528187564, 48.616140704034045],
                            [1.735051904617793, 48.61627858171641],
                            [1.735416453448309, 48.61640185964643],
                            [1.735700509355322, 48.61650448565926],
                            [1.736118400616596, 48.61666849225283],
                            [1.73662893378723, 48.61688771214603],
                            [1.737128419882355, 48.61713066608248],
                            [1.737613414131461, 48.617385438162295],
                            [1.738176789876074, 48.61768820766534],
                            [1.739206442296197, 48.61824716517372],
                            [1.741299163883872, 48.6193957511759],
                            [1.742141432978434, 48.61985520135366],
                            [1.74227888849434, 48.6199305613069],
                            [1.743006647069244, 48.62032555690394],
                            [1.74489072274351, 48.62135338060881],
                            [1.745400155266238, 48.621632114120146],
                            [1.746110372444097, 48.622023400901604],
                            [1.746923058199457, 48.62246827377949],
                            [1.747351618058591, 48.62270521140857],
                            [1.747993154892228, 48.62305656137718],
                            [1.748315821852758, 48.62322918680917],
                            [1.74864394769576, 48.62340457921662],
                            [1.749225400092165, 48.62370738726556],
                            [1.749717864516617, 48.62394786939482],
                            [1.750232064636066, 48.62417180597167],
                            [1.750750081591739, 48.62437672465485],
                            [1.751243370865006, 48.6245482021914],
                            [1.751477216915868, 48.62462403080442],
                            [1.751772552074101, 48.62471986217807],
                            [1.752112357837091, 48.62481916526055],
                            [1.752459400461618, 48.62491374461888],
                            [1.752899589038873, 48.62502307857849],
                            [1.753468788099778, 48.62514972841898],
                            [1.754045335226777, 48.62526213593195],
                            [1.75454000686991, 48.62534300228491],
                            [1.755073682583444, 48.62541450896965],
                            [1.755572261406586, 48.625466091672735],
                            [1.756066809447514, 48.62550762289316],
                            [1.756640690999757, 48.62554148343574],
                            [1.757204026353638, 48.62555625384714],
                            [1.758039961170519, 48.62558668573713],
                            [1.76035780162803, 48.62565556593719],
                            [1.762969892897444, 48.625730643001404],
                            [1.764598817781383, 48.62578168142527],
                            [1.766360593629876, 48.62582860311534],
                            [1.768068457153744, 48.6258823673683],
                            [1.770232050842416, 48.62594551572048],
                            [1.771695684383177, 48.62599081977363],
                        ],
                    },
                },
                332: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.9595916214073, 2.0998737547584434],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 5297.93914143,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.077657913150019,
                            48.95535580717803,
                            2.129364252725261,
                            48.970665048322616,
                        ),
                        "coordinates": [
                            [2.077731764565598, 48.970665048322616],
                            [2.077713428440962, 48.97020607519221],
                            [2.077666663850801, 48.968780737284256],
                            [2.077657913150019, 48.968380986942186],
                            [2.077663602435409, 48.96798364698958],
                            [2.077672942097042, 48.96757917840914],
                            [2.07770371805565, 48.96722234540526],
                            [2.077760076342673, 48.96681084505308],
                            [2.077830973140419, 48.966382720502864],
                            [2.077919988109309, 48.96594512162838],
                            [2.07803413788236, 48.965538511126155],
                            [2.078148021341955, 48.96518186572114],
                            [2.078280085569287, 48.964803846958326],
                            [2.078466350566502, 48.96436861325265],
                            [2.078702630029098, 48.96388924113729],
                            [2.079039124446443, 48.963310490892766],
                            [2.079935206901635, 48.96177020066142],
                            [2.081269498119995, 48.959486631807394],
                            [2.081576885889697, 48.959014757589514],
                            [2.081962423068169, 48.95842290385134],
                            [2.082204796463363, 48.95808388765979],
                            [2.082491784790015, 48.957758553390214],
                            [2.082785468171426, 48.9574671884172],
                            [2.083092761861423, 48.95720301632429],
                            [2.083527479832346, 48.95689158805297],
                            [2.08402061712912, 48.956582551446964],
                            [2.084572230045801, 48.956264585846434],
                            [2.08502365930724, 48.956043739219396],
                            [2.085533436266342, 48.9558388632136],
                            [2.08606709192164, 48.9556702559415],
                            [2.086528259554914, 48.9555603452975],
                            [2.087023708061739, 48.95546861786422],
                            [2.087549980094023, 48.955399591068044],
                            [2.088234240794546, 48.95535580717803],
                            [2.08881169270236, 48.95536158826986],
                            [2.089392372021006, 48.95541038479252],
                            [2.090049094052679, 48.9555077143591],
                            [2.090965551896499, 48.955759521922786],
                            [2.091629119016726, 48.95600839857278],
                            [2.092616904674272, 48.956453072810454],
                            [2.093748859474221, 48.95697418499068],
                            [2.09476909746265, 48.957440322996504],
                            [2.0955478386849, 48.95778935426055],
                            [2.096056379650619, 48.957978396582085],
                            [2.096619155640453, 48.95816041083464],
                            [2.099321260320342, 48.95903451962543],
                            [2.100024840541383, 48.95924536241682],
                            [2.100526538013056, 48.95936060796886],
                            [2.101533689958154, 48.95956255116235],
                            [2.103576875758549, 48.959975984953374],
                            [2.104114822892135, 48.96006987357507],
                            [2.104667333755934, 48.96013999856306],
                            [2.105472847324208, 48.96019635556919],
                            [2.106864507749246, 48.96027246135338],
                            [2.108998595220719, 48.9603890227399],
                            [2.110207309949713, 48.960435844847396],
                            [2.110982541698929, 48.96044255990134],
                            [2.111836563158214, 48.96043128677169],
                            [2.112702463065718, 48.96040448105194],
                            [2.113261405801899, 48.960377071297685],
                            [2.113993640200212, 48.96031889773775],
                            [2.11465504974062, 48.96025799264028],
                            [2.115422851301998, 48.9601661921512],
                            [2.11619464093085, 48.96006143667261],
                            [2.117053244524919, 48.95990242454472],
                            [2.119688187319351, 48.959394366937204],
                            [2.120653186762333, 48.95919665912094],
                            [2.1214213543062, 48.95901412130886],
                            [2.122550460530804, 48.958699897629074],
                            [2.123184478903895, 48.95850264268088],
                            [2.123808423411372, 48.95828529971081],
                            [2.124663027741345, 48.9579680472141],
                            [2.126128581952765, 48.957370569020895],
                            [2.126812861159789, 48.95704109907121],
                            [2.127580583459889, 48.956628500051835],
                            [2.128210736805959, 48.956277508281566],
                            [2.129364252725261, 48.95558180229322],
                        ],
                    },
                },
                333: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.0889152610119, 1.9859581591299293],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3348.68147194,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.970535722321773,
                            49.08049370702575,
                            2.003715373018928,
                            49.099650121708414,
                        ),
                        "coordinates": [
                            [2.003715373018928, 49.08049370702575],
                            [2.003547570629936, 49.08055669547531],
                            [2.003194743877491, 49.08070405129703],
                            [2.002920136442579, 49.08082375520123],
                            [2.002719664092107, 49.080912200403745],
                            [2.002308995130275, 49.08110974472391],
                            [2.000843475638629, 49.08181409489413],
                            [1.999189688504895, 49.082615892503455],
                            [1.99911414030077, 49.082652540825876],
                            [1.999039967263214, 49.08268829325596],
                            [1.998987779109487, 49.08271242039148],
                            [1.997147217253244, 49.08359007528347],
                            [1.995792687758831, 49.084259615204665],
                            [1.995634691924411, 49.08433918112899],
                            [1.993983481308018, 49.085140010831175],
                            [1.993575537861701, 49.085329437973385],
                            [1.992002545761859, 49.08609540089205],
                            [1.991135713332791, 49.086510057673934],
                            [1.990909032976474, 49.08661998508319],
                            [1.989366275453086, 49.087358126334024],
                            [1.988685693923971, 49.087691991181586],
                            [1.988284357301213, 49.08788992267321],
                            [1.987363982355846, 49.08833039492414],
                            [1.986541515581259, 49.08872992756838],
                            [1.986125246843903, 49.08892649670459],
                            [1.985239586077623, 49.08935463584482],
                            [1.984431366759692, 49.08974548002464],
                            [1.984145817277239, 49.08986950025343],
                            [1.98375123051329, 49.090030319531444],
                            [1.983324044711368, 49.0901896101539],
                            [1.982646338589363, 49.0904245017808],
                            [1.982076707587914, 49.09059191257148],
                            [1.98147561394448, 49.090751371374594],
                            [1.981083660375881, 49.09084172234247],
                            [1.979957028198716, 49.091084285058024],
                            [1.978856858580296, 49.091329258753255],
                            [1.978436519057312, 49.09144001369728],
                            [1.978051563974808, 49.091557301195984],
                            [1.977508295010657, 49.09174261697837],
                            [1.977043829812726, 49.09192070497828],
                            [1.97662335063183, 49.09210066905528],
                            [1.976278962452549, 49.09225769542364],
                            [1.975689724344398, 49.092574199223414],
                            [1.97535325091785, 49.09277800095605],
                            [1.974985476377034, 49.09300519545367],
                            [1.974481719753129, 49.09335702307657],
                            [1.973974755645611, 49.093771787405615],
                            [1.973525256585286, 49.09419212776733],
                            [1.973167500616184, 49.09457737825696],
                            [1.972955499032007, 49.09484973777532],
                            [1.972920402169598, 49.09489245460434],
                            [1.972890797833858, 49.09492733689051],
                            [1.97284909562573, 49.094981453923616],
                            [1.9727376485112, 49.09513342801445],
                            [1.972645887453138, 49.09526954293259],
                            [1.97245156907172, 49.09561940579742],
                            [1.97232974103675, 49.09587179106469],
                            [1.972134977621871, 49.09628484215855],
                            [1.97183317397005, 49.096913380350486],
                            [1.971354494738784, 49.09794063551677],
                            [1.971029037263927, 49.09861675788842],
                            [1.970871839033678, 49.098947192227556],
                            [1.970535722321773, 49.099650121708414],
                        ],
                    },
                },
                334: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.857420161219245, 2.3360102898696686],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1738.6722232,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325620298740735,
                            48.85333579289227,
                            2.346034985851638,
                            48.86070823076494,
                        ),
                        "coordinates": [
                            [2.346034985851638, 48.85333579289227],
                            [2.345907892957767, 48.85336873855313],
                            [2.344887247687885, 48.853635003555446],
                            [2.344233164905792, 48.85386076766378],
                            [2.342986280062955, 48.85445464936386],
                            [2.342285594334723, 48.85487256895882],
                            [2.34189481858839, 48.85515855701591],
                            [2.341713582367341, 48.85530244861159],
                            [2.34141924098911, 48.85553537397197],
                            [2.341049948552972, 48.855826754792744],
                            [2.340521208490326, 48.85619907437647],
                            [2.340267736690628, 48.856380736777844],
                            [2.340259560796243, 48.8563852334311],
                            [2.339927731137451, 48.85657838396466],
                            [2.33948141502974, 48.85683399481777],
                            [2.339263367994021, 48.85694640978577],
                            [2.338716531799063, 48.857227920693774],
                            [2.338280628507666, 48.85742758098966],
                            [2.338071533441895, 48.85750010934028],
                            [2.337896005383008, 48.85755617695443],
                            [2.337692158261464, 48.85761260290408],
                            [2.33743958324096, 48.85767461979302],
                            [2.336937003020826, 48.85777275678894],
                            [2.336275440182249, 48.85788781174538],
                            [2.335462398875377, 48.85800578572366],
                            [2.334967677481534, 48.85808042027029],
                            [2.334543823481463, 48.85815145646423],
                            [2.334055912776827, 48.85824497193187],
                            [2.333829171919461, 48.85828708741927],
                            [2.333627966903686, 48.8583267959171],
                            [2.333381282555507, 48.85838614169282],
                            [2.333224550472934, 48.858423007975766],
                            [2.332518565338944, 48.858616329624276],
                            [2.331613586685024, 48.85887708436926],
                            [2.330469928217356, 48.85920739385645],
                            [2.329262505065705, 48.859560409663246],
                            [2.325974952816833, 48.86059971663194],
                            [2.325620298740735, 48.86070823076494],
                        ],
                    },
                },
                335: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.77314071828095, 2.4104429502163347],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2086.48660115,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.409541656460374,
                            48.76378680955171,
                            2.411386724936104,
                            48.78250543550023,
                        ),
                        "coordinates": [
                            [2.411386724936104, 48.76378680955171],
                            [2.411327217835018, 48.763968394246305],
                            [2.411255717612045, 48.76428964998598],
                            [2.411184339710723, 48.76469418252225],
                            [2.411148752220556, 48.76496544994747],
                            [2.410981564960481, 48.766288466990666],
                            [2.410943269257952, 48.76660807062959],
                            [2.410810783113312, 48.76807936723669],
                            [2.410672871619905, 48.769567753651664],
                            [2.41063709737736, 48.77021255492548],
                            [2.410606989875543, 48.77101023025481],
                            [2.41058061315596, 48.771572292333126],
                            [2.410562142373555, 48.77196079016195],
                            [2.410519442718912, 48.77252466268932],
                            [2.410463428132036, 48.77328638315034],
                            [2.41041910536067, 48.773674897608615],
                            [2.410332529397457, 48.774933035940535],
                            [2.410261693083095, 48.77579638421732],
                            [2.410163806074753, 48.7767712590885],
                            [2.410151755115293, 48.77690256107511],
                            [2.410070299183182, 48.77795026655007],
                            [2.410032922058886, 48.778440394601496],
                            [2.4099848371692, 48.77905193190946],
                            [2.409937977507461, 48.77957174165585],
                            [2.4098076829105, 48.780743720800345],
                            [2.409732889392154, 48.78129815197806],
                            [2.409679415371185, 48.78165984567194],
                            [2.40964018779611, 48.78191683785356],
                            [2.409590234985702, 48.782226183530135],
                            [2.409541656460374, 48.78250543550023],
                        ],
                    },
                },
                336: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.973674330186945, 2.186111200792598],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1664.95730783,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.180012382147682,
                            48.968496267514055,
                            2.193442867808299,
                            48.98026352072714,
                        ),
                        "coordinates": [
                            [2.193442867808299, 48.968496267514055],
                            [2.19157186409578, 48.969381401203755],
                            [2.190978338607006, 48.96966378651482],
                            [2.1902435522939, 48.97004830082599],
                            [2.189573802459474, 48.97043527342087],
                            [2.189030671122052, 48.97077719678384],
                            [2.188541736648982, 48.97112156793707],
                            [2.188009246432196, 48.97152536561181],
                            [2.187208567566102, 48.97217150173453],
                            [2.184686399255714, 48.974347652006415],
                            [2.184037682844878, 48.97491307022139],
                            [2.183696960901743, 48.97522668737213],
                            [2.183432299089941, 48.97548806020267],
                            [2.183160316039686, 48.97577797485107],
                            [2.18292814199018, 48.97605128699664],
                            [2.182688659938041, 48.97634838219843],
                            [2.182507150741869, 48.97660034733762],
                            [2.182332830843454, 48.97686421893191],
                            [2.182100344733173, 48.97723508257516],
                            [2.181261152372282, 48.97858065112672],
                            [2.181108546755353, 48.97883265542286],
                            [2.180901519983585, 48.97914644528001],
                            [2.180727228100482, 48.979396037441305],
                            [2.180502184911612, 48.97969076845007],
                            [2.180284459880419, 48.97995695947532],
                            [2.180012382147682, 48.98026352072714],
                        ],
                    },
                },
                337: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.80159350709192, 2.1803056079532266],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 1409.23025778,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.171389812756379,
                            48.800562566282714,
                            2.188630276475413,
                            48.80468335617195,
                        ),
                        "coordinates": [
                            [2.171389812756379, 48.80071846386355],
                            [2.171400515562385, 48.80071880338744],
                            [2.171903089010338, 48.800720766349464],
                            [2.172336889530995, 48.8007152310616],
                            [2.173064633662477, 48.800682384781815],
                            [2.174282238330508, 48.80061633996727],
                            [2.175919822294987, 48.800562566282714],
                            [2.176654529377904, 48.80057787835856],
                            [2.177065087651669, 48.80059035108217],
                            [2.177472022349711, 48.80060995499961],
                            [2.177821314060172, 48.80063423733164],
                            [2.178130972336866, 48.80066322078583],
                            [2.178829444870606, 48.80074746856324],
                            [2.179484646053586, 48.800848307096956],
                            [2.180395418194379, 48.8009994604146],
                            [2.180870559494049, 48.80109290627654],
                            [2.181241265784936, 48.80118144902706],
                            [2.181593965000977, 48.80126996535506],
                            [2.182000649095227, 48.80137283057331],
                            [2.182619617426564, 48.801547361657526],
                            [2.183263715791572, 48.80175047635265],
                            [2.18369906739649, 48.80190334016584],
                            [2.184022859062761, 48.802025121632084],
                            [2.184346637733814, 48.80215166090101],
                            [2.184663193889977, 48.80228532641381],
                            [2.18528884657049, 48.802585985680665],
                            [2.18617119065725, 48.803021992614916],
                            [2.186618693408936, 48.803266228377815],
                            [2.187022675207288, 48.80350363756777],
                            [2.187439361841892, 48.80377659275736],
                            [2.18767194257462, 48.80394609535828],
                            [2.188295526284685, 48.804415587530144],
                            [2.188630276475413, 48.80468335617195],
                        ],
                    },
                },
                338: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.99657254688042, 2.1299884517998438],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4941.80459689,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.097773988463467,
                            48.99028999637593,
                            2.161906605592158,
                            48.99979671296073,
                        ),
                        "coordinates": [
                            [2.161906605592158, 48.99028999637593],
                            [2.15923014594755, 48.991568342011966],
                            [2.158455061479418, 48.991940692780005],
                            [2.157904591270145, 48.992187286227285],
                            [2.157321599845263, 48.99242668486999],
                            [2.156745974028562, 48.99262802631285],
                            [2.156282645324772, 48.992770057174816],
                            [2.155504506747006, 48.99297820929998],
                            [2.154802464889393, 48.99313888997199],
                            [2.154006442734905, 48.993289898786436],
                            [2.139280305094473, 48.99580181352906],
                            [2.129238908610416, 48.99751144928054],
                            [2.119616616472705, 48.99914724319426],
                            [2.117582820296915, 48.99948599369093],
                            [2.116674632522669, 48.99960321829139],
                            [2.116027025676284, 48.99967097126729],
                            [2.115303531131314, 48.999726677793134],
                            [2.114659678871864, 48.999763500405905],
                            [2.113979715866031, 48.99978835091058],
                            [2.113386614391936, 48.99979671296073],
                            [2.112627212024045, 48.99979522849163],
                            [2.111726917029646, 48.99976253077739],
                            [2.11099662750251, 48.999720642735035],
                            [2.110483314415267, 48.99967918160778],
                            [2.109644717011229, 48.99959900042681],
                            [2.108791819863549, 48.999483096487594],
                            [2.108000458725831, 48.99935541393121],
                            [2.107317578091048, 48.99923031995456],
                            [2.106504736264994, 48.99905737335512],
                            [2.105645080149547, 48.99884387984697],
                            [2.104926360260342, 48.99865207751207],
                            [2.104189664929885, 48.9984388205304],
                            [2.101845916210095, 48.997779715308944],
                            [2.099711705675492, 48.997173337919804],
                            [2.097773988463467, 48.996630090663984],
                        ],
                    },
                },
                339: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.9952497406855, 1.9344608926455718],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3244.37487682,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.91353050809466,
                            48.99259195475149,
                            1.955479247534605,
                            48.99691260485347,
                        ),
                        "coordinates": [
                            [1.91353050809466, 48.99259195475149],
                            [1.914576327498934, 48.99291161503717],
                            [1.915593398212429, 48.99321516514029],
                            [1.916555546139149, 48.99351142624859],
                            [1.917579668505943, 48.99383877849321],
                            [1.920263019336911, 48.994741973170775],
                            [1.920984351431904, 48.994962309530834],
                            [1.921384748750244, 48.99507797624157],
                            [1.92182845850146, 48.99520331234422],
                            [1.922400355372786, 48.995350526662065],
                            [1.923482825723805, 48.995628070229905],
                            [1.92455996185554, 48.9958960667543],
                            [1.92531248088211, 48.99606652162601],
                            [1.926220369315713, 48.99625180470593],
                            [1.926910003834282, 48.996375626036155],
                            [1.927596122291052, 48.996487532344894],
                            [1.928532127221156, 48.99660895228301],
                            [1.929212208220014, 48.99668632747381],
                            [1.929933029999748, 48.996756705033796],
                            [1.931057849940289, 48.996839219235376],
                            [1.932109699192833, 48.99689112723586],
                            [1.932825555334845, 48.99690614782384],
                            [1.933644538996546, 48.99691260485347],
                            [1.934422973373977, 48.996902853489175],
                            [1.935250354420043, 48.99687720845795],
                            [1.935923210175312, 48.99684387816518],
                            [1.936669432121215, 48.99679295403667],
                            [1.937521592397335, 48.99672098118938],
                            [1.938341304558058, 48.99663639680717],
                            [1.939367496568034, 48.99650612551201],
                            [1.940108768293799, 48.99639448845814],
                            [1.941037548214503, 48.99623531262664],
                            [1.941874172375299, 48.99606867399918],
                            [1.942792434493267, 48.99586661825114],
                            [1.94365924570416, 48.99565367265234],
                            [1.944982759903459, 48.995301306452596],
                            [1.949599332851387, 48.994095515878435],
                            [1.953609858696253, 48.99308826854502],
                            [1.955479247534605, 48.992613881639144],
                        ],
                    },
                },
                340: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.94881760118019, 2.2563323665234707],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 516.027525374,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25508371139436,
                            48.946796942080006,
                            2.25789748402742,
                            48.95101678180594,
                        ),
                        "coordinates": [
                            [2.25789748402742, 48.946796942080006],
                            [2.257719474961042, 48.947029691305865],
                            [2.257223578321887, 48.947652735034254],
                            [2.25681465623077, 48.94809738662814],
                            [2.256089519497871, 48.948962950155284],
                            [2.255738023161628, 48.94949945977133],
                            [2.255532155148722, 48.949836346592356],
                            [2.255364231847696, 48.9501441322196],
                            [2.255243717775441, 48.95043531092136],
                            [2.255170564402458, 48.95063554238053],
                            [2.255135434217287, 48.950774786794724],
                            [2.25508371139436, 48.95101678180594],
                        ],
                    },
                },
                341: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.49626023449947, 2.673189432649022],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 6014.82244004,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.662762979853312,
                            48.4755230723766,
                            2.692033259866399,
                            48.52299439391623,
                        ),
                        "coordinates": [
                            [2.692033259866399, 48.4755230723766],
                            [2.691686618251609, 48.47573547002441],
                            [2.691082585997087, 48.476085628404626],
                            [2.690201672341864, 48.47659646343196],
                            [2.689179331329361, 48.47719316237408],
                            [2.688308042660941, 48.477694655809366],
                            [2.687341920267955, 48.47825100163571],
                            [2.686797727956086, 48.47857012448603],
                            [2.685800639284007, 48.4791442682248],
                            [2.684678641092634, 48.4797879591731],
                            [2.684017587024792, 48.48016549439286],
                            [2.683138720729849, 48.48066586280016],
                            [2.681825301379014, 48.48142987195499],
                            [2.680747342325166, 48.482046323434545],
                            [2.679865594292645, 48.482560045525055],
                            [2.678729156609944, 48.48322687067516],
                            [2.678211687771568, 48.48351349737593],
                            [2.677683525694789, 48.48381993816555],
                            [2.676902051155626, 48.48427371684216],
                            [2.676315311077137, 48.48466750341887],
                            [2.675869257828674, 48.4849710434032],
                            [2.675310433482517, 48.48538056771836],
                            [2.674688974199491, 48.48591079287395],
                            [2.674152618102982, 48.486385278011646],
                            [2.673688668469069, 48.486850622469895],
                            [2.673270343616544, 48.48731582958682],
                            [2.672542708741492, 48.48816523927329],
                            [2.672142267013732, 48.48867760912956],
                            [2.671837831290883, 48.489065293583025],
                            [2.670936229207066, 48.490348645122864],
                            [2.670598898136044, 48.49087305679068],
                            [2.670374309885933, 48.49123183263913],
                            [2.670284607947011, 48.491373280588135],
                            [2.670137386763549, 48.4916129181202],
                            [2.669985510166678, 48.49188844484194],
                            [2.669839626069873, 48.49215476071982],
                            [2.669685661113397, 48.492417531945335],
                            [2.66954513113252, 48.49267758660376],
                            [2.669217898751352, 48.493315225069395],
                            [2.669086771982049, 48.49360061375874],
                            [2.668951348319225, 48.49392390767301],
                            [2.66884171002255, 48.49420831050155],
                            [2.668743055740724, 48.49449867668083],
                            [2.668625864950517, 48.49482772073163],
                            [2.668431507923496, 48.49551172865773],
                            [2.668275153579723, 48.49621450967455],
                            [2.66819901872877, 48.496568142078864],
                            [2.668089155594461, 48.49734542666724],
                            [2.668054065400957, 48.497983396007264],
                            [2.668035848462255, 48.4984912417543],
                            [2.668023119565936, 48.49922597641024],
                            [2.66801225872781, 48.500447206650136],
                            [2.66800747022895, 48.500949909040024],
                            [2.667997729069282, 48.50131773676442],
                            [2.667992267625602, 48.50151469131494],
                            [2.667985995651498, 48.50173084369807],
                            [2.667972568379602, 48.502422105057335],
                            [2.667962569523811, 48.50288726809226],
                            [2.66794603577719, 48.503727913515704],
                            [2.667923053262378, 48.506182971152654],
                            [2.667893896852581, 48.5068889781593],
                            [2.667862013054771, 48.50723461494378],
                            [2.667826882823972, 48.50760049241765],
                            [2.667777829706965, 48.50795773883156],
                            [2.667697297700236, 48.508468660149894],
                            [2.667506590539158, 48.50950876627907],
                            [2.667391866202985, 48.51017006054065],
                            [2.667318807013511, 48.510583036065846],
                            [2.667240863100024, 48.51107606050739],
                            [2.667120095556507, 48.511847981112325],
                            [2.666974816933652, 48.51269298176516],
                            [2.666627393525305, 48.51471177511217],
                            [2.666402152575688, 48.51599713041929],
                            [2.666169971066119, 48.51717556295379],
                            [2.666034064152957, 48.51774699210963],
                            [2.665883184139579, 48.51822091304845],
                            [2.665777699602716, 48.518518633338644],
                            [2.665647269707232, 48.518835459780725],
                            [2.665460053427252, 48.519230967710705],
                            [2.665237033935429, 48.51962895890787],
                            [2.665120094388878, 48.51981964392905],
                            [2.665003188616977, 48.52001508501247],
                            [2.66489333261209, 48.52019385132316],
                            [2.664708827309792, 48.52045848827051],
                            [2.664489345627315, 48.52077632477222],
                            [2.664286752785638, 48.521052984124765],
                            [2.663991620118767, 48.52146210352899],
                            [2.663562202076866, 48.52203797222404],
                            [2.662762979853312, 48.52299439391623],
                        ],
                    },
                },
                342: {
                    "attributes": {
                        "reseau": "SNCF ST LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.9944939518614, 1.666806027152818],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 5479.84243843,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.63016762729846,
                            48.989502508030505,
                            1.703016134167223,
                            48.99739200091919,
                        ),
                        "coordinates": [
                            [1.703016134167223, 48.989502508030505],
                            [1.702229252761286, 48.98982613658998],
                            [1.701117874093648, 48.990332962137074],
                            [1.700209104186259, 48.99071099479692],
                            [1.699177153526214, 48.99110736786792],
                            [1.698352248295661, 48.99142874751734],
                            [1.697610888866044, 48.991719654366115],
                            [1.696851246640918, 48.99196456862695],
                            [1.695527734695914, 48.99233216723468],
                            [1.69408322699894, 48.99268596160869],
                            [1.693114936652899, 48.99290656285181],
                            [1.692328098556521, 48.993075829826566],
                            [1.690863496640551, 48.993367376662306],
                            [1.690201699342695, 48.99348377964712],
                            [1.688848912001961, 48.99371094157248],
                            [1.687634475182295, 48.9938812206661],
                            [1.687442830000291, 48.99390531376858],
                            [1.68487389525556, 48.99419017274886],
                            [1.683806667794129, 48.99429269634315],
                            [1.682196184793544, 48.994397704259356],
                            [1.681173829670414, 48.99443792217545],
                            [1.680303001069112, 48.99445810890186],
                            [1.678492990542466, 48.994499869002205],
                            [1.675790041477323, 48.994579611067365],
                            [1.675226803595984, 48.99459254315479],
                            [1.672834185723328, 48.994664117058534],
                            [1.67044292643981, 48.994735649385284],
                            [1.668053015001883, 48.99480803943132],
                            [1.666569395749004, 48.99486590619205],
                            [1.664074259051832, 48.994936696944755],
                            [1.663955319087725, 48.99493959499422],
                            [1.663878743441095, 48.99494274164851],
                            [1.66213417449838, 48.994993621236326],
                            [1.660388247932471, 48.995043566399985],
                            [1.658645051046726, 48.99509350142313],
                            [1.656460225528515, 48.995156971641485],
                            [1.653043557642145, 48.99525351551286],
                            [1.651140492796044, 48.99529968258946],
                            [1.646900537918747, 48.995433373233624],
                            [1.646538295715394, 48.99543838269525],
                            [1.646018646227835, 48.99546042728361],
                            [1.642034566713777, 48.99557030198722],
                            [1.641487745866455, 48.99558047016644],
                            [1.640544464949111, 48.99559901508954],
                            [1.640119193298352, 48.99561531252166],
                            [1.638883748279223, 48.99571450411125],
                            [1.637754624258731, 48.99582212083545],
                            [1.637033152297899, 48.99590854090188],
                            [1.636188238910179, 48.996025677164766],
                            [1.634736148869059, 48.99626408691703],
                            [1.634052241097602, 48.99639928213538],
                            [1.633735688980259, 48.996458490703745],
                            [1.632745794770312, 48.99667813053987],
                            [1.631856996759631, 48.99690018397305],
                            [1.631125697618198, 48.99709892086752],
                            [1.63016762729846, 48.99739200091919],
                        ],
                    },
                },
                343: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.38966575859781, 2.7815569849457447],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 3183.56021636,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.764028188787889,
                            48.37952262366741,
                            2.796343615000022,
                            48.394308438758266,
                        ),
                        "coordinates": [
                            [2.796343615000022, 48.37952262366741],
                            [2.795804114952155, 48.379757731391244],
                            [2.795455588458932, 48.37992093750524],
                            [2.795092926116259, 48.38010085394565],
                            [2.79474840830428, 48.38028880150869],
                            [2.79434573544456, 48.38051695810893],
                            [2.793717604439072, 48.38091607007878],
                            [2.793232794525476, 48.38126062128909],
                            [2.79280287196363, 48.381604303737774],
                            [2.79237726262125, 48.38197270801431],
                            [2.79203200173299, 48.38230682285543],
                            [2.791739181237861, 48.38261824446364],
                            [2.791327913166158, 48.38311808554881],
                            [2.791058657327165, 48.38349865355215],
                            [2.790745980361188, 48.384004391577975],
                            [2.790556477437568, 48.3843499549572],
                            [2.790295740303872, 48.38482542012837],
                            [2.789388612976097, 48.386483684455754],
                            [2.788826470190544, 48.38747691232892],
                            [2.788504465338002, 48.38800156629908],
                            [2.788120219457178, 48.388512078490045],
                            [2.787823651077299, 48.38886397211266],
                            [2.787439676181402, 48.38925577960185],
                            [2.787102421341764, 48.38957633920049],
                            [2.786776733932136, 48.389856425270864],
                            [2.786512087926109, 48.390063419487696],
                            [2.786218931957193, 48.39028848735143],
                            [2.785925135359764, 48.39050008072888],
                            [2.785448504521254, 48.3908005260766],
                            [2.785063141279581, 48.39104035680475],
                            [2.784758092508918, 48.39120253218271],
                            [2.784421919349669, 48.391378718314485],
                            [2.784092754110054, 48.391540588987915],
                            [2.783788238582416, 48.39168563936983],
                            [2.78347548436483, 48.39181910055571],
                            [2.783119156239362, 48.39197141655894],
                            [2.782741756386987, 48.392115663313035],
                            [2.782396250629812, 48.39223123104279],
                            [2.782036496174382, 48.392351612687364],
                            [2.781679963424882, 48.392459254444546],
                            [2.781288172776693, 48.39256631277871],
                            [2.780864026619599, 48.39267742600338],
                            [2.780436242154062, 48.3927814145815],
                            [2.780065364240782, 48.39285662689779],
                            [2.779687275726896, 48.392924728960644],
                            [2.779344826324155, 48.39298317252175],
                            [2.779077603703484, 48.39302070662395],
                            [2.778680447783015, 48.39306666596609],
                            [2.778091263564066, 48.393122024338346],
                            [2.777555852275356, 48.393172327375346],
                            [2.776234973781218, 48.393288976058464],
                            [2.774316280975593, 48.39344659162968],
                            [2.772559525079437, 48.3935945581559],
                            [2.770802741473515, 48.393740699263226],
                            [2.76874639223484, 48.39391043873702],
                            [2.764636389731928, 48.39425429190967],
                            [2.764028188787889, 48.394308438758266],
                        ],
                    },
                },
                344: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.67516040842263, 2.540926256650133],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 1829.78536074,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.533130656571037,
                            48.66790196104987,
                            2.547548045814366,
                            48.681016616342724,
                        ),
                        "coordinates": [
                            [2.547548045814366, 48.66790196104987],
                            [2.547348686316046, 48.66815565279031],
                            [2.546936715185344, 48.66865821031244],
                            [2.546187249572257, 48.66951793741603],
                            [2.545703076215958, 48.670105095825214],
                            [2.545268515695883, 48.67064647776249],
                            [2.544849737351404, 48.67120789293389],
                            [2.544595890033647, 48.67155440833831],
                            [2.544327250061974, 48.671919274446985],
                            [2.543841130820052, 48.67256404023298],
                            [2.543631723390859, 48.6728171170834],
                            [2.542789732901142, 48.67387787296055],
                            [2.542248530670807, 48.6745615186306],
                            [2.54196611267488, 48.67489476031959],
                            [2.541182059662686, 48.675748683993945],
                            [2.540682882707013, 48.67620821032145],
                            [2.540118697984313, 48.67671191427601],
                            [2.539770922870442, 48.677008397381165],
                            [2.538973727723166, 48.67765279794266],
                            [2.538375311458164, 48.678095404188156],
                            [2.537373162911307, 48.67878213970355],
                            [2.536577987693703, 48.67927590337635],
                            [2.535782643729166, 48.67973159245183],
                            [2.535396400589289, 48.67994363163423],
                            [2.53475743599448, 48.68027452171034],
                            [2.53415927174302, 48.68056679224762],
                            [2.533636323913351, 48.6808003978775],
                            [2.533130656571037, 48.681016616342724],
                        ],
                    },
                },
                345: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.532107762372455, 2.6399020333534953],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 2554.04400073,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.625522155066302,
                            48.52724332146015,
                            2.654990282141887,
                            48.538775256627815,
                        ),
                        "coordinates": [
                            [2.654990282141887, 48.52724332146015],
                            [2.654417667755585, 48.527373220137065],
                            [2.653539149006601, 48.527567222324514],
                            [2.652441044420506, 48.5277977343036],
                            [2.651811198282233, 48.527929944006594],
                            [2.650964790072547, 48.528107648819606],
                            [2.649877643332884, 48.528326480112945],
                            [2.648970394125592, 48.5285196253129],
                            [2.648041592983785, 48.52873170790309],
                            [2.646964303886952, 48.52901612918054],
                            [2.646087244964201, 48.52927841262732],
                            [2.645104865128238, 48.52958985389654],
                            [2.644227958615014, 48.5298787821565],
                            [2.64308156242943, 48.530282957076125],
                            [2.642288253494157, 48.53060392470094],
                            [2.641480867215042, 48.530967751740775],
                            [2.640805811554372, 48.53129790876197],
                            [2.640173563304269, 48.5315993950506],
                            [2.639544829852352, 48.531891350354464],
                            [2.638498231610322, 48.53239617430495],
                            [2.638027283354891, 48.532624691505994],
                            [2.636290729471906, 48.53340715551677],
                            [2.635863317546536, 48.53358832560296],
                            [2.635274563263848, 48.533830618538126],
                            [2.634908946248339, 48.53397373548194],
                            [2.633888629708109, 48.53437365345555],
                            [2.632919252629083, 48.534741809195076],
                            [2.63187330765147, 48.53513902812013],
                            [2.631071995193906, 48.53546834053523],
                            [2.630307385170337, 48.535822459476606],
                            [2.629675126113145, 48.53615652577562],
                            [2.629127210173015, 48.536467967457895],
                            [2.628483252127347, 48.536853701990076],
                            [2.626960072940523, 48.537820721361946],
                            [2.625522155066302, 48.538775256627815],
                        ],
                    },
                },
                346: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [49.00850024068352, 2.4391577071200583],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4690.2959091,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.416187488926984,
                            48.99377714689271,
                            2.462168966135235,
                            49.023161999031025,
                        ),
                        "coordinates": [
                            [2.462168966135235, 49.023161999031025],
                            [2.461637819177708, 49.02282008129321],
                            [2.45957424580728, 49.02151246167271],
                            [2.458646604677116, 49.020909096479514],
                            [2.456298742943019, 49.01943637087454],
                            [2.453672021568733, 49.01777353475143],
                            [2.451650448321431, 49.01648359096697],
                            [2.449263121727429, 49.014970312375645],
                            [2.446806447041264, 49.01336683260676],
                            [2.444355532290668, 49.011802960739466],
                            [2.441997629978844, 49.010308538791975],
                            [2.439821045732223, 49.008973321067614],
                            [2.431601326313747, 49.00364952227296],
                            [2.429092201685547, 49.002097854666516],
                            [2.426775049581427, 49.00062926036458],
                            [2.424791094503519, 48.99936974502618],
                            [2.422666062298229, 48.99802226604768],
                            [2.421862399551127, 48.9975017869719],
                            [2.421084063973647, 48.996981284987235],
                            [2.420392605158946, 48.996505921330645],
                            [2.419311335005715, 48.99575754727189],
                            [2.418413610427097, 48.99516335241997],
                            [2.416512197885109, 48.99398531664587],
                            [2.416187488926984, 48.99377714689271],
                        ],
                    },
                },
                347: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.85364462756499, 2.2205156657930702],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 856.688342886,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.220126909963688,
                            48.84985048784913,
                            2.221232683266963,
                            48.85747140891035,
                        ),
                        "coordinates": [
                            [2.221232683266963, 48.84985048784913],
                            [2.221047460579947, 48.85037084738684],
                            [2.2209512403951, 48.85072866285021],
                            [2.220671133005042, 48.85222027932689],
                            [2.220553428312457, 48.85267385178063],
                            [2.220314439899669, 48.85340234917223],
                            [2.220271265519501, 48.85353605287041],
                            [2.220211009063311, 48.8537620713721],
                            [2.220187544237856, 48.853888845214726],
                            [2.220158327756784, 48.85414420989267],
                            [2.220126909963688, 48.85466254749798],
                            [2.220129464290609, 48.854828530499105],
                            [2.220135739940582, 48.85505785309832],
                            [2.220162451438993, 48.8552898936142],
                            [2.22020056814672, 48.85554060098677],
                            [2.220325401965139, 48.85612009310926],
                            [2.220375375673608, 48.85634023882102],
                            [2.220460259708715, 48.856728141954825],
                            [2.22052216815029, 48.85706183713221],
                            [2.220603560028727, 48.85747140891035],
                        ],
                    },
                },
                348: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.140644259661926, 2.25661509353494],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2281.38746549,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.242677776778168,
                            49.13600056459098,
                            2.270552769414137,
                            49.14528660789949,
                        ),
                        "coordinates": [
                            [2.270552769414137, 49.14528660789949],
                            [2.269743236183263, 49.14500488613763],
                            [2.269302047347389, 49.14485894638779],
                            [2.268144282979521, 49.14447427146042],
                            [2.266697426891478, 49.14400577719803],
                            [2.263988800988784, 49.14309942671274],
                            [2.263248974900613, 49.14285615239424],
                            [2.262473533643898, 49.14260205909189],
                            [2.261599475581499, 49.142304730336974],
                            [2.260867904046181, 49.14205695025374],
                            [2.259278722453668, 49.141534311464746],
                            [2.2584512841806, 49.141250480354444],
                            [2.257656714077337, 49.140990046123456],
                            [2.256252547927994, 49.140523247688755],
                            [2.254599083982394, 49.13997711839591],
                            [2.254459351589149, 49.13993385394562],
                            [2.25312648427628, 49.13948685209989],
                            [2.25226074478818, 49.13919935094932],
                            [2.251758007767848, 49.1390380106257],
                            [2.249817008069427, 49.13838458521303],
                            [2.247902071679876, 49.1377464354801],
                            [2.246546053857624, 49.137282254235444],
                            [2.244564082650314, 49.13662511119795],
                            [2.242802675280278, 49.136042753448876],
                            [2.242677776778168, 49.13600056459098],
                        ],
                    },
                },
                349: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.72750703493137, 2.26015897022313],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 651.563967896,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.257355188147784,
                            48.725197641013786,
                            2.263073689251946,
                            48.72964839824706,
                        ),
                        "coordinates": [
                            [2.257355188147784, 48.725197641013786],
                            [2.257778713275225, 48.725547753209774],
                            [2.258437089058175, 48.72609226903183],
                            [2.259125337391235, 48.72666647771476],
                            [2.259658835692192, 48.72711557836338],
                            [2.260258879362076, 48.727610583675755],
                            [2.260709586199597, 48.727990379614496],
                            [2.261194250005631, 48.728392677946474],
                            [2.261434550189701, 48.728589778298236],
                            [2.261592038535468, 48.72871847896838],
                            [2.261847279907502, 48.72892548037518],
                            [2.262065880253492, 48.729093788299494],
                            [2.262255984973359, 48.72922970366661],
                            [2.26236055272001, 48.72929811624791],
                            [2.262497724590652, 48.72937914095845],
                            [2.26269196666858, 48.72947638904561],
                            [2.262848181870324, 48.72955023184723],
                            [2.263073689251946, 48.72964839824706],
                        ],
                    },
                },
                350: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.09019258602023, 2.201395865842013],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 205.938948237,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.200978026879316,
                            49.08930709608885,
                            2.201823484236059,
                            49.091073452190784,
                        ),
                        "coordinates": [
                            [2.201823484236059, 49.091073452190784],
                            [2.201233908368463, 49.08986674700063],
                            [2.200978026879316, 49.08930709608885],
                        ],
                    },
                },
                351: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.81509883082487, 2.200502674169532],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 2833.8656305,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.188630276475413,
                            48.80468335617195,
                            2.21485979543755,
                            48.82121703789382,
                        ),
                        "coordinates": [
                            [2.188630276475413, 48.80468335617195],
                            [2.188888364112657, 48.80489180470413],
                            [2.190130396655551, 48.80585445347174],
                            [2.190879114462857, 48.80646960241897],
                            [2.191205078562442, 48.80676817769711],
                            [2.192204894999361, 48.807801977914885],
                            [2.193192280259932, 48.80892389751863],
                            [2.193425587277886, 48.80921685062757],
                            [2.193612218374021, 48.80945739927336],
                            [2.193780838580899, 48.80969792413766],
                            [2.193924347805145, 48.80990272769857],
                            [2.194178998798047, 48.81029325907732],
                            [2.194397752727306, 48.810640916982294],
                            [2.194555512544857, 48.81090284144721],
                            [2.194720431450146, 48.81118143034729],
                            [2.195480288140415, 48.812545739218464],
                            [2.195889001983542, 48.81324577238028],
                            [2.196028913824722, 48.81345532787757],
                            [2.196193895682154, 48.8137172584058],
                            [2.196384071819588, 48.8139887387419],
                            [2.196588702309362, 48.814245959581456],
                            [2.196796935496198, 48.81450318441473],
                            [2.197048312852099, 48.81479377314574],
                            [2.197278188397551, 48.815043885965395],
                            [2.197508112738683, 48.81527734260119],
                            [2.197827911713186, 48.81558228979503],
                            [2.198086683276045, 48.815808641880565],
                            [2.198334703570967, 48.81601594661987],
                            [2.198553994257274, 48.81618990544645],
                            [2.198827224330921, 48.81640199736579],
                            [2.198996217879864, 48.816525928242406],
                            [2.199262285211288, 48.81672373450449],
                            [2.19952842016228, 48.81689774877625],
                            [2.199762176020057, 48.817055066025915],
                            [2.1999887549869, 48.81720285780244],
                            [2.200244133836916, 48.81736020000458],
                            [2.200539106644035, 48.817531866669285],
                            [2.200816120784877, 48.817684474803265],
                            [2.201082351603755, 48.81782755304185],
                            [2.201341410383679, 48.817958724191456],
                            [2.201614877217186, 48.818092292522],
                            [2.201935133243039, 48.81824494923385],
                            [2.202241017817394, 48.818383312179435],
                            [2.202564911898397, 48.81852407529773],
                            [2.202885243873133, 48.818650556517206],
                            [2.203248782978426, 48.81878898545574],
                            [2.203529553085071, 48.818889246473255],
                            [2.203965144916838, 48.819032514286704],
                            [2.204321526519534, 48.81915427587529],
                            [2.204749960902796, 48.81928087768617],
                            [2.205128022534456, 48.81938124766058],
                            [2.20555290731222, 48.819488807011396],
                            [2.206085843546433, 48.81961314551864],
                            [2.206917673573451, 48.81980206331435],
                            [2.208808246226439, 48.82022296562755],
                            [2.210241485326939, 48.8205481551328],
                            [2.211015770086697, 48.82070842748345],
                            [2.211813886409471, 48.82086169087755],
                            [2.212548645199531, 48.82098146094638],
                            [2.213369923332198, 48.82108704380508],
                            [2.214534922067827, 48.821192881756104],
                            [2.214826732024399, 48.82121460828407],
                            [2.21485979543755, 48.82121703789382],
                        ],
                    },
                },
                352: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.80176382222756, 2.053380890324718],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 2321.68204867,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.040519204703665,
                            48.79732506967021,
                            2.066485347074011,
                            48.807246612101615,
                        ),
                        "coordinates": [
                            [2.040519204703665, 48.807246612101615],
                            [2.041192976220792, 48.80714535065465],
                            [2.042427465284648, 48.80697768194369],
                            [2.04279948671281, 48.80692018848258],
                            [2.043392284347026, 48.806825493155365],
                            [2.043910194796925, 48.80673150103106],
                            [2.044177344232738, 48.806680028894135],
                            [2.044392733368044, 48.80663292015054],
                            [2.044650399385934, 48.80657332847251],
                            [2.045105773933606, 48.80646298438009],
                            [2.045622600116632, 48.80632042063562],
                            [2.04605006579162, 48.80618877835486],
                            [2.046479621219892, 48.806035215989795],
                            [2.046917294493745, 48.805861489588445],
                            [2.047352649442775, 48.805680041310005],
                            [2.047512326698659, 48.805613001355496],
                            [2.048087153166116, 48.805326688422326],
                            [2.048603358009649, 48.80505281472314],
                            [2.049275641527573, 48.804626454563284],
                            [2.049438247958287, 48.80452254798157],
                            [2.049550359208598, 48.804440096679166],
                            [2.049605064818826, 48.8043970685931],
                            [2.049661119540862, 48.80435584286759],
                            [2.049670680669816, 48.8043504710469],
                            [2.049751354549552, 48.804289523173274],
                            [2.049873031359331, 48.80420080123756],
                            [2.04995780453566, 48.804137165034135],
                            [2.050171266780792, 48.803948852740874],
                            [2.050689894255028, 48.803486127159786],
                            [2.051098358838669, 48.803084705835275],
                            [2.051631781798463, 48.802568522506846],
                            [2.051812389057314, 48.802409801191565],
                            [2.052180439090405, 48.8020869793518],
                            [2.052660491123719, 48.80169788905792],
                            [2.053319470205989, 48.8012031270199],
                            [2.054377481369481, 48.800435968477544],
                            [2.054883262586163, 48.80006491810069],
                            [2.0552031522012, 48.7998265004729],
                            [2.055342586137571, 48.79972342780654],
                            [2.055762068442829, 48.79944568562206],
                            [2.05591236876153, 48.79934623648076],
                            [2.056290723078192, 48.799118750635174],
                            [2.05680953814243, 48.798845746474605],
                            [2.057557562345262, 48.798478876900475],
                            [2.057995513361116, 48.798301891796704],
                            [2.058220577319807, 48.79821970801082],
                            [2.058422454232756, 48.79814556103973],
                            [2.058970661123973, 48.79796794246049],
                            [2.059479172941588, 48.79782889323918],
                            [2.060061156693806, 48.79769541604137],
                            [2.06066344561544, 48.79758176887924],
                            [2.060935938750183, 48.797536565915664],
                            [2.061761449133004, 48.7974252515452],
                            [2.062334822776733, 48.79736997956536],
                            [2.062951668340983, 48.79733009677424],
                            [2.063479844712087, 48.79732506967021],
                            [2.064028362920984, 48.79733357858281],
                            [2.064250187280952, 48.797343101930764],
                            [2.064912794623935, 48.797397742283074],
                            [2.065560704539495, 48.79747301751546],
                            [2.065985368655327, 48.79753113122936],
                            [2.066485347074011, 48.79761321151646],
                        ],
                    },
                },
                353: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.11239507600253, 1.9608504878270299],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3162.90993663,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.949332680280041,
                            49.099650121708414,
                            1.970535722321773,
                            49.12345185404933,
                        ),
                        "coordinates": [
                            [1.970535722321773, 49.099650121708414],
                            [1.970390535247909, 49.09995375145234],
                            [1.969858965222135, 49.10108694738046],
                            [1.969661412761697, 49.101500885080576],
                            [1.969281559520533, 49.10230272788293],
                            [1.968869878219135, 49.103146734184264],
                            [1.96839652011748, 49.10417849139565],
                            [1.967375339221423, 49.10630111277325],
                            [1.966935505568179, 49.10723764776223],
                            [1.966332856188451, 49.10851268478888],
                            [1.966071447897214, 49.10903162589225],
                            [1.965785432617782, 49.10954329242144],
                            [1.965461199360876, 49.11003594968727],
                            [1.965138741201041, 49.110473755700504],
                            [1.964705881556704, 49.1110191157457],
                            [1.96427902592455, 49.1114934516386],
                            [1.964013999370876, 49.111760576782125],
                            [1.963845619232703, 49.11192729590076],
                            [1.963643966339815, 49.11214065818842],
                            [1.963119947402951, 49.11260479189255],
                            [1.962636147718336, 49.11299710086697],
                            [1.962169039027187, 49.11335528942647],
                            [1.961406058772328, 49.113888767077846],
                            [1.96125464680586, 49.113983595496286],
                            [1.960980704767987, 49.11415805871265],
                            [1.960388938366326, 49.11451223462818],
                            [1.960002336804692, 49.114728592018835],
                            [1.957997082069814, 49.11573115850887],
                            [1.955729242071239, 49.11688667767492],
                            [1.954701574036264, 49.117406717971804],
                            [1.954053712273795, 49.11775753250874],
                            [1.953718710005357, 49.11793301524582],
                            [1.953400362455397, 49.11811050234628],
                            [1.95305075558635, 49.11831886586386],
                            [1.95281800842862, 49.11847456207997],
                            [1.95232606584323, 49.11883892353868],
                            [1.952080612599014, 49.11904223777728],
                            [1.951858483213578, 49.11924113384537],
                            [1.95141257556591, 49.11967398990842],
                            [1.951174830352074, 49.1199420768664],
                            [1.951123668121318, 49.12000215708756],
                            [1.951058643560165, 49.120082873909645],
                            [1.950853748851131, 49.120354667965465],
                            [1.950785912632721, 49.12044436805002],
                            [1.950754021583975, 49.12049282257167],
                            [1.950590338164125, 49.12075036572137],
                            [1.950520885542191, 49.120871535289616],
                            [1.950426433764886, 49.121035785627406],
                            [1.950263545596749, 49.12136617380972],
                            [1.950170168131946, 49.12156819773915],
                            [1.950078178849535, 49.12176752895752],
                            [1.949769923265884, 49.12246433371333],
                            [1.949332680280041, 49.12345185404933],
                        ],
                    },
                },
                354: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.04011512442914, 2.2032496870682654],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1527.63946237,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.197087678318264,
                            49.0353113085212,
                            2.21024652105706,
                            49.04543025423756,
                        ),
                        "coordinates": [
                            [2.197087678318264, 49.04543025423756],
                            [2.197091584578418, 49.04539358810968],
                            [2.197128241811315, 49.04500784383413],
                            [2.197250225733227, 49.04444054996809],
                            [2.197407351607283, 49.04402347794081],
                            [2.197540752370864, 49.043771843022085],
                            [2.197630118776123, 49.04361277976131],
                            [2.197649355411089, 49.04358222808735],
                            [2.197793559990601, 49.04338006582437],
                            [2.197989858698796, 49.04313749985846],
                            [2.198293074597037, 49.04281682594025],
                            [2.198615340773231, 49.04253034582485],
                            [2.198944341208773, 49.04228074412014],
                            [2.199147147291959, 49.04215418994457],
                            [2.199440389363224, 49.041971988923954],
                            [2.200034945660414, 49.041654357020164],
                            [2.201032167398774, 49.04115104963407],
                            [2.201729355047593, 49.04079726823742],
                            [2.202422478287046, 49.04045395046211],
                            [2.204740031468318, 49.03929208260162],
                            [2.205789162215096, 49.038778900688854],
                            [2.20635074933096, 49.03848457933566],
                            [2.206852110795169, 49.03820367582338],
                            [2.207274061122938, 49.03795055781521],
                            [2.207675532602531, 49.03768122792333],
                            [2.208056494534667, 49.037407377732265],
                            [2.208585600289199, 49.03696822512475],
                            [2.208878982019251, 49.036706864228776],
                            [2.209258816733971, 49.03633408799743],
                            [2.21024652105706, 49.0353113085212],
                        ],
                    },
                },
                355: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.077356465579214, 2.1902180994569003],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 3024.8644252,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.17530420994616,
                            49.07046236344271,
                            2.200978026879316,
                            49.08930709608885,
                        ),
                        "coordinates": [
                            [2.17530420994616, 49.07046236344271],
                            [2.176502735182653, 49.070800828510784],
                            [2.17723567597815, 49.071015877714025],
                            [2.177399767025015, 49.07106466703065],
                            [2.179608192614743, 49.07171609196469],
                            [2.181123406166229, 49.07214711277687],
                            [2.18264000980854, 49.07257991387108],
                            [2.184155276543216, 49.07301089431915],
                            [2.185336860290723, 49.073351487144635],
                            [2.186610126684593, 49.07370657658923],
                            [2.186958872886292, 49.07380505390974],
                            [2.187523670157187, 49.07397665244145],
                            [2.187819031123659, 49.07407685512089],
                            [2.188281209806101, 49.07423662638641],
                            [2.189016876617136, 49.07448937306324],
                            [2.189730670975323, 49.074759450521285],
                            [2.190384129375513, 49.075019899659026],
                            [2.191213958322949, 49.07537796780438],
                            [2.191395765574382, 49.07546273068268],
                            [2.191697840368354, 49.07561329156911],
                            [2.192457737448099, 49.07602634120472],
                            [2.193224298779143, 49.07649200484572],
                            [2.193762501216803, 49.07688476001333],
                            [2.193895001677773, 49.076982046479586],
                            [2.194412585405919, 49.077408046821475],
                            [2.194734770147043, 49.07771330017156],
                            [2.195170155702176, 49.07816617295605],
                            [2.195413029641761, 49.07844434839856],
                            [2.195726746600739, 49.07884311254356],
                            [2.19589853035864, 49.07908972462166],
                            [2.196068883235101, 49.07935881620565],
                            [2.196123362377816, 49.07945690434504],
                            [2.196215983867895, 49.07962158450512],
                            [2.196338559986879, 49.079843854981476],
                            [2.196550909890396, 49.08027037059615],
                            [2.196764612401425, 49.08070408181002],
                            [2.197869890237941, 49.08296350063568],
                            [2.198083565392199, 49.08341519426123],
                            [2.1984075261658, 49.08408771308517],
                            [2.199153171729724, 49.08559234742135],
                            [2.199410836755904, 49.08614068948192],
                            [2.200078802745266, 49.08752785009951],
                            [2.200559892669533, 49.0885008521167],
                            [2.200781858852642, 49.08894265839431],
                            [2.200978026879316, 49.08930709608885],
                        ],
                    },
                },
                356: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.81566265602977, 2.2834403248277875],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 1393.62176248,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.274489672177882,
                            48.81423944550172,
                            2.292061814554318,
                            48.81838763956164,
                        ),
                        "coordinates": [
                            [2.274489672177882, 48.81423944550172],
                            [2.275701339241957, 48.81433722414059],
                            [2.277689860029413, 48.81450482747072],
                            [2.278911079583619, 48.81460538603321],
                            [2.279523485459035, 48.814662799578],
                            [2.280125086670432, 48.814717824489364],
                            [2.280503332003678, 48.81475846037191],
                            [2.280845543234628, 48.81480621645205],
                            [2.28120935891414, 48.8148634982778],
                            [2.281544357517018, 48.814918386128774],
                            [2.282293591089642, 48.815054368950776],
                            [2.282815890430948, 48.815152171217434],
                            [2.283284150745847, 48.815249944055765],
                            [2.283687574903952, 48.81533578922809],
                            [2.284361133768253, 48.81549551717757],
                            [2.285059890572856, 48.81568142392574],
                            [2.28607919747397, 48.81597454071003],
                            [2.286648278644856, 48.81614610534814],
                            [2.287267771603163, 48.81634861985592],
                            [2.287912470100058, 48.81657255537023],
                            [2.288459916480592, 48.8167726531065],
                            [2.289090191692901, 48.81702036967745],
                            [2.289828504851223, 48.81732761026884],
                            [2.290354322884574, 48.81755862203575],
                            [2.291297906892865, 48.817992040533404],
                            [2.291683254683314, 48.818184920450896],
                            [2.292061814554318, 48.81838763956164],
                        ],
                    },
                },
                357: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.8313405743801, 1.9522089654843893],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 1152.77195771,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.944401758066846,
                            48.83095952864679,
                            1.960026560248269,
                            48.83191618431854,
                        ),
                        "coordinates": [
                            [1.944401758066846, 48.83191618431854],
                            [1.945643641363587, 48.83181188089133],
                            [1.947853050022673, 48.83163957817671],
                            [1.950061074642666, 48.83146812741733],
                            [1.952226981664214, 48.83128408886308],
                            [1.953001650153108, 48.8312160296678],
                            [1.953427913655874, 48.83118105943918],
                            [1.953861171157909, 48.83115360686729],
                            [1.95503036982163, 48.83109097898018],
                            [1.957612195748289, 48.83101595687798],
                            [1.957807038649854, 48.83100851144845],
                            [1.957858798504205, 48.83100868276726],
                            [1.957909210260055, 48.831007051572136],
                            [1.958112184109033, 48.831005028042256],
                            [1.960026560248269, 48.83095952864679],
                        ],
                    },
                },
                358: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.8168767144128, 2.2353499494160367],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 932.904086543,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.229808003729513,
                            48.81488431421452,
                            2.240919294866535,
                            48.818947800937735,
                        ),
                        "coordinates": [
                            [2.229808003729513, 48.818947800937735],
                            [2.229857218778483, 48.81892887000757],
                            [2.230953446759334, 48.81851112931037],
                            [2.232067676451515, 48.81809101450884],
                            [2.233459526133406, 48.8175712087063],
                            [2.236571238318494, 48.816415248560084],
                            [2.238590346168604, 48.815665134263284],
                            [2.239592639617607, 48.81530671268915],
                            [2.240299259538093, 48.81506700072195],
                            [2.240919294866535, 48.81488431421452],
                        ],
                    },
                },
                359: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.99348921556762, 2.261616972660548],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 662.260272877,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.259655619057618,
                            48.99065124967573,
                            2.263182622862856,
                            48.99609884257494,
                        ),
                        "coordinates": [
                            [2.259655619057618, 48.99609884257494],
                            [2.259936038504019, 48.995750918986936],
                            [2.26057546032276, 48.994973472504206],
                            [2.261835158362254, 48.99338618340801],
                            [2.262140515774405, 48.9929817089451],
                            [2.262417229385822, 48.992537647091815],
                            [2.262541924089943, 48.99231200999636],
                            [2.26268993446837, 48.992029733002774],
                            [2.262884447316756, 48.991526981431136],
                            [2.263150986764796, 48.99075665689007],
                            [2.263182622862856, 48.99065124967573],
                        ],
                    },
                },
                360: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.023280348033, 2.2260537831875817],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 590.063120613,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.222727322175325,
                            49.02177395624445,
                            2.229376488386948,
                            49.02477854792459,
                        ),
                        "coordinates": [
                            [2.222727322175325, 49.02477854792459],
                            [2.224586745203469, 49.02394102138565],
                            [2.225260201728623, 49.02363772338902],
                            [2.2256680978113, 49.02345646592867],
                            [2.226292266646845, 49.0231746971702],
                            [2.226601601256457, 49.02303920403792],
                            [2.227095715482583, 49.02282115490708],
                            [2.228788889933695, 49.02203769485087],
                            [2.229376488386948, 49.02177395624445],
                        ],
                    },
                },
                361: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.86418569899698, 2.2182244218238187],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1741.80985106,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.216428094448963,
                            48.85641999136021,
                            2.22102955043113,
                            48.87171419115656,
                        ),
                        "coordinates": [
                            [2.22102955043113, 48.87171419115656],
                            [2.220894669092794, 48.871487870802966],
                            [2.220742622310365, 48.87121613449376],
                            [2.220529673973555, 48.87075548791683],
                            [2.220509323901252, 48.87071320090687],
                            [2.220491695521402, 48.870673615286826],
                            [2.220315456853119, 48.87025617106526],
                            [2.21970597124377, 48.86857929398958],
                            [2.219659898570216, 48.86844850707879],
                            [2.219468869000787, 48.86795101063171],
                            [2.218718426828335, 48.865959237033714],
                            [2.218260627857895, 48.86473484593172],
                            [2.217961438504086, 48.863880221831714],
                            [2.217672941003725, 48.86311823276067],
                            [2.217546994015398, 48.862779973134785],
                            [2.217511774179814, 48.86268910894574],
                            [2.217502311227092, 48.86265672586783],
                            [2.217488762878157, 48.86262253893962],
                            [2.217453558740573, 48.86252538019936],
                            [2.217178618969485, 48.861800274912206],
                            [2.217040551897419, 48.861403548497684],
                            [2.216884930684409, 48.860940257566156],
                            [2.21673362826217, 48.860382546184184],
                            [2.216686366197515, 48.860200842680115],
                            [2.216647343487939, 48.85999306838162],
                            [2.216605567841313, 48.85979698211102],
                            [2.216596133208005, 48.859752907341374],
                            [2.21657466926078, 48.85961169819425],
                            [2.216495339606462, 48.85916467391442],
                            [2.216449827210608, 48.85882379964996],
                            [2.216444609293364, 48.85872757137128],
                            [2.216429122011755, 48.858369641962824],
                            [2.216428094448963, 48.85823115299411],
                            [2.216525865305397, 48.85725194211249],
                            [2.216570050176368, 48.85645163199814],
                            [2.216572237792291, 48.85641999136021],
                        ],
                    },
                },
                362: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.88776937314183, 2.2353815318139403],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1021.40188656,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.233691920150409,
                            48.883383813825255,
                            2.2370182854985,
                            48.89218735760208,
                        ),
                        "coordinates": [
                            [2.2370182854985, 48.89218735760208],
                            [2.237008762476744, 48.892175658644554],
                            [2.23645945873214, 48.89134874307954],
                            [2.236028515567895, 48.890672107456865],
                            [2.235859998789124, 48.89038239139515],
                            [2.235831524982709, 48.89030143136774],
                            [2.235790804463067, 48.89020697148228],
                            [2.235651199841928, 48.88978418759566],
                            [2.235526703932197, 48.889310158515435],
                            [2.235502312481371, 48.88923369858623],
                            [2.235471339434205, 48.88904122537198],
                            [2.235453838811784, 48.888929700204564],
                            [2.235451156765767, 48.888908115185785],
                            [2.235435222869895, 48.888696770014626],
                            [2.235431501330873, 48.8885160127913],
                            [2.23543157078741, 48.88848184022446],
                            [2.23543164576526, 48.88844496968036],
                            [2.235426535201084, 48.888276800562906],
                            [2.23542533702923, 48.888195864246754],
                            [2.235425371077484, 48.8881787779541],
                            [2.235426808880497, 48.88814280824479],
                            [2.235424178418346, 48.888095144553006],
                            [2.235420236190109, 48.888022299127854],
                            [2.235416435186294, 48.887880210104],
                            [2.235409909001369, 48.8877372196105],
                            [2.235407352650535, 48.88765358376268],
                            [2.235407504920138, 48.88757894419381],
                            [2.235406605812297, 48.88735142664091],
                            [2.235391910667516, 48.887202133511735],
                            [2.235379821595172, 48.88711219444047],
                            [2.235307274632951, 48.886578858714955],
                            [2.235190974947321, 48.886103038333516],
                            [2.235079905141784, 48.88573783290799],
                            [2.235014793117077, 48.88557140874087],
                            [2.234933420331685, 48.88535461021591],
                            [2.234815339394884, 48.88508562122766],
                            [2.234708086634803, 48.884856210174824],
                            [2.234591286860087, 48.88462768944146],
                            [2.234436441129308, 48.88433528523546],
                            [2.234183546855574, 48.88398074320581],
                            [2.234115559444409, 48.88388805661572],
                            [2.234032590326588, 48.883787263699645],
                            [2.233968663111559, 48.883709868399215],
                            [2.233907461047741, 48.88363337454792],
                            [2.233768728819554, 48.88346418582298],
                            [2.233691920150409, 48.883383813825255],
                        ],
                    },
                },
                363: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.58280828379595, 2.2920727742292355],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3812.58387719,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.289865556646717,
                            48.565593862821814,
                            2.297950577822679,
                            48.599059348508746,
                        ),
                        "coordinates": [
                            [2.297950577822679, 48.599059348508746],
                            [2.297796610370011, 48.598739963504954],
                            [2.29742850385053, 48.598064147306225],
                            [2.297065960805043, 48.59739274863074],
                            [2.29646365374937, 48.5962699549272],
                            [2.295961268022348, 48.59534440502075],
                            [2.295430363290502, 48.59435816283735],
                            [2.294850945938367, 48.59329794612421],
                            [2.294274423986171, 48.59222445438471],
                            [2.293692204962389, 48.59115475080187],
                            [2.293112861085381, 48.59009642094857],
                            [2.292827498452052, 48.5895520879013],
                            [2.292553570329796, 48.58901344682872],
                            [2.292288231678495, 48.58846532684841],
                            [2.292045760295363, 48.58792480030807],
                            [2.291806154535732, 48.587378585916504],
                            [2.291586565575498, 48.58683048298481],
                            [2.291244437224698, 48.58588791063855],
                            [2.291056305540707, 48.5853341299479],
                            [2.290910974206209, 48.58486190564954],
                            [2.290748567703737, 48.584313824869284],
                            [2.290600474524313, 48.58374488968763],
                            [2.290469525048672, 48.58318165066457],
                            [2.290347151288747, 48.58262220726403],
                            [2.290236220000186, 48.582055184476786],
                            [2.290142434970886, 48.581490063626234],
                            [2.290062936435053, 48.580930638275824],
                            [2.289997746245572, 48.58035415126983],
                            [2.289946827126436, 48.57979663468733],
                            [2.289901645858044, 48.57921826042657],
                            [2.289873600697814, 48.57865316685381],
                            [2.289865556646717, 48.57808997802331],
                            [2.289866099180354, 48.577513520210275],
                            [2.289878059465193, 48.57695033959064],
                            [2.28990146075575, 48.57637578711881],
                            [2.290106470664412, 48.57411364920344],
                            [2.290322897717185, 48.57184393218805],
                            [2.290481595376772, 48.57018288599388],
                            [2.290591216436173, 48.56905466561792],
                            [2.290686413694198, 48.568072448890774],
                            [2.290796029791331, 48.566940435592386],
                            [2.290924468489718, 48.565593862821814],
                        ],
                    },
                },
                364: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.85125332713814, 2.2172000345642893],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1152.26395896,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.216572237792291,
                            48.84610294864101,
                            2.217785185939174,
                            48.85641999136021,
                        ),
                        "coordinates": [
                            [2.216572237792291, 48.85641999136021],
                            [2.216579936038335, 48.85630865716042],
                            [2.216688010001731, 48.85501111289101],
                            [2.216726191708887, 48.854437414007705],
                            [2.216759874326773, 48.85403367388381],
                            [2.216852626529476, 48.85343395321325],
                            [2.216854017892107, 48.85342226424424],
                            [2.216866440187264, 48.85335662964841],
                            [2.216876140734322, 48.85329009315532],
                            [2.21688027197423, 48.8532721121523],
                            [2.217090790594797, 48.85186766191821],
                            [2.217270677953445, 48.8507302642016],
                            [2.217284516088511, 48.85064214902991],
                            [2.217320445004932, 48.85043445332479],
                            [2.217441897458479, 48.84979429531697],
                            [2.21763671982561, 48.84867220018686],
                            [2.217713051009426, 48.84809314509538],
                            [2.217759589607089, 48.847604367235505],
                            [2.217785185939174, 48.84698980715465],
                            [2.217755892601807, 48.846704705976016],
                            [2.217723662074243, 48.84650862975517],
                            [2.217677850199557, 48.846293654285255],
                            [2.217621080890435, 48.84610294864101],
                        ],
                    },
                },
                365: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.90649150370045, 2.27676333533518],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1040.88267942,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.269964779194514,
                            48.90562211913642,
                            2.283517328323657,
                            48.90688968790891,
                        ),
                        "coordinates": [
                            [2.283517328323657, 48.90562211913642],
                            [2.283228263560746, 48.90574331654968],
                            [2.282534795797109, 48.90599454943257],
                            [2.281576742424243, 48.906317681169455],
                            [2.281052025063218, 48.906450670649136],
                            [2.28031554298247, 48.90658989676857],
                            [2.27955501202741, 48.906713245561136],
                            [2.278866709792296, 48.90679855519838],
                            [2.278265083107542, 48.90684266383883],
                            [2.277769353330115, 48.906867790306684],
                            [2.277172563991536, 48.90688968790891],
                            [2.276445867444664, 48.90688296221917],
                            [2.275622949099537, 48.906850801214944],
                            [2.274785628319458, 48.90679324684433],
                            [2.274227438079463, 48.9067358385848],
                            [2.273731837405183, 48.906659427822774],
                            [2.273354094033049, 48.906594973302504],
                            [2.272975185123038, 48.90653052039973],
                            [2.272621553914518, 48.906458942508024],
                            [2.271398410200804, 48.90614418270848],
                            [2.270532462729012, 48.90591209586192],
                            [2.269964779194514, 48.90576265710707],
                        ],
                    },
                },
                366: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.89632629965541, 2.2224867138685793],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 168.502709336,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.221777707808168,
                            48.89574531120744,
                            2.223212968406662,
                            48.89692808639933,
                        ),
                        "coordinates": [
                            [2.223212968406662, 48.89574531120744],
                            [2.223097768246708, 48.895834984594465],
                            [2.222723386371388, 48.896127776369696],
                            [2.222480174077497, 48.896317281357625],
                            [2.222242391102349, 48.89651758249748],
                            [2.221777707808168, 48.89692808639933],
                        ],
                    },
                },
                367: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.90214627321892, 2.1076969624071342],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2630.85408301,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.094836628297753,
                            48.89797344633643,
                            2.122117447472966,
                            48.90395224576787,
                        ),
                        "coordinates": [
                            [2.122117447472966, 48.89797344633643],
                            [2.121889851109667, 48.898272582678324],
                            [2.121624388138437, 48.89857140572676],
                            [2.121312839877928, 48.898909483544344],
                            [2.120938867610329, 48.89927838140593],
                            [2.12054727909835, 48.89961936709452],
                            [2.120195471532308, 48.899907369393524],
                            [2.119682334430012, 48.90028049465578],
                            [2.119355366238673, 48.9005010950796],
                            [2.118886260607473, 48.90078437356431],
                            [2.118324265610653, 48.901097148268306],
                            [2.117926430207006, 48.901300523136705],
                            [2.117819797000306, 48.90135427555351],
                            [2.117309315571932, 48.90158115922447],
                            [2.116931834158807, 48.90173747079418],
                            [2.116443761523338, 48.90192782918905],
                            [2.116038182303329, 48.90207123466025],
                            [2.115576125481837, 48.902228546404764],
                            [2.115192429658407, 48.90234369685256],
                            [2.114986437347918, 48.90240468441817],
                            [2.114658234376702, 48.9024911468489],
                            [2.114543582619405, 48.90251880746378],
                            [2.114327393785238, 48.90256900467727],
                            [2.114060783632475, 48.90262558978364],
                            [2.113742164125282, 48.90269063806429],
                            [2.113380232562741, 48.90275560051027],
                            [2.11274522285841, 48.90286999226481],
                            [2.112134045573046, 48.90298157242501],
                            [2.111542360439765, 48.90309176069343],
                            [2.110549743109244, 48.90326967720748],
                            [2.109385865475218, 48.903485789586384],
                            [2.108969766371848, 48.903554912683745],
                            [2.108675006679958, 48.903608573897856],
                            [2.108215568116396, 48.90368331738571],
                            [2.107929515079511, 48.90372700136675],
                            [2.107649990047645, 48.90376355836952],
                            [2.107370465987234, 48.903800114728895],
                            [2.107175456217205, 48.90382399203149],
                            [2.106856977575596, 48.903854759145744],
                            [2.106532029497411, 48.90387980142163],
                            [2.106265555961135, 48.90390353264426],
                            [2.105916799814191, 48.90392567059907],
                            [2.10563088756806, 48.90393793981017],
                            [2.105228033501956, 48.90395139966259],
                            [2.104594047467554, 48.90395224576787],
                            [2.104262621478913, 48.9039398802782],
                            [2.103668268796986, 48.90391694703783],
                            [2.103118729670844, 48.90387516439407],
                            [2.102612128952876, 48.90382639379955],
                            [2.102108312361334, 48.90375641479013],
                            [2.10163402770257, 48.90367942176053],
                            [2.101154456145507, 48.90358650570194],
                            [2.100492824259921, 48.90343310415956],
                            [2.099930381172673, 48.903286977158835],
                            [2.09937332260618, 48.90313732117504],
                            [2.099009153174594, 48.903026958034275],
                            [2.098452244013643, 48.90284724551101],
                            [2.097879326709025, 48.90265158584375],
                            [2.097336012054991, 48.90243477091125],
                            [2.097025010509281, 48.902285339151035],
                            [2.096709674886361, 48.902114790574],
                            [2.096388617980394, 48.901914575407],
                            [2.09609530192421, 48.90170558155667],
                            [2.095886907800864, 48.90154780439112],
                            [2.095621856082281, 48.901294881969974],
                            [2.095383419942889, 48.901010322254805],
                            [2.09520351452713, 48.90074631799638],
                            [2.095061396289771, 48.9004206071207],
                            [2.094940034753221, 48.900038800626675],
                            [2.094877333208755, 48.899728204852494],
                            [2.094836628297753, 48.89807641113002],
                        ],
                    },
                },
                368: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.7840647766408, 2.5085976120310183],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2726.17331396,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.506983692598489,
                            48.77170790696431,
                            2.513423298184714,
                            48.79538383561483,
                        ),
                        "coordinates": [
                            [2.513423298184714, 48.79538383561483],
                            [2.512925820821219, 48.79472213022168],
                            [2.512762970173293, 48.7944987231693],
                            [2.512516938468329, 48.794175512368206],
                            [2.512393924448012, 48.79401390584664],
                            [2.512249184665318, 48.7938190230782],
                            [2.511891681371778, 48.79330565851364],
                            [2.511563340130671, 48.79281658649002],
                            [2.51124668422907, 48.79227260931218],
                            [2.510662048143134, 48.791282498624696],
                            [2.510128795708753, 48.790419805563104],
                            [2.509867990632014, 48.789980023864366],
                            [2.509231637309309, 48.78893845705302],
                            [2.508526939045144, 48.7878388052131],
                            [2.508026139547098, 48.78705628840074],
                            [2.507737519114613, 48.78662956491367],
                            [2.507655382744877, 48.78648940127089],
                            [2.507497075111131, 48.78620710168822],
                            [2.507353894440941, 48.78588014267036],
                            [2.507219209340811, 48.7854954538551],
                            [2.507136226189927, 48.78510708992795],
                            [2.507091213069102, 48.78467910215973],
                            [2.507079803497445, 48.78452624141747],
                            [2.507048611710499, 48.784160283333776],
                            [2.507023297321696, 48.78369332733725],
                            [2.506988799397989, 48.78308188916892],
                            [2.506983692598489, 48.782641718309364],
                            [2.506996898433735, 48.78229193587679],
                            [2.507082697923174, 48.78106168902557],
                            [2.507116958470422, 48.780552458440496],
                            [2.507158730758331, 48.78015474187864],
                            [2.507172944253692, 48.77993439814084],
                            [2.507196336932359, 48.77961332075873],
                            [2.50722868460527, 48.77912586508952],
                            [2.507248115881627, 48.77883986664289],
                            [2.507260838536927, 48.77858175515595],
                            [2.507286812690802, 48.7782202068872],
                            [2.507306178012511, 48.77791532320698],
                            [2.507325561564952, 48.77761583592727],
                            [2.507343563183762, 48.77731005425142],
                            [2.507362905601295, 48.776998876212375],
                            [2.507377203565582, 48.776803711858875],
                            [2.507384830265207, 48.776647226639206],
                            [2.507393602259271, 48.77642778975114],
                            [2.507399610768646, 48.776195767777885],
                            [2.507400317550412, 48.7760051198092],
                            [2.507398312596794, 48.77581717412619],
                            [2.507401474869616, 48.77554918575513],
                            [2.507396649795382, 48.77533246725106],
                            [2.507394031564279, 48.77496556641248],
                            [2.507391434238081, 48.77460496046973],
                            [2.507387582194276, 48.77427493167784],
                            [2.50739242536282, 48.774100465437854],
                            [2.507390411959852, 48.77390982119309],
                            [2.507398785643945, 48.77357437872963],
                            [2.507421314345074, 48.77300240604265],
                            [2.507452314060897, 48.772309925157735],
                            [2.507482645714313, 48.77170790696431],
                        ],
                    },
                },
                369: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.82786062461341, 2.467502021582397],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1601.31773223,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.463856795362316,
                            48.82103881506317,
                            2.471681242571033,
                            48.83428889889614,
                        ),
                        "coordinates": [
                            [2.471681242571033, 48.83428889889614],
                            [2.471629160541253, 48.83391929662283],
                            [2.471572150263288, 48.833680602095825],
                            [2.471448629456371, 48.83333902272404],
                            [2.471297876527697, 48.83300107217281],
                            [2.471174560991881, 48.832734132017805],
                            [2.471008906179359, 48.83242497549678],
                            [2.47076406198089, 48.83204666806528],
                            [2.470578121208017, 48.83179059210177],
                            [2.470500185004961, 48.831680972011924],
                            [2.470360794955251, 48.83151207084109],
                            [2.470280164370353, 48.831413245372325],
                            [2.469996020829289, 48.83110692400566],
                            [2.469580878293461, 48.83070992737625],
                            [2.468889036811954, 48.83012919127464],
                            [2.467991819722641, 48.82935835545486],
                            [2.467718680741118, 48.82910266615643],
                            [2.467353655650094, 48.82870573468983],
                            [2.467013818979892, 48.8282921176756],
                            [2.466775077958355, 48.82794976447464],
                            [2.466601318934022, 48.8276501658297],
                            [2.466449182236019, 48.82735054189709],
                            [2.466264302342994, 48.8269296090615],
                            [2.466101087353648, 48.82652530553112],
                            [2.465977732023202, 48.826204234269966],
                            [2.465836206621116, 48.82582370006869],
                            [2.465560299419782, 48.82503644972632],
                            [2.465429609275889, 48.82466304016429],
                            [2.465313560936869, 48.8243776503386],
                            [2.465088823099827, 48.823863966127725],
                            [2.464824428763375, 48.823340807898376],
                            [2.464682132499301, 48.823050990748804],
                            [2.464560243799497, 48.822785840879234],
                            [2.464340974967003, 48.82225281464043],
                            [2.46414921176749, 48.82182227634054],
                            [2.464038209418929, 48.821551717930284],
                            [2.463931283275691, 48.821276658285946],
                            [2.463856795362316, 48.82103881506317],
                        ],
                    },
                },
                370: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.90030398207737, 2.2189431664425214],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 866.110760726,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.215232347269524,
                            48.89692808639933,
                            2.221777707808168,
                            48.90209427759857,
                        ),
                        "coordinates": [
                            [2.221777707808168, 48.89692808639933],
                            [2.221686115216007, 48.89701792166386],
                            [2.221399026158222, 48.897303603280015],
                            [2.221270511826984, 48.89743386861681],
                            [2.221143359673207, 48.89756503479995],
                            [2.220961512566591, 48.89775459835939],
                            [2.220834276792964, 48.89790200106332],
                            [2.220680110524153, 48.89808600651048],
                            [2.220568894387991, 48.89825150065601],
                            [2.220506254534603, 48.89835564735355],
                            [2.220441045424031, 48.89846265154659],
                            [2.220404517868152, 48.89854989435333],
                            [2.220278958813144, 48.898831008941585],
                            [2.220222075185744, 48.89899035423621],
                            [2.220154089882262, 48.899186433174755],
                            [2.220034020182195, 48.89949555675834],
                            [2.219929837429747, 48.89971577337752],
                            [2.219870884279972, 48.89984341074025],
                            [2.219726934464894, 48.90015261482189],
                            [2.219430812069878, 48.90078450264536],
                            [2.219337585193054, 48.90098404691166],
                            [2.219293755015011, 48.90106043976696],
                            [2.21916090472507, 48.90128782058044],
                            [2.219059646723024, 48.901421708892116],
                            [2.218961317178462, 48.90154476490823],
                            [2.218887360803794, 48.9016223200041],
                            [2.218848433925076, 48.901663139338844],
                            [2.218703049394057, 48.90178861947321],
                            [2.218581621334506, 48.90185701889459],
                            [2.218425542045155, 48.90192680906574],
                            [2.218294471756604, 48.9019685782236],
                            [2.218100498063121, 48.90202069525896],
                            [2.217955342807056, 48.902049096214654],
                            [2.217827530322331, 48.90207037696062],
                            [2.217654253156048, 48.9020873280147],
                            [2.2174723356799, 48.90209427759857],
                            [2.217335912578498, 48.902094134430364],
                            [2.217206562777914, 48.902087445262744],
                            [2.217063304081775, 48.90207187590115],
                            [2.216864748393399, 48.90204262756259],
                            [2.216700097287168, 48.90201120392542],
                            [2.216537780698629, 48.90197296403428],
                            [2.21638269215105, 48.90192997239622],
                            [2.216198767206722, 48.90187267508963],
                            [2.21597158000034, 48.901796296540866],
                            [2.215279199952366, 48.90156476710142],
                            [2.215232347269524, 48.9015496742534],
                        ],
                    },
                },
                371: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.874478546360336, 2.3124027418885893],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2691.38388151,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.294490592832005,
                            48.87215749487708,
                            2.329927170608276,
                            48.87526354418469,
                        ),
                        "coordinates": [
                            [2.329927170608276, 48.87215749487708],
                            [2.328517439799408, 48.872936176993655],
                            [2.327946216855231, 48.873282977325296],
                            [2.327543081726972, 48.87351338959546],
                            [2.327513327319374, 48.87353039533204],
                            [2.32722473822704, 48.87366361529761],
                            [2.326993870714385, 48.87374449377356],
                            [2.326726937691462, 48.87380157478165],
                            [2.326093334052294, 48.87390540132687],
                            [2.32466727790539, 48.874101305859234],
                            [2.324592292495362, 48.87411298790103],
                            [2.323894257004666, 48.87420823728352],
                            [2.32272586288709, 48.874355583970264],
                            [2.320458582790299, 48.87465204975219],
                            [2.320427225790457, 48.87465654111149],
                            [2.319973219556722, 48.87471852641524],
                            [2.319876417798898, 48.87473739769716],
                            [2.31939786806072, 48.874807470328534],
                            [2.318481666309689, 48.87494132249868],
                            [2.316900774288894, 48.875161296934245],
                            [2.315845912764297, 48.875249072969275],
                            [2.315176360104978, 48.87526354418469],
                            [2.314353385166362, 48.87523645945851],
                            [2.312821026612146, 48.87518129734126],
                            [2.311960782693089, 48.87514694306575],
                            [2.309198737041365, 48.875036606749916],
                            [2.308635694608429, 48.87501578759135],
                            [2.307051397603954, 48.874952404804795],
                            [2.306151630456958, 48.87488770687992],
                            [2.305348846224523, 48.87480810623697],
                            [2.303843851908616, 48.87464132115434],
                            [2.302288428254897, 48.874469104993956],
                            [2.301271478681907, 48.874356386331456],
                            [2.301043823960449, 48.874332035915074],
                            [2.299649275282409, 48.87417691900811],
                            [2.29900952044549, 48.87410015579756],
                            [2.29838932674357, 48.87403462507202],
                            [2.298008855163854, 48.87401730706288],
                            [2.297680497990323, 48.874006881300964],
                            [2.297237464883782, 48.87401016642565],
                            [2.296570281663985, 48.87404775317011],
                            [2.295866600394945, 48.87409907481094],
                            [2.295329714102762, 48.87414357612667],
                            [2.294667710764419, 48.87421553405908],
                            [2.294490592832005, 48.874238476656075],
                        ],
                    },
                },
                372: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.80683203922729, 2.498347693702],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1801.36895526,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.486349748779074,
                            48.80537766216148,
                            2.510307237115641,
                            48.8078122706965,
                        ),
                        "coordinates": [
                            [2.486349748779074, 48.80537766216148],
                            [2.487273437182616, 48.80549557645088],
                            [2.489259147078454, 48.80574293449047],
                            [2.490619797415975, 48.8059317523713],
                            [2.491330775245508, 48.80603150906297],
                            [2.492236499074415, 48.80614988039989],
                            [2.493486835767924, 48.80631992867163],
                            [2.496398878918412, 48.8067178632461],
                            [2.500746687162176, 48.807337587621504],
                            [2.502653656477599, 48.80760821336127],
                            [2.503310174441267, 48.8076926891465],
                            [2.503927151563486, 48.80775923362493],
                            [2.504725130913757, 48.80780302599041],
                            [2.505164924112995, 48.8078122706965],
                            [2.50551753832117, 48.80780905208652],
                            [2.505791166638798, 48.807799654579355],
                            [2.506177683590879, 48.807784840892474],
                            [2.506576616284907, 48.80776161855605],
                            [2.506916423754081, 48.807729604247214],
                            [2.507323299792775, 48.80767665177688],
                            [2.507820166426115, 48.80760452857652],
                            [2.508151359998122, 48.807542168065055],
                            [2.508496921329099, 48.80746788959469],
                            [2.508950409341252, 48.80735299780153],
                            [2.509349910872673, 48.807252461634036],
                            [2.509785392332404, 48.80713997324496],
                            [2.510192034951663, 48.80702276838696],
                            [2.510307237115641, 48.80698507164624],
                        ],
                    },
                },
                373: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.89311462452497, 2.127689751004597],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1324.94231309,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.122117447472966,
                            48.89008623555385,
                            2.134600875228717,
                            48.89797344633643,
                        ),
                        "coordinates": [
                            [2.134600875228717, 48.89008623555385],
                            [2.132509251750519, 48.89072717189471],
                            [2.130044463596309, 48.89149792583881],
                            [2.129229238089342, 48.891780540535315],
                            [2.128498457512234, 48.892052316506444],
                            [2.127924568300293, 48.89231205977543],
                            [2.127599341692016, 48.89246434154056],
                            [2.127295932360578, 48.89261666270645],
                            [2.12676143013769, 48.892912442710085],
                            [2.126146361448998, 48.89328387805275],
                            [2.125762099972098, 48.89352871722993],
                            [2.125421112334521, 48.8937793455187],
                            [2.124943122441343, 48.89416962490165],
                            [2.124662767463997, 48.89441608124908],
                            [2.124425815648569, 48.89463834800254],
                            [2.124143224746739, 48.89490050187107],
                            [2.123919198431834, 48.89513706814241],
                            [2.12363630672492, 48.89546774589566],
                            [2.123466459398321, 48.89569156378578],
                            [2.123359684978365, 48.89584982856207],
                            [2.123260519925938, 48.89601723051225],
                            [2.123101324848784, 48.89630582998661],
                            [2.123020247113228, 48.896446865854415],
                            [2.122845688445648, 48.896757689384025],
                            [2.12262661023311, 48.89714044417571],
                            [2.122469411426023, 48.89744137549287],
                            [2.122332019575936, 48.8976681075112],
                            [2.122170771555959, 48.897903360216596],
                            [2.122117447472966, 48.89797344633643],
                        ],
                    },
                },
                374: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.9447488719057, 2.0671612677018625],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 4574.55828958,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.041072289675926,
                            48.93326540612854,
                            2.093521901580612,
                            48.95540224453111,
                        ),
                        "coordinates": [
                            [2.041072289675926, 48.93326540612854],
                            [2.045668504587519, 48.93529966502182],
                            [2.048460294797077, 48.93653211266265],
                            [2.053997431953846, 48.938980034483606],
                            [2.063909453931477, 48.943358356350146],
                            [2.069404894499701, 48.94578163311858],
                            [2.072525787399531, 48.9471641609139],
                            [2.075109865164508, 48.94830505866521],
                            [2.087559970412699, 48.95376495153617],
                            [2.088475704144185, 48.9541523995623],
                            [2.089216048741711, 48.95442352812452],
                            [2.089784880943044, 48.954616830409066],
                            [2.09041982801554, 48.95480379054842],
                            [2.091033257892704, 48.954959769637476],
                            [2.091639584520061, 48.955091935833345],
                            [2.092029394089491, 48.955171289332526],
                            [2.092321810369193, 48.95521950257172],
                            [2.092971637236077, 48.95532320200608],
                            [2.093521901580612, 48.95540224453111],
                        ],
                    },
                },
                375: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.20283254658722, 2.716911750278763],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 6203.63706657,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.703936052961915,
                            48.18093685577102,
                            2.736249842909681,
                            48.229549937455864,
                        ),
                        "coordinates": [
                            [2.703936052961915, 48.229549937455864],
                            [2.703985765329806, 48.22946151109987],
                            [2.704101421761575, 48.229265103554084],
                            [2.704225164985404, 48.229070467980414],
                            [2.704352886364159, 48.2288677252921],
                            [2.704517841918618, 48.22860371505364],
                            [2.70467751708113, 48.22835410852025],
                            [2.704861205445985, 48.22807564906738],
                            [2.705023496755266, 48.227816141933936],
                            [2.705181874539825, 48.22757373319775],
                            [2.70536014788292, 48.22729169349031],
                            [2.70550115941089, 48.22706732563995],
                            [2.705648891838918, 48.226842035858034],
                            [2.705801892812961, 48.2266014429016],
                            [2.70595490661124, 48.22636264750474],
                            [2.706158455915499, 48.22604185629278],
                            [2.706328803153279, 48.22578142228816],
                            [2.706476514209562, 48.225554333469084],
                            [2.706601505187193, 48.2253489006608],
                            [2.706689285050819, 48.225207434414294],
                            [2.706773041571207, 48.225067780164956],
                            [2.706839500167284, 48.22495515917468],
                            [2.706921909296604, 48.22481550865272],
                            [2.707004357709474, 48.22466118810824],
                            [2.707065320270406, 48.22455336357048],
                            [2.707146269835485, 48.224398430932204],
                            [2.707225813562455, 48.22423541019387],
                            [2.707319775214898, 48.22405038312066],
                            [2.707388982455865, 48.223915649196634],
                            [2.707486973277202, 48.22369951293949],
                            [2.70762734827228, 48.22339151642417],
                            [2.707756870759499, 48.22308896802133],
                            [2.70793450292641, 48.222683029049314],
                            [2.708045672228668, 48.22242515946952],
                            [2.708147324444039, 48.22218754196321],
                            [2.708286300392824, 48.22187325501202],
                            [2.708422601763943, 48.22156167408185],
                            [2.708565517848919, 48.22123478501777],
                            [2.708706939045614, 48.22088811745996],
                            [2.708765136296709, 48.220751243513426],
                            [2.708827234973856, 48.22059637174785],
                            [2.708874746945234, 48.220470323694485],
                            [2.708971678277027, 48.220197938446205],
                            [2.709048686366518, 48.21997247819565],
                            [2.709149993140247, 48.21966101231183],
                            [2.70920526312418, 48.21949267523329],
                            [2.709264435585181, 48.21930634030446],
                            [2.709318225868206, 48.21912002267478],
                            [2.709368046736703, 48.21894271108707],
                            [2.709424486162038, 48.218750990366836],
                            [2.709502488760634, 48.218382050362464],
                            [2.709547283037827, 48.21815443899932],
                            [2.70957626777858, 48.21798794630537],
                            [2.709599974819012, 48.217736983955085],
                            [2.709613257142747, 48.21753191744798],
                            [2.709618479314898, 48.21732867566423],
                            [2.709609001286167, 48.217138970108465],
                            [2.709592448184047, 48.216902529295],
                            [2.709570927201045, 48.216721855834535],
                            [2.709532868581779, 48.21648818381126],
                            [2.709477891089822, 48.21615025674991],
                            [2.709423274324293, 48.215860887512655],
                            [2.709386955125592, 48.215680262969016],
                            [2.709347684235613, 48.21546457899056],
                            [2.709307248617781, 48.215273178280206],
                            [2.709283245178246, 48.21512038918399],
                            [2.70925925485543, 48.214969398775246],
                            [2.709232494118538, 48.21480762656162],
                            [2.709222123613283, 48.214679072563065],
                            [2.709210123097969, 48.21451185602511],
                            [2.709207760414496, 48.21437428243087],
                            [2.709203452617789, 48.214155786033146],
                            [2.709211514118181, 48.21397231733615],
                            [2.709223737121063, 48.21380592065657],
                            [2.709238491540321, 48.213617934348214],
                            [2.709270489525792, 48.2133966199641],
                            [2.709304079744115, 48.2132085710698],
                            [2.709345847307024, 48.213034883104605],
                            [2.709402221394513, 48.21283506875077],
                            [2.709469298142296, 48.21262712676873],
                            [2.709547051418953, 48.21240745971294],
                            [2.70963433368146, 48.212203047639356],
                            [2.709740084195719, 48.21197737561937],
                            [2.709830476274736, 48.211801344969054],
                            [2.709926095360049, 48.21163287450498],
                            [2.710048387780507, 48.21143284267847],
                            [2.71019605432599, 48.211207547441234],
                            [2.710350465630802, 48.2109849283053],
                            [2.71049972145941, 48.210792899988974],
                            [2.710645065964089, 48.210617968706536],
                            [2.710797171205638, 48.21044751134172],
                            [2.710941388693076, 48.210302258308516],
                            [2.711129688537949, 48.210114595051046],
                            [2.711323446157342, 48.2099377045137],
                            [2.71164295909947, 48.20966597671235],
                            [2.711970621691362, 48.209405012285714],
                            [2.712563014471554, 48.20892465443174],
                            [2.712924110789214, 48.20863839715556],
                            [2.713095290449376, 48.20850204371293],
                            [2.713212940639064, 48.20840363567997],
                            [2.7133426585274, 48.20829979236943],
                            [2.713456231273418, 48.20819600242793],
                            [2.713571156975474, 48.20809310734561],
                            [2.713714149565788, 48.207965839104226],
                            [2.713842372065293, 48.20784221685366],
                            [2.714015342792432, 48.20766332775619],
                            [2.714209396741369, 48.20745162626286],
                            [2.714293398500193, 48.207351531352224],
                            [2.71439075722646, 48.20723880318539],
                            [2.714466768441794, 48.20714952592521],
                            [2.714537363960081, 48.207055769851536],
                            [2.714629266697856, 48.20693316835028],
                            [2.714697150289967, 48.20683672423348],
                            [2.714771672675774, 48.20672856729727],
                            [2.714846114398255, 48.20660962069083],
                            [2.714923163633058, 48.20647987470275],
                            [2.714992224206144, 48.20636094559194],
                            [2.715139446658792, 48.20608169257097],
                            [2.715221518134324, 48.205904270289544],
                            [2.715335223767999, 48.205640417088524],
                            [2.715386646004452, 48.20550176398288],
                            [2.71542352624199, 48.20539733096837],
                            [2.71545897384051, 48.205281212457635],
                            [2.715494367180454, 48.20515789994235],
                            [2.715534937429664, 48.2050075934489],
                            [2.715578529584745, 48.204802037830945],
                            [2.715607562470922, 48.204654941856454],
                            [2.715638444425401, 48.20446141821218],
                            [2.715652057004335, 48.20430400851502],
                            [2.715664358442297, 48.204151099116096],
                            [2.715675132235256, 48.20397391675516],
                            [2.715674163857806, 48.20384533102925],
                            [2.715671687187926, 48.2035162241197],
                            [2.715667711929983, 48.20334538572704],
                            [2.715664020523567, 48.203212313308974],
                            [2.715652371310211, 48.20291560920674],
                            [2.715648138742553, 48.20271060038188],
                            [2.715636374214697, 48.20239861016432],
                            [2.715629560643321, 48.20220799808585],
                            [2.715621244675989, 48.20199670864886],
                            [2.715615220153311, 48.20173235831187],
                            [2.71560837174563, 48.2015372497771],
                            [2.715602869382034, 48.201342137258],
                            [2.715594283083424, 48.201094880367705],
                            [2.715585731866197, 48.20085211890368],
                            [2.715573597483122, 48.20066961807093],
                            [2.715567377369465, 48.200379190895276],
                            [2.715561813901625, 48.20017598529307],
                            [2.715556019504955, 48.19994220758914],
                            [2.715550788034258, 48.199783063109656],
                            [2.715546683432086, 48.19959513949964],
                            [2.715541506126994, 48.19944318899457],
                            [2.715533224587629, 48.199236396416836],
                            [2.715528938667036, 48.19902419484873],
                            [2.715526383355073, 48.19886324271902],
                            [2.715530099033233, 48.19864202279452],
                            [2.715538025262077, 48.19844416724339],
                            [2.715551339672104, 48.19824719384682],
                            [2.715568702222668, 48.19805200457377],
                            [2.715591470618959, 48.197860394191906],
                            [2.715615888972144, 48.19770924360806],
                            [2.715642921715625, 48.197548192512215],
                            [2.715685655367018, 48.19732863916533],
                            [2.7157350995227, 48.197107265431654],
                            [2.715786098424808, 48.19691376127032],
                            [2.715833277227634, 48.196749045950554],
                            [2.715886078114076, 48.19657493671469],
                            [2.715927866467486, 48.196450187348056],
                            [2.715969984017179, 48.19632775213296],
                            [2.716109811087196, 48.19596399694512],
                            [2.716173237249966, 48.19581361376144],
                            [2.71626314678736, 48.19560828937853],
                            [2.716365119156295, 48.19539752938364],
                            [2.716465923468639, 48.19521015227839],
                            [2.71654689758047, 48.19506870277493],
                            [2.716679693193127, 48.194843450438036],
                            [2.716890919270105, 48.1944965394436],
                            [2.717146900109505, 48.1941417206653],
                            [2.71733551274196, 48.1938862688341],
                            [2.717443455962247, 48.19375461899209],
                            [2.717551417861278, 48.19362566578977],
                            [2.717691371582509, 48.19345883803613],
                            [2.71782073401307, 48.1933145257198],
                            [2.718027451657028, 48.19308452630762],
                            [2.718224992216332, 48.19288603095799],
                            [2.718439918568245, 48.19267488590107],
                            [2.718649537943883, 48.19247365079896],
                            [2.718855265490582, 48.19229131177645],
                            [2.719153278541325, 48.19204211792696],
                            [2.719317668195639, 48.191906677310534],
                            [2.719445979104611, 48.19180193298652],
                            [2.719753522782259, 48.19156889005158],
                            [2.720054532582699, 48.19136104776338],
                            [2.720338131659676, 48.19116315486281],
                            [2.720605825797976, 48.19099588890988],
                            [2.720944378768769, 48.19077442730669],
                            [2.721311060433757, 48.1905384812761],
                            [2.721699144230601, 48.190288074289974],
                            [2.722060522154168, 48.19006293440417],
                            [2.722534251077435, 48.18975827904674],
                            [2.722915592862175, 48.189506991001714],
                            [2.72330901933349, 48.189253862013615],
                            [2.72381756593059, 48.18893199591477],
                            [2.724113287354183, 48.188740346875534],
                            [2.724981746018108, 48.18818254239143],
                            [2.725293540694679, 48.187983641133684],
                            [2.726065572709857, 48.18748011425554],
                            [2.726992930631392, 48.186893316221486],
                            [2.727976333029956, 48.18625326338009],
                            [2.728648185346315, 48.185823417241274],
                            [2.729231419941952, 48.18545129530457],
                            [2.729908422740339, 48.18501461508867],
                            [2.730719437880147, 48.1844817629396],
                            [2.731222053684885, 48.18415167853432],
                            [2.73160428289024, 48.18389576745479],
                            [2.732036222014905, 48.18362778543925],
                            [2.732482235994008, 48.18334071999235],
                            [2.733639771166605, 48.18260148272277],
                            [2.734809003672546, 48.18185555650667],
                            [2.735598311273384, 48.18135010489242],
                            [2.736249842909681, 48.18093685577102],
                        ],
                    },
                },
                376: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.24941853311187, 2.6960834155399858],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4520.41587191,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.68564708993975,
                            48.229549937455864,
                            2.703936052961915,
                            48.26775810993438,
                        ),
                        "coordinates": [
                            [2.68564708993975, 48.26775810993438],
                            [2.685830313827444, 48.26751612159178],
                            [2.686250497479578, 48.26704177353725],
                            [2.686487945864353, 48.266792899007015],
                            [2.686850418277224, 48.266430283037046],
                            [2.687214483540642, 48.2661036297662],
                            [2.687480836498322, 48.2658645046267],
                            [2.688033931048953, 48.265414066435994],
                            [2.689345883702873, 48.264283232575465],
                            [2.689637596632948, 48.264014349152866],
                            [2.690029433103608, 48.26362015719037],
                            [2.690543620710754, 48.26300616803842],
                            [2.690906415917873, 48.2625059557208],
                            [2.691323592449331, 48.261888670656056],
                            [2.691579048548333, 48.261521229425],
                            [2.691771555936461, 48.26124610889578],
                            [2.692007439935492, 48.260858411463346],
                            [2.692231206061809, 48.26046618762296],
                            [2.692425683451772, 48.26005076683954],
                            [2.692555293353361, 48.259716742988594],
                            [2.692701283508169, 48.259223502918275],
                            [2.692781078103009, 48.25889143481272],
                            [2.692811844394738, 48.25867192532545],
                            [2.692870613909288, 48.25803328514041],
                            [2.69290799704218, 48.256656444802864],
                            [2.692930019805266, 48.2563434430829],
                            [2.692952264601215, 48.25606191377403],
                            [2.693008742291233, 48.2556705699214],
                            [2.693069522795977, 48.255417611712566],
                            [2.693160982117407, 48.255074067474915],
                            [2.69334432729476, 48.254551420504626],
                            [2.693508380183719, 48.25416098029063],
                            [2.694330868397965, 48.252612597341724],
                            [2.694564072513331, 48.252176157958786],
                            [2.69486235977706, 48.25161546188483],
                            [2.695429696302523, 48.250549869732986],
                            [2.696274650642705, 48.24895913762218],
                            [2.69778376066048, 48.24611994270639],
                            [2.698149070659552, 48.24543445914578],
                            [2.698776103427554, 48.24426524742434],
                            [2.699068413283547, 48.243728368312304],
                            [2.699348463230589, 48.24320258187557],
                            [2.699603716600194, 48.242725804203346],
                            [2.69988266953105, 48.242206050834255],
                            [2.700214724246778, 48.24158361438647],
                            [2.700490862568579, 48.24104858382148],
                            [2.70082166331228, 48.240417410626456],
                            [2.701259953188705, 48.23962082555225],
                            [2.701428640264105, 48.2393073488037],
                            [2.701573395610863, 48.23903531428073],
                            [2.701635813601244, 48.23891821247668],
                            [2.701702184729609, 48.23878940825473],
                            [2.701772548795654, 48.23864065797963],
                            [2.701837015559999, 48.23849787986672],
                            [2.701913016850792, 48.23831222148008],
                            [2.701977508920031, 48.23814646939549],
                            [2.702033031730077, 48.23800690956407],
                            [2.70208306595699, 48.23785297906438],
                            [2.702135608613895, 48.23767386297008],
                            [2.702181486769021, 48.23750376017419],
                            [2.702216745966819, 48.237354373988694],
                            [2.702265020507399, 48.23714379900299],
                            [2.702295809761331, 48.23693507845354],
                            [2.702326129061472, 48.23666161428319],
                            [2.702356543779326, 48.23638144786916],
                            [2.702384092733924, 48.236117394549645],
                            [2.702412980668557, 48.23583224571354],
                            [2.702433163089409, 48.235646040308936],
                            [2.702456875156807, 48.235389683756416],
                            [2.702505864966412, 48.23490753893102],
                            [2.702535417656313, 48.234528868762276],
                            [2.702566752837356, 48.234210440304516],
                            [2.702595500078212, 48.233906407980136],
                            [2.702630597635736, 48.233550200908084],
                            [2.702654667420769, 48.233343300183705],
                            [2.702675050519214, 48.23318497001422],
                            [2.702695304543422, 48.23300865655287],
                            [2.702723619746322, 48.232830517899515],
                            [2.702752059365686, 48.23266946360359],
                            [2.702789736897144, 48.232483201853505],
                            [2.702824918789129, 48.232323924421344],
                            [2.702871910354836, 48.23213257798207],
                            [2.702921644607597, 48.23192885025211],
                            [2.702987381750284, 48.23171462089179],
                            [2.703082171389999, 48.23142386274446],
                            [2.703171759897397, 48.23115829959109],
                            [2.703274825426444, 48.23089539121442],
                            [2.703332996691143, 48.23075132614692],
                            [2.703377982105059, 48.23064507083379],
                            [2.703431011114985, 48.23053429359786],
                            [2.703476030130194, 48.23043253451096],
                            [2.703483967553372, 48.23041362577977],
                            [2.703543606618239, 48.23028664024834],
                            [2.703624471649865, 48.23011732292088],
                            [2.703693537471563, 48.22999120672108],
                            [2.70376785516964, 48.229847089157154],
                            [2.703883460713511, 48.22964348801119],
                            [2.703936052961915, 48.229549937455864],
                        ],
                    },
                },
                377: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.844008930145264, 2.7417808146406566],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 5275.454365,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.708981742262277,
                            48.83653643294522,
                            2.773433916520679,
                            48.855394809029356,
                        ),
                        "coordinates": [
                            [2.773433916520679, 48.855394809029356],
                            [2.772162236779692, 48.854673808791816],
                            [2.768446704184702, 48.8525673950862],
                            [2.76734577854822, 48.85195643853933],
                            [2.766664192323958, 48.851614579595086],
                            [2.766417857258289, 48.85149320397099],
                            [2.765367321035669, 48.85103132150576],
                            [2.765071975964661, 48.850914623256855],
                            [2.764165661700949, 48.85058258488851],
                            [2.763539801446871, 48.85037809030951],
                            [2.763142213031498, 48.85025547436178],
                            [2.76212204795284, 48.8499921914594],
                            [2.761717823304127, 48.84988937967155],
                            [2.761414723737606, 48.849820363588414],
                            [2.759621048190263, 48.849450220636164],
                            [2.757981554897479, 48.849101063402756],
                            [2.757114383663718, 48.848924342154405],
                            [2.756121194026461, 48.84870953638914],
                            [2.754994598334726, 48.84844567484859],
                            [2.754272271570309, 48.84826666358267],
                            [2.753571141361217, 48.84806934070409],
                            [2.752804975496333, 48.847847523598794],
                            [2.751925521255908, 48.847573778440854],
                            [2.75120401878794, 48.84732729751239],
                            [2.75007776200981, 48.84690781698892],
                            [2.749055195466366, 48.846502338980564],
                            [2.748040523126321, 48.84606085125006],
                            [2.747013361387449, 48.84558972400341],
                            [2.745869816013136, 48.8450470610526],
                            [2.744995713978788, 48.84462662626337],
                            [2.743499309579684, 48.84391523557751],
                            [2.741856552722065, 48.84312880563004],
                            [2.741175400058909, 48.84280388023045],
                            [2.740475038152181, 48.842461033043584],
                            [2.739595620849011, 48.84204597180921],
                            [2.738956833879311, 48.84173347352262],
                            [2.738504168656263, 48.841522835735965],
                            [2.737679691633019, 48.84115882580184],
                            [2.73677889821295, 48.840790580728395],
                            [2.735946793386785, 48.840491333752574],
                            [2.735030224337505, 48.840191475635365],
                            [2.734380163517125, 48.839995898994346],
                            [2.733373934852096, 48.83972601702911],
                            [2.732569936880194, 48.83953006655052],
                            [2.732082733203, 48.839424740169335],
                            [2.731590147590309, 48.83932752345223],
                            [2.73076472214735, 48.8391765983845],
                            [2.729863131688801, 48.83904121788197],
                            [2.729673577504314, 48.83901758938645],
                            [2.728500787306475, 48.83886964216392],
                            [2.726895797600204, 48.83867819639975],
                            [2.726046290723572, 48.838580377863885],
                            [2.721607721856354, 48.838045069757285],
                            [2.718699202680301, 48.83769692559316],
                            [2.715792093512761, 48.83734960240928],
                            [2.712786852554258, 48.83699083802682],
                            [2.710847926869701, 48.836759799445],
                            [2.709528041022325, 48.83660134796955],
                            [2.708981742262277, 48.83653643294522],
                        ],
                    },
                },
                378: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.38966575859781, 2.7815569849457447],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 3183.56021636,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.764028188787889,
                            48.37952262366741,
                            2.796343615000022,
                            48.394308438758266,
                        ),
                        "coordinates": [
                            [2.796343615000022, 48.37952262366741],
                            [2.795804114952155, 48.379757731391244],
                            [2.795455588458932, 48.37992093750524],
                            [2.795092926116259, 48.38010085394565],
                            [2.79474840830428, 48.38028880150869],
                            [2.79434573544456, 48.38051695810893],
                            [2.793717604439072, 48.38091607007878],
                            [2.793232794525476, 48.38126062128909],
                            [2.79280287196363, 48.381604303737774],
                            [2.79237726262125, 48.38197270801431],
                            [2.79203200173299, 48.38230682285543],
                            [2.791739181237861, 48.38261824446364],
                            [2.791327913166158, 48.38311808554881],
                            [2.791058657327165, 48.38349865355215],
                            [2.790745980361188, 48.384004391577975],
                            [2.790556477437568, 48.3843499549572],
                            [2.790295740303872, 48.38482542012837],
                            [2.789388612976097, 48.386483684455754],
                            [2.788826470190544, 48.38747691232892],
                            [2.788504465338002, 48.38800156629908],
                            [2.788120219457178, 48.388512078490045],
                            [2.787823651077299, 48.38886397211266],
                            [2.787439676181402, 48.38925577960185],
                            [2.787102421341764, 48.38957633920049],
                            [2.786776733932136, 48.389856425270864],
                            [2.786512087926109, 48.390063419487696],
                            [2.786218931957193, 48.39028848735143],
                            [2.785925135359764, 48.39050008072888],
                            [2.785448504521254, 48.3908005260766],
                            [2.785063141279581, 48.39104035680475],
                            [2.784758092508918, 48.39120253218271],
                            [2.784421919349669, 48.391378718314485],
                            [2.784092754110054, 48.391540588987915],
                            [2.783788238582416, 48.39168563936983],
                            [2.78347548436483, 48.39181910055571],
                            [2.783119156239362, 48.39197141655894],
                            [2.782741756386987, 48.392115663313035],
                            [2.782396250629812, 48.39223123104279],
                            [2.782036496174382, 48.392351612687364],
                            [2.781679963424882, 48.392459254444546],
                            [2.781288172776693, 48.39256631277871],
                            [2.780864026619599, 48.39267742600338],
                            [2.780436242154062, 48.3927814145815],
                            [2.780065364240782, 48.39285662689779],
                            [2.779687275726896, 48.392924728960644],
                            [2.779344826324155, 48.39298317252175],
                            [2.779077603703484, 48.39302070662395],
                            [2.778680447783015, 48.39306666596609],
                            [2.778091263564066, 48.393122024338346],
                            [2.777555852275356, 48.393172327375346],
                            [2.776234973781218, 48.393288976058464],
                            [2.774316280975593, 48.39344659162968],
                            [2.772559525079437, 48.3935945581559],
                            [2.770802741473515, 48.393740699263226],
                            [2.76874639223484, 48.39391043873702],
                            [2.764636389731928, 48.39425429190967],
                            [2.764028188787889, 48.394308438758266],
                        ],
                    },
                },
                379: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.92382711606271, 1.8487648060113193],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 3519.95865451,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.840517029657971,
                            48.90930537596191,
                            1.857227537127738,
                            48.93871923993318,
                        ),
                        "coordinates": [
                            [1.857227537127738, 48.90930537596191],
                            [1.85712590272219, 48.909369046854245],
                            [1.85668920623179, 48.909663979077486],
                            [1.856080562334649, 48.91010387250079],
                            [1.855989780959639, 48.910179930569456],
                            [1.855574419826138, 48.91052440999987],
                            [1.854890208454059, 48.91115732671301],
                            [1.854654618896742, 48.91139284731552],
                            [1.854229330699102, 48.911914440705125],
                            [1.854175415154536, 48.911987055496375],
                            [1.854122872676552, 48.91205877772853],
                            [1.853805844305684, 48.91253046641334],
                            [1.853564225273821, 48.912963803606274],
                            [1.852976383229974, 48.91420234121349],
                            [1.852659938186628, 48.914891659073845],
                            [1.851639212054924, 48.91713826298202],
                            [1.851475887887029, 48.917514373625785],
                            [1.851186216023402, 48.91825236258693],
                            [1.851095210133959, 48.91848848979546],
                            [1.85050944912226, 48.92019825475057],
                            [1.850145968335598, 48.92122370192491],
                            [1.84973038610369, 48.92241169689954],
                            [1.849555646142469, 48.922835419344175],
                            [1.849395184583136, 48.923194452515276],
                            [1.849265634167208, 48.92346278934344],
                            [1.848826266950478, 48.92442855424574],
                            [1.848730081984784, 48.92463408197598],
                            [1.848580958646926, 48.9249490971864],
                            [1.848031239394895, 48.926169787773915],
                            [1.847749581685022, 48.926776506215475],
                            [1.846935319722306, 48.92852304580808],
                            [1.846737199683602, 48.928960152566184],
                            [1.846546565795222, 48.92932984404897],
                            [1.846497928722657, 48.92941776649678],
                            [1.84572410347682, 48.930793062547586],
                            [1.845358708894, 48.9314425809393],
                            [1.844392800073066, 48.93318665212398],
                            [1.844292769664877, 48.93336338192229],
                            [1.844124797161808, 48.93364683560616],
                            [1.843933386162074, 48.93395356841005],
                            [1.843771422144674, 48.934181290739275],
                            [1.843624632911881, 48.93439289173311],
                            [1.843455948970307, 48.93460979246324],
                            [1.84254768227431, 48.935761462634346],
                            [1.842365151401569, 48.935997187156964],
                            [1.841980894235166, 48.93647664738376],
                            [1.841407236850366, 48.93719449765197],
                            [1.841103793768826, 48.9376446274236],
                            [1.840958005240096, 48.9378904024925],
                            [1.840835492569125, 48.93812908264213],
                            [1.840530895345835, 48.938693417019884],
                            [1.840517029657971, 48.93871923993318],
                        ],
                    },
                },
                380: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.33606074025781, 2.7150681704821813],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 3453.05578905,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.692480190584066,
                            48.33268364471056,
                            2.738001618532588,
                            48.336948497679415,
                        ),
                        "coordinates": [
                            [2.738001618532588, 48.336481780613234],
                            [2.736762659171073, 48.33651262837991],
                            [2.735878364828087, 48.33653770750051],
                            [2.734612970880228, 48.33656975861058],
                            [2.732432980645761, 48.336617268752406],
                            [2.728731439796928, 48.33671110369936],
                            [2.726687246750097, 48.33676630014547],
                            [2.725137717425952, 48.33679635238013],
                            [2.724783071117859, 48.33680566399128],
                            [2.724328648426573, 48.336818914286134],
                            [2.723615322912011, 48.33683934410153],
                            [2.721535973996009, 48.33689230567229],
                            [2.720261667635255, 48.33692541422257],
                            [2.718930609839109, 48.33694521164816],
                            [2.717691142274704, 48.336948497679415],
                            [2.716711299646037, 48.33693927068468],
                            [2.715662428958664, 48.33692114809484],
                            [2.714664095502014, 48.33688582487598],
                            [2.712594360656635, 48.33678302090136],
                            [2.711390648661376, 48.336697093654635],
                            [2.709557805600562, 48.33652690442291],
                            [2.708508937160571, 48.33640446636896],
                            [2.707582817398796, 48.336283414393336],
                            [2.70713516862115, 48.336220739296465],
                            [2.706625597587514, 48.33615076632596],
                            [2.706148975814798, 48.336079486461344],
                            [2.705589999602982, 48.33599678418312],
                            [2.704894644748266, 48.335892042088645],
                            [2.703832519572033, 48.335702041279276],
                            [2.702830726332853, 48.33550738864384],
                            [2.701987278172267, 48.33532929475771],
                            [2.700781637483038, 48.33507676757434],
                            [2.699665057682811, 48.33481535695403],
                            [2.698849565787158, 48.33461183433904],
                            [2.697963621192474, 48.33439020234251],
                            [2.697279883743135, 48.33420714392918],
                            [2.696614967483384, 48.33401502916253],
                            [2.695685998889145, 48.333741127829356],
                            [2.694716520807782, 48.33344153318228],
                            [2.693826264481449, 48.33314745535343],
                            [2.692853203481901, 48.33282107583971],
                            [2.692480190584066, 48.33268364471056],
                        ],
                    },
                },
                381: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.79999368232182, 2.4490086068934627],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 722.7261571,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.446927482880671,
                            48.796740767488686,
                            2.449865075384561,
                            48.80263769071178,
                        ),
                        "coordinates": [
                            [2.449433177038806, 48.796740767488686],
                            [2.449626644027905, 48.797247536929106],
                            [2.449665562767123, 48.797348323733104],
                            [2.449725976920727, 48.79752778380019],
                            [2.449775611874137, 48.79770868357382],
                            [2.4498143929595, 48.797890734918816],
                            [2.449842256310614, 48.798073657841506],
                            [2.449859159915866, 48.798257165251044],
                            [2.449865075384561, 48.79844096921702],
                            [2.449862403964756, 48.79853769073881],
                            [2.449858793805307, 48.79862789725313],
                            [2.449842917669431, 48.79882689316819],
                            [2.449816173172553, 48.79902537943125],
                            [2.449778601022389, 48.799223098998084],
                            [2.449730246031678, 48.79941979304186],
                            [2.449671176121575, 48.79961520643691],
                            [2.449601464690514, 48.79980908138216],
                            [2.449521201382928, 48.800001169142604],
                            [2.449430490851767, 48.80019121835182],
                            [2.449329454073292, 48.80037897951505],
                            [2.449218218798837, 48.8005642067641],
                            [2.449096934492898, 48.80074666152401],
                            [2.448965757434512, 48.800926105249246],
                            [2.448824856134732, 48.801102302147285],
                            [2.448674418086957, 48.80127502460597],
                            [2.448514638933627, 48.80144404774772],
                            [2.448345723846542, 48.80160914763716],
                            [2.448167892878084, 48.801770110299934],
                            [2.447981382351685, 48.801926729031244],
                            [2.447786434055796, 48.80207879625173],
                            [2.447583296482056, 48.80222611520546],
                            [2.447372241238901, 48.80236849284079],
                            [2.44715354122092, 48.80250574420688],
                            [2.446927482880671, 48.80263769071178],
                        ],
                    },
                },
                382: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.860582770308255, 2.295416613701717],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1011.36657611,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.290391553460649,
                            48.857293413870465,
                            2.300989969386769,
                            48.86266245169434,
                        ),
                        "coordinates": [
                            [2.300989969386769, 48.86266245169434],
                            [2.300489376303076, 48.86262060013306],
                            [2.300032815891246, 48.862567398790404],
                            [2.299490401215816, 48.86249438141424],
                            [2.298927572098009, 48.86238628327973],
                            [2.298494214862682, 48.86229351367372],
                            [2.29800637041118, 48.8621620556285],
                            [2.297826501717835, 48.86210623886935],
                            [2.297464042713203, 48.86199010797553],
                            [2.297153379144549, 48.861873095721656],
                            [2.296750074591071, 48.86170748768124],
                            [2.296048439329894, 48.8613538246328],
                            [2.295530772178002, 48.86104788535211],
                            [2.29518069637236, 48.86080855129745],
                            [2.294891922429404, 48.86060880715892],
                            [2.294201323231796, 48.86013373465184],
                            [2.293821293267962, 48.859873701813434],
                            [2.292941392127579, 48.85926365878662],
                            [2.291533049514775, 48.85828559758574],
                            [2.29113808270113, 48.85799857196018],
                            [2.290786737550953, 48.85770436759405],
                            [2.290694652871954, 48.857616747019215],
                            [2.290586576383536, 48.85751184216011],
                            [2.290391553460649, 48.857293413870465],
                        ],
                    },
                },
                383: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.865295374914346, 2.3654140513451205],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 479.75079632,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.363957837859411,
                            48.8632579449589,
                            2.366661093353452,
                            48.86715872534515,
                        ),
                        "coordinates": [
                            [2.366661093353452, 48.8632579449589],
                            [2.366193621325488, 48.86404905684988],
                            [2.364976213365195, 48.8661091626122],
                            [2.364955686062861, 48.866143315039345],
                            [2.364864304289108, 48.86628304927547],
                            [2.36476287438522, 48.86641973168987],
                            [2.364651623688508, 48.866553047796266],
                            [2.364530813501833, 48.866682693179946],
                            [2.364400721450723, 48.86680836710899],
                            [2.364261645463939, 48.86692978154916],
                            [2.36411390107977, 48.86704665845192],
                            [2.363957837859411, 48.86715872534515],
                        ],
                    },
                },
                384: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.84716184367326, 2.296043067143132],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 600.789701113,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.293951963648718,
                            48.84479476371181,
                            2.298301401728378,
                            48.84935055362092,
                        ),
                        "coordinates": [
                            [2.298301401728378, 48.84935055362092],
                            [2.297916394991733, 48.849064406730065],
                            [2.297214693589996, 48.84854287185959],
                            [2.296820873142968, 48.8481211407298],
                            [2.294833592708225, 48.845817030455216],
                            [2.293951963648718, 48.84479476371181],
                        ],
                    },
                },
                385: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.81107072470063, 1.6359811483903433],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 6438.15660307,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.602701692990599,
                            48.795680661252575,
                            1.669010161365564,
                            48.82942901532876,
                        ),
                        "coordinates": [
                            [1.602701692990599, 48.79602536780062],
                            [1.603236408008472, 48.79599968779957],
                            [1.603826127095842, 48.795978300038406],
                            [1.604511266455972, 48.795947630704326],
                            [1.605130979733526, 48.79592283220414],
                            [1.605746609968344, 48.7958980035499],
                            [1.606687775028809, 48.795859070009335],
                            [1.607003769575837, 48.795845805181926],
                            [1.60769429664843, 48.795818748794105],
                            [1.608691300917315, 48.795777457381384],
                            [1.609097244149182, 48.795756668166376],
                            [1.609398251726842, 48.79574420035714],
                            [1.609560324958897, 48.795738039162174],
                            [1.609787782080818, 48.79572869852583],
                            [1.610096968672011, 48.795715382320495],
                            [1.61053145302376, 48.795697466696495],
                            [1.610926361143088, 48.79568649244778],
                            [1.611281719315086, 48.795680661252575],
                            [1.611616568377337, 48.79568099343828],
                            [1.611917325860914, 48.795685604357196],
                            [1.612235699068487, 48.795695721685966],
                            [1.612596134830515, 48.795715099403985],
                            [1.612929282986005, 48.795738798980395],
                            [1.613107426670145, 48.79575072152044],
                            [1.613254292537207, 48.795760647344075],
                            [1.61355197547651, 48.79578951598316],
                            [1.613855011498673, 48.795824711940476],
                            [1.614171579974363, 48.795865390037804],
                            [1.614483988532269, 48.79591143589807],
                            [1.614785455417056, 48.79596100970799],
                            [1.61487913514537, 48.795977790136156],
                            [1.615092301769348, 48.79601511204463],
                            [1.615397646048974, 48.79607909796122],
                            [1.615735577351389, 48.79614868398936],
                            [1.616090968852056, 48.79623456702565],
                            [1.616383974679737, 48.79630476701647],
                            [1.616699831480257, 48.79639489490388],
                            [1.617022379307295, 48.79649315805075],
                            [1.617395053900527, 48.79660792420768],
                            [1.617778359092972, 48.79674074289106],
                            [1.618055954674448, 48.796841417441335],
                            [1.61835382603619, 48.796952111466],
                            [1.618630023766397, 48.79705547419264],
                            [1.618896475175063, 48.797174062904695],
                            [1.619184627333971, 48.797298182727786],
                            [1.619490112523963, 48.79744759286315],
                            [1.620027936925946, 48.79772166713097],
                            [1.620585601566154, 48.79803633403803],
                            [1.621049664254151, 48.798328825736746],
                            [1.621452778255632, 48.79860024950755],
                            [1.621862172992021, 48.79890858342306],
                            [1.622654067081801, 48.79959792059035],
                            [1.623977418153144, 48.80091559896419],
                            [1.624783673213797, 48.8017471032376],
                            [1.625785165228847, 48.80273180292078],
                            [1.626083123217934, 48.80303043347278],
                            [1.62688298894613, 48.80383760182552],
                            [1.627198388003273, 48.804155222753316],
                            [1.627312455759458, 48.804271044405496],
                            [1.62757819742035, 48.80453889308971],
                            [1.62814725603027, 48.80511349389317],
                            [1.628590295430443, 48.80555151245271],
                            [1.629217274900464, 48.80617143284072],
                            [1.630136364803175, 48.80702698059911],
                            [1.631334338473437, 48.808092887304],
                            [1.631510605067852, 48.80824056509661],
                            [1.631567121104171, 48.80828767909742],
                            [1.631786622225868, 48.80845900616437],
                            [1.631891626739228, 48.808543290706474],
                            [1.632020857289967, 48.8086475108403],
                            [1.632594533628995, 48.809095314216954],
                            [1.633037711829012, 48.80943259383599],
                            [1.633259983911212, 48.80960123672812],
                            [1.633425687366549, 48.809726363541785],
                            [1.633920155133423, 48.810096331501875],
                            [1.634414934951727, 48.810444715659074],
                            [1.634963495996341, 48.81084199105448],
                            [1.635355844643397, 48.81111689560507],
                            [1.635717035587376, 48.81138081658174],
                            [1.635849131873667, 48.81147605554681],
                            [1.635912476427781, 48.81152230972428],
                            [1.636555442014567, 48.81198580717627],
                            [1.637140444776068, 48.81240847692926],
                            [1.63761632275407, 48.81274863647501],
                            [1.637845521917745, 48.81291101834833],
                            [1.638553386474041, 48.8134099746252],
                            [1.639211341718301, 48.81387624739934],
                            [1.639836972328668, 48.81431803588154],
                            [1.641173002361624, 48.81527676435546],
                            [1.641361804220146, 48.81540831572849],
                            [1.641799940486337, 48.815724845709966],
                            [1.642471623554868, 48.81618758497156],
                            [1.642994780281967, 48.81656038494807],
                            [1.64358672481966, 48.816981264107845],
                            [1.64417460722227, 48.817401216108436],
                            [1.64473958865818, 48.81780393928613],
                            [1.645953204715318, 48.81866743972935],
                            [1.646535779913486, 48.81908015277366],
                            [1.647080634520988, 48.819463856636645],
                            [1.647482538831972, 48.81974687092492],
                            [1.648075946593855, 48.820165937140644],
                            [1.648665265711571, 48.82058587410759],
                            [1.650530477750688, 48.82190830519779],
                            [1.65057079768746, 48.82194721751852],
                            [1.65144638289829, 48.822548724212325],
                            [1.652009166739748, 48.8229217203294],
                            [1.652233483538641, 48.8230498692825],
                            [1.6527199658362, 48.82332707793472],
                            [1.653350806374975, 48.823627124538675],
                            [1.653952853301261, 48.823898331876386],
                            [1.654407855534273, 48.82408901072828],
                            [1.656463490380098, 48.82485401219692],
                            [1.657356654846587, 48.82517499412996],
                            [1.658970679761503, 48.82577004756353],
                            [1.660338379630538, 48.826253001490045],
                            [1.662297974402805, 48.82698225472081],
                            [1.664256278129541, 48.827710567158114],
                            [1.666215988004955, 48.82843975260579],
                            [1.667853355853103, 48.8290366146316],
                            [1.66810953854447, 48.82912984607092],
                            [1.668373919237159, 48.82922132701306],
                            [1.668707472003886, 48.82933479503642],
                            [1.669010161365564, 48.82942901532876],
                        ],
                    },
                },
                386: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.89834534905035, 2.321568134125083],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1671.51699482,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.315599220546768,
                            48.89416838621195,
                            2.324051867179437,
                            48.9056549540281,
                        ),
                        "coordinates": [
                            [2.315599220546768, 48.89416838621195],
                            [2.3162044042611, 48.8942882150201],
                            [2.316453371762191, 48.894342984278055],
                            [2.316770892021817, 48.89442155714364],
                            [2.3170811941327, 48.89450250807315],
                            [2.317214696296079, 48.89453822063951],
                            [2.317377062772124, 48.894583455053905],
                            [2.317647672528863, 48.89466677727455],
                            [2.318058720102041, 48.89480752097976],
                            [2.318459207455153, 48.89496098162603],
                            [2.318953233173107, 48.89515723387387],
                            [2.319328480557982, 48.8952881539551],
                            [2.319707521763037, 48.89540288229673],
                            [2.320035697914932, 48.89550001855271],
                            [2.320346575176216, 48.89558323403162],
                            [2.320706851523712, 48.895654770620645],
                            [2.321370812806657, 48.895745274616935],
                            [2.321614991242529, 48.89578132064631],
                            [2.321987277734828, 48.895855362146364],
                            [2.322182303559252, 48.8958940551107],
                            [2.322269587252762, 48.89591295102933],
                            [2.32242778596023, 48.89596153095794],
                            [2.322570978320146, 48.896018203321496],
                            [2.322671893970456, 48.89606497768878],
                            [2.322720986220413, 48.89609106227637],
                            [2.322738715386656, 48.89610005683397],
                            [2.322815082882335, 48.89613873504687],
                            [2.322881903693294, 48.89617471432631],
                            [2.322902359288628, 48.896185507629106],
                            [2.323046911643662, 48.89626376182044],
                            [2.323201008551196, 48.89635100992517],
                            [2.323495545356364, 48.89660284014326],
                            [2.323608718396747, 48.89672425553888],
                            [2.323768237930779, 48.89694729319441],
                            [2.323850033698968, 48.897097481174356],
                            [2.323896380127263, 48.89719910438095],
                            [2.323956357156106, 48.89733759930978],
                            [2.324029958516564, 48.89753185072025],
                            [2.324051867179437, 48.897792805161146],
                            [2.324016164001098, 48.89812896825027],
                            [2.323885062233823, 48.89873866214313],
                            [2.323856391184517, 48.898842975118654],
                            [2.323826349653045, 48.89897066893779],
                            [2.323799038128615, 48.89909116830721],
                            [2.323786749099442, 48.899144224403564],
                            [2.323702084095518, 48.899505724042804],
                            [2.323624244318794, 48.899847439274524],
                            [2.323560062636204, 48.900121711573405],
                            [2.323557330495518, 48.90013430098865],
                            [2.323540943250696, 48.90020803977016],
                            [2.323509535114344, 48.90033843168901],
                            [2.323482224230977, 48.9004517372017],
                            [2.323463103634747, 48.900540763308705],
                            [2.323442619655118, 48.90062889048006],
                            [2.323426231503564, 48.900701729891274],
                            [2.32339345543893, 48.9008438114234],
                            [2.323389358379954, 48.90086359485296],
                            [2.323386627887909, 48.900872587893716],
                            [2.323337457247732, 48.90111178940839],
                            [2.323297847430144, 48.901303330687696],
                            [2.323273261077127, 48.90142293138489],
                            [2.323211795668932, 48.901722383162216],
                            [2.323191308459891, 48.90181950335237],
                            [2.323146233274699, 48.902038921180136],
                            [2.322909926282011, 48.903182773225005],
                            [2.3228853385237, 48.90330507158649],
                            [2.322879872963146, 48.90333564620399],
                            [2.322576618681681, 48.90480143042753],
                            [2.322547930300097, 48.904943512757725],
                            [2.322506947213364, 48.905144945021966],
                            [2.322491922761533, 48.90521059092353],
                            [2.322459134923079, 48.90537695306019],
                            [2.322431814261328, 48.905501948866274],
                            [2.322400403166692, 48.9056549540281],
                        ],
                    },
                },
                387: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.861618855861444, 2.7793826269248703],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1834.91531522,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.773433916520679,
                            48.855394809029356,
                            2.782226723449037,
                            48.86995013493981,
                        ),
                        "coordinates": [
                            [2.782226723449037, 48.86995013493981],
                            [2.78199211938028, 48.86853354002491],
                            [2.781806768929136, 48.86747219934415],
                            [2.781638587606743, 48.86650072047971],
                            [2.781622773563798, 48.86640905398943],
                            [2.781285845025224, 48.864400450496376],
                            [2.781261371289797, 48.86425486013037],
                            [2.780907682911392, 48.862197758435045],
                            [2.7808547327188, 48.86191558709017],
                            [2.780780422125615, 48.86153097901146],
                            [2.780711357716559, 48.861275849260444],
                            [2.780644067730559, 48.86106657633022],
                            [2.780563244346494, 48.86086814680073],
                            [2.780486718799938, 48.86069308223025],
                            [2.780393751151808, 48.86050819020617],
                            [2.780277285982469, 48.860286517659716],
                            [2.780140371004218, 48.86006402497578],
                            [2.780009156754974, 48.85986938826765],
                            [2.779862951918892, 48.85967481014016],
                            [2.779698989734511, 48.859475803223695],
                            [2.779485615036379, 48.859237419909306],
                            [2.779156952895809, 48.858908653787346],
                            [2.778935992096375, 48.858709616020356],
                            [2.778696813771512, 48.858507553869714],
                            [2.778433381769834, 48.85830983049734],
                            [2.778168602086251, 48.85812019881627],
                            [2.77779229801271, 48.85787707546556],
                            [2.777408142163433, 48.85765551104085],
                            [2.776687636892254, 48.85724461659766],
                            [2.775965708560566, 48.8568256291537],
                            [2.773514041910894, 48.85544023635753],
                            [2.773433916520679, 48.855394809029356],
                        ],
                    },
                },
                388: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.01330973476587, 2.1761501915558954],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 3401.85573029,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.154663485640923,
                            49.00742329713069,
                            2.197619813968745,
                            49.01913673984224,
                        ),
                        "coordinates": [
                            [2.197619813968745, 49.00742329713069],
                            [2.197008091251297, 49.00762122621544],
                            [2.195541488379903, 49.008043884046316],
                            [2.193848750432538, 49.00850968595437],
                            [2.193439730674932, 49.00861862390083],
                            [2.191999067670692, 49.009011780942245],
                            [2.188342468293504, 49.0100239728252],
                            [2.187896449261309, 49.01014479582501],
                            [2.187193217458812, 49.01033362619896],
                            [2.184690434061876, 49.01100332858747],
                            [2.183093995563466, 49.01142947821652],
                            [2.182666827481433, 49.01154311184559],
                            [2.181816094022191, 49.01177275870757],
                            [2.180640878382492, 49.012089256590286],
                            [2.178049332489053, 49.01279432270234],
                            [2.178011018908898, 49.01280506074413],
                            [2.177708624539413, 49.01288647504226],
                            [2.177500636811216, 49.012943739858976],
                            [2.17674806297863, 49.01314682586018],
                            [2.175980425213717, 49.013356181143195],
                            [2.175078680235649, 49.013602211686965],
                            [2.174902164377811, 49.01364962398947],
                            [2.173447578949681, 49.01404773584815],
                            [2.173094537525855, 49.01414345457021],
                            [2.173043910225493, 49.01415597212351],
                            [2.172982332209368, 49.014172970655586],
                            [2.172861922373489, 49.01420337340517],
                            [2.172684032000837, 49.01425167940884],
                            [2.17239393191633, 49.014330399893325],
                            [2.172159933807473, 49.01439481122292],
                            [2.172124355370923, 49.01440465172236],
                            [2.169334150834148, 49.015161393541376],
                            [2.169280778493651, 49.015176602617416],
                            [2.168298240149801, 49.01544134684781],
                            [2.168121710485582, 49.015488749087595],
                            [2.16618532079457, 49.01601465458309],
                            [2.165480549707653, 49.01620514827598],
                            [2.163890874453162, 49.016629500666156],
                            [2.162296022835996, 49.01706274690875],
                            [2.161461213926096, 49.017287190064884],
                            [2.161117706484206, 49.01738018850346],
                            [2.157681202315227, 49.01830651546753],
                            [2.157593610267531, 49.018330658660545],
                            [2.156513748668304, 49.018628423148],
                            [2.154943888066075, 49.01906119071421],
                            [2.154663485640923, 49.01913673984224],
                        ],
                    },
                },
                389: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.82924746132682, 1.6861227690356781],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 2594.18157048,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.669010161365564,
                            48.82657842806816,
                            1.703218425476859,
                            48.83074231216928,
                        ),
                        "coordinates": [
                            [1.669010161365564, 48.82942901532876],
                            [1.669552535490319, 48.8295978430664],
                            [1.670307161934505, 48.82980010246816],
                            [1.670855573358035, 48.82994089903769],
                            [1.671405646330195, 48.83007055268127],
                            [1.6721213331017, 48.83022077242586],
                            [1.673303802883533, 48.83041471291954],
                            [1.673763306598018, 48.83048213471682],
                            [1.674703121401377, 48.83058921568764],
                            [1.67535351756511, 48.83064245186013],
                            [1.676411048375846, 48.830707034338346],
                            [1.676763554789907, 48.83072885982571],
                            [1.677379068764591, 48.83074231216928],
                            [1.678665053352695, 48.830733552518375],
                            [1.679178878634652, 48.83071133515903],
                            [1.679589104045875, 48.83069481404013],
                            [1.680104431817055, 48.830661810294934],
                            [1.681325085841878, 48.83054562689286],
                            [1.681866705803939, 48.83048129011324],
                            [1.683175668677035, 48.8302783622613],
                            [1.684810141621017, 48.829973858998216],
                            [1.685304420754806, 48.829883156091505],
                            [1.685461430572626, 48.82985527520535],
                            [1.686424034845003, 48.829679108651675],
                            [1.68848309706375, 48.829296936115625],
                            [1.689142587700028, 48.82917478039558],
                            [1.690557132118364, 48.82891301329351],
                            [1.692263792710037, 48.82860161844907],
                            [1.692768953336082, 48.8285100459288],
                            [1.694033340364509, 48.82827076870544],
                            [1.69518429951968, 48.82805961809246],
                            [1.696085405654453, 48.82789381609272],
                            [1.69614956824781, 48.82788248621767],
                            [1.696204187065305, 48.82787200119313],
                            [1.696462236749577, 48.82782398819324],
                            [1.697880767016839, 48.82756395125347],
                            [1.699098590728624, 48.827340546110285],
                            [1.700341011477919, 48.827110068910876],
                            [1.701029124747011, 48.82698170811411],
                            [1.701338987810995, 48.82692857632825],
                            [1.702408030924794, 48.82672768509554],
                            [1.703218425476859, 48.82657842806816],
                        ],
                    },
                },
                390: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.8747439381964, 2.2797326247762855],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1034.47953057,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.275574526847743,
                            48.870974138193766,
                            2.284431219916768,
                            48.87790843816007,
                        ),
                        "coordinates": [
                            [2.275574526847743, 48.870974138193766],
                            [2.275774542519901, 48.87128179743647],
                            [2.275785427127885, 48.8712979903803],
                            [2.27598136738516, 48.87159575508543],
                            [2.276064373472024, 48.87171899994623],
                            [2.276087505707381, 48.87175408395329],
                            [2.276135130415138, 48.871826051673956],
                            [2.27621405722599, 48.87194209944553],
                            [2.276264400331111, 48.872021263018226],
                            [2.276453549682009, 48.8723028361081],
                            [2.276529753021967, 48.872417084646756],
                            [2.276581463810724, 48.87249355018142],
                            [2.276988446838697, 48.873017142076705],
                            [2.277529762025498, 48.87358473147246],
                            [2.27792077196972, 48.873945448132936],
                            [2.278265717019365, 48.874271393089536],
                            [2.278449590922048, 48.87441717006801],
                            [2.278929109238398, 48.87473215971842],
                            [2.279652588531028, 48.87511741361032],
                            [2.27984197783899, 48.875216428661886],
                            [2.280145840198249, 48.875357766026944],
                            [2.280517871638934, 48.87549823616644],
                            [2.28150809952964, 48.87583263263776],
                            [2.282279979614384, 48.87612858247744],
                            [2.282503436157638, 48.87625099055574],
                            [2.282767737421722, 48.8764264747647],
                            [2.282933932325939, 48.876551552591934],
                            [2.283082418220776, 48.876664031359894],
                            [2.28333167499062, 48.876887168374715],
                            [2.283507368452717, 48.877056314166545],
                            [2.283604056915825, 48.8771606750098],
                            [2.283638102946602, 48.87719666263622],
                            [2.283795558364668, 48.87734960150105],
                            [2.284028990935218, 48.87757633760556],
                            [2.284301425006699, 48.87780847578239],
                            [2.284431219916768, 48.87790843816007],
                        ],
                    },
                },
                391: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.98022007333439, 2.0552128182098466],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1604.1909791,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.049083121493801,
                            48.97482086455293,
                            2.05978806303153,
                            48.98705700117252,
                        ),
                        "coordinates": [
                            [2.049083121493801, 48.97482086455293],
                            [2.049084494313324, 48.97482161645026],
                            [2.051445168138702, 48.97616093298332],
                            [2.051840650117065, 48.976403186488994],
                            [2.052398093672699, 48.97676718752143],
                            [2.052931631366626, 48.97714112029085],
                            [2.053467184058789, 48.97754360791849],
                            [2.053851353709436, 48.977871482222646],
                            [2.054190180684881, 48.978164981295464],
                            [2.054563394845749, 48.978514240687765],
                            [2.05491283932303, 48.97884916395295],
                            [2.055240430275703, 48.97921401207399],
                            [2.055608982067314, 48.979623215937586],
                            [2.055854620192034, 48.97990791479121],
                            [2.056091415739849, 48.98022257141917],
                            [2.056358189770312, 48.9806058267493],
                            [2.056562458671274, 48.9809204016805],
                            [2.056773091890544, 48.981260689900104],
                            [2.057228238550051, 48.98208839091795],
                            [2.058011225649485, 48.98363355133636],
                            [2.058502577100653, 48.98458839360021],
                            [2.05978806303153, 48.98705700117252],
                        ],
                    },
                },
                392: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.99069825532223, 2.0666198882620925],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1300.81933277,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.05978806303153,
                            48.98705700117252,
                            2.074499463834352,
                            48.99192549246806,
                        ),
                        "coordinates": [
                            [2.05978806303153, 48.98705700117252],
                            [2.05991484049557, 48.98727287854603],
                            [2.060043787433295, 48.9874887601406],
                            [2.060284896578749, 48.98781912204343],
                            [2.060513350739319, 48.9880852092369],
                            [2.060776300253543, 48.98838992544602],
                            [2.061054566006323, 48.98867183651444],
                            [2.061404323859338, 48.98897105064195],
                            [2.061767116749642, 48.98926743932941],
                            [2.062052304929325, 48.98947655530041],
                            [2.062431176203509, 48.98973938876656],
                            [2.062759152206382, 48.98993080413802],
                            [2.063147265516642, 48.99015245589833],
                            [2.063613486489634, 48.99039253863686],
                            [2.064111211082558, 48.99061500655352],
                            [2.064699994766732, 48.99084768120881],
                            [2.065249962912493, 48.99103886021585],
                            [2.065732928729662, 48.99118562235484],
                            [2.066192158383023, 48.99130948396328],
                            [2.066925221637417, 48.991476613489915],
                            [2.06730452282478, 48.99153937134352],
                            [2.067746121113482, 48.9915937173418],
                            [2.068468804924978, 48.99167631149164],
                            [2.069130201799466, 48.991725447724946],
                            [2.069856773892852, 48.99175807585139],
                            [2.071985128391772, 48.99184771918191],
                            [2.073620620466596, 48.99189837244827],
                            [2.074499463834352, 48.99192549246806],
                        ],
                    },
                },
                393: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.9736197317407, 2.0155419615449826],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2158.77493621,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.00593089306856,
                            48.9703669339495,
                            2.027518775677185,
                            48.98107191008835,
                        ),
                        "coordinates": [
                            [2.00593089306856, 48.98107191008835],
                            [2.00632553617416, 48.980643534398844],
                            [2.006774079107144, 48.98005522334414],
                            [2.007819102789939, 48.97847786047376],
                            [2.009232325584228, 48.976307654684994],
                            [2.009525576746523, 48.97590733369938],
                            [2.009842546382175, 48.975527065878424],
                            [2.010117771867198, 48.975228052716346],
                            [2.010462650387159, 48.97488926491349],
                            [2.010713534259615, 48.97466298937024],
                            [2.011082017997406, 48.974361384128606],
                            [2.011406825104223, 48.9741053365819],
                            [2.011785900151924, 48.973840878104575],
                            [2.012112596514757, 48.973626235974045],
                            [2.012434852931297, 48.97342728324033],
                            [2.01285498737829, 48.97318292497152],
                            [2.013233617255454, 48.97298412915656],
                            [2.0136708895827, 48.97277122333888],
                            [2.014092829344619, 48.97258111381198],
                            [2.014610374689509, 48.9723612923108],
                            [2.015079929813678, 48.97218416242056],
                            [2.015592834661504, 48.972010007046315],
                            [2.016066499163984, 48.97186714679403],
                            [2.016839947144251, 48.97165211804439],
                            [2.017167836944298, 48.97157328519476],
                            [2.017471836182582, 48.97150989269007],
                            [2.018058049805687, 48.97139874562907],
                            [2.018609427118438, 48.97130891354083],
                            [2.019245335641266, 48.97122502388581],
                            [2.020102489934215, 48.97113175057434],
                            [2.021289557139614, 48.97100063887289],
                            [2.025535274501641, 48.97056971191711],
                            [2.027484526486944, 48.970370375718026],
                            [2.027518775677185, 48.9703669339495],
                        ],
                    },
                },
                394: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.993278736485884, 2.0846622086240383],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1552.7197956,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.074499463834352,
                            48.99192549246806,
                            2.094643978492074,
                            48.9957468339842,
                        ),
                        "coordinates": [
                            [2.074499463834352, 48.99192549246806],
                            [2.074928583126531, 48.991938731425776],
                            [2.079367802644813, 48.992096327653385],
                            [2.080004004540704, 48.992126309643055],
                            [2.080596786708784, 48.99216332956366],
                            [2.081344879520058, 48.99223162440971],
                            [2.081941046576137, 48.992313851860224],
                            [2.082475721629355, 48.9924006986824],
                            [2.082970593798657, 48.992494592226464],
                            [2.083617069148672, 48.992638785780315],
                            [2.084241757262916, 48.99280196304223],
                            [2.084920539558528, 48.992993807257555],
                            [2.086397256823127, 48.9934134357019],
                            [2.087581556012936, 48.99374675171935],
                            [2.093929315140013, 48.99554491624509],
                            [2.094500636238049, 48.99570855071274],
                            [2.094643978492074, 48.9957468339842],
                        ],
                    },
                },
                395: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.82662512935481, 2.561416453473115],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3060.8398722,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.542679794015853,
                            48.823151855834304,
                            2.579837253911679,
                            48.82891571807522,
                        ),
                        "coordinates": [
                            [2.542679794015853, 48.823266634124074],
                            [2.54319738223279, 48.82338471744232],
                            [2.543768420899775, 48.823522702070726],
                            [2.544135028007035, 48.823620902156875],
                            [2.544519516486454, 48.82372389086675],
                            [2.544909853942727, 48.82383934236116],
                            [2.545704764477432, 48.82409216533853],
                            [2.546404616029224, 48.824334809483716],
                            [2.546729249941615, 48.82445112001773],
                            [2.547585891862722, 48.82476698733664],
                            [2.550071962898491, 48.82572584429529],
                            [2.55133196244352, 48.82619076630898],
                            [2.552655102877416, 48.826692469934414],
                            [2.554434357872877, 48.82738363684643],
                            [2.555078456953258, 48.8276222441678],
                            [2.555655915997571, 48.82781862551826],
                            [2.556139496028702, 48.827972356133905],
                            [2.556662675469705, 48.82811649061705],
                            [2.557279454291553, 48.82826487072206],
                            [2.557957044876824, 48.828411042333876],
                            [2.558610088654659, 48.828537438840264],
                            [2.55932468798049, 48.828660963895196],
                            [2.560034359742709, 48.82875412311142],
                            [2.56059443107277, 48.828812379401555],
                            [2.561050894207676, 48.82885015310555],
                            [2.561606775303715, 48.828885031160354],
                            [2.562196656524036, 48.828908148790205],
                            [2.562875590550873, 48.82891571807522],
                            [2.563639072825642, 48.828904393445136],
                            [2.564257328554799, 48.828877083955135],
                            [2.5648196817397, 48.82883729344595],
                            [2.565429590017577, 48.828772224897726],
                            [2.56603944629848, 48.828696361668],
                            [2.566601596526989, 48.82861339741075],
                            [2.567301127896613, 48.82849058427833],
                            [2.567927089355076, 48.82836431845818],
                            [2.568374753950253, 48.828267189121206],
                            [2.56885377192259, 48.82814690297063],
                            [2.56932022524758, 48.82801976331371],
                            [2.569992099984153, 48.827811558659405],
                            [2.570618989808419, 48.82759624746719],
                            [2.571215913056742, 48.827381893966056],
                            [2.571856173993155, 48.82711618819398],
                            [2.572448720058697, 48.82684248486357],
                            [2.572864563004583, 48.826645582308366],
                            [2.573401306854942, 48.82638278014],
                            [2.573918951437667, 48.82611462014532],
                            [2.574482801824951, 48.825831879093215],
                            [2.577113247823859, 48.824509017813746],
                            [2.579837253911679, 48.823151855834304],
                        ],
                    },
                },
                396: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.862011753167764, 2.486683183549044],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1774.87225707,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.485192413733974,
                            48.85426899363537,
                            2.489167460948015,
                            48.86991241918608,
                        ),
                        "coordinates": [
                            [2.485761140611789, 48.86991241918608],
                            [2.485403140820869, 48.86804852924353],
                            [2.485296894981928, 48.867494280596155],
                            [2.485237977223209, 48.86708748898079],
                            [2.485204566862315, 48.86676869949371],
                            [2.48519291070255, 48.86648795169036],
                            [2.485192413733974, 48.86632139865094],
                            [2.485195565335754, 48.866169116595756],
                            [2.485205832004424, 48.86598351428096],
                            [2.485219795221389, 48.86582883789328],
                            [2.485237338016089, 48.86566464035502],
                            [2.48525851491468, 48.86550995537428],
                            [2.485286891217929, 48.86535050159098],
                            [2.485322444662407, 48.86517914269481],
                            [2.48536163207203, 48.865017296347084],
                            [2.485400847911842, 48.864864966831185],
                            [2.485454390657542, 48.86467930842683],
                            [2.485511551502227, 48.86449840411123],
                            [2.485575917800938, 48.86431511060469],
                            [2.485650961964073, 48.86408421531657],
                            [2.485915670629444, 48.86336292829613],
                            [2.486530753394955, 48.861634717413814],
                            [2.487149450555291, 48.859923154078274],
                            [2.487764484693475, 48.858206834380155],
                            [2.488286436263018, 48.8567238098652],
                            [2.488872799812502, 48.85509079809266],
                            [2.489137306418753, 48.85435309723007],
                            [2.489167460948015, 48.85426899363537],
                        ],
                    },
                },
                397: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.846836692583395, 2.4917993337281956],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1701.44033125,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.489167460948015,
                            48.839341939180265,
                            2.494188055346116,
                            48.85426899363537,
                        ),
                        "coordinates": [
                            [2.489167460948015, 48.85426899363537],
                            [2.489441244458785, 48.85350539416663],
                            [2.490005965305802, 48.85189382114354],
                            [2.490577868338836, 48.85028461304433],
                            [2.491113984856464, 48.84877300403469],
                            [2.491678865449789, 48.84724707839666],
                            [2.492243249362621, 48.84557362952163],
                            [2.492675472029595, 48.84437157499402],
                            [2.492897141309431, 48.84378595362841],
                            [2.493075866128748, 48.8433027016065],
                            [2.493186673629519, 48.84300275211929],
                            [2.493301182367373, 48.84273372791304],
                            [2.493419234998187, 48.84244566579689],
                            [2.493522978770402, 48.84219331280554],
                            [2.493633737464267, 48.84187908611802],
                            [2.493708573693987, 48.841605358805346],
                            [2.493812044012337, 48.841267349070705],
                            [2.493893947463762, 48.84094840320628],
                            [2.493972167761648, 48.840605670838706],
                            [2.494064475159349, 48.8401582260201],
                            [2.494120997567285, 48.83979410847092],
                            [2.494188055346116, 48.839341939180265],
                        ],
                    },
                },
                398: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.585015544181076, 2.2316501282304406],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 1477.83665606,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.22243331383282,
                            48.58248559694799,
                            2.241070080902974,
                            48.58632790141752,
                        ),
                        "coordinates": [
                            [2.22243331383282, 48.58248559694799],
                            [2.223030270952659, 48.58262405439505],
                            [2.224021659880004, 48.58284820389986],
                            [2.224606218467712, 48.58299368274531],
                            [2.225170664737299, 48.58315412710434],
                            [2.2257225406609, 48.58332455050398],
                            [2.226269352313955, 48.58351661722245],
                            [2.227016784877082, 48.58380214510024],
                            [2.227751670375946, 48.58408932022777],
                            [2.229131150795893, 48.58463858891828],
                            [2.231235572742492, 48.5854616594381],
                            [2.231945435806981, 48.5857337962075],
                            [2.232266526528431, 48.58584734652248],
                            [2.232581508771994, 48.58594581931543],
                            [2.23295896669429, 48.58605283865107],
                            [2.233307744257541, 48.58613310135934],
                            [2.233626444503126, 48.58619168488598],
                            [2.233972773017592, 48.58624363022461],
                            [2.234251359525463, 48.58627719225871],
                            [2.234710685197544, 48.58631591275238],
                            [2.235077179814213, 48.58632790141752],
                            [2.235441195156416, 48.5863248951593],
                            [2.235812755577665, 48.5863152335268],
                            [2.236392713474805, 48.58628910008277],
                            [2.23888082315863, 48.58613804772422],
                            [2.241070080902974, 48.58600789080001],
                        ],
                    },
                },
                399: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.82350969214343, 2.52727402884048],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2287.98565054,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.511855553451007,
                            48.8226267426856,
                            2.542679794015853,
                            48.82484856949889,
                        ),
                        "coordinates": [
                            [2.511855553451007, 48.82484856949889],
                            [2.512217423074874, 48.824814209134196],
                            [2.512766104006487, 48.824761206978174],
                            [2.513779054037772, 48.82466431774589],
                            [2.514398530826373, 48.82460490286682],
                            [2.515277862235902, 48.8245217806584],
                            [2.516086782843057, 48.82444758916252],
                            [2.517586244095618, 48.82430360031815],
                            [2.519199053721701, 48.824154236778675],
                            [2.521241312349522, 48.823960514265316],
                            [2.524109452066047, 48.823686052109736],
                            [2.525845360479719, 48.823526472729434],
                            [2.527401006831997, 48.82336915348054],
                            [2.529221956706923, 48.8231825061319],
                            [2.530345099939552, 48.82307089557032],
                            [2.533322450370636, 48.822780738035966],
                            [2.534735677133574, 48.82267308066506],
                            [2.53526263108855, 48.8226478853317],
                            [2.535856350601355, 48.822630665180206],
                            [2.536557711833274, 48.8226267426856],
                            [2.537180108559238, 48.82262924851815],
                            [2.537611893034019, 48.822644677351896],
                            [2.538214618943187, 48.82267325433027],
                            [2.538975174795262, 48.822733773378026],
                            [2.539696134074657, 48.822803874373214],
                            [2.54044406314881, 48.8228917732283],
                            [2.541219710124115, 48.822995674472836],
                            [2.54197740742918, 48.82312792268585],
                            [2.542679794015853, 48.823266634124074],
                        ],
                    },
                },
                400: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.73709408748731, 2.280614702034518],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1187.16998712,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.273483464396533,
                            48.734716586800225,
                            2.287667495463073,
                            48.73968104253053,
                        ),
                        "coordinates": [
                            [2.273483464396533, 48.734716586800225],
                            [2.274031620340385, 48.73489774142893],
                            [2.275473449753474, 48.73538233747892],
                            [2.276333671280968, 48.73566876733563],
                            [2.276904428808763, 48.73586780974144],
                            [2.277130016218571, 48.73594616481338],
                            [2.277400450874468, 48.736038931251876],
                            [2.278114751585832, 48.73629061184682],
                            [2.278288585868304, 48.73634661778088],
                            [2.278468848814772, 48.736401603656944],
                            [2.278655448101448, 48.73645132616507],
                            [2.278824707294772, 48.736493872116554],
                            [2.27896942208531, 48.73652677404454],
                            [2.27917117419971, 48.73656756304211],
                            [2.279459465816022, 48.73662002100706],
                            [2.279772100456614, 48.73667323497265],
                            [2.280207071036519, 48.73674719326826],
                            [2.280557756121379, 48.73681571212309],
                            [2.28079833681008, 48.736868888460535],
                            [2.281050094857402, 48.736934177101105],
                            [2.281215588400944, 48.73698509963458],
                            [2.281400416617344, 48.7370490382791],
                            [2.281585238935444, 48.737119270966886],
                            [2.28175102851868, 48.73718859553033],
                            [2.28189778689946, 48.737255213153205],
                            [2.282026872083625, 48.737321821437824],
                            [2.2822239040297, 48.73741723925846],
                            [2.282583979720338, 48.737608957070975],
                            [2.283092170198256, 48.7378771820766],
                            [2.283459049997222, 48.738069798772166],
                            [2.283700929779215, 48.73818861624478],
                            [2.283910197864844, 48.73829033149673],
                            [2.284156976186859, 48.73840560207419],
                            [2.284362725844899, 48.73849467700002],
                            [2.284635922673314, 48.738605687717424],
                            [2.284964781923204, 48.73872966309639],
                            [2.286426716475407, 48.7392460597942],
                            [2.287225043838089, 48.73952764747857],
                            [2.287667495463073, 48.73968104253053],
                        ],
                    },
                },
                401: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.88401295162234, 2.368514326925099],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 416.279056555,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.365893819935268,
                            48.883147451389796,
                            2.371001440751848,
                            48.88442088636331,
                        ),
                        "coordinates": [
                            [2.365893819935268, 48.88442088636331],
                            [2.366801719624653, 48.88436572688525],
                            [2.367762320790586, 48.88429824465871],
                            [2.367861540329076, 48.88429127356261],
                            [2.368230014690921, 48.88426001619312],
                            [2.368277314712684, 48.88425571517573],
                            [2.368444232229268, 48.88423584648875],
                            [2.368608847728725, 48.884208895818674],
                            [2.368770472516362, 48.88417497465779],
                            [2.368928428462436, 48.88413422333588],
                            [2.369082053414334, 48.884086814645855],
                            [2.369230702648352, 48.884032946656454],
                            [2.369373754281278, 48.88397284633775],
                            [2.369510605224135, 48.88390676594195],
                            [2.369640686214639, 48.883834980384464],
                            [2.36976344400414, 48.88375779434399],
                            [2.369878371541243, 48.883675527132645],
                            [2.369984981890481, 48.883588526947186],
                            [2.37005672458185, 48.883529981399036],
                            [2.370070909498041, 48.883518562625405],
                            [2.370161793374441, 48.883452118199884],
                            [2.370260584317621, 48.88339078030626],
                            [2.370366626950686, 48.88333495647191],
                            [2.370479215869042, 48.883285019787785],
                            [2.370597601203895, 48.88324129994457],
                            [2.370720996715233, 48.8832040904707],
                            [2.370848579921185, 48.883173637941546],
                            [2.371001440751848, 48.883147451389796],
                        ],
                    },
                },
                402: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.862624401001334, 2.3709454820937617],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 646.151904331,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368410025658025,
                            48.859873623471316,
                            2.372261187769952,
                            48.864657879612494,
                        ),
                        "coordinates": [
                            [2.371913980100838, 48.859873623471316],
                            [2.372162864975679, 48.860400602886365],
                            [2.372172552370367, 48.86043654212099],
                            [2.372211185549215, 48.860605127575546],
                            [2.372238866560517, 48.86077465201493],
                            [2.372255544594646, 48.860944798610625],
                            [2.372261187769952, 48.86111526322138],
                            [2.372255786162703, 48.861285729227575],
                            [2.372250374273217, 48.86140817640429],
                            [2.37223386788835, 48.86154152838965],
                            [2.372206349277859, 48.86167408602531],
                            [2.372167899443488, 48.8618054549169],
                            [2.372118636158102, 48.861935243558186],
                            [2.372058700358824, 48.86206306146122],
                            [2.371988276463264, 48.86218853005531],
                            [2.371907573385642, 48.86231127449338],
                            [2.371816831309918, 48.86243092728533],
                            [2.37171631892117, 48.86254713188104],
                            [2.371606338879815, 48.86265954090069],
                            [2.371487218216247, 48.86276782148099],
                            [2.371359312507505, 48.86287164810239],
                            [2.371255167227236, 48.862948299816956],
                            [2.369439470695181, 48.864039330871336],
                            [2.368413782586321, 48.86465562140258],
                            [2.368410025658025, 48.864657879612494],
                        ],
                    },
                },
                403: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.837139874950296, 2.3349876319808494],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 719.842000266,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332852309960891,
                            48.8342929804732,
                            2.337096430880091,
                            48.84003378741809,
                        ),
                        "coordinates": [
                            [2.332852309960891, 48.8342929804732],
                            [2.332853119762731, 48.83443844744721],
                            [2.332889883850911, 48.834639885819335],
                            [2.333015181308162, 48.834964527978926],
                            [2.333121952762951, 48.835131827019254],
                            [2.333221308453096, 48.835268426865625],
                            [2.333420921883711, 48.83549645862412],
                            [2.333748001578204, 48.83586831766564],
                            [2.334113063870981, 48.83625321572299],
                            [2.334425007013477, 48.836556277449596],
                            [2.334433180313827, 48.8365643704827],
                            [2.334860914847897, 48.83698883523912],
                            [2.335317266277421, 48.83743667897673],
                            [2.335580181420807, 48.83768488130097],
                            [2.335949359600945, 48.83804189566062],
                            [2.336281758825807, 48.838377325808935],
                            [2.336496344030231, 48.83866216411467],
                            [2.336695079514002, 48.83900404274471],
                            [2.336829405428655, 48.83931096972329],
                            [2.336961556197291, 48.83961292799368],
                            [2.337096430880091, 48.84003378741809],
                        ],
                    },
                },
                404: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.90904477627035, 2.3328481288571736],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 671.207845175,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.33183083796241,
                            48.90609405024862,
                            2.333924890479715,
                            48.911964897880885,
                        ),
                        "coordinates": [
                            [2.33183083796241, 48.90609405024862],
                            [2.331971071265832, 48.90651530957108],
                            [2.332630286510647, 48.90835914189018],
                            [2.333247008200374, 48.91023802318024],
                            [2.333682994258166, 48.9115280007971],
                            [2.333690169370554, 48.91154911149255],
                            [2.33372472428407, 48.91163505629655],
                            [2.333733386492259, 48.91165660153007],
                            [2.333787069120198, 48.91176202377902],
                            [2.333850992433355, 48.91186493271743],
                            [2.333924890479715, 48.911964897880885],
                        ],
                    },
                },
                405: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.85709234280276, 2.324540484981041],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 384.052253424,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.323154855841107,
                            48.85555093926606,
                            2.325712422182565,
                            48.85851112987378,
                        ),
                        "coordinates": [
                            [2.325712422182565, 48.85555093926606],
                            [2.325650608740697, 48.85576345823528],
                            [2.325516613328169, 48.85611336933598],
                            [2.3254899735242, 48.856191918951126],
                            [2.325451644624868, 48.85627209074976],
                            [2.325402872630789, 48.85634975291842],
                            [2.325344027688822, 48.85642431485764],
                            [2.325275560047069, 48.856495210700636],
                            [2.325197989187658, 48.85656189655412],
                            [2.325144330398777, 48.85660178336797],
                            [2.324728405337845, 48.85690072132983],
                            [2.324417673881433, 48.85719164042272],
                            [2.323836281545636, 48.85781315615626],
                            [2.323404150153949, 48.85825166178013],
                            [2.323154855841107, 48.85851112987378],
                        ],
                    },
                },
                406: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.88172027768981, 2.327128424903093],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 463.998074021,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.327022200889503,
                            48.879634760656806,
                            2.32724895353536,
                            48.8838045280338,
                        ),
                        "coordinates": [
                            [2.327022200889503, 48.879634760656806],
                            [2.327031718944625, 48.87989039339968],
                            [2.327040372641861, 48.88005833431565],
                            [2.327192896192302, 48.883018383829594],
                            [2.327228335720636, 48.8834300138257],
                            [2.327243451000938, 48.883598315147744],
                            [2.32724895353536, 48.88370142295037],
                            [2.327243410587406, 48.8838045280338],
                        ],
                    },
                },
                407: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.853656139871006, 2.3262662781843573],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 429.107404116,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325712422182565,
                            48.851762052495474,
                            2.326822568897497,
                            48.85555093926606,
                        ),
                        "coordinates": [
                            [2.326822568897497, 48.851762052495474],
                            [2.326707569248708, 48.85215317718144],
                            [2.326071801651592, 48.854315354235716],
                            [2.32578824043593, 48.855290274837685],
                            [2.325712422182565, 48.85555093926606],
                        ],
                    },
                },
                408: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.842185741361824, 2.3101989076057903],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 363.439434879,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307948677974289,
                            48.84150552236008,
                            2.312447513065986,
                            48.84287127500633,
                        ),
                        "coordinates": [
                            [2.307948677974289, 48.84150552236008],
                            [2.311432645326878, 48.84255737430997],
                            [2.311837674692292, 48.84268265191761],
                            [2.312445317373061, 48.84287059595653],
                            [2.312447513065986, 48.84287127500633],
                        ],
                    },
                },
                409: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.85800785247979, 2.3710601830486095],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 433.517105508,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.370209339755371,
                            48.856140711155,
                            2.371913980100838,
                            48.859873623471316,
                        ),
                        "coordinates": [
                            [2.370209339755371, 48.856140711155],
                            [2.371805810083091, 48.85964458563125],
                            [2.371913980100838, 48.859873623471316],
                        ],
                    },
                },
                410: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.833077284177875, 2.266822144680703],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 872.834045821,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.26317856570046,
                            48.82989015779482,
                            2.271241500950403,
                            48.8347526052236,
                        ),
                        "coordinates": [
                            [2.271241500950403, 48.83475000945583],
                            [2.270654565605306, 48.8347526052236],
                            [2.270069715589676, 48.834744135909865],
                            [2.269665508977426, 48.83472704552112],
                            [2.269315094843371, 48.83470302891731],
                            [2.269100465033629, 48.83468839238587],
                            [2.268875055162889, 48.83467130892278],
                            [2.268599513404118, 48.83463059853828],
                            [2.268429805306133, 48.83460005389039],
                            [2.268299062443663, 48.834566891852305],
                            [2.268163367519128, 48.834527035882964],
                            [2.2679203343243, 48.83443036389918],
                            [2.267812179138208, 48.83438020642782],
                            [2.267696323206512, 48.83431382010626],
                            [2.267609835574024, 48.83426093867959],
                            [2.26747790188097, 48.83415876008381],
                            [2.267395245250384, 48.83408972034953],
                            [2.267291499809982, 48.83398247890164],
                            [2.267013114860874, 48.83368284613388],
                            [2.266853380334234, 48.83350720337058],
                            [2.26658425865588, 48.833215717037106],
                            [2.266231641967273, 48.832825301461696],
                            [2.266131249748594, 48.83272369065375],
                            [2.266028081466807, 48.83262692115992],
                            [2.265997454512236, 48.83260055767777],
                            [2.265932596333635, 48.83254780766691],
                            [2.265856137545985, 48.83249974592646],
                            [2.265688603177494, 48.83241781109594],
                            [2.265280977575384, 48.83225842720503],
                            [2.26504326525075, 48.83215120776228],
                            [2.264938841337256, 48.832086899847766],
                            [2.264852438056038, 48.832022602772945],
                            [2.264773245069802, 48.831955931522494],
                            [2.264704879108315, 48.83187975018158],
                            [2.264489016839667, 48.83162026577037],
                            [2.264024665024739, 48.83102875940732],
                            [2.263651963273142, 48.830558268379974],
                            [2.263429433387372, 48.83025697696482],
                            [2.263310336942995, 48.83008508935263],
                            [2.26317856570046, 48.82989015779482],
                        ],
                    },
                },
                411: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.751485845971615, 2.3545460848099062],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 327.893865157,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.354036523459074,
                            48.750174036206914,
                            2.355360989087524,
                            48.75267435087357,
                        ),
                        "coordinates": [
                            [2.354367279157914, 48.750174036206914],
                            [2.35449437161057, 48.7503731954562],
                            [2.354581413188614, 48.750493606564824],
                            [2.35464247383274, 48.75061958769411],
                            [2.354643963053583, 48.75067385416871],
                            [2.354628089705112, 48.75073516651716],
                            [2.354597173734, 48.75079068524384],
                            [2.354540277573215, 48.75085177583928],
                            [2.354448729303448, 48.75092124619045],
                            [2.35418041850057, 48.751141112985735],
                            [2.354114849595354, 48.75120501126408],
                            [2.35407526089138, 48.75126333953104],
                            [2.354044167374734, 48.751333136558635],
                            [2.354036523459074, 48.75142733347255],
                            [2.354053160785915, 48.751478826159776],
                            [2.354097532248996, 48.75155759850572],
                            [2.354154982427431, 48.751626446152784],
                            [2.354612753884986, 48.751975889647966],
                            [2.35473029157739, 48.75207504706208],
                            [2.354817565906012, 48.752176895643245],
                            [2.35493603189771, 48.75231746598386],
                            [2.354989270105092, 48.75237772331384],
                            [2.355049057236895, 48.75243230458337],
                            [2.355119605875864, 48.75248979963917],
                            [2.355360989087524, 48.75267435087357],
                        ],
                    },
                },
                412: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.968228468382414, 2.3650381293332745],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 593.602295167,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.363572223970633,
                            48.96585557438446,
                            2.366003889114339,
                            48.97088340423817,
                        ),
                        "coordinates": [
                            [2.366003889114339, 48.97088340423817],
                            [2.365954807402065, 48.97072224548213],
                            [2.365911347398312, 48.970581637417354],
                            [2.365780283665909, 48.9701419663548],
                            [2.365647442856294, 48.969699906124326],
                            [2.365425082636528, 48.96896828868101],
                            [2.365248864086724, 48.968379671671556],
                            [2.365113316738489, 48.96793819015702],
                            [2.365080410772443, 48.967821430741935],
                            [2.365022843231778, 48.96765279111953],
                            [2.3649560091535, 48.967503136077184],
                            [2.364870138496159, 48.967358734346035],
                            [2.364763440429955, 48.96721838578248],
                            [2.364458182434314, 48.96684024522825],
                            [2.364038935816653, 48.9663276643408],
                            [2.363961507160727, 48.96623208148453],
                            [2.363882279224569, 48.966135894613785],
                            [2.363825206909035, 48.96607491972243],
                            [2.36369735788663, 48.965965388751755],
                            [2.363572223970633, 48.96585557438446],
                        ],
                    },
                },
                413: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89596460738566, 2.3966215006017264],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 475.021680526,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.395041749682104,
                            48.89388028252993,
                            2.397738850646979,
                            48.89745697697398,
                        ),
                        "coordinates": [
                            [2.397738850646979, 48.89388028252993],
                            [2.397678231569433, 48.89411375858865],
                            [2.39761417835626, 48.894316403121195],
                            [2.397523718776776, 48.89452438797588],
                            [2.397396305646275, 48.894760541315065],
                            [2.397147179514814, 48.89519978133141],
                            [2.396347032845788, 48.896576640991086],
                            [2.395909962493173, 48.89731396664284],
                            [2.395867631948511, 48.89735420425667],
                            [2.395832668286991, 48.897381628722],
                            [2.395789093425557, 48.89740472809833],
                            [2.395744147314155, 48.897421633259924],
                            [2.395679680420903, 48.897441295224546],
                            [2.395569065973029, 48.897456916561566],
                            [2.395484642172851, 48.89745697697398],
                            [2.395041749682104, 48.897432849464856],
                        ],
                    },
                },
                414: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93259821683135, 2.2916253471806223],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 468.534549341,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.28865600459439,
                            48.93181399693573,
                            2.294602555676577,
                            48.93335304151244,
                        ),
                        "coordinates": [
                            [2.294602555676577, 48.93335304151244],
                            [2.294293234805131, 48.93329316388419],
                            [2.293913555591217, 48.933211571168854],
                            [2.29355360447873, 48.933123792175444],
                            [2.293240567052677, 48.933038668290315],
                            [2.292744027561021, 48.93290368307023],
                            [2.292094583915452, 48.93272615264121],
                            [2.291146541830304, 48.93246476523011],
                            [2.290153615741154, 48.93218525784211],
                            [2.289773879884242, 48.93209717118495],
                            [2.289458645494878, 48.93203718653347],
                            [2.289316398249412, 48.932007790444636],
                            [2.289125679412883, 48.931957881519466],
                            [2.28865600459439, 48.93181399693573],
                        ],
                    },
                },
                415: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.97800950352086, 2.3879195749329325],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 447.050492649,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.385049192009276,
                            48.97716161245337,
                            2.390673192863133,
                            48.9785246242919,
                        ),
                        "coordinates": [
                            [2.390673192863133, 48.97716161245337],
                            [2.390529029061577, 48.97724962683469],
                            [2.390172971988623, 48.97746813653081],
                            [2.389885389688922, 48.977641788261195],
                            [2.389769820170161, 48.97769544750424],
                            [2.389680534347155, 48.977726875180835],
                            [2.389584059912826, 48.977754935396916],
                            [2.389488397416433, 48.977775386637916],
                            [2.388879772849351, 48.97789363014758],
                            [2.387915808194519, 48.97804527066544],
                            [2.387563058179282, 48.97810437892894],
                            [2.387062294351735, 48.97820936401057],
                            [2.386873945975499, 48.9782426627829],
                            [2.385301512163756, 48.97848501527229],
                            [2.385049192009276, 48.9785246242919],
                        ],
                    },
                },
                416: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.82307767970448, 2.3738188888060527],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 618.731246369,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.370053603529677,
                            48.821829558069034,
                            2.377583361890927,
                            48.82432821353967,
                        ),
                        "coordinates": [
                            [2.370053603529677, 48.821829558069034],
                            [2.370364542022957, 48.821931496977754],
                            [2.37296615981159, 48.822791116695214],
                            [2.37669519921868, 48.82403705921481],
                            [2.377232613280091, 48.824211191003975],
                            [2.377583361890927, 48.82432821353967],
                        ],
                    },
                },
                417: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.82494339695696, 2.379377019122971],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 297.197922783,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.377583672650781,
                            48.82432831049086,
                            2.381166046342601,
                            48.825570391064204,
                        ),
                        "coordinates": [
                            [2.377583672650781, 48.82432831049086],
                            [2.377934732236625, 48.82444542892787],
                            [2.379379906013518, 48.824927667180305],
                            [2.379623241437514, 48.825012453756955],
                            [2.379813662689536, 48.825091968499656],
                            [2.380039625509621, 48.82518308923923],
                            [2.380375479592772, 48.82530690281294],
                            [2.380777347288345, 48.82544081096568],
                            [2.381166046342601, 48.825570391064204],
                        ],
                    },
                },
                418: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.78519333984691, 2.3670550166844997],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 464.179904951,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.366988444947912,
                            48.783107550449365,
                            2.367157833315663,
                            48.78728035004914,
                        ),
                        "coordinates": [
                            [2.367157833315663, 48.783107550449365],
                            [2.367071471963607, 48.78466663129567],
                            [2.36700739065166, 48.78586702157471],
                            [2.367012977203101, 48.786171574836835],
                            [2.367002439649003, 48.78660699519474],
                            [2.366988444947912, 48.78728035004914],
                        ],
                    },
                },
                419: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.8253157474748, 2.3161048821425343],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 422.097037659,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313380087366043,
                            48.824711018803754,
                            2.318829692620227,
                            48.82592054697145,
                        ),
                        "coordinates": [
                            [2.313380087366043, 48.82592054697145],
                            [2.313782660722515, 48.82583124778299],
                            [2.318466130941962, 48.82479157880133],
                            [2.318829692620227, 48.824711018803754],
                        ],
                    },
                },
                420: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.93068485258403, 2.3549130588100393],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 434.663527626,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352701984386339,
                            48.929812105656694,
                            2.357292070882457,
                            48.932051822712985,
                        ),
                        "coordinates": [
                            [2.352701984386339, 48.932051822712985],
                            [2.353083753014158, 48.931789826700104],
                            [2.354454907203267, 48.93088260416948],
                            [2.354931945985122, 48.93056276748829],
                            [2.355581795649085, 48.93013916553578],
                            [2.355602576918359, 48.93012682750446],
                            [2.355626909181352, 48.93011319559897],
                            [2.355654436386561, 48.930098475638836],
                            [2.355684806588474, 48.93008287256647],
                            [2.355717669173333, 48.930066594029356],
                            [2.355752669467364, 48.9300498449556],
                            [2.355789454129044, 48.930032832978554],
                            [2.355827672580592, 48.930015763048964],
                            [2.355866970128847, 48.92999884189442],
                            [2.355906994833477, 48.929982274459135],
                            [2.35594739472196, 48.92996626838553],
                            [2.355987815126603, 48.92995102860405],
                            [2.356027905441733, 48.929936762765415],
                            [2.356067311012846, 48.92992367490186],
                            [2.356105681225146, 48.92991197356424],
                            [2.356142661425817, 48.929901862785684],
                            [2.35621308209294, 48.92988489110008],
                            [2.356281995266447, 48.92987017838727],
                            [2.356348908860574, 48.92985756463109],
                            [2.356413333485154, 48.92984689252867],
                            [2.356474778395145, 48.92983800387143],
                            [2.356532752845009, 48.92983074045163],
                            [2.356586766087525, 48.929824944062204],
                            [2.356636326021322, 48.929820455590054],
                            [2.356680943239515, 48.92981711863468],
                            [2.356720127025468, 48.929814772292374],
                            [2.356753386594601, 48.929813261054655],
                            [2.356780229852117, 48.929812424909315],
                            [2.356800167409923, 48.929812105656694],
                            [2.356812708503154, 48.92981214598831],
                            [2.35681736238889, 48.929812386795994],
                            [2.356813636936702, 48.929812670761336],
                            [2.357292070882457, 48.92981642738062],
                        ],
                    },
                },
                421: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.00850024068352, 2.4391577071200583],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4690.2959091,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.416187488926984,
                            48.99377714689271,
                            2.462168966135235,
                            49.023161999031025,
                        ),
                        "coordinates": [
                            [2.462168966135235, 49.023161999031025],
                            [2.461637819177708, 49.02282008129321],
                            [2.45957424580728, 49.02151246167271],
                            [2.458646604677116, 49.020909096479514],
                            [2.456298742943019, 49.01943637087454],
                            [2.453672021568733, 49.01777353475143],
                            [2.451650448321431, 49.01648359096697],
                            [2.449263121727429, 49.014970312375645],
                            [2.446806447041264, 49.01336683260676],
                            [2.444355532290668, 49.011802960739466],
                            [2.441997629978844, 49.010308538791975],
                            [2.439821045732223, 49.008973321067614],
                            [2.431601326313747, 49.00364952227296],
                            [2.429092201685547, 49.002097854666516],
                            [2.426775049581427, 49.00062926036458],
                            [2.424791094503519, 48.99936974502618],
                            [2.422666062298229, 48.99802226604768],
                            [2.421862399551127, 48.9975017869719],
                            [2.421084063973647, 48.996981284987235],
                            [2.420392605158946, 48.996505921330645],
                            [2.419311335005715, 48.99575754727189],
                            [2.418413610427097, 48.99516335241997],
                            [2.416512197885109, 48.99398531664587],
                            [2.416187488926984, 48.99377714689271],
                        ],
                    },
                },
                422: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.028171202330086, 2.4701018555958556],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1608.78315616,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.462168966135235,
                            49.023161999031025,
                            2.478033365115083,
                            49.033182769031264,
                        ),
                        "coordinates": [
                            [2.478033365115083, 49.033182769031264],
                            [2.476579460789503, 49.03226199604023],
                            [2.475261556334177, 49.031422443060364],
                            [2.472731440110162, 49.02982654697679],
                            [2.470186920742401, 49.028194922678715],
                            [2.467773230317047, 49.026717749750894],
                            [2.466044492685873, 49.02562045194961],
                            [2.46386288351023, 49.02425238540592],
                            [2.463418001262921, 49.02396601912603],
                            [2.462168966135235, 49.023161999031025],
                        ],
                    },
                },
                423: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.22851149897188, 2.4534808497047265],
                        "indice_lig": "D",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 9276.91081032,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.442510307190429,
                            49.1873335365493,
                            2.468914115351039,
                            49.26394414450533,
                        ),
                        "coordinates": [
                            [2.459520081112193, 49.1873335365493],
                            [2.457393035027741, 49.202123786737765],
                            [2.456554549866675, 49.20730086553362],
                            [2.455836361280597, 49.20931001739014],
                            [2.44903116013877, 49.22100249636138],
                            [2.44418514990101, 49.229339952598174],
                            [2.442510307190429, 49.233630459804836],
                            [2.442515288283561, 49.23595874790341],
                            [2.44364447306937, 49.23889870640681],
                            [2.450962253011323, 49.24710198287682],
                            [2.458843796152947, 49.25518165120713],
                            [2.468914115351039, 49.26394414450533],
                        ],
                    },
                },
                424: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98550517065901, 2.403355582328755],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2646.63525035,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.390763932713399,
                            48.97686858845462,
                            2.416187488926984,
                            48.99377714689271,
                        ),
                        "coordinates": [
                            [2.416187488926984, 48.99377714689271],
                            [2.415543364629177, 48.99336419260263],
                            [2.414519126943772, 48.99273674349286],
                            [2.413603510445466, 48.9921924897475],
                            [2.412247274999493, 48.9913635749675],
                            [2.411773210763645, 48.99108550257167],
                            [2.410604288473538, 48.9903510426507],
                            [2.408575693042949, 48.98907013552481],
                            [2.406020941025929, 48.98745137051067],
                            [2.404381782694417, 48.986407814293294],
                            [2.40349162633148, 48.9858063607705],
                            [2.401092570394125, 48.984120773847636],
                            [2.398722629214109, 48.98246129652324],
                            [2.396472231527975, 48.98088022978824],
                            [2.394359444460042, 48.97939184415406],
                            [2.392156364001073, 48.9778558765243],
                            [2.390763932713399, 48.97686858845462],
                        ],
                    },
                },
                425: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89219353786196, 2.308541671036779],
                        "indice_lig": "3",
                        "idf": 0,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 970.233000102,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.303104617664385,
                            48.88965743471613,
                            2.314064654430934,
                            48.89453086415558,
                        ),
                        "coordinates": [
                            [2.314064654430934, 48.89453086415558],
                            [2.313195651109761, 48.8942066233475],
                            [2.310422385207186, 48.89312227615755],
                            [2.308485091838318, 48.89224304544838],
                            [2.307022310754275, 48.89153340125769],
                            [2.303104617664385, 48.88965743471613],
                        ],
                    },
                },
                426: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.73628619541636, 2.370416845584951],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 509.807382147,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.369910148025347,
                            48.73408816211109,
                            2.371250376223923,
                            48.73856277815784,
                        ),
                        "coordinates": [
                            [2.371250376223923, 48.73408816211109],
                            [2.370589489768202, 48.73567057060207],
                            [2.370395305083298, 48.73613246222172],
                            [2.370193094103238, 48.7366111603106],
                            [2.370144245947536, 48.73672370462911],
                            [2.370095208170027, 48.736851954016565],
                            [2.37004808692292, 48.737000204535065],
                            [2.370020961494983, 48.73710143955727],
                            [2.370000122875599, 48.73721841563693],
                            [2.369987434859445, 48.73737541410719],
                            [2.369910148025347, 48.73856277815784],
                        ],
                    },
                },
                427: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [49.045431012009466, 2.1031051862686283],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 295.647988421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.101108482966614,
                            49.045311648350264,
                            2.105110703444507,
                            49.04564873988319,
                        ),
                        "coordinates": [
                            [2.105110703444507, 49.045311648350264],
                            [2.104628215681291, 49.04532047996179],
                            [2.104374559147197, 49.04533000897707],
                            [2.104086670840201, 49.04534147623432],
                            [2.103441731027953, 49.045386363089136],
                            [2.10270505892091, 49.04544511964608],
                            [2.102295453480011, 49.045478428084046],
                            [2.101824629861494, 49.0455337048508],
                            [2.101108482966614, 49.04564873988319],
                        ],
                    },
                },
                428: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.8737527308725, 2.3593365424844777],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 732.603478694,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358047505360747,
                            48.87080998359611,
                            2.361027462783641,
                            48.8761263529489,
                        ),
                        "coordinates": [
                            [2.361027462783641, 48.87080998359611],
                            [2.360611007375577, 48.87127473501522],
                            [2.35879285929743, 48.87330360654299],
                            [2.35873470773835, 48.87336461092388],
                            [2.358676863507737, 48.87343795941994],
                            [2.358628931500165, 48.873514353987524],
                            [2.358591274744211, 48.87359321381271],
                            [2.358564181538437, 48.87367393789372],
                            [2.358547855818036, 48.87375591218367],
                            [2.358542425277118, 48.873838514130384],
                            [2.358547927734611, 48.873921112603455],
                            [2.358564324598289, 48.874003081456046],
                            [2.358591487285937, 48.87408379495582],
                            [2.358629213427404, 48.87416264046255],
                            [2.358656197099907, 48.87420785977149],
                            [2.358912890960272, 48.87462678214095],
                            [2.359510077155185, 48.87560136191418],
                            [2.359514759814944, 48.87560940274169],
                            [2.359531732567397, 48.87565113725989],
                            [2.359537461410554, 48.87569418040498],
                            [2.359531771494897, 48.87573722630809],
                            [2.359514835688981, 48.8757789655617],
                            [2.359487169918483, 48.87581813196036],
                            [2.359449612310728, 48.875853535665065],
                            [2.359403306416993, 48.87588409728938],
                            [2.359349655670478, 48.87590889262343],
                            [2.359290293238288, 48.87592716506506],
                            [2.359249708032612, 48.87593523970266],
                            [2.359019868392366, 48.87597177860782],
                            [2.358047505360747, 48.8761263529489],
                        ],
                    },
                },
                429: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86407180886607, 2.3924144223637644],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 1004.29510699,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.385882449326147,
                            48.86294203278712,
                            2.398984440248072,
                            48.8649928967798,
                        ),
                        "coordinates": [
                            [2.398984440248072, 48.86491668505183],
                            [2.39848073567902, 48.864931346295215],
                            [2.39711185639064, 48.864971177452304],
                            [2.396437597854936, 48.86499280318625],
                            [2.396258768535164, 48.8649928967798],
                            [2.396080270144145, 48.86498572690429],
                            [2.395917300105721, 48.86497249894109],
                            [2.395902781291291, 48.86497132036876],
                            [2.395726970709241, 48.86494973271527],
                            [2.39555351091393, 48.86492104558953],
                            [2.395383055031417, 48.86488536662389],
                            [2.395308088449703, 48.86486721421237],
                            [2.389854570123981, 48.86349003715552],
                            [2.38809536329861, 48.8630500320595],
                            [2.387978845677541, 48.863023018962636],
                            [2.387818308556641, 48.86299251507435],
                            [2.387655068697662, 48.862969077665795],
                            [2.387434950999083, 48.862949833042585],
                            [2.387323335824844, 48.86294378109641],
                            [2.387156295791435, 48.86294203278712],
                            [2.386989446727353, 48.862947571698605],
                            [2.386823514002038, 48.8629603745682],
                            [2.386659228829974, 48.86298038489125],
                            [2.386506738312475, 48.863005725600814],
                            [2.385882449326147, 48.86312321464207],
                        ],
                    },
                },
                430: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.8775929943799, 2.356892689261168],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 513.028823651,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356297005212164,
                            48.8761263529489,
                            2.358047505360747,
                            48.87985014162011,
                        ),
                        "coordinates": [
                            [2.358047505360747, 48.8761263529489],
                            [2.356904843379572, 48.876307988351044],
                            [2.356836230013125, 48.876321070180616],
                            [2.356748885143178, 48.87634445392422],
                            [2.35666634465754, 48.87637448702341],
                            [2.356589769937599, 48.87641074854594],
                            [2.356520233459821, 48.87645273074753],
                            [2.356458714672568, 48.87649984174704],
                            [2.356406072529634, 48.876551421565935],
                            [2.356363048182956, 48.87660674483978],
                            [2.356330248410039, 48.87666503781592],
                            [2.356308130593566, 48.87672548007049],
                            [2.356297005212164, 48.87678722340738],
                            [2.356297028910056, 48.8768494008139],
                            [2.356299066848186, 48.87686697667079],
                            [2.356319114628649, 48.87700856413617],
                            [2.356362975613072, 48.87724976934221],
                            [2.356417706342783, 48.87749000587518],
                            [2.356483256393008, 48.87772906300488],
                            [2.356559569948568, 48.87796672457353],
                            [2.356646577444988, 48.87820278334019],
                            [2.356744202552222, 48.87843702752845],
                            [2.35685236067644, 48.87866925161044],
                            [2.356970953606369, 48.878899248184155],
                            [2.357051280346298, 48.87904343072644],
                            [2.357226463992578, 48.879389758217954],
                            [2.357459347963283, 48.87985014162011],
                        ],
                    },
                },
                431: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.88038906115705, 2.3189180212610503],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 619.456600664,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.315176626220464,
                            48.87877036758757,
                            2.322265213130598,
                            48.881229507618905,
                        ),
                        "coordinates": [
                            [2.322265213130598, 48.87877036758757],
                            [2.321995135297573, 48.87928583948993],
                            [2.321992304976831, 48.879291152923344],
                            [2.321955054963838, 48.87934925936952],
                            [2.321908002917385, 48.87940418688948],
                            [2.321851764933991, 48.87945521769513],
                            [2.321787075035847, 48.8795016886256],
                            [2.32171477287728, 48.879542992876964],
                            [2.321635806307745, 48.87957859260836],
                            [2.321575948566833, 48.879600246662406],
                            [2.317214119972457, 48.881028761401815],
                            [2.317104482663537, 48.88106466524559],
                            [2.317020200517923, 48.88109093067521],
                            [2.316870217683635, 48.88113138589677],
                            [2.316716435869087, 48.881165071540906],
                            [2.316559558043239, 48.88119183242409],
                            [2.31640029766416, 48.88121154580202],
                            [2.316239381368746, 48.88122412408304],
                            [2.316077546338835, 48.881229507618905],
                            [2.315915529274156, 48.88122767363508],
                            [2.315754069188332, 48.88121863085074],
                            [2.315593903328888, 48.88120241855634],
                            [2.315589074648051, 48.881201814478665],
                            [2.315176626220464, 48.881150028474686],
                        ],
                    },
                },
                432: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.841663644504266, 2.3520288975743235],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 267.605338121,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351739487166927,
                            48.8404866526412,
                            2.352224728183084,
                            48.84286683068266,
                        ),
                        "coordinates": [
                            [2.351739487166927, 48.8404866526412],
                            [2.351791834680588, 48.84059030113526],
                            [2.351851853606968, 48.840732168265184],
                            [2.351901164410743, 48.84087582102722],
                            [2.351939656947682, 48.84102090628706],
                            [2.351948722704825, 48.841062914316836],
                            [2.352224728183084, 48.84286683068266],
                        ],
                    },
                },
                433: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.876823136769715, 2.3536732945644543],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 655.648770547,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.349293903828172,
                            48.87627270260409,
                            2.358057907074739,
                            48.87732082237144,
                        ),
                        "coordinates": [
                            [2.349293903828172, 48.877236320043274],
                            [2.34961395829101, 48.877302599159094],
                            [2.349752154817334, 48.87731535061323],
                            [2.349891451248783, 48.87732082237144],
                            [2.350030964471204, 48.87731897636004],
                            [2.350169816217755, 48.8773098230998],
                            [2.350307126230718, 48.87729342346724],
                            [2.350376259383474, 48.87728230424885],
                            [2.355543697431944, 48.87655489858274],
                            [2.355674136043512, 48.876539926222826],
                            [2.356191427346504, 48.876498220189006],
                            [2.358057907074739, 48.87627270260409],
                        ],
                    },
                },
                434: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86584974082297, 2.3543988787984196],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 359.104428428,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352068318061256,
                            48.86548921204227,
                            2.356736756794993,
                            48.86634029838925,
                        ),
                        "coordinates": [
                            [2.356736756794993, 48.865586478498976],
                            [2.356477216415505, 48.865527256376815],
                            [2.356374321248331, 48.86550757224181],
                            [2.35626734890844, 48.86549472987817],
                            [2.356171638706309, 48.86548985862922],
                            [2.356158940652986, 48.86548921204227],
                            [2.356050247577217, 48.86549107798513],
                            [2.355942421764998, 48.865500306925775],
                            [2.355836605342329, 48.8655168015892],
                            [2.355799745833064, 48.865524371727034],
                            [2.355359432753813, 48.86562066070523],
                            [2.352549303024253, 48.86623513389228],
                            [2.352068318061256, 48.86634029838925],
                        ],
                    },
                },
                435: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.892211615309854, 2.407837146992592],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 835.316847835,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.402352143900472,
                            48.89122859320346,
                            2.41331313951059,
                            48.89325758997389,
                        ),
                        "coordinates": [
                            [2.402352143900472, 48.89122859320346],
                            [2.4026016816087, 48.89129322953661],
                            [2.402828854856646, 48.89133630417273],
                            [2.403841964453604, 48.89145022011501],
                            [2.410268232791069, 48.89265820559498],
                            [2.41331313951059, 48.89325758997389],
                        ],
                    },
                },
                436: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.889531417471254, 2.3757574030146014],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 361.493486468,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.374204014730727,
                            48.888267619682566,
                            2.377315755595574,
                            48.89078896952844,
                        ),
                        "coordinates": [
                            [2.374204014730727, 48.888267619682566],
                            [2.377015365812425, 48.89055584089168],
                            [2.377315755595574, 48.89078896952844],
                        ],
                    },
                },
                437: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86801170848309, 2.3441203059749802],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 521.813395937,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.340720722310919,
                            48.86730947407226,
                            2.347516213290017,
                            48.86869597783536,
                        ),
                        "coordinates": [
                            [2.347516213290017, 48.86730947407226],
                            [2.344491472086398, 48.86794533596063],
                            [2.340720722310919, 48.86869597783536],
                        ],
                    },
                },
                438: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.83312366182905, 2.357153081741308],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 579.520535583,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35558027407791,
                            48.83097267298836,
                            2.358823490459311,
                            48.83549535538991,
                        ),
                        "coordinates": [
                            [2.35558027407791, 48.83097267298836],
                            [2.355658315522834, 48.83097309345897],
                            [2.355747665564762, 48.830980530534504],
                            [2.35583489795444, 48.830995302203696],
                            [2.355918635658552, 48.83101717351403],
                            [2.355997562906212, 48.83104580192185],
                            [2.356070433359942, 48.83108073733562],
                            [2.35613609596157, 48.831121424952606],
                            [2.356193515108725, 48.83116722605197],
                            [2.356241789736123, 48.831217417197394],
                            [2.35628015447838, 48.831271206430856],
                            [2.356308006759085, 48.83132774600888],
                            [2.356324903924456, 48.83138614407828],
                            [2.356330582115913, 48.83144548096569],
                            [2.356324950691226, 48.83150481993971],
                            [2.356308098838454, 48.83156322343502],
                            [2.356307826371801, 48.83156377598114],
                            [2.356290256485517, 48.831602438012105],
                            [2.356263092592192, 48.83168110098517],
                            [2.35624671966071, 48.83176105416739],
                            [2.356241268288572, 48.8318416543161],
                            [2.356246781950631, 48.831922253220114],
                            [2.356263216974461, 48.83200219949824],
                            [2.356290440999016, 48.83208085298105],
                            [2.356328237147474, 48.8321575775384],
                            [2.356376297003979, 48.832231758130206],
                            [2.356382629514607, 48.83224031823894],
                            [2.358823490459311, 48.83549535538991],
                        ],
                    },
                },
                439: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.791971324050365, 2.3688703618757008],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 1018.87012726,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.367804105603498,
                            48.787562792945664,
                            2.369516887107938,
                            48.79648308455052,
                        ),
                        "coordinates": [
                            [2.367804105603498, 48.787562792945664],
                            [2.368534266478156, 48.78917126278885],
                            [2.369331488933287, 48.79080876692161],
                            [2.369380003322078, 48.790921536358255],
                            [2.369429035758015, 48.79105971120821],
                            [2.369467325594659, 48.79119935922295],
                            [2.36949477641593, 48.791340116545605],
                            [2.369511310879738, 48.791481617618594],
                            [2.369516887107938, 48.79162349077283],
                            [2.369511497195277, 48.79176536901266],
                            [2.369495149646184, 48.791906879130366],
                            [2.369467882857234, 48.79204765257013],
                            [2.36945252039872, 48.792108991626],
                            [2.36930276303625, 48.792823681128745],
                            [2.368973360448986, 48.794521060028536],
                            [2.368688454641112, 48.79535489564057],
                            [2.368470523167456, 48.795941821375266],
                            [2.368269540049694, 48.79648308455052],
                        ],
                    },
                },
                440: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.8906369630242, 2.354963791394675],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 784.562285611,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.349815453218361,
                            48.89020146262561,
                            2.359997197146954,
                            48.89146500033268,
                        ),
                        "coordinates": [
                            [2.349815453218361, 48.89146500033268],
                            [2.350773478846647, 48.89128888939723],
                            [2.354880884192041, 48.890533732310374],
                            [2.356415254166853, 48.89027311644459],
                            [2.357124143933403, 48.89023748730658],
                            [2.358030456299826, 48.890219568035064],
                            [2.359618750976291, 48.89020150492339],
                            [2.359625640099253, 48.89020146262561],
                            [2.359690635601214, 48.890205198848],
                            [2.359753659593468, 48.89021632142602],
                            [2.35981279875665, 48.89023449098097],
                            [2.359866252846404, 48.8902591556024],
                            [2.359912399949642, 48.89028956738397],
                            [2.359949837163143, 48.890324801525466],
                            [2.359977427947737, 48.890363787161476],
                            [2.359994333108266, 48.8904053390022],
                            [2.359997197146954, 48.89044772141095],
                            [2.359995766394621, 48.8904854547466],
                        ],
                    },
                },
                441: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.81929381421627, 2.362127586742411],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 378.920467965,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.359705216746021,
                            48.81900247113484,
                            2.364531953109201,
                            48.819876221057115,
                        ),
                        "coordinates": [
                            [2.364531953109201, 48.819876221057115],
                            [2.36420585137535, 48.819758038582634],
                            [2.362570236411678, 48.81928181209212],
                            [2.362436463033214, 48.81924479090153],
                            [2.362281484665367, 48.81920929423903],
                            [2.362086319066492, 48.819168258650556],
                            [2.361921647910426, 48.81914135195193],
                            [2.361880173019467, 48.8191357388344],
                            [2.361314806556538, 48.819071718923404],
                            [2.361016591267889, 48.81903972748938],
                            [2.360803568529717, 48.81901687427453],
                            [2.3608031238414, 48.81901681973327],
                            [2.360685973079111, 48.819006053803115],
                            [2.360567817684378, 48.81900247113484],
                            [2.360449665052659, 48.819006104095436],
                            [2.360332522022617, 48.81901691939803],
                            [2.360217394778832, 48.819034826195605],
                            [2.360129742015262, 48.81905151465142],
                            [2.35999706772991, 48.81909124344267],
                            [2.359893754617645, 48.81912927204872],
                            [2.359796192504509, 48.819173431855226],
                            [2.359705216746021, 48.819223349609054],
                        ],
                    },
                },
                442: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.84069055854842, 2.3629089055842063],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 558.913509615,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.360966902272541,
                            48.838426942998495,
                            2.365338652974602,
                            48.84226538647533,
                        ),
                        "coordinates": [
                            [2.360966902272541, 48.838426942998495],
                            [2.361324513793816, 48.83890251688475],
                            [2.361896295675618, 48.83969061084703],
                            [2.363229626508351, 48.84145062581518],
                            [2.363304944209204, 48.841530408927284],
                            [2.363368847420293, 48.841590620474705],
                            [2.363462416130625, 48.84167190450744],
                            [2.363549127987718, 48.84172759390627],
                            [2.363654088587842, 48.841780267620976],
                            [2.363754479306031, 48.841820896961124],
                            [2.363861709406659, 48.84185399625224],
                            [2.364014565296341, 48.84188858993207],
                            [2.364361339053198, 48.84196830607375],
                            [2.364730930699276, 48.84205554502024],
                            [2.365004710487243, 48.84213527723537],
                            [2.365338652974602, 48.84226538647533],
                        ],
                    },
                },
                443: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.87057658603268, 2.2812022079740033],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 634.730930195,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.277083018415725,
                            48.86979106381203,
                            2.285335094686169,
                            48.87146657813589,
                        ),
                        "coordinates": [
                            [2.277083018415725, 48.87146657813589],
                            [2.278886175327061, 48.87106755968001],
                            [2.284594167627079, 48.86984569788956],
                            [2.284647827094815, 48.86983484421303],
                            [2.284782608610446, 48.869812994214506],
                            [2.2849196193193, 48.86979836924646],
                            [2.2850579691165, 48.86979106381203],
                            [2.285196760350522, 48.86979112650641],
                            [2.285276802599255, 48.86979542671476],
                            [2.285335094686169, 48.86979855646068],
                        ],
                    },
                },
                444: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.86413825335641, 2.335344726482419],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 418.309482864,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.334330724377939,
                            48.862829671905764,
                            2.3368784003342,
                            48.865980920486436,
                        ),
                        "coordinates": [
                            [2.3368784003342, 48.862829671905764],
                            [2.336646891837073, 48.862891456553655],
                            [2.336011045292881, 48.86315365255889],
                            [2.33560228091726, 48.86335591714292],
                            [2.335386540999341, 48.8635806541584],
                            [2.335146206157979, 48.86412835345397],
                            [2.334427485913044, 48.86576110282936],
                            [2.334330724377939, 48.865980920486436],
                        ],
                    },
                },
                445: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.80740712725704, 2.3631021717494596],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 617.678068009,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362263387127349,
                            48.804688120911365,
                            2.363953196602166,
                            48.81012995727393,
                        ),
                        "coordinates": [
                            [2.363953196602166, 48.804688120911365],
                            [2.363699364060565, 48.80548645043683],
                            [2.363379205373079, 48.806493346001865],
                            [2.362263387127349, 48.81012995727393],
                        ],
                    },
                },
                446: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.865958242878, 2.3662925184927937],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 430.659895467,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.364264950425284,
                            48.864657879612494,
                            2.368410025658025,
                            48.867384472882776,
                        ),
                        "coordinates": [
                            [2.368410025658025, 48.864657879612494],
                            [2.367452158974442, 48.86523339712806],
                            [2.365277132986022, 48.866531670728385],
                            [2.364264950425284, 48.867384472882776],
                        ],
                    },
                },
                447: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86914372429099, 2.338470385869941],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 344.732680251,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.336218847521674,
                            48.86869597783536,
                            2.340720722310919,
                            48.869585243484515,
                        ),
                        "coordinates": [
                            [2.340720722310919, 48.86869597783536],
                            [2.338384284784166, 48.869161018568334],
                            [2.337010125510509, 48.869436350584834],
                            [2.336218847521674, 48.869585243484515],
                        ],
                    },
                },
                448: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.846481074535, 2.2563163108751216],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 398.67386163,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.254756719786218,
                            48.845227500732506,
                            2.257744680363202,
                            48.847971541497,
                        ),
                        "coordinates": [
                            [2.254756719786218, 48.845227500732506],
                            [2.255346281583587, 48.84535703422342],
                            [2.255423064949881, 48.845375968102964],
                            [2.255523422471574, 48.845407383494226],
                            [2.255618632709014, 48.84544514150637],
                            [2.255707777050716, 48.84548887488917],
                            [2.25578999483381, 48.84553816549067],
                            [2.255864502535025, 48.845592536281785],
                            [2.255930573100721, 48.84565146741536],
                            [2.255987574227174, 48.84571438747022],
                            [2.256034955827927, 48.84578069225911],
                            [2.256078139367036, 48.84586302106814],
                            [2.256408502797454, 48.846635992544186],
                            [2.256575461896249, 48.846901247583965],
                            [2.25665176223917, 48.84699751073441],
                            [2.257216016681242, 48.847695472325114],
                            [2.257225297005742, 48.84770664073271],
                            [2.257277255387388, 48.84776012403635],
                            [2.257338114483744, 48.84780935009696],
                            [2.257407078096379, 48.847853676307864],
                            [2.257483249598494, 48.84789252599237],
                            [2.257565633246133, 48.84792539201046],
                            [2.257653157227749, 48.84795184499667],
                            [2.257744680363202, 48.847971541497],
                        ],
                    },
                },
                449: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.793180358021935, 2.449025396453432],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 798.054799716,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.448367032663893,
                            48.78997831034893,
                            2.450453177915302,
                            48.796740767488686,
                        ),
                        "coordinates": [
                            [2.450453177915302, 48.78997831034893],
                            [2.449228582549607, 48.791267140339635],
                            [2.448985406666049, 48.79156777896702],
                            [2.448832977406044, 48.79178913033529],
                            [2.4486785613234, 48.792045985798566],
                            [2.448540976011039, 48.79234747377089],
                            [2.448454504301135, 48.79258145955184],
                            [2.448415552193294, 48.79272077309764],
                            [2.44839113422081, 48.7928914777894],
                            [2.448368856087026, 48.793093585666156],
                            [2.448367032663893, 48.79320282300079],
                            [2.44836946080322, 48.79336339574557],
                            [2.448373806789816, 48.79345897276279],
                            [2.448386311649348, 48.79358576310097],
                            [2.448436695192611, 48.79385420728575],
                            [2.448536592108501, 48.79416474839838],
                            [2.449433177038806, 48.796740767488686],
                        ],
                    },
                },
                450: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.74558913351448, 2.7283573369901104],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 253.938046092,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.727229371429766,
                            48.74472077575101,
                            2.729481333043577,
                            48.746452320704556,
                        ),
                        "coordinates": [
                            [2.727229371429766, 48.746452320704556],
                            [2.728179796656208, 48.74572975657104],
                            [2.729481333043577, 48.74472077575101],
                        ],
                    },
                },
                451: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.86832367873688, 2.3594673927861662],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 751.110876798,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.354603790708304,
                            48.867111639484264,
                            2.364234945635964,
                            48.8692241707531,
                        ),
                        "coordinates": [
                            [2.354603790708304, 48.8692241707531],
                            [2.356237303022795, 48.86887087427413],
                            [2.358173198819874, 48.868560898711706],
                            [2.361565472058887, 48.86805005713664],
                            [2.361582877457654, 48.86804741328271],
                            [2.361806268782234, 48.86800944642526],
                            [2.362026640348221, 48.867964457188656],
                            [2.362243489140825, 48.867912549031104],
                            [2.362456317417096, 48.86785384073091],
                            [2.362664632662775, 48.86778846998345],
                            [2.362867957255941, 48.867716583559556],
                            [2.363065820168313, 48.867638347153886],
                            [2.363189100155265, 48.867585151484754],
                            [2.364234945635964, 48.867111639484264],
                        ],
                    },
                },
                452: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84793185423078, 2.2609809895708297],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 476.870794455,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.257744680363202,
                            48.84786255639442,
                            2.264218775687729,
                            48.84798972679629,
                        ),
                        "coordinates": [
                            [2.257744680363202, 48.847971541497],
                            [2.257839008469428, 48.84798422317132],
                            [2.257934911935306, 48.84798972679629],
                            [2.258031143527707, 48.847987978080376],
                            [2.258038077387989, 48.84798757139786],
                            [2.258465394243113, 48.847961297025606],
                            [2.258927085345143, 48.84792476091969],
                            [2.259512781729036, 48.84787968754671],
                            [2.259903223665492, 48.84786479424277],
                            [2.260537054968977, 48.84786255639442],
                            [2.262802669984459, 48.84798801555344],
                            [2.26293728894271, 48.84798955816811],
                            [2.263248708005019, 48.84798795528603],
                            [2.26335682586998, 48.84798489135754],
                            [2.263559852867985, 48.84797913878114],
                            [2.26387033620816, 48.847963121562344],
                            [2.264130426738311, 48.84794309720084],
                            [2.264218775687729, 48.84793480789206],
                        ],
                    },
                },
                453: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.869311448661655, 2.291798175977209],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 577.877750267,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.290058833580487,
                            48.86698310944948,
                            2.293524290329624,
                            48.871649770042794,
                        ),
                        "coordinates": [
                            [2.293524290329624, 48.871649770042794],
                            [2.293178513862981, 48.87117583434373],
                            [2.291683639061527, 48.869126783325896],
                            [2.290741952090107, 48.8679196075365],
                            [2.290058833580487, 48.86698310944948],
                        ],
                    },
                },
                454: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.87086513854975, 2.3468328531630798],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 558.980299709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.343154773075233,
                            48.870164201799824,
                            2.350497971851879,
                            48.87149773935003,
                        ),
                        "coordinates": [
                            [2.343154773075233, 48.87149773935003],
                            [2.344395064966588, 48.87128251993561],
                            [2.34524170993027, 48.871135598315604],
                            [2.346645561090464, 48.87092338792206],
                            [2.347975366047469, 48.870697494284876],
                            [2.34886485986124, 48.87051251804543],
                            [2.350497971851879, 48.870164201799824],
                        ],
                    },
                },
                455: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.85011080880986, 2.3273053056830686],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 374.096721839,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.326822568897497,
                            48.848457849448714,
                            2.32778212849858,
                            48.851762052495474,
                        ),
                        "coordinates": [
                            [2.32778212849858, 48.848457849448714],
                            [2.327345261152634, 48.84998425936861],
                            [2.32693524339044, 48.85137882973943],
                            [2.326822568897497, 48.851762052495474],
                        ],
                    },
                },
                456: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.846700907563324, 2.3282824290516126],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 397.646005519,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32778212849858,
                            48.84494263342595,
                            2.32877802689008,
                            48.848457849448714,
                        ),
                        "coordinates": [
                            [2.32877802689008, 48.84494263342595],
                            [2.328287692312688, 48.84669129290385],
                            [2.327901799353064, 48.84803969690239],
                            [2.327860769560224, 48.84818306367505],
                            [2.32778212849858, 48.848457849448714],
                        ],
                    },
                },
                457: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.874136985451266, 2.324528814293897],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 473.961687889,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.321361928104079,
                            48.87371340670774,
                            2.327695409630174,
                            48.87455838471093,
                        ),
                        "coordinates": [
                            [2.321361928104079, 48.87455838471093],
                            [2.322184393057072, 48.87444921076161],
                            [2.324660626843565, 48.87412047643024],
                            [2.326264148260965, 48.873905444631156],
                            [2.326999857517563, 48.87380673385489],
                            [2.327695409630174, 48.87371340670774],
                        ],
                    },
                },
                458: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89780707209598, 2.4293987926745437],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 4313.53099779,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.400361703159176,
                            48.896260322962334,
                            2.458363412015992,
                            48.89887033891491,
                        ),
                        "coordinates": [
                            [2.400361703159176, 48.898112306280396],
                            [2.403281547204399, 48.8983438213715],
                            [2.404876826547504, 48.89847136687579],
                            [2.405450682176829, 48.89850671463484],
                            [2.406020912342306, 48.898530163543775],
                            [2.407403173866654, 48.89858166368836],
                            [2.408521966211799, 48.898614278896304],
                            [2.409633528019113, 48.89863737105588],
                            [2.41263233951892, 48.898676559246276],
                            [2.413472391835469, 48.8986734053139],
                            [2.413883777660752, 48.898658852205685],
                            [2.414421450071567, 48.89862755761662],
                            [2.414944681641715, 48.898593891432306],
                            [2.415713296251286, 48.89854815551904],
                            [2.416146323114309, 48.89852644188184],
                            [2.416608232083264, 48.898511844231294],
                            [2.417019628566003, 48.89850441914446],
                            [2.417499613034112, 48.898508839242446],
                            [2.417947125452648, 48.898518040421095],
                            [2.419379904883467, 48.89855746392422],
                            [2.420978711081432, 48.89860864377334],
                            [2.424111357756001, 48.898699089762765],
                            [2.427846738939663, 48.89881276436524],
                            [2.42932644878034, 48.898852026787786],
                            [2.429896676332358, 48.89886584003609],
                            [2.430214265413721, 48.89887033891491],
                            [2.430578757373056, 48.89886766133943],
                            [2.430914364672341, 48.89885786856133],
                            [2.431286045461826, 48.898840905981636],
                            [2.431690180914725, 48.89880963985484],
                            [2.432025749779658, 48.898780808992264],
                            [2.432415416154168, 48.898732897522414],
                            [2.432794241858564, 48.89867785497748],
                            [2.433133358374563, 48.89861808627199],
                            [2.433458034450159, 48.89855594966109],
                            [2.433829588397613, 48.89847473819822],
                            [2.434309326591622, 48.89835298313319],
                            [2.434882797779406, 48.89818355988485],
                            [2.435607717209017, 48.89795451927382],
                            [2.437259492611106, 48.897429625227275],
                            [2.438323331177323, 48.8970622661271],
                            [2.438813792515264, 48.89690241428735],
                            [2.439087894363203, 48.89682365164865],
                            [2.439445450651772, 48.896725945649514],
                            [2.439780394912604, 48.896642199826694],
                            [2.440162745475339, 48.896558577560285],
                            [2.440678596698777, 48.896465316512106],
                            [2.441154809413359, 48.89640063993438],
                            [2.441576925802698, 48.896352666637725],
                            [2.441991858898001, 48.89632135409288],
                            [2.442421241332333, 48.896297166078696],
                            [2.442872297336787, 48.89628247245745],
                            [2.443756413206839, 48.89627688942672],
                            [2.444514209915559, 48.896264281247326],
                            [2.445448854167565, 48.89626101817673],
                            [2.446177806648478, 48.896260322962334],
                            [2.446719118883842, 48.8962645625113],
                            [2.44714858881238, 48.896280804457405],
                            [2.4476971821202, 48.89631358493711],
                            [2.448361265144072, 48.89635100837806],
                            [2.449736363934091, 48.89643293507745],
                            [2.450819069581169, 48.89647468855999],
                            [2.45599294890596, 48.89665511724568],
                            [2.458363412015992, 48.896652451144085],
                        ],
                    },
                },
                459: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.95660698892599, 2.3096096050528767],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 480.100513642,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.30787256835423,
                            48.95543742610714,
                            2.311526308692633,
                            48.957384005034584,
                        ),
                        "coordinates": [
                            [2.30787256835423, 48.95543742610714],
                            [2.308010547692303, 48.95565735938328],
                            [2.308218511480654, 48.95599404516436],
                            [2.308659563676015, 48.95657191167997],
                            [2.308894573263774, 48.95683166174167],
                            [2.309009995947945, 48.95695510016859],
                            [2.309159969265118, 48.95708873115502],
                            [2.309387069937059, 48.957291330740574],
                            [2.309404022227097, 48.95730551817787],
                            [2.309422398028904, 48.957318428751],
                            [2.309442095903109, 48.95733009155124],
                            [2.309463015811321, 48.95734053297987],
                            [2.309485056349633, 48.95734977943061],
                            [2.309508114724375, 48.9573578590876],
                            [2.309532090908531, 48.95736479745316],
                            [2.309556882096506, 48.95737062361074],
                            [2.309582388260948, 48.95737536306283],
                            [2.309608506607817, 48.95737904399383],
                            [2.309635137086055, 48.95738169370477],
                            [2.309662178302649, 48.957383337690395],
                            [2.309689527451629, 48.957384005034584],
                            [2.309717085871184, 48.95738372124806],
                            [2.309744748048068, 48.95738251360065],
                            [2.309772416650237, 48.95738041030881],
                            [2.30979205806748, 48.95737822753075],
                            [2.309811753037025, 48.95737530225888],
                            [2.309831462906971, 48.957371665745264],
                            [2.309851143635194, 48.957367343815264],
                            [2.309870755228379, 48.95736236591467],
                            [2.30989025770521, 48.957356760590194],
                            [2.309909608365274, 48.957350555473425],
                            [2.30992876859289, 48.95734377911901],
                            [2.30994769429853, 48.957336460949236],
                            [2.309966345525137, 48.95732862771242],
                            [2.309984682267598, 48.95732030975376],
                            [2.310002661838127, 48.957311533805836],
                            [2.310020244255848, 48.95730232841553],
                            [2.310037388174576, 48.957292722121736],
                            [2.310054052236181, 48.957282744362644],
                            [2.310070196484115, 48.95727242188673],
                            [2.311306252047978, 48.95609277570172],
                            [2.311526308692633, 48.95587687488741],
                        ],
                    },
                },
                460: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78517603334055, 2.2507492381584395],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 647.808839798,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.246977649164128,
                            48.78368721522512,
                            2.254502152039991,
                            48.78671618223311,
                        ),
                        "coordinates": [
                            [2.246977649164128, 48.78368721522512],
                            [2.247450187560723, 48.78388175977367],
                            [2.247822766648736, 48.78401618017294],
                            [2.248070225930573, 48.78408675016291],
                            [2.248380325435442, 48.78418388948691],
                            [2.249574699218645, 48.78466805459751],
                            [2.251184103325618, 48.78534256804436],
                            [2.252360902262542, 48.78585062858891],
                            [2.253593503030584, 48.786341416061134],
                            [2.254502152039991, 48.78671618223311],
                        ],
                    },
                },
                461: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78459720281997, 2.2171708820825233],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 456.690348459,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.214433502050177,
                            48.78362462215807,
                            2.220009516856533,
                            48.785093327422665,
                        ),
                        "coordinates": [
                            [2.214433502050177, 48.78362462215807],
                            [2.216242574385837, 48.78437612147364],
                            [2.21770688436717, 48.784995403568914],
                            [2.217787158964784, 48.785024409306466],
                            [2.21786816555335, 48.78504835423408],
                            [2.217949845858956, 48.78506721998084],
                            [2.218032183567638, 48.78508100374073],
                            [2.218113073979154, 48.78508955322947],
                            [2.218195032280962, 48.785093327422665],
                            [2.218275169556402, 48.78509255296058],
                            [2.21837965886068, 48.78508690457621],
                            [2.219552003168104, 48.785004613650386],
                            [2.220009516856533, 48.78496976326486],
                        ],
                    },
                },
                462: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.805577880886446, 2.1722235855488785],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 544.300490318,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.168520392870995,
                            48.80549303372225,
                            2.175926961285955,
                            48.80565394221556,
                        ),
                        "coordinates": [
                            [2.168520392870995, 48.80549303372225],
                            [2.169115529887067, 48.80550428265101],
                            [2.169991367736622, 48.805530583317825],
                            [2.170549039721886, 48.80554143634422],
                            [2.17212526143468, 48.80558660907516],
                            [2.173501198412026, 48.805607624873666],
                            [2.174939944042228, 48.8056278666348],
                            [2.175488064593126, 48.805640870212834],
                            [2.175926961285955, 48.80565394221556],
                        ],
                    },
                },
                463: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.93366797153279, 2.3502882054557857],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 503.501333769,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347862407755533,
                            48.932051822712985,
                            2.352701984386339,
                            48.93526614581903,
                        ),
                        "coordinates": [
                            [2.347862407755533, 48.93526614581903],
                            [2.348208659499462, 48.93504317881456],
                            [2.350078698039068, 48.93380574276572],
                            [2.350403229141642, 48.933599830534305],
                            [2.351721474110418, 48.932724697307954],
                            [2.3523202119245, 48.93231381654702],
                            [2.352701984386339, 48.932051822712985],
                        ],
                    },
                },
                464: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.947397244588835, 2.341216111107315],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 311.793921215,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.339180923415564,
                            48.94698706127986,
                            2.343251343552804,
                            48.94780764959912,
                        ),
                        "coordinates": [
                            [2.339180923415564, 48.94780764959912],
                            [2.339567542061335, 48.947729477352524],
                            [2.343251343552804, 48.94698706127986],
                        ],
                    },
                },
                465: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.71643058349215, 2.277365341765458],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 4518.75826316,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263073689251946,
                            48.702239386903386,
                            2.294557747854634,
                            48.73115415790263,
                        ),
                        "coordinates": [
                            [2.263073689251946, 48.72964839824706],
                            [2.263454077215723, 48.729805117917095],
                            [2.263765178125915, 48.72993661265436],
                            [2.264102090300497, 48.730079812967276],
                            [2.264292283102973, 48.73016086919445],
                            [2.264869665033552, 48.7304031406679],
                            [2.265377766082045, 48.73061568928092],
                            [2.265646764091223, 48.730726468814275],
                            [2.265853282589221, 48.73080213621915],
                            [2.266048939320782, 48.7308688048377],
                            [2.266244608278086, 48.73092737896986],
                            [2.266409026242424, 48.730976042053264],
                            [2.266600634722214, 48.73102202339225],
                            [2.266773226191539, 48.73105810058573],
                            [2.266943113291285, 48.731085183417065],
                            [2.267098053413373, 48.731106861123195],
                            [2.267303291505616, 48.73112856946],
                            [2.267395721167573, 48.73113492122651],
                            [2.267527570695094, 48.731143095182816],
                            [2.267611847285641, 48.731147642803876],
                            [2.267705640511055, 48.73115129712408],
                            [2.267770888455745, 48.73115313474746],
                            [2.267856528925774, 48.731154086430436],
                            [2.267974796152814, 48.73115415790263],
                            [2.268056361471213, 48.73115240855939],
                            [2.268199102637317, 48.73114889803126],
                            [2.268204541280311, 48.73114890079395],
                            [2.268309791562912, 48.731146603004234],
                            [2.268441447227594, 48.731136690241485],
                            [2.268602880317386, 48.73112216298843],
                            [2.268861199717673, 48.73109623834504],
                            [2.269120895590522, 48.73105772465082],
                            [2.269324861518742, 48.73101558082765],
                            [2.269458115929544, 48.73099047947526],
                            [2.269768167057491, 48.73090793013916],
                            [2.270012187904604, 48.73083306951555],
                            [2.27030264099206, 48.730731987004816],
                            [2.270596438795645, 48.73060356268054],
                            [2.270864408039228, 48.730473323945645],
                            [2.271116088278002, 48.73032508949165],
                            [2.27137320654664, 48.730174159633485],
                            [2.271525593190765, 48.73006903273687],
                            [2.271690251058171, 48.72993603521267],
                            [2.271845399621338, 48.72979673629009],
                            [2.272109497057917, 48.729501925735796],
                            [2.272316517085674, 48.72919269361662],
                            [2.272508662798811, 48.72882140299808],
                            [2.27261648025196, 48.728487833240145],
                            [2.272663100737706, 48.72817401401529],
                            [2.272670055934793, 48.72805081768148],
                            [2.272667646939937, 48.72780981133782],
                            [2.272639816036738, 48.727254044534504],
                            [2.272637266073099, 48.72712364935275],
                            [2.272632035005529, 48.7269635753702],
                            [2.272614840187014, 48.726593065007755],
                            [2.272592535279834, 48.725969857211375],
                            [2.272568961716421, 48.725276504818396],
                            [2.272558586842029, 48.72488981185418],
                            [2.272550776333793, 48.72462182400001],
                            [2.272551063595406, 48.72439880465827],
                            [2.272556781900592, 48.72418028421598],
                            [2.272569205836226, 48.724031911525344],
                            [2.272588474409817, 48.72384577336106],
                            [2.272611868589173, 48.72362186752144],
                            [2.272637936363906, 48.72343303545508],
                            [2.272678948083629, 48.72324960666707],
                            [2.272726791663308, 48.72303740512087],
                            [2.272790992079262, 48.72278924274592],
                            [2.272874245404659, 48.72252040704018],
                            [2.273057092058846, 48.72195756523596],
                            [2.27324905046466, 48.721313161754445],
                            [2.273459693589715, 48.720654745274366],
                            [2.273581175931571, 48.72024294626791],
                            [2.273716264871817, 48.7198176658535],
                            [2.273802227674528, 48.71954793150471],
                            [2.273860912163876, 48.71935462070352],
                            [2.274086091444276, 48.718612846021244],
                            [2.274196618352734, 48.71825949308822],
                            [2.274477782896371, 48.717297425928535],
                            [2.274605730930263, 48.71689822698959],
                            [2.27472749537954, 48.7164837217094],
                            [2.274828478910071, 48.716147448990995],
                            [2.274937615575277, 48.715810282096285],
                            [2.275034428018997, 48.71554774743654],
                            [2.275236245819788, 48.71498850982511],
                            [2.27536164427676, 48.714683724821086],
                            [2.27559329097284, 48.7141730634331],
                            [2.275704987159952, 48.71395819759878],
                            [2.275924285554908, 48.71353925501875],
                            [2.276369562678905, 48.71278590250201],
                            [2.276572409393378, 48.71247756026925],
                            [2.276967182917771, 48.71189594000629],
                            [2.277255720528805, 48.711513002472344],
                            [2.27757145000388, 48.71111299128091],
                            [2.277893960552392, 48.71072017819877],
                            [2.278590572756904, 48.70995975311715],
                            [2.278865372167183, 48.70968471721832],
                            [2.279522392734328, 48.70906095593929],
                            [2.28028133036463, 48.708413860737366],
                            [2.280828050274365, 48.707975287662286],
                            [2.281282258133949, 48.70763198933155],
                            [2.281590950582322, 48.70740012789819],
                            [2.282060067167396, 48.70708201345272],
                            [2.282952020634881, 48.706505108122286],
                            [2.283471391940017, 48.706187910662216],
                            [2.284408096998167, 48.705661373721696],
                            [2.284954588723514, 48.70537745559441],
                            [2.28543853413841, 48.70513217423605],
                            [2.285887913471626, 48.70492089380368],
                            [2.286301704526414, 48.704731487226304],
                            [2.28675569447271, 48.70453834475485],
                            [2.287115725821168, 48.70438466226381],
                            [2.287473903969532, 48.704246341481536],
                            [2.287832083353679, 48.70410659305472],
                            [2.288277984538534, 48.70393919258839],
                            [2.289183148212736, 48.70362213379452],
                            [2.289918411799518, 48.70336794685478],
                            [2.290596567138263, 48.703155997074845],
                            [2.291072207384759, 48.70302579539243],
                            [2.292281652979747, 48.70272502141019],
                            [2.292834723029183, 48.70259574246507],
                            [2.293356529837167, 48.70248263548257],
                            [2.293909481649249, 48.70236453317409],
                            [2.294557747854634, 48.702239386903386],
                        ],
                    },
                },
                466: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.89780707209598, 2.4293987926745437],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 4313.53099779,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.400361703159176,
                            48.896260322962334,
                            2.458363412015992,
                            48.89887033891491,
                        ),
                        "coordinates": [
                            [2.400361703159176, 48.898112306280396],
                            [2.403281547204399, 48.8983438213715],
                            [2.404876826547504, 48.89847136687579],
                            [2.405450682176829, 48.89850671463484],
                            [2.406020912342306, 48.898530163543775],
                            [2.407403173866654, 48.89858166368836],
                            [2.408521966211799, 48.898614278896304],
                            [2.409633528019113, 48.89863737105588],
                            [2.41263233951892, 48.898676559246276],
                            [2.413472391835469, 48.8986734053139],
                            [2.413883777660752, 48.898658852205685],
                            [2.414421450071567, 48.89862755761662],
                            [2.414944681641715, 48.898593891432306],
                            [2.415713296251286, 48.89854815551904],
                            [2.416146323114309, 48.89852644188184],
                            [2.416608232083264, 48.898511844231294],
                            [2.417019628566003, 48.89850441914446],
                            [2.417499613034112, 48.898508839242446],
                            [2.417947125452648, 48.898518040421095],
                            [2.419379904883467, 48.89855746392422],
                            [2.420978711081432, 48.89860864377334],
                            [2.424111357756001, 48.898699089762765],
                            [2.427846738939663, 48.89881276436524],
                            [2.42932644878034, 48.898852026787786],
                            [2.429896676332358, 48.89886584003609],
                            [2.430214265413721, 48.89887033891491],
                            [2.430578757373056, 48.89886766133943],
                            [2.430914364672341, 48.89885786856133],
                            [2.431286045461826, 48.898840905981636],
                            [2.431690180914725, 48.89880963985484],
                            [2.432025749779658, 48.898780808992264],
                            [2.432415416154168, 48.898732897522414],
                            [2.432794241858564, 48.89867785497748],
                            [2.433133358374563, 48.89861808627199],
                            [2.433458034450159, 48.89855594966109],
                            [2.433829588397613, 48.89847473819822],
                            [2.434309326591622, 48.89835298313319],
                            [2.434882797779406, 48.89818355988485],
                            [2.435607717209017, 48.89795451927382],
                            [2.437259492611106, 48.897429625227275],
                            [2.438323331177323, 48.8970622661271],
                            [2.438813792515264, 48.89690241428735],
                            [2.439087894363203, 48.89682365164865],
                            [2.439445450651772, 48.896725945649514],
                            [2.439780394912604, 48.896642199826694],
                            [2.440162745475339, 48.896558577560285],
                            [2.440678596698777, 48.896465316512106],
                            [2.441154809413359, 48.89640063993438],
                            [2.441576925802698, 48.896352666637725],
                            [2.441991858898001, 48.89632135409288],
                            [2.442421241332333, 48.896297166078696],
                            [2.442872297336787, 48.89628247245745],
                            [2.443756413206839, 48.89627688942672],
                            [2.444514209915559, 48.896264281247326],
                            [2.445448854167565, 48.89626101817673],
                            [2.446177806648478, 48.896260322962334],
                            [2.446719118883842, 48.8962645625113],
                            [2.44714858881238, 48.896280804457405],
                            [2.4476971821202, 48.89631358493711],
                            [2.448361265144072, 48.89635100837806],
                            [2.449736363934091, 48.89643293507745],
                            [2.450819069581169, 48.89647468855999],
                            [2.45599294890596, 48.89665511724568],
                            [2.458363412015992, 48.896652451144085],
                        ],
                    },
                },
                467: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.909655729358406, 2.3000722101512774],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 1700.94851779,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.294685111702555,
                            48.903330094573725,
                            2.305924149869319,
                            48.9163823099221,
                        ),
                        "coordinates": [
                            [2.305924149869319, 48.903330094573725],
                            [2.305527381317546, 48.90377014101282],
                            [2.304366616846673, 48.90481915003097],
                            [2.302736354991042, 48.90654125319612],
                            [2.302559173495204, 48.90671627609177],
                            [2.302450470529421, 48.906816305237626],
                            [2.302317596744764, 48.90693006542794],
                            [2.302146645053836, 48.90704470258972],
                            [2.301985973672868, 48.90714682788626],
                            [2.301840261138811, 48.90722187455181],
                            [2.30166465850468, 48.9073092229744],
                            [2.301481594259069, 48.90738425827491],
                            [2.301160302420667, 48.907510952939965],
                            [2.300964157725269, 48.907594601205844],
                            [2.300756803773836, 48.907686861198975],
                            [2.300596139617583, 48.90777175018055],
                            [2.300416777101403, 48.90788863975687],
                            [2.300274770536492, 48.907995692045354],
                            [2.300190670817302, 48.908080605017766],
                            [2.300087889789824, 48.90817412852129],
                            [2.299990691274503, 48.90829350475854],
                            [2.299893485170509, 48.908423960409394],
                            [2.299818683434946, 48.90856057772802],
                            [2.299751347338648, 48.90870212190124],
                            [2.299704566567085, 48.90882766869401],
                            [2.299409016272809, 48.90946646563404],
                            [2.299033019189146, 48.910282497648126],
                            [2.298870269039818, 48.91063820525987],
                            [2.29849051259984, 48.911461621318225],
                            [2.298266012614386, 48.9119601041155],
                            [2.297979770305945, 48.912591513124674],
                            [2.297841332636104, 48.91288567564096],
                            [2.297674886590073, 48.91316998186238],
                            [2.297515941774022, 48.913412434721266],
                            [2.297295304624897, 48.913727496367834],
                            [2.297115400390914, 48.913967384922344],
                            [2.296820438150603, 48.91431082873082],
                            [2.296482067518097, 48.914697245712965],
                            [2.296130600866361, 48.91510335329522],
                            [2.295732405181075, 48.91554391183368],
                            [2.295486980283568, 48.91576399817309],
                            [2.295212291023368, 48.91599733399766],
                            [2.294950912208373, 48.91619565919043],
                            [2.294685111702555, 48.9163823099221],
                        ],
                    },
                },
                468: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.845825704517935, 2.360661561005443],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 1123.29195239,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.354917983707404,
                            48.84243679792477,
                            2.365184811993381,
                            48.847480688781914,
                        ),
                        "coordinates": [
                            [2.365184811993381, 48.84243679792477],
                            [2.365148350519312, 48.842480149713445],
                            [2.365047904856827, 48.842609587821265],
                            [2.36495736169021, 48.84274216860473],
                            [2.364876941724532, 48.8428775640905],
                            [2.364806846717999, 48.843015436309805],
                            [2.36474724986782, 48.843155443542685],
                            [2.364698299917906, 48.8432972385409],
                            [2.364660118455222, 48.84344046671468],
                            [2.364632802557162, 48.843584772442206],
                            [2.364616417999393, 48.84372979723452],
                            [2.364612258536634, 48.84380463610279],
                            [2.364607461081599, 48.84387133956159],
                            [2.364591163862304, 48.843971747517955],
                            [2.364564051812147, 48.84407113300644],
                            [2.364526270053787, 48.84416898775334],
                            [2.364478005810045, 48.84426481539778],
                            [2.364419506215975, 48.844358123492206],
                            [2.364351071277591, 48.84444844235197],
                            [2.364273048631397, 48.84453530793992],
                            [2.364185837435587, 48.84461827807595],
                            [2.364137474401958, 48.844659352006914],
                            [2.36105048980519, 48.84673808223202],
                            [2.36070864507171, 48.84698218917149],
                            [2.360414819480437, 48.84725849701021],
                            [2.360282392914332, 48.84734381347846],
                            [2.360186176776986, 48.84738328262181],
                            [2.360084640377893, 48.84741644031684],
                            [2.35997872918899, 48.847442975034404],
                            [2.359869430146436, 48.84746263932423],
                            [2.359757767561307, 48.84747524979343],
                            [2.359644779931198, 48.847480688781914],
                            [2.35953152810308, 48.84747890530516],
                            [2.359419062557283, 48.84746991577904],
                            [2.359308435658089, 48.84745380498441],
                            [2.359200685344117, 48.84743072238235],
                            [2.359096810577607, 48.84740088378118],
                            [2.358997787749318, 48.847364566926984],
                            [2.358904536600895, 48.847322112220056],
                            [2.358841663871713, 48.847288083544576],
                            [2.357501719222974, 48.84641256537105],
                            [2.357452166745333, 48.84638188652361],
                            [2.357360203085477, 48.8463328424748],
                            [2.357261686033204, 48.846289697115814],
                            [2.357157480265233, 48.846252830110224],
                            [2.357048501562036, 48.8462225647385],
                            [2.356935707261004, 48.846199168747106],
                            [2.35682008954415, 48.84618284621829],
                            [2.35670266586908, 48.84617374021732],
                            [2.356637370359253, 48.846171836806],
                            [2.356032949821477, 48.84616455759717],
                            [2.35515551944739, 48.84615398561217],
                            [2.354917983707404, 48.84615112218132],
                        ],
                    },
                },
                469: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.05603243333109, 2.3210322350458443],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 2424.47927487,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.320418181969663,
                            49.045169460276206,
                            2.322920457193825,
                            49.06628869769713,
                        ),
                        "coordinates": [
                            [2.322917846227109, 49.045169460276206],
                            [2.320958012205755, 49.0503632922462],
                            [2.320831206037497, 49.05069875981011],
                            [2.320718886612013, 49.051010437325786],
                            [2.320646403158674, 49.051269774119554],
                            [2.320602880734363, 49.051519597505795],
                            [2.320562950823169, 49.051855079155295],
                            [2.320544741683039, 49.05218342347354],
                            [2.320451368667623, 49.06084656261316],
                            [2.320429271828573, 49.06196960451012],
                            [2.320418181969663, 49.06265722955245],
                            [2.320439792809436, 49.062997477819486],
                            [2.320493957369586, 49.06344242092699],
                            [2.320562659883669, 49.063727949424035],
                            [2.32067118654574, 49.064039657778835],
                            [2.320808688650253, 49.06432043877425],
                            [2.320971545263676, 49.06458694625891],
                            [2.321170609771251, 49.064860597859216],
                            [2.321427604820848, 49.06516756616938],
                            [2.321662895628199, 49.06540315139011],
                            [2.321909058051313, 49.06562208260262],
                            [2.322184194740665, 49.065831499731104],
                            [2.322437617990567, 49.06600046380841],
                            [2.3225932944537, 49.06610041562377],
                            [2.322879310694304, 49.06626700427635],
                            [2.322920457193825, 49.06628869769713],
                        ],
                    },
                },
                470: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.957733520262124, 2.2118862744385672],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 3603.6938682,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.193442867808299,
                            48.949898714178275,
                            2.231110035011993,
                            48.968496267514055,
                        ),
                        "coordinates": [
                            [2.231110035011993, 48.950304353547466],
                            [2.230618923375161, 48.950208725581376],
                            [2.229958044697145, 48.950101041167706],
                            [2.22938379752255, 48.95002912244919],
                            [2.228719221894747, 48.949964254820316],
                            [2.228061820683885, 48.94992318525593],
                            [2.227350194319123, 48.949898714178275],
                            [2.226649336167539, 48.94990517906743],
                            [2.226031531561676, 48.949928377633626],
                            [2.225431751224789, 48.949968243554316],
                            [2.224752442393621, 48.950031823527716],
                            [2.224112818105142, 48.95011685180226],
                            [2.22355988812403, 48.95020434196695],
                            [2.222992454027753, 48.95031560806404],
                            [2.222284009217263, 48.950476698198116],
                            [2.221615253911829, 48.95065685763171],
                            [2.221018739938992, 48.950839463880364],
                            [2.220331783065522, 48.951074323815234],
                            [2.219738746613332, 48.951311650818],
                            [2.219214352979787, 48.951544288800854],
                            [2.218707984972419, 48.951791220091565],
                            [2.218244967362918, 48.952038193584286],
                            [2.217832526969044, 48.95228283694584],
                            [2.21743814174728, 48.95252987819864],
                            [2.217090747756366, 48.95276507024004],
                            [2.216736055056345, 48.95302880545211],
                            [2.216352355721841, 48.95333295902083],
                            [2.216033765586253, 48.95360386871602],
                            [2.206847714441461, 48.96132428890472],
                            [2.205670756552687, 48.9623056141098],
                            [2.205261567352605, 48.96263111460411],
                            [2.204751089968308, 48.96299694638334],
                            [2.204291394440727, 48.963286694893945],
                            [2.203734043965727, 48.96360725895176],
                            [2.203194870949078, 48.963885013209364],
                            [2.20272810794125, 48.964110506482974],
                            [2.199569281228541, 48.9656033682291],
                            [2.196750450023953, 48.96692524278801],
                            [2.193442867808299, 48.968496267514055],
                        ],
                    },
                },
                471: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.03723791311105, 2.3282935298336507],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 1882.94048772,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.322917846227109,
                            49.03297204677151,
                            2.336829689836827,
                            49.045169460276206,
                        ),
                        "coordinates": [
                            [2.336829689836827, 49.03297204677151],
                            [2.333064263333692, 49.03374705691817],
                            [2.330408070052809, 49.034296565814984],
                            [2.330020851695396, 49.034389336126274],
                            [2.32956487214166, 49.034510655044976],
                            [2.329098029981884, 49.03466766032541],
                            [2.328703558317814, 49.034827049292154],
                            [2.32830546200745, 49.03500784921652],
                            [2.327871163158731, 49.03525288756775],
                            [2.327415139404125, 49.03553361254796],
                            [2.327045964523047, 49.035816723357385],
                            [2.326760021360279, 49.0360760453743],
                            [2.326481305745596, 49.036378195790334],
                            [2.326264113513084, 49.0366565587332],
                            [2.326101208501819, 49.036906374028256],
                            [2.325960013264103, 49.03716570756672],
                            [2.325851392708387, 49.03739887170784],
                            [2.325728276642763, 49.03771531217994],
                            [2.32560153743536, 49.03804364741978],
                            [2.322917846227109, 49.045169460276206],
                        ],
                    },
                },
                472: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.895388948025, 2.4704655160288738],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 1400.08129764,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461119310778047,
                            48.89401251501928,
                            2.479793329961401,
                            48.89660443742263,
                        ),
                        "coordinates": [
                            [2.461119310778047, 48.89660443742263],
                            [2.461738202346405, 48.89656859352891],
                            [2.462168760216375, 48.89653865460159],
                            [2.462597686871036, 48.89650456189185],
                            [2.463041100390823, 48.89646443888365],
                            [2.463698059792477, 48.89639389562711],
                            [2.464405130247954, 48.896302694529815],
                            [2.465474273048822, 48.896143366243585],
                            [2.468911962696823, 48.89562312740705],
                            [2.472493893137381, 48.89509071815194],
                            [2.476065006438233, 48.894589139317695],
                            [2.478928382273328, 48.89414048098197],
                            [2.479793329961401, 48.89401251501928],
                        ],
                    },
                },
                473: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.92685137807428, 2.2849361841156757],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 875.498117153,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.284174448270924,
                            48.92310377966602,
                            2.286279577529783,
                            48.930757004235524,
                        ),
                        "coordinates": [
                            [2.286279577529783, 48.92310377966602],
                            [2.285074116791198, 48.92529551521697],
                            [2.284934624174094, 48.92555448294591],
                            [2.284740385707861, 48.92595373479756],
                            [2.284677343411207, 48.9261965483136],
                            [2.284657996424277, 48.926421391979126],
                            [2.284649650790099, 48.92657069079094],
                            [2.284641148178865, 48.92686749367112],
                            [2.284640998573596, 48.927009601084585],
                            [2.284621377159811, 48.92749527584894],
                            [2.284595923299467, 48.92833531587129],
                            [2.284490688341557, 48.93010593462904],
                            [2.284461083502885, 48.930236000420564],
                            [2.284378325598231, 48.93047476610835],
                            [2.284316328698898, 48.93058540242357],
                            [2.284174448270924, 48.930757004235524],
                        ],
                    },
                },
                474: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.77014789560134, 2.367926573076137],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 428.662858857,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.367815001629962,
                            48.76822178037075,
                            2.368041520670991,
                            48.77207421663938,
                        ),
                        "coordinates": [
                            [2.368041520670991, 48.76822178037075],
                            [2.36801991940518, 48.7685717203649],
                            [2.367996416460415, 48.76892901193795],
                            [2.367815001629962, 48.77207421663938],
                        ],
                    },
                },
                475: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.96819576829251, 1.7618663504148935],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 7402.88524229,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.716985230225326,
                            48.96309520715419,
                            1.809094508773784,
                            48.98294677854624,
                        ),
                        "coordinates": [
                            [1.716985230225326, 48.98294677854624],
                            [1.717594407918111, 48.982703772839415],
                            [1.718462645660327, 48.98237410203644],
                            [1.71949191677146, 48.98201047192969],
                            [1.720264259571234, 48.98172269510186],
                            [1.72246249361554, 48.98082320878138],
                            [1.723319687472679, 48.98049469202141],
                            [1.72402769662093, 48.98024389026234],
                            [1.725298437784954, 48.979796223139395],
                            [1.726086328698559, 48.979514904576845],
                            [1.72683809647815, 48.979231005763666],
                            [1.727503048619697, 48.97895140103639],
                            [1.728113742786351, 48.978673882942175],
                            [1.728862982753179, 48.97829954063289],
                            [1.730103599862883, 48.977647032933106],
                            [1.731923671988704, 48.97660497542186],
                            [1.732666373100019, 48.97616871062862],
                            [1.733569628129071, 48.97560717877947],
                            [1.7341272785774, 48.975227033636926],
                            [1.734546623902395, 48.97492467822281],
                            [1.735060972266274, 48.97453716214809],
                            [1.735447806546557, 48.9742322545396],
                            [1.736155971960294, 48.97365777816402],
                            [1.736714214009256, 48.97322527819537],
                            [1.737406942404305, 48.97272923479087],
                            [1.737986331490821, 48.97233966732065],
                            [1.738569093653484, 48.97196915082827],
                            [1.739136988581911, 48.97163186407823],
                            [1.739671949524783, 48.9713277163682],
                            [1.740257613960113, 48.97101431042357],
                            [1.740999302518121, 48.9706493696809],
                            [1.742260283059671, 48.97007773759341],
                            [1.743081221101059, 48.969732229617016],
                            [1.744414288685574, 48.969172843744644],
                            [1.746223205312962, 48.968408892905884],
                            [1.747472689567889, 48.96788235148487],
                            [1.74843494005744, 48.96749946352447],
                            [1.749258897543363, 48.96719675619359],
                            [1.749948321962167, 48.96696235705018],
                            [1.750789935183282, 48.96669304138924],
                            [1.751747233380135, 48.96641955140475],
                            [1.752479520296583, 48.9662258061199],
                            [1.754762826784092, 48.965666393247496],
                            [1.755712131011992, 48.96545469591098],
                            [1.757320044285388, 48.9651654299684],
                            [1.758261546780888, 48.96500126089294],
                            [1.759315143228286, 48.96483050902828],
                            [1.760611090710833, 48.964639556318616],
                            [1.762174483775721, 48.964445174002414],
                            [1.763343221870768, 48.96431541627785],
                            [1.764417700490392, 48.964211345998606],
                            [1.765629489902814, 48.96410795388584],
                            [1.767235389594588, 48.963985097537076],
                            [1.769672844099819, 48.96382589443027],
                            [1.772211191739051, 48.963690935560294],
                            [1.773613949196232, 48.96363360909356],
                            [1.775099652863674, 48.963590948124676],
                            [1.776948362263403, 48.96355337477295],
                            [1.782026620456471, 48.96345915675499],
                            [1.792204806172105, 48.96326539029052],
                            [1.79934146825186, 48.963108244055825],
                            [1.801692782735805, 48.96309520715419],
                            [1.803191036621014, 48.963110230415914],
                            [1.805456304559444, 48.96316890655146],
                            [1.80751423281709, 48.96325064241118],
                            [1.809094508773784, 48.96334411275807],
                        ],
                    },
                },
                476: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96820640618312, 2.329563826993754],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 2292.27150128,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.323367369423834,
                            48.95987163649979,
                            2.338524070645141,
                            48.9760542531305,
                        ),
                        "coordinates": [
                            [2.32609015753849, 48.95987163649979],
                            [2.324885630232892, 48.96076982868086],
                            [2.324571202075725, 48.961026764774104],
                            [2.324285678592874, 48.961286082271954],
                            [2.324018214026023, 48.961562057256074],
                            [2.323804941054537, 48.96186420909687],
                            [2.323653101596296, 48.962144953733834],
                            [2.323526551115186, 48.96243521832882],
                            [2.32345421960038, 48.96266124737491],
                            [2.323392724389629, 48.962901553974454],
                            [2.323367369423834, 48.96312520947326],
                            [2.323370909353959, 48.963386936511526],
                            [2.323406962418852, 48.963693875855114],
                            [2.323479157749756, 48.9639794051549],
                            [2.323580261005653, 48.96426255786572],
                            [2.323735571127393, 48.96454571665097],
                            [2.323916179734658, 48.96482887839174],
                            [2.324107644110294, 48.96506445343938],
                            [2.324317178915503, 48.96529051410366],
                            [2.324598989257063, 48.965530857954995],
                            [2.324906099623052, 48.965759305956404],
                            [2.325292715948479, 48.96598776159834],
                            [2.32566488971572, 48.966175765892196],
                            [2.326102114516491, 48.96635901503515],
                            [2.326589940313568, 48.966525613560286],
                            [2.327446352769263, 48.96681834442656],
                            [2.327923342359423, 48.966999211779054],
                            [2.328346129488286, 48.96718007309296],
                            [2.328696643555899, 48.96735616871943],
                            [2.329036314637615, 48.967544160100424],
                            [2.329365144468706, 48.9677583213095],
                            [2.329668676877239, 48.96798437767777],
                            [2.329928847129441, 48.96820567216525],
                            [2.330196241987498, 48.968460277233376],
                            [2.330460021564683, 48.968741053312165],
                            [2.334724277539246, 48.97337615805659],
                            [2.335143519601112, 48.97382586077935],
                            [2.335396513383135, 48.97408283224838],
                            [2.335682040432722, 48.97433742401675],
                            [2.336003713630905, 48.97459439582541],
                            [2.336390449475247, 48.97485612402674],
                            [2.336842248107739, 48.97512974896363],
                            [2.337883211512192, 48.97569840494845],
                            [2.338524070645141, 48.9760542531305],
                        ],
                    },
                },
                477: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.02530767207706, 2.1407440104440876],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 2590.05747503,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.128263873923673,
                            49.01913673984224,
                            2.154663485640923,
                            49.033987636271455,
                        ),
                        "coordinates": [
                            [2.154663485640923, 49.01913673984224],
                            [2.153012708040501, 49.01958148730108],
                            [2.1525802036884, 49.01969859749183],
                            [2.15187945004989, 49.01988361913078],
                            [2.150826891488006, 49.020175078735726],
                            [2.149978124031571, 49.020447077518284],
                            [2.149305915162764, 49.020671697973114],
                            [2.148826714662678, 49.02083817803502],
                            [2.148341998062405, 49.021016337694384],
                            [2.147705252554311, 49.02125989135247],
                            [2.147065696758275, 49.02152142255902],
                            [2.146498651858204, 49.021770480878665],
                            [2.14594799358884, 49.022024060222314],
                            [2.145346607428395, 49.02231082549486],
                            [2.144350588173181, 49.02280825434546],
                            [2.144093057933043, 49.02292652594874],
                            [2.143931358634076, 49.0230152822196],
                            [2.143650524185861, 49.02314790214863],
                            [2.143031225952273, 49.02346250313366],
                            [2.142701050689537, 49.023622914676324],
                            [2.142370881211854, 49.02378152687329],
                            [2.140962391049982, 49.0244841602294],
                            [2.139784055706185, 49.0250711659449],
                            [2.139636077743041, 49.02514465214651],
                            [2.139127744838577, 49.025396473601596],
                            [2.13819053882378, 49.02585977871451],
                            [2.137680805934782, 49.02611608728359],
                            [2.137340936435868, 49.026298048944646],
                            [2.137228556776113, 49.026359004402956],
                            [2.137055835991663, 49.026462120063606],
                            [2.136598001860149, 49.02673200308702],
                            [2.136292293463326, 49.02691851828956],
                            [2.135953572336817, 49.02715173687216],
                            [2.135933000988131, 49.02716608896057],
                            [2.13552704267224, 49.02745494442121],
                            [2.1353610539308, 49.02758234935377],
                            [2.13530891614649, 49.02762452376745],
                            [2.135145673271377, 49.027749236079515],
                            [2.134734036963733, 49.02808663965612],
                            [2.134330518977245, 49.02844383931215],
                            [2.133111242287299, 49.029505863609465],
                            [2.132522779267561, 49.03005920334172],
                            [2.131989640429896, 49.030574865619776],
                            [2.13162187645773, 49.03091147979036],
                            [2.131232357216787, 49.03125697622124],
                            [2.130733854692106, 49.03170399224864],
                            [2.13009097662359, 49.03227744575314],
                            [2.129407148815588, 49.03290435640467],
                            [2.129093756160098, 49.03321072338393],
                            [2.128263873923673, 49.033987636271455],
                        ],
                    },
                },
                478: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.01330973476587, 2.1761501915558954],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 3401.85573029,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.154663485640923,
                            49.00742329713069,
                            2.197619813968745,
                            49.01913673984224,
                        ),
                        "coordinates": [
                            [2.197619813968745, 49.00742329713069],
                            [2.197008091251297, 49.00762122621544],
                            [2.195541488379903, 49.008043884046316],
                            [2.193848750432538, 49.00850968595437],
                            [2.193439730674932, 49.00861862390083],
                            [2.191999067670692, 49.009011780942245],
                            [2.188342468293504, 49.0100239728252],
                            [2.187896449261309, 49.01014479582501],
                            [2.187193217458812, 49.01033362619896],
                            [2.184690434061876, 49.01100332858747],
                            [2.183093995563466, 49.01142947821652],
                            [2.182666827481433, 49.01154311184559],
                            [2.181816094022191, 49.01177275870757],
                            [2.180640878382492, 49.012089256590286],
                            [2.178049332489053, 49.01279432270234],
                            [2.178011018908898, 49.01280506074413],
                            [2.177708624539413, 49.01288647504226],
                            [2.177500636811216, 49.012943739858976],
                            [2.17674806297863, 49.01314682586018],
                            [2.175980425213717, 49.013356181143195],
                            [2.175078680235649, 49.013602211686965],
                            [2.174902164377811, 49.01364962398947],
                            [2.173447578949681, 49.01404773584815],
                            [2.173094537525855, 49.01414345457021],
                            [2.173043910225493, 49.01415597212351],
                            [2.172982332209368, 49.014172970655586],
                            [2.172861922373489, 49.01420337340517],
                            [2.172684032000837, 49.01425167940884],
                            [2.17239393191633, 49.014330399893325],
                            [2.172159933807473, 49.01439481122292],
                            [2.172124355370923, 49.01440465172236],
                            [2.169334150834148, 49.015161393541376],
                            [2.169280778493651, 49.015176602617416],
                            [2.168298240149801, 49.01544134684781],
                            [2.168121710485582, 49.015488749087595],
                            [2.16618532079457, 49.01601465458309],
                            [2.165480549707653, 49.01620514827598],
                            [2.163890874453162, 49.016629500666156],
                            [2.162296022835996, 49.01706274690875],
                            [2.161461213926096, 49.017287190064884],
                            [2.161117706484206, 49.01738018850346],
                            [2.157681202315227, 49.01830651546753],
                            [2.157593610267531, 49.018330658660545],
                            [2.156513748668304, 49.018628423148],
                            [2.154943888066075, 49.01906119071421],
                            [2.154663485640923, 49.01913673984224],
                        ],
                    },
                },
                479: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.962002055426225, 1.9940103249898837],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 4929.3745197,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.983143352086498,
                            48.93948681080073,
                            1.999603609660236,
                            48.98144596941029,
                        ),
                        "coordinates": [
                            [1.983143352086498, 48.98144596941029],
                            [1.985340988872836, 48.97994898514042],
                            [1.98739040784258, 48.97843485119064],
                            [1.987862935756174, 48.97806273195275],
                            [1.988441100695305, 48.977574346080175],
                            [1.988950423817492, 48.97710716156023],
                            [1.989591011343472, 48.97647619566364],
                            [1.990239311090215, 48.97577387075046],
                            [1.99074231896534, 48.97517103625501],
                            [1.991176409229675, 48.97460130023088],
                            [1.991563389677002, 48.97404807761586],
                            [1.991928790942554, 48.97347813228685],
                            [1.992269163858888, 48.97286766158834],
                            [1.992521945842703, 48.97237827467398],
                            [1.9927567681866, 48.971872175628135],
                            [1.992955248295027, 48.97139452047125],
                            [1.99311723636855, 48.97096672227368],
                            [1.993272060286449, 48.97052938315263],
                            [1.993408975130323, 48.970068197702645],
                            [1.993512786240843, 48.969690190999394],
                            [1.993628292576129, 48.969188491657484],
                            [1.993729243048589, 48.96870102540323],
                            [1.99398738330238, 48.967431218555205],
                            [1.994118454353673, 48.96676776752097],
                            [1.994286758732096, 48.96594501173718],
                            [1.994507830980454, 48.964805958086565],
                            [1.99482946101371, 48.9632317804725],
                            [1.995888335689857, 48.957959889931864],
                            [1.9992371126774, 48.94132973750179],
                            [1.999603609660236, 48.93948681080073],
                        ],
                    },
                },
                480: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.950727955417, 2.1369859807537135],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1556.71188936,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.129364252725261,
                            48.945795934518046,
                            2.144558756800802,
                            48.95558180229322,
                        ),
                        "coordinates": [
                            [2.129364252725261, 48.95558180229322],
                            [2.130186393825507, 48.95510504093087],
                            [2.130918026939952, 48.954668561787386],
                            [2.1323489735282, 48.95373842337728],
                            [2.134018912585963, 48.9526611748752],
                            [2.134996935419867, 48.95202999852488],
                            [2.13705434703725, 48.95069641978865],
                            [2.139423112433903, 48.94916585477055],
                            [2.141654189842415, 48.94770400653005],
                            [2.14260315743467, 48.94706319950211],
                            [2.143302133117028, 48.94660517253894],
                            [2.144558756800802, 48.945795934518046],
                        ],
                    },
                },
                481: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.93251347378888, 2.4652205859443646],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1532.65028221,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.454766382765777,
                            48.93230541606912,
                            2.475674370833512,
                            48.93270621869947,
                        ),
                        "coordinates": [
                            [2.454766382765777, 48.93270621869947],
                            [2.45518364315076, 48.932700995781666],
                            [2.457598821452279, 48.93267475387125],
                            [2.459869971859382, 48.93263783496673],
                            [2.462118221556601, 48.93260520910067],
                            [2.463698639395359, 48.932580933909804],
                            [2.464275473393231, 48.93256638793979],
                            [2.466635518401334, 48.9324895754969],
                            [2.469417617732813, 48.932398319719525],
                            [2.471060166345491, 48.93235468930533],
                            [2.47238270795745, 48.932341542495124],
                            [2.475674370833512, 48.93230541606912],
                        ],
                    },
                },
                482: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.982368326609844, 1.8809392022219384],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 5285.39546558,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.848348808282502,
                            48.97214167690781,
                            1.91353050809466,
                            48.99259195475149,
                        ),
                        "coordinates": [
                            [1.848348808282502, 48.97214167690781],
                            [1.851021812508963, 48.97298425217767],
                            [1.861468323330048, 48.97626411273591],
                            [1.868665313283026, 48.97852090074438],
                            [1.8821924830449, 48.98276556001553],
                            [1.896839668836701, 48.98735317831446],
                            [1.908712966964527, 48.99107198435066],
                            [1.911421019791048, 48.991922003146975],
                            [1.913213127495083, 48.99249494421094],
                            [1.91353050809466, 48.99259195475149],
                        ],
                    },
                },
                483: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.05786014298378, 2.1267907263053805],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 853.909345945,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.122735908273571,
                            49.05510176049028,
                            2.13087413699018,
                            49.06059168305009,
                        ),
                        "coordinates": [
                            [2.122735908273571, 49.05510176049028],
                            [2.122941784839978, 49.05531244053711],
                            [2.123243573991299, 49.05558617135187],
                            [2.123556743123518, 49.05580998739711],
                            [2.124163911709783, 49.05621219293198],
                            [2.124764339066789, 49.05659369933939],
                            [2.125954403837653, 49.057326106733456],
                            [2.12806979020558, 49.058643821124825],
                            [2.129277032233856, 49.05942085308345],
                            [2.129901510006047, 49.059871677728786],
                            [2.130764207723083, 49.06050375583142],
                            [2.13087413699018, 49.06059168305009],
                        ],
                    },
                },
                484: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.06741885629995, 2.325290399828083],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 427.358013077,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.322920457193825,
                            49.06628869769713,
                            2.327669570460789,
                            49.068530235211696,
                        ),
                        "coordinates": [
                            [2.322920457193825, 49.06628869769713],
                            [2.323226884488961, 49.0664502544886],
                            [2.323614289009766, 49.06663826779407],
                            [2.327669570460789, 49.068530235211696],
                        ],
                    },
                },
                485: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.74069806140985, 2.4112039151073685],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1589.11927858,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.40290860736794,
                            48.739201399103095,
                            2.417520977896491,
                            48.745072166893884,
                        ),
                        "coordinates": [
                            [2.40290860736794, 48.74187870567889],
                            [2.404148997694423, 48.74099924519451],
                            [2.404757643217121, 48.74064726679039],
                            [2.405086455081131, 48.74048519987144],
                            [2.405426135443845, 48.74031862960775],
                            [2.405987298049764, 48.74005390302935],
                            [2.406208773621854, 48.73995035151224],
                            [2.406476476959746, 48.739847669815504],
                            [2.406710207050344, 48.73975849825125],
                            [2.407073043981454, 48.739629678050854],
                            [2.407395152591308, 48.73954494655495],
                            [2.408133187830964, 48.73937991804247],
                            [2.408564079746463, 48.73930680465609],
                            [2.408755749852512, 48.739282402478366],
                            [2.409118717043212, 48.73924889836191],
                            [2.40930495829174, 48.739231693627914],
                            [2.409787586284275, 48.73920980122712],
                            [2.4102661560042, 48.739201399103095],
                            [2.410664530200711, 48.73920833398242],
                            [2.410811379616232, 48.73921633169249],
                            [2.411019421589991, 48.739230584525146],
                            [2.411075169715351, 48.739234144303495],
                            [2.411465435589616, 48.73927255734691],
                            [2.411906039467219, 48.739332517606854],
                            [2.412392916845483, 48.73942302048742],
                            [2.412942417322595, 48.739564737557345],
                            [2.413773559218267, 48.73983395734561],
                            [2.414097365070003, 48.7399722255866],
                            [2.414456565445204, 48.74013834493735],
                            [2.414837562557761, 48.740329628350366],
                            [2.415195486350047, 48.7405452064186],
                            [2.415548012333417, 48.740784168391286],
                            [2.415793035794553, 48.74096475144346],
                            [2.416055824997396, 48.7412010771217],
                            [2.416330905349029, 48.74146886698946],
                            [2.416512065030532, 48.741671076148776],
                            [2.416878676187535, 48.742204985630586],
                            [2.416987721592861, 48.742373072345345],
                            [2.417091393483954, 48.74258073036333],
                            [2.417259384866112, 48.74304373628445],
                            [2.417316901741602, 48.74329639139475],
                            [2.417387046518704, 48.74379004150383],
                            [2.417520977896491, 48.745072166893884],
                        ],
                    },
                },
                486: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.99657254688042, 2.1299884517998438],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 4941.80459689,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.097773988463467,
                            48.99028999637593,
                            2.161906605592158,
                            48.99979671296073,
                        ),
                        "coordinates": [
                            [2.161906605592158, 48.99028999637593],
                            [2.15923014594755, 48.991568342011966],
                            [2.158455061479418, 48.991940692780005],
                            [2.157904591270145, 48.992187286227285],
                            [2.157321599845263, 48.99242668486999],
                            [2.156745974028562, 48.99262802631285],
                            [2.156282645324772, 48.992770057174816],
                            [2.155504506747006, 48.99297820929998],
                            [2.154802464889393, 48.99313888997199],
                            [2.154006442734905, 48.993289898786436],
                            [2.139280305094473, 48.99580181352906],
                            [2.129238908610416, 48.99751144928054],
                            [2.119616616472705, 48.99914724319426],
                            [2.117582820296915, 48.99948599369093],
                            [2.116674632522669, 48.99960321829139],
                            [2.116027025676284, 48.99967097126729],
                            [2.115303531131314, 48.999726677793134],
                            [2.114659678871864, 48.999763500405905],
                            [2.113979715866031, 48.99978835091058],
                            [2.113386614391936, 48.99979671296073],
                            [2.112627212024045, 48.99979522849163],
                            [2.111726917029646, 48.99976253077739],
                            [2.11099662750251, 48.999720642735035],
                            [2.110483314415267, 48.99967918160778],
                            [2.109644717011229, 48.99959900042681],
                            [2.108791819863549, 48.999483096487594],
                            [2.108000458725831, 48.99935541393121],
                            [2.107317578091048, 48.99923031995456],
                            [2.106504736264994, 48.99905737335512],
                            [2.105645080149547, 48.99884387984697],
                            [2.104926360260342, 48.99865207751207],
                            [2.104189664929885, 48.9984388205304],
                            [2.101845916210095, 48.997779715308944],
                            [2.099711705675492, 48.997173337919804],
                            [2.097773988463467, 48.996630090663984],
                        ],
                    },
                },
                487: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.7741151956113, 2.461426653626426],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 1322.09531368,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.459368396259053,
                            48.768715125271434,
                            2.464564993211323,
                            48.77990531695967,
                        ),
                        "coordinates": [
                            [2.459368396259053, 48.77990531695967],
                            [2.4593715905214, 48.77984552829019],
                            [2.459420843517519, 48.778923788634266],
                            [2.459572624717776, 48.77726354827119],
                            [2.459695679008785, 48.7765982074326],
                            [2.459934446396963, 48.77590330679193],
                            [2.460207154272526, 48.77545793356428],
                            [2.460848421399567, 48.774630400529745],
                            [2.461842383719526, 48.77348511716719],
                            [2.462237245534871, 48.772915755715914],
                            [2.462581195306345, 48.77227295539292],
                            [2.462655362776355, 48.771708970893755],
                            [2.463120734116186, 48.77087405010121],
                            [2.463751735234357, 48.76970197275064],
                            [2.464564993211323, 48.768715125271434],
                        ],
                    },
                },
                488: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.87293060781886, 2.3238430303205524],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 666.474909189,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.322923073783207,
                            48.87066702089793,
                            2.325752635286725,
                            48.87576459402025,
                        ),
                        "coordinates": [
                            [2.325752635286725, 48.87066702089793],
                            [2.325035146941893, 48.871017127282386],
                            [2.324329629858781, 48.8714174639711],
                            [2.323816181771692, 48.87181466277247],
                            [2.323359297129648, 48.87225305139134],
                            [2.323270402110932, 48.87236424162656],
                            [2.323190120419306, 48.872480148968144],
                            [2.32311999940976, 48.87259889176699],
                            [2.323060267798635, 48.87272008011991],
                            [2.32301112297741, 48.87284332214574],
                            [2.322972722984288, 48.872968212248345],
                            [2.322945195870713, 48.873094344659464],
                            [2.322928626137311, 48.873221307965714],
                            [2.322923073783207, 48.87334868791445],
                            [2.322928553809522, 48.873476070894874],
                            [2.322945051295299, 48.873603037728124],
                            [2.322972508951563, 48.8737291770869],
                            [2.323010839529901, 48.87385407477373],
                            [2.32305991609095, 48.87397732805536],
                            [2.323119580382039, 48.87409853042167],
                            [2.323189638511849, 48.874217289548085],
                            [2.323269858375131, 48.87433321558999],
                            [2.323337953537984, 48.87441978154101],
                            [2.324256032653556, 48.87576459402025],
                        ],
                    },
                },
                489: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.140644259661926, 2.25661509353494],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2281.38746549,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.242677776778168,
                            49.13600056459098,
                            2.270552769414137,
                            49.14528660789949,
                        ),
                        "coordinates": [
                            [2.270552769414137, 49.14528660789949],
                            [2.269743236183263, 49.14500488613763],
                            [2.269302047347389, 49.14485894638779],
                            [2.268144282979521, 49.14447427146042],
                            [2.266697426891478, 49.14400577719803],
                            [2.263988800988784, 49.14309942671274],
                            [2.263248974900613, 49.14285615239424],
                            [2.262473533643898, 49.14260205909189],
                            [2.261599475581499, 49.142304730336974],
                            [2.260867904046181, 49.14205695025374],
                            [2.259278722453668, 49.141534311464746],
                            [2.2584512841806, 49.141250480354444],
                            [2.257656714077337, 49.140990046123456],
                            [2.256252547927994, 49.140523247688755],
                            [2.254599083982394, 49.13997711839591],
                            [2.254459351589149, 49.13993385394562],
                            [2.25312648427628, 49.13948685209989],
                            [2.25226074478818, 49.13919935094932],
                            [2.251758007767848, 49.1390380106257],
                            [2.249817008069427, 49.13838458521303],
                            [2.247902071679876, 49.1377464354801],
                            [2.246546053857624, 49.137282254235444],
                            [2.244564082650314, 49.13662511119795],
                            [2.242802675280278, 49.136042753448876],
                            [2.242677776778168, 49.13600056459098],
                        ],
                    },
                },
                490: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84631939570162, 2.4475549319721153],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2121.00087685,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.433299716281995,
                            48.844305524221596,
                            2.461697053166161,
                            48.84730835944483,
                        ),
                        "coordinates": [
                            [2.461697053166161, 48.844305524221596],
                            [2.460194914200598, 48.84459901691133],
                            [2.459558911499368, 48.844713012629775],
                            [2.458740430914106, 48.844867666611755],
                            [2.45709118124421, 48.84517337385812],
                            [2.455440552464621, 48.84547995774213],
                            [2.453990106821428, 48.84574944134958],
                            [2.452610244714963, 48.846012282858624],
                            [2.451138519871245, 48.84626277065126],
                            [2.450073004225481, 48.8464161661206],
                            [2.449059746907014, 48.846546745105584],
                            [2.448082282228678, 48.84665049022125],
                            [2.447445040745762, 48.84671202146806],
                            [2.446686652468244, 48.84676795543142],
                            [2.445296710565295, 48.84685113490022],
                            [2.44379688035156, 48.84693121706998],
                            [2.441533870470245, 48.84702414438487],
                            [2.440001091498193, 48.847072304185495],
                            [2.439036453258144, 48.84709835315031],
                            [2.43690828410544, 48.84717308181109],
                            [2.435897350806671, 48.84721713002533],
                            [2.434712001826961, 48.847258621676175],
                            [2.433826396209083, 48.847289953883305],
                            [2.433299716281995, 48.84730835944483],
                        ],
                    },
                },
                491: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.85753510889561, 2.3921956672766265],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 428.358496347,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.38972985234297,
                            48.85637735808082,
                            2.394561944549864,
                            48.85846655033305,
                        ),
                        "coordinates": [
                            [2.38972985234297, 48.85846655033305],
                            [2.389814467765861, 48.85841063867674],
                            [2.389906544880689, 48.85836011521203],
                            [2.390005290806112, 48.85831541476181],
                            [2.390109866985816, 48.85827691615788],
                            [2.390208506867914, 48.85824776919368],
                            [2.391456620064829, 48.85789230223473],
                            [2.39205855437378, 48.85772086426741],
                            [2.392386168879081, 48.85759210226877],
                            [2.394273237984915, 48.856578827557655],
                            [2.394425337052354, 48.85649022833206],
                            [2.394561944549864, 48.85637735808082],
                        ],
                    },
                },
                492: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.87948889688533, 2.370333000197338],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 440.543327994,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.370262128023678,
                            48.87761018741785,
                            2.370811395312745,
                            48.88149859591725,
                        ),
                        "coordinates": [
                            [2.370262128023678, 48.88149859591725],
                            [2.370282702547283, 48.87859554589099],
                            [2.370299887668615, 48.87845879487809],
                            [2.370326968040279, 48.878354599544444],
                            [2.370378704439229, 48.87821295528958],
                            [2.370445256257325, 48.878082702505345],
                            [2.370506884729263, 48.8779736129459],
                            [2.370588761133375, 48.87785388188476],
                            [2.370662445959182, 48.87776118209142],
                            [2.370745648089061, 48.87767205405856],
                            [2.370811395312745, 48.87761018741785],
                        ],
                    },
                },
                493: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.860537119654886, 2.3886383027771565],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 491.971819488,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.387607288151709,
                            48.85846655033305,
                            2.38972985234297,
                            48.86265401909355,
                        ),
                        "coordinates": [
                            [2.387607288151709, 48.86265401909355],
                            [2.387835956453657, 48.862183747877275],
                            [2.389577761684016, 48.85860129799121],
                            [2.389585804342266, 48.85859259647261],
                            [2.389653412909127, 48.85852737628639],
                            [2.38972985234297, 48.85846655033305],
                        ],
                    },
                },
                494: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.867973691566384, 2.3819902637677313],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 329.932916856,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.380542586000037,
                            48.86680003509802,
                            2.383383250455203,
                            48.86909116202569,
                        ),
                        "coordinates": [
                            [2.380542586000037, 48.86909116202569],
                            [2.381004820607528, 48.86872013903556],
                            [2.382896615622108, 48.86729984789996],
                            [2.38300456250198, 48.867213874448964],
                            [2.383113287474196, 48.86711626924769],
                            [2.383212880067785, 48.867014510493455],
                            [2.383302976021693, 48.866908970456215],
                            [2.383383250455203, 48.86680003509802],
                        ],
                    },
                },
                495: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.8244578830612, 2.261852181932542],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1281.0515701,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.258759767033708,
                            48.81967448818826,
                            2.263689648725751,
                            48.830119640157896,
                        ),
                        "coordinates": [
                            [2.263689648725751, 48.830119640157896],
                            [2.263346232609672, 48.829696466430924],
                            [2.263161366679126, 48.82944185212201],
                            [2.263040396501341, 48.8292700128134],
                            [2.26298330636689, 48.82919083915351],
                            [2.262803907393523, 48.82892633585935],
                            [2.262634123155269, 48.82860878205818],
                            [2.262556715913852, 48.82845495551708],
                            [2.26248469548901, 48.82829302630381],
                            [2.26240742426411, 48.8280987444057],
                            [2.262308474382768, 48.82777853824987],
                            [2.262280972837698, 48.82764571314718],
                            [2.262232289143338, 48.82742868566543],
                            [2.262194904473243, 48.82721911446792],
                            [2.262176356026218, 48.826872881103455],
                            [2.262172658902515, 48.826613887802544],
                            [2.262176843488879, 48.826548243273066],
                            [2.262178319812067, 48.82647270499077],
                            [2.262204533389988, 48.826248803050674],
                            [2.262274934494922, 48.82590593771449],
                            [2.26240622374005, 48.82526332833843],
                            [2.262473477124769, 48.82491805081996],
                            [2.26251340780637, 48.82462761110604],
                            [2.26254109110546, 48.8243299690432],
                            [2.262532073651375, 48.82398554023579],
                            [2.262526704310095, 48.82393247930002],
                            [2.26251466657006, 48.823785889605745],
                            [2.262482352195592, 48.823537669153],
                            [2.262418754581196, 48.82326244945372],
                            [2.262342828231274, 48.823034883175985],
                            [2.262260124812575, 48.822786628652956],
                            [2.262095834500931, 48.82245468891747],
                            [2.262022496980392, 48.82231884970712],
                            [2.261882889810527, 48.82206638158086],
                            [2.261712713697331, 48.82183753399766],
                            [2.261541451527959, 48.82161709858423],
                            [2.261323935558723, 48.82136605696377],
                            [2.261109068584909, 48.821164476946656],
                            [2.261034274357683, 48.82109338484533],
                            [2.260913247115648, 48.82097729741371],
                            [2.260703789295706, 48.82080269840944],
                            [2.260541928789346, 48.82067309480275],
                            [2.260452156858628, 48.820601992416776],
                            [2.260158312621298, 48.82039945794022],
                            [2.259860361121074, 48.82021220757875],
                            [2.259541961649865, 48.820039331570165],
                            [2.259324922990989, 48.819920739289394],
                            [2.259018063679556, 48.81978088335963],
                            [2.258759767033708, 48.81967448818826],
                        ],
                    },
                },
                496: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.82974976174606, 2.5009613591628375],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2304.08009043,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.494188055346116,
                            48.82484856949889,
                            2.511855553451007,
                            48.839341939180265,
                        ),
                        "coordinates": [
                            [2.494188055346116, 48.839341939180265],
                            [2.494247766895406, 48.838846953662475],
                            [2.49428634106946, 48.83850665376865],
                            [2.494335041496361, 48.83794981945879],
                            [2.49440876096613, 48.83732632879831],
                            [2.49444007068898, 48.83696938300809],
                            [2.494492824963791, 48.83655530353588],
                            [2.494553057041376, 48.83622687146399],
                            [2.494606625712022, 48.83600754436564],
                            [2.494677919395311, 48.835757614148676],
                            [2.494785088492835, 48.83545528867773],
                            [2.494874454512325, 48.83522198901582],
                            [2.494988959541596, 48.83496010230668],
                            [2.495092814994253, 48.834750575106625],
                            [2.495250507616648, 48.83446959352472],
                            [2.495401095686161, 48.83422193256743],
                            [2.496322846076571, 48.832809693311546],
                            [2.496712946261206, 48.83219844504028],
                            [2.497140330411507, 48.831552605217134],
                            [2.497320489863974, 48.83129060209894],
                            [2.49768548971296, 48.830733342726056],
                            [2.497893531093397, 48.83042849144205],
                            [2.4981267353821, 48.83010457095283],
                            [2.498321673575904, 48.82986671831846],
                            [2.498521609160343, 48.82962576369708],
                            [2.49869037660845, 48.82943755598253],
                            [2.499101887977773, 48.829023344577465],
                            [2.499323720496731, 48.828814886859284],
                            [2.499628931941801, 48.828544098368724],
                            [2.499934239976472, 48.82830409190573],
                            [2.500267467584421, 48.82804497023481],
                            [2.500646486652083, 48.82778552795893],
                            [2.501191511108631, 48.82743672379359],
                            [2.501691788944037, 48.82715003217035],
                            [2.502106461696296, 48.826926411390446],
                            [2.502574264952994, 48.82670720837081],
                            [2.502874036656867, 48.82657485091107],
                            [2.50319948682061, 48.826442221633926],
                            [2.503541299313914, 48.826302924058766],
                            [2.504073190058934, 48.826109700224784],
                            [2.504311268842221, 48.8260293155916],
                            [2.504535748512162, 48.82595929506318],
                            [2.504858178104163, 48.82586103227905],
                            [2.505331909786763, 48.825726674456156],
                            [2.505642006799357, 48.82564965816218],
                            [2.506225849975233, 48.825518398747874],
                            [2.506561054164337, 48.82545323751325],
                            [2.507099534828155, 48.82535528254552],
                            [2.50754384646785, 48.82528963736865],
                            [2.507984529348589, 48.825229805287194],
                            [2.508844977549582, 48.825138583558406],
                            [2.509435855385033, 48.82507654159762],
                            [2.509914257207523, 48.82502670696369],
                            [2.510482958774583, 48.82497528756578],
                            [2.511177234201497, 48.82491292453119],
                            [2.511855553451007, 48.82484856949889],
                        ],
                    },
                },
                497: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.84505406284946, 2.3191194287557293],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 653.486092189,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.316424352050892,
                            48.84232743772648,
                            2.320984834266813,
                            48.84705255542816,
                        ),
                        "coordinates": [
                            [2.320984834266813, 48.84232743772648],
                            [2.320782164307052, 48.84283324152782],
                            [2.320035797243541, 48.84473264522306],
                            [2.320014641258075, 48.84480271042847],
                            [2.319995714922577, 48.844845275863385],
                            [2.319947456260746, 48.84493506652904],
                            [2.319889049275929, 48.84502219042287],
                            [2.319820824711712, 48.845106151163925],
                            [2.31974317174453, 48.84518646529295],
                            [2.319656540568837, 48.84526267307985],
                            [2.319561426047721, 48.84533433843141],
                            [2.319478861276227, 48.845388571682335],
                            [2.319029276532875, 48.84561537537982],
                            [2.317063803955226, 48.84658388106742],
                            [2.316973862121948, 48.846629825986575],
                            [2.316851883672146, 48.84669998581574],
                            [2.316737441471143, 48.84677547680999],
                            [2.316634671102764, 48.84685485575205],
                            [2.316533269514071, 48.84694101911718],
                            [2.316444491528307, 48.84703029795952],
                            [2.316424352050892, 48.84705255542816],
                        ],
                    },
                },
                498: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.83614892899476, 2.331705730124358],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 639.080908531,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.330754192086216,
                            48.833450858213496,
                            2.332393261591429,
                            48.838964280710556,
                        ),
                        "coordinates": [
                            [2.331740130985349, 48.833450858213496],
                            [2.332245772967149, 48.83403301240606],
                            [2.332255655703247, 48.834046070689475],
                            [2.332304649392604, 48.83412054502511],
                            [2.332343179365558, 48.834197651844796],
                            [2.332370930905341, 48.834276750848204],
                            [2.332387671208866, 48.83435718779991],
                            [2.332393261591429, 48.834438299094074],
                            [2.332387656172084, 48.834519408149426],
                            [2.332374000209267, 48.83458831187027],
                            [2.332353254265583, 48.83466829493065],
                            [2.332293041778883, 48.83487039006441],
                            [2.332222063879577, 48.83507095635961],
                            [2.332217155067424, 48.835083732391226],
                            [2.330928467459536, 48.83850203992784],
                            [2.330754192086216, 48.838964280710556],
                        ],
                    },
                },
                499: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.86580275698777, 2.3603545132596815],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 671.632729286,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356729869173701,
                            48.864693598877,
                            2.363826143977408,
                            48.86750342377884,
                        ),
                        "coordinates": [
                            [2.356729869173701, 48.865322711678054],
                            [2.357846194669268, 48.865070737849976],
                            [2.359468058190322, 48.86470463193337],
                            [2.359525493277145, 48.864695503394444],
                            [2.359585714402995, 48.864693598877],
                            [2.359645394215222, 48.86469924682117],
                            [2.359702371906783, 48.86471224590558],
                            [2.359754593618367, 48.864732121984396],
                            [2.359800169283975, 48.86475816076684],
                            [2.35983674878057, 48.86478870389026],
                            [2.360722811429663, 48.865689606944926],
                            [2.36133769816816, 48.86627336057079],
                            [2.361989420355609, 48.86675168020361],
                            [2.363022188828014, 48.86717313926737],
                            [2.363826143977408, 48.86750342377884],
                        ],
                    },
                },
                500: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.05477417638451, 2.076491814986491],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 3358.17440629,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.057902989161614,
                            49.04664576264113,
                            2.095195067225969,
                            49.062969678597184,
                        ),
                        "coordinates": [
                            [2.095195067225969, 49.04664576264113],
                            [2.094126920089523, 49.046874735810704],
                            [2.093499901776588, 49.04703212246902],
                            [2.092920593297768, 49.04720250649252],
                            [2.091159286398372, 49.04767568235559],
                            [2.090079360752798, 49.047925572243905],
                            [2.089365325756049, 49.048114379438736],
                            [2.088875888051575, 49.04828292630655],
                            [2.088586733759366, 49.04837942216064],
                            [2.088282463472209, 49.048489374520706],
                            [2.088011043893093, 49.048595798794416],
                            [2.087919199938083, 49.04863157114024],
                            [2.087564035054227, 49.04879536629087],
                            [2.087321255508606, 49.048918938849724],
                            [2.08711964160572, 49.04901831911531],
                            [2.086742399599353, 49.04921803602306],
                            [2.086380108170661, 49.04943666812055],
                            [2.085943546619811, 49.049731575890895],
                            [2.085655127112803, 49.04995036857075],
                            [2.085085125800879, 49.05038706596251],
                            [2.084191046955512, 49.051055061107206],
                            [2.0834499148253, 49.05150756055048],
                            [2.083164513940505, 49.05166700098783],
                            [2.082850384475092, 49.05182547685646],
                            [2.082275798305706, 49.052080496960116],
                            [2.081993344976037, 49.05219767407753],
                            [2.08158070709133, 49.05235412949175],
                            [2.081465597200733, 49.0523889447606],
                            [2.081405294315293, 49.05240859467244],
                            [2.081340877238093, 49.052430034008474],
                            [2.081133875839146, 49.052507809537985],
                            [2.080461012986365, 49.05271403927922],
                            [2.079742889510717, 49.05293994862055],
                            [2.079013908555118, 49.053147842735186],
                            [2.078968686543511, 49.053161229787634],
                            [2.07839722346008, 49.0533353022831],
                            [2.077866873530738, 49.05349597458154],
                            [2.076632119279961, 49.05386997607687],
                            [2.076538917675931, 49.053900339330134],
                            [2.076481352443694, 49.053919093309645],
                            [2.076101638657753, 49.0540531218026],
                            [2.075614925514857, 49.05423906401237],
                            [2.075145899653117, 49.05444302942589],
                            [2.074532664979615, 49.05474828138031],
                            [2.074399595778393, 49.05481362380417],
                            [2.074335077758354, 49.054853044730535],
                            [2.07391778700268, 49.05510388620937],
                            [2.073552583806506, 49.05533686031318],
                            [2.073279280494053, 49.05552687986573],
                            [2.072781914389743, 49.05590972676529],
                            [2.072608669357216, 49.05606670100856],
                            [2.072427226918978, 49.056220959011256],
                            [2.072231875564163, 49.05641745067627],
                            [2.07210796360099, 49.05656014968658],
                            [2.071937393171934, 49.05672792064698],
                            [2.070613223507392, 49.05818438299689],
                            [2.07028297358326, 49.058526240368955],
                            [2.070181093504082, 49.05864111154397],
                            [2.069804365072053, 49.05897296732316],
                            [2.069731536102972, 49.059029452258955],
                            [2.069682080643006, 49.05906530853524],
                            [2.069443000103234, 49.059246404752855],
                            [2.069210862523064, 49.05940863301776],
                            [2.068753610679042, 49.05969893113579],
                            [2.068601146673209, 49.05978070353879],
                            [2.06805560213539, 49.060033612207086],
                            [2.066851653333208, 49.06049801807876],
                            [2.066184835043928, 49.06074684882443],
                            [2.06613274208745, 49.06076381224054],
                            [2.066050478703724, 49.06079239544044],
                            [2.064875560292593, 49.06118529581779],
                            [2.06424768462518, 49.061388840495226],
                            [2.063611648208768, 49.061582469221776],
                            [2.063552705376659, 49.06160031511514],
                            [2.063492385020961, 49.06161995496162],
                            [2.062713833074689, 49.061847412342175],
                            [2.061905204383233, 49.0620684963418],
                            [2.06041698661609, 49.062434520964196],
                            [2.05985653531546, 49.06256626160598],
                            [2.058432985971604, 49.06286497070554],
                            [2.057902989161614, 49.062969678597184],
                        ],
                    },
                },
                501: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.18233049428746, 1.927051585410233],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 4789.03517654,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.920111493432765,
                            49.16267058077503,
                            1.936963126849634,
                            49.20269360297641,
                        ),
                        "coordinates": [
                            [1.936928635785827, 49.16267058077503],
                            [1.936963126849634, 49.163675521261766],
                            [1.93691640361495, 49.164196042571255],
                            [1.936853586857697, 49.164671544555986],
                            [1.936632234372513, 49.16558804052991],
                            [1.936480269359919, 49.16606413094077],
                            [1.936288840544083, 49.16667137841608],
                            [1.936221156076793, 49.16690045885496],
                            [1.936094364050522, 49.16731548542977],
                            [1.935918454123258, 49.16786792971006],
                            [1.935855099679006, 49.16807004689457],
                            [1.935751054891891, 49.16831534775284],
                            [1.935668649640234, 49.16853317062894],
                            [1.935571017034716, 49.16876416061875],
                            [1.935343123247464, 49.16918993667314],
                            [1.935207931840512, 49.16941061645384],
                            [1.934967357367741, 49.169783748378876],
                            [1.934733083983348, 49.17003674541137],
                            [1.934566350443587, 49.1702112273786],
                            [1.93338857884256, 49.17134558782178],
                            [1.933264006541073, 49.17148453885352],
                            [1.933028304514656, 49.171795761001526],
                            [1.932825786028799, 49.17207382623494],
                            [1.932701720831058, 49.172317994971195],
                            [1.932652916747922, 49.17241584485284],
                            [1.932482339449547, 49.17281272694295],
                            [1.932295419492284, 49.173362429543715],
                            [1.932161949165087, 49.173749549783395],
                            [1.93196074718093, 49.17436754687089],
                            [1.931799396454741, 49.17480852520891],
                            [1.931775511497547, 49.17487768579857],
                            [1.931729143027445, 49.175012414767],
                            [1.931656073329921, 49.17522528675495],
                            [1.931463516720904, 49.175791155398485],
                            [1.931456488324099, 49.17581181349296],
                            [1.931449475095587, 49.17583067346095],
                            [1.931333092076561, 49.17613961584883],
                            [1.931068825349872, 49.17691836060446],
                            [1.930969163298852, 49.17719498680245],
                            [1.930898962784217, 49.177391681986364],
                            [1.930778213481298, 49.17773028377056],
                            [1.930661770313186, 49.178045520156935],
                            [1.93057052582442, 49.178298795505526],
                            [1.930517323297216, 49.17842990237041],
                            [1.930493544957204, 49.17848557381584],
                            [1.930468292780109, 49.178553829845924],
                            [1.930441824813714, 49.17860319698278],
                            [1.930360935092428, 49.17876478105686],
                            [1.930271747982409, 49.17893442936181],
                            [1.930168724445757, 49.179118418035664],
                            [1.930111648908888, 49.17921983431229],
                            [1.929965642422839, 49.17945942598759],
                            [1.929824039149715, 49.17966396094408],
                            [1.929560492351161, 49.18001734315282],
                            [1.929148942040459, 49.18051858203903],
                            [1.928816881447752, 49.18086182878829],
                            [1.928570726333448, 49.18110106183028],
                            [1.928370275420154, 49.18128739991404],
                            [1.927983452033404, 49.181616060453536],
                            [1.927900571964765, 49.181685010373755],
                            [1.927614746102435, 49.18190971261044],
                            [1.927257339631823, 49.18216383439086],
                            [1.926849075255081, 49.18242946481641],
                            [1.926449209513245, 49.18267444115933],
                            [1.92571319172877, 49.18308997557925],
                            [1.925146747608871, 49.18340359520289],
                            [1.924111891994474, 49.183978731041215],
                            [1.923032542919152, 49.18460364103877],
                            [1.921718928505674, 49.18577842758823],
                            [1.920865292274841, 49.18724587027777],
                            [1.920286613586217, 49.18935766157126],
                            [1.920111493432765, 49.1934928906288],
                            [1.920547706067206, 49.20269360297641],
                        ],
                    },
                },
                502: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9429407406498, 2.3037045736209234],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2358.83064982,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.301294975906111,
                            48.93289616644866,
                            2.307943234074898,
                            48.95339646167632,
                        ),
                        "coordinates": [
                            [2.307943234074898, 48.93289616644866],
                            [2.307790373610745, 48.93320410885454],
                            [2.307700179597064, 48.93338933674383],
                            [2.307592219082522, 48.933610531607584],
                            [2.307231435003357, 48.9343478463323],
                            [2.306959967215049, 48.934914773842294],
                            [2.306942389887075, 48.934951480188985],
                            [2.306791361624463, 48.935266792095796],
                            [2.306211875969694, 48.936451885601386],
                            [2.305632363899749, 48.93763697590386],
                            [2.305054188036975, 48.93882296299697],
                            [2.304996778965808, 48.93893985323258],
                            [2.304909298806844, 48.93911878538438],
                            [2.304789010420524, 48.939366052886314],
                            [2.304164316422684, 48.940649143463794],
                            [2.303885466982651, 48.94119582386023],
                            [2.303633933861768, 48.94171193616121],
                            [2.303159550238386, 48.94270280078087],
                            [2.303096664922068, 48.94282957971184],
                            [2.303035148519818, 48.942950964551486],
                            [2.302854685341371, 48.943326808992296],
                            [2.302061722366169, 48.944958757593575],
                            [2.302058987723681, 48.94496415265967],
                            [2.302045313819851, 48.944993824036494],
                            [2.301755434922947, 48.94562502796113],
                            [2.301543394204471, 48.94621938486529],
                            [2.301418786496034, 48.9467319330652],
                            [2.301355724831788, 48.94709252378621],
                            [2.301322748803998, 48.94738387867186],
                            [2.301295098929685, 48.947861386022794],
                            [2.301294975906111, 48.948033147065296],
                            [2.301313813540341, 48.94841984144111],
                            [2.301364024439001, 48.94884791273588],
                            [2.30146468453999, 48.949374019617075],
                            [2.301580375162466, 48.949887541064854],
                            [2.301658725763627, 48.950268171329256],
                            [2.301768236604624, 48.950678961235134],
                            [2.301791371778074, 48.950786881701916],
                            [2.301894825858126, 48.95123565119294],
                            [2.301917970788922, 48.9513309817407],
                            [2.302083730736812, 48.95209563320852],
                            [2.302144981440925, 48.952331205612126],
                            [2.302191588827377, 48.952519007640106],
                            [2.302275983078653, 48.95289852691586],
                            [2.302335798780749, 48.95327803966121],
                            [2.30234042019572, 48.95339646167632],
                        ],
                    },
                },
                503: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.00596191886903, 2.0882839213425717],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3008.10735935,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.085506679860896,
                            48.995462534556246,
                            2.094643974392771,
                            49.01834916361145,
                        ),
                        "coordinates": [
                            [2.094643974392771, 48.99574683395328],
                            [2.094115793261617, 48.995631206683015],
                            [2.093749494578502, 48.995566662210194],
                            [2.093352059656961, 48.995501574705614],
                            [2.092896647311002, 48.995462534556246],
                            [2.092455498486702, 48.99546397305766],
                            [2.091996081612054, 48.99550344011252],
                            [2.091605246115984, 48.9955668459734],
                            [2.091210619108013, 48.995665930766954],
                            [2.090790492348363, 48.995803031724805],
                            [2.090431784401015, 48.99594978007585],
                            [2.090109150295021, 48.99611325923673],
                            [2.089844381610968, 48.99627448493622],
                            [2.089575805183725, 48.99647376950273],
                            [2.089375987873591, 48.99666130569426],
                            [2.089172342072614, 48.99689166331516],
                            [2.089019243828573, 48.997136404045776],
                            [2.088858511452071, 48.997462026615274],
                            [2.088774556142994, 48.99766941850957],
                            [2.088653983776406, 48.99819439395835],
                            [2.088283466587654, 48.999851410536195],
                            [2.088171523848284, 49.00037005180863],
                            [2.088059416498945, 49.000921067583164],
                            [2.087829779056399, 49.00203004764123],
                            [2.087759262258183, 49.00238917605548],
                            [2.08762642643255, 49.00291576456261],
                            [2.087564108166994, 49.003200564597314],
                            [2.087124533193176, 49.00526165541821],
                            [2.08701554469947, 49.00573174133361],
                            [2.086676559529283, 49.007354201266836],
                            [2.086561849354139, 49.007872835421814],
                            [2.086375748551401, 49.008722248144664],
                            [2.086279170620937, 49.009168080012586],
                            [2.08625538646241, 49.00927594164314],
                            [2.085806100710601, 49.0113433012357],
                            [2.085579489851317, 49.012358091396464],
                            [2.085532733313348, 49.01268172920538],
                            [2.085506679860896, 49.01296674442584],
                            [2.085524365549785, 49.013253652989704],
                            [2.085552513396006, 49.01336432689372],
                            [2.085565883876988, 49.01342370825528],
                            [2.085678753985918, 49.01381244534922],
                            [2.085820813494618, 49.01410682136232],
                            [2.085952412419675, 49.01430764943292],
                            [2.086194093017157, 49.01462478800239],
                            [2.086488001898017, 49.01491583604665],
                            [2.087009451542514, 49.01534862891433],
                            [2.087201471451877, 49.015498328538634],
                            [2.087371888939506, 49.015594023785575],
                            [2.088199244624964, 49.01609942066983],
                            [2.08859712910706, 49.016367370471684],
                            [2.089009926742526, 49.016661429272084],
                            [2.089481020740325, 49.01705543400022],
                            [2.090052730601043, 49.01756386144909],
                            [2.090557643614887, 49.018034373000205],
                            [2.090906063354292, 49.01834916361145],
                        ],
                    },
                },
                504: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.94166787115946, 2.150760739942237],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1284.07893555,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.144558756800802,
                            48.93773606341459,
                            2.157086496469818,
                            48.945795934518046,
                        ),
                        "coordinates": [
                            [2.144558756800802, 48.945795934518046],
                            [2.146753189057277, 48.94439103172525],
                            [2.14745577502546, 48.94391394942269],
                            [2.147933873262263, 48.94357449457276],
                            [2.148459092094536, 48.94318990649488],
                            [2.148973504613955, 48.942795781350526],
                            [2.149404596685325, 48.942463379849556],
                            [2.149911625986352, 48.94210730967307],
                            [2.150342526973852, 48.9418224908282],
                            [2.150766182551382, 48.94154241953934],
                            [2.151349105221197, 48.941169810212344],
                            [2.153087010268662, 48.940044806929784],
                            [2.153651740968178, 48.93969832985609],
                            [2.154545805962058, 48.9391715445828],
                            [2.155276891353209, 48.93876107928797],
                            [2.157086496469818, 48.93773606341459],
                        ],
                    },
                },
                505: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.94166787115946, 2.150760739942237],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1284.07893555,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.144558756800802,
                            48.93773606341459,
                            2.157086496469818,
                            48.945795934518046,
                        ),
                        "coordinates": [
                            [2.144558756800802, 48.945795934518046],
                            [2.146753189057277, 48.94439103172525],
                            [2.14745577502546, 48.94391394942269],
                            [2.147933873262263, 48.94357449457276],
                            [2.148459092094536, 48.94318990649488],
                            [2.148973504613955, 48.942795781350526],
                            [2.149404596685325, 48.942463379849556],
                            [2.149911625986352, 48.94210730967307],
                            [2.150342526973852, 48.9418224908282],
                            [2.150766182551382, 48.94154241953934],
                            [2.151349105221197, 48.941169810212344],
                            [2.153087010268662, 48.940044806929784],
                            [2.153651740968178, 48.93969832985609],
                            [2.154545805962058, 48.9391715445828],
                            [2.155276891353209, 48.93876107928797],
                            [2.157086496469818, 48.93773606341459],
                        ],
                    },
                },
                506: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.94166787115946, 2.150760739942237],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1284.07893555,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.144558756800802,
                            48.93773606341459,
                            2.157086496469818,
                            48.945795934518046,
                        ),
                        "coordinates": [
                            [2.144558756800802, 48.945795934518046],
                            [2.146753189057277, 48.94439103172525],
                            [2.14745577502546, 48.94391394942269],
                            [2.147933873262263, 48.94357449457276],
                            [2.148459092094536, 48.94318990649488],
                            [2.148973504613955, 48.942795781350526],
                            [2.149404596685325, 48.942463379849556],
                            [2.149911625986352, 48.94210730967307],
                            [2.150342526973852, 48.9418224908282],
                            [2.150766182551382, 48.94154241953934],
                            [2.151349105221197, 48.941169810212344],
                            [2.153087010268662, 48.940044806929784],
                            [2.153651740968178, 48.93969832985609],
                            [2.154545805962058, 48.9391715445828],
                            [2.155276891353209, 48.93876107928797],
                            [2.157086496469818, 48.93773606341459],
                        ],
                    },
                },
                507: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.895388948025, 2.4704655160288738],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1400.08129764,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461119310778047,
                            48.89401251501928,
                            2.479793329961401,
                            48.89660443742263,
                        ),
                        "coordinates": [
                            [2.461119310778047, 48.89660443742263],
                            [2.461738202346405, 48.89656859352891],
                            [2.462168760216375, 48.89653865460159],
                            [2.462597686871036, 48.89650456189185],
                            [2.463041100390823, 48.89646443888365],
                            [2.463698059792477, 48.89639389562711],
                            [2.464405130247954, 48.896302694529815],
                            [2.465474273048822, 48.896143366243585],
                            [2.468911962696823, 48.89562312740705],
                            [2.472493893137381, 48.89509071815194],
                            [2.476065006438233, 48.894589139317695],
                            [2.478928382273328, 48.89414048098197],
                            [2.479793329961401, 48.89401251501928],
                        ],
                    },
                },
                508: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.909162564643374, 2.2382814723671878],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 230.639608371,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.236878028463527,
                            48.90869458435905,
                            2.239684117127617,
                            48.90963293312601,
                        ),
                        "coordinates": [
                            [2.236878028463527, 48.90869458435905],
                            [2.238445939948255, 48.90921623446079],
                            [2.239684117127617, 48.90963293312601],
                        ],
                    },
                },
                509: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.886415433638916, 2.5190042434335185],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1115.16191874,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.512566821462173,
                            48.88373428097723,
                            2.525434250765843,
                            48.88907659470566,
                        ),
                        "coordinates": [
                            [2.512566821462173, 48.88907659470566],
                            [2.512998832387353, 48.888924515379514],
                            [2.51336355369073, 48.888784347605245],
                            [2.514432503756536, 48.88834352057677],
                            [2.515351998005951, 48.88794826774535],
                            [2.517499182084499, 48.88705597118021],
                            [2.521107305737947, 48.885521719400764],
                            [2.52210153410764, 48.885103250811575],
                            [2.525434250765843, 48.88373428097723],
                        ],
                    },
                },
                510: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.0889152610119, 1.9859581591299293],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 3348.68147194,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.970535722321773,
                            49.08049370702575,
                            2.003715373018928,
                            49.099650121708414,
                        ),
                        "coordinates": [
                            [2.003715373018928, 49.08049370702575],
                            [2.003547570629936, 49.08055669547531],
                            [2.003194743877491, 49.08070405129703],
                            [2.002920136442579, 49.08082375520123],
                            [2.002719664092107, 49.080912200403745],
                            [2.002308995130275, 49.08110974472391],
                            [2.000843475638629, 49.08181409489413],
                            [1.999189688504895, 49.082615892503455],
                            [1.99911414030077, 49.082652540825876],
                            [1.999039967263214, 49.08268829325596],
                            [1.998987779109487, 49.08271242039148],
                            [1.997147217253244, 49.08359007528347],
                            [1.995792687758831, 49.084259615204665],
                            [1.995634691924411, 49.08433918112899],
                            [1.993983481308018, 49.085140010831175],
                            [1.993575537861701, 49.085329437973385],
                            [1.992002545761859, 49.08609540089205],
                            [1.991135713332791, 49.086510057673934],
                            [1.990909032976474, 49.08661998508319],
                            [1.989366275453086, 49.087358126334024],
                            [1.988685693923971, 49.087691991181586],
                            [1.988284357301213, 49.08788992267321],
                            [1.987363982355846, 49.08833039492414],
                            [1.986541515581259, 49.08872992756838],
                            [1.986125246843903, 49.08892649670459],
                            [1.985239586077623, 49.08935463584482],
                            [1.984431366759692, 49.08974548002464],
                            [1.984145817277239, 49.08986950025343],
                            [1.98375123051329, 49.090030319531444],
                            [1.983324044711368, 49.0901896101539],
                            [1.982646338589363, 49.0904245017808],
                            [1.982076707587914, 49.09059191257148],
                            [1.98147561394448, 49.090751371374594],
                            [1.981083660375881, 49.09084172234247],
                            [1.979957028198716, 49.091084285058024],
                            [1.978856858580296, 49.091329258753255],
                            [1.978436519057312, 49.09144001369728],
                            [1.978051563974808, 49.091557301195984],
                            [1.977508295010657, 49.09174261697837],
                            [1.977043829812726, 49.09192070497828],
                            [1.97662335063183, 49.09210066905528],
                            [1.976278962452549, 49.09225769542364],
                            [1.975689724344398, 49.092574199223414],
                            [1.97535325091785, 49.09277800095605],
                            [1.974985476377034, 49.09300519545367],
                            [1.974481719753129, 49.09335702307657],
                            [1.973974755645611, 49.093771787405615],
                            [1.973525256585286, 49.09419212776733],
                            [1.973167500616184, 49.09457737825696],
                            [1.972955499032007, 49.09484973777532],
                            [1.972920402169598, 49.09489245460434],
                            [1.972890797833858, 49.09492733689051],
                            [1.97284909562573, 49.094981453923616],
                            [1.9727376485112, 49.09513342801445],
                            [1.972645887453138, 49.09526954293259],
                            [1.97245156907172, 49.09561940579742],
                            [1.97232974103675, 49.09587179106469],
                            [1.972134977621871, 49.09628484215855],
                            [1.97183317397005, 49.096913380350486],
                            [1.971354494738784, 49.09794063551677],
                            [1.971029037263927, 49.09861675788842],
                            [1.970871839033678, 49.098947192227556],
                            [1.970535722321773, 49.099650121708414],
                        ],
                    },
                },
                511: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.984038492963194, 1.301075511581922],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 26827.0627974,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.149003549412462,
                            48.92509435108641,
                            1.443790938714628,
                            49.02325888077188,
                        ),
                        "coordinates": [
                            [1.443790938714628, 48.92509435108641],
                            [1.443169488362618, 48.92550558019977],
                            [1.442548899409676, 48.92627804630356],
                            [1.44180433179974, 48.9273826763383],
                            [1.432025570626304, 48.940647726954495],
                            [1.420984740711732, 48.955756424975945],
                            [1.419789110742343, 48.957010304637954],
                            [1.417188415116765, 48.95930576473904],
                            [1.414698630850616, 48.961356389220384],
                            [1.412486882362214, 48.96277747836252],
                            [1.410231549824778, 48.96367173077757],
                            [1.407070133990015, 48.96455857824879],
                            [1.4051462655656, 48.96482369338519],
                            [1.399012747968997, 48.965019245750376],
                            [1.392458157632949, 48.96493023529105],
                            [1.388830095864572, 48.965110808592414],
                            [1.3840126576229, 48.96615877593156],
                            [1.336061743827007, 48.978208695823994],
                            [1.330749314096914, 48.97988185084992],
                            [1.322612609555163, 48.98405673233255],
                            [1.309486739488169, 48.9915927124982],
                            [1.306901327928386, 48.99281736528049],
                            [1.304706682289505, 48.993483936057125],
                            [1.302330190051859, 48.9937744570718],
                            [1.298722574142231, 48.99399137841412],
                            [1.295313697945157, 48.99377323720066],
                            [1.288141926817602, 48.992147909720536],
                            [1.275205610831355, 48.98965769071688],
                            [1.271329887163217, 48.98912252664976],
                            [1.267917431607779, 48.98909071559201],
                            [1.261454096276194, 48.98984131813932],
                            [1.255069018361898, 48.99134103439014],
                            [1.248197231976045, 48.99339732593294],
                            [1.245435718315689, 48.993932589795435],
                            [1.242873386111395, 48.99403292597064],
                            [1.239942892961065, 48.993630518403656],
                            [1.234568521250822, 48.992268606128086],
                            [1.229943035799648, 48.99135044749813],
                            [1.227007216508765, 48.99119723603635],
                            [1.222448708675265, 48.991527326163244],
                            [1.219194754449162, 48.992868304030765],
                            [1.213688135307376, 48.99736927569819],
                            [1.203740609920876, 49.0052578847798],
                            [1.188778939932108, 49.01652726353219],
                            [1.184728842876982, 49.01935679619903],
                            [1.181561058166084, 49.020947179735806],
                            [1.176405545539146, 49.02233017231581],
                            [1.173357077476896, 49.02286081291173],
                            [1.169552647866164, 49.02325888077188],
                            [1.165759960202374, 49.02315777727426],
                            [1.162361496964889, 49.02243663095141],
                            [1.159065402176316, 49.02140445473137],
                            [1.156439329666474, 49.020129505355506],
                            [1.154369058556744, 49.019421796733006],
                            [1.149003549412462, 49.018420291805135],
                        ],
                    },
                },
                512: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.76624571222825, 2.1546265860375127],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1535.54348104,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.146831644750671,
                            48.764776012952915,
                            2.163947085881832,
                            48.77042520300475,
                        ),
                        "coordinates": [
                            [2.146831644750671, 48.77042520300475],
                            [2.146839575361204, 48.770321959612254],
                            [2.146873092690811, 48.770093682186655],
                            [2.14693520256974, 48.76985347182722],
                            [2.147032885748731, 48.7695758827279],
                            [2.147161777495458, 48.769310810798224],
                            [2.147427373432981, 48.768871505640504],
                            [2.147572381326453, 48.76866041672841],
                            [2.147691286307381, 48.768515830601466],
                            [2.147863449005765, 48.76831827559078],
                            [2.147993178295162, 48.76818899483355],
                            [2.14829351412852, 48.76791251510234],
                            [2.148440898967235, 48.76779045723079],
                            [2.148595671417843, 48.767662475921256],
                            [2.148751952214536, 48.767556260007716],
                            [2.14907649251712, 48.767352659983054],
                            [2.149560438791216, 48.76708367301127],
                            [2.14979685464987, 48.766972065613906],
                            [2.150079001396661, 48.76686020301495],
                            [2.150327388968289, 48.76676194385585],
                            [2.150697958710484, 48.766630916480445],
                            [2.151146005275975, 48.76650883849901],
                            [2.151387073138179, 48.766445477534695],
                            [2.152968950578792, 48.76613509322431],
                            [2.154530379153004, 48.76583095001423],
                            [2.156517878035001, 48.76544202913235],
                            [2.157218934575256, 48.765306445903285],
                            [2.157745735806253, 48.76520745606435],
                            [2.158269800867355, 48.765112055896395],
                            [2.158906826270819, 48.765000643720605],
                            [2.159421272692855, 48.76493130235175],
                            [2.160116648983136, 48.764858642212516],
                            [2.160764321506296, 48.764811983998186],
                            [2.161308536428679, 48.76478584523993],
                            [2.163872745041115, 48.764777178118926],
                            [2.163947085881832, 48.764776012952915],
                        ],
                    },
                },
                513: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.99069825532223, 2.0666198882620925],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1300.81933277,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.05978806303153,
                            48.98705700117252,
                            2.074499463834352,
                            48.99192549246806,
                        ),
                        "coordinates": [
                            [2.05978806303153, 48.98705700117252],
                            [2.05991484049557, 48.98727287854603],
                            [2.060043787433295, 48.9874887601406],
                            [2.060284896578749, 48.98781912204343],
                            [2.060513350739319, 48.9880852092369],
                            [2.060776300253543, 48.98838992544602],
                            [2.061054566006323, 48.98867183651444],
                            [2.061404323859338, 48.98897105064195],
                            [2.061767116749642, 48.98926743932941],
                            [2.062052304929325, 48.98947655530041],
                            [2.062431176203509, 48.98973938876656],
                            [2.062759152206382, 48.98993080413802],
                            [2.063147265516642, 48.99015245589833],
                            [2.063613486489634, 48.99039253863686],
                            [2.064111211082558, 48.99061500655352],
                            [2.064699994766732, 48.99084768120881],
                            [2.065249962912493, 48.99103886021585],
                            [2.065732928729662, 48.99118562235484],
                            [2.066192158383023, 48.99130948396328],
                            [2.066925221637417, 48.991476613489915],
                            [2.06730452282478, 48.99153937134352],
                            [2.067746121113482, 48.9915937173418],
                            [2.068468804924978, 48.99167631149164],
                            [2.069130201799466, 48.991725447724946],
                            [2.069856773892852, 48.99175807585139],
                            [2.071985128391772, 48.99184771918191],
                            [2.073620620466596, 48.99189837244827],
                            [2.074499463834352, 48.99192549246806],
                        ],
                    },
                },
                514: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9736197317407, 2.0155419615449826],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2158.77493621,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.00593089306856,
                            48.9703669339495,
                            2.027518775677185,
                            48.98107191008835,
                        ),
                        "coordinates": [
                            [2.00593089306856, 48.98107191008835],
                            [2.00632553617416, 48.980643534398844],
                            [2.006774079107144, 48.98005522334414],
                            [2.007819102789939, 48.97847786047376],
                            [2.009232325584228, 48.976307654684994],
                            [2.009525576746523, 48.97590733369938],
                            [2.009842546382175, 48.975527065878424],
                            [2.010117771867198, 48.975228052716346],
                            [2.010462650387159, 48.97488926491349],
                            [2.010713534259615, 48.97466298937024],
                            [2.011082017997406, 48.974361384128606],
                            [2.011406825104223, 48.9741053365819],
                            [2.011785900151924, 48.973840878104575],
                            [2.012112596514757, 48.973626235974045],
                            [2.012434852931297, 48.97342728324033],
                            [2.01285498737829, 48.97318292497152],
                            [2.013233617255454, 48.97298412915656],
                            [2.0136708895827, 48.97277122333888],
                            [2.014092829344619, 48.97258111381198],
                            [2.014610374689509, 48.9723612923108],
                            [2.015079929813678, 48.97218416242056],
                            [2.015592834661504, 48.972010007046315],
                            [2.016066499163984, 48.97186714679403],
                            [2.016839947144251, 48.97165211804439],
                            [2.017167836944298, 48.97157328519476],
                            [2.017471836182582, 48.97150989269007],
                            [2.018058049805687, 48.97139874562907],
                            [2.018609427118438, 48.97130891354083],
                            [2.019245335641266, 48.97122502388581],
                            [2.020102489934215, 48.97113175057434],
                            [2.021289557139614, 48.97100063887289],
                            [2.025535274501641, 48.97056971191711],
                            [2.027484526486944, 48.970370375718026],
                            [2.027518775677185, 48.9703669339495],
                        ],
                    },
                },
                515: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96953947194933, 2.3118606772568446],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 994.155034711,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307137032071533,
                            48.966326544842126,
                            2.3165820711557,
                            48.972749119759264,
                        ),
                        "coordinates": [
                            [2.3165820711557, 48.966326544842126],
                            [2.316484910128924, 48.96639374526073],
                            [2.315909726745558, 48.966785727178284],
                            [2.314688285531393, 48.96762002714814],
                            [2.313242728158259, 48.96859725303137],
                            [2.312868353708528, 48.96884357757444],
                            [2.311414516053476, 48.96984595844002],
                            [2.310403360643432, 48.97053097845368],
                            [2.309758391346334, 48.97097057431772],
                            [2.308411024472593, 48.971888410684016],
                            [2.307137032071533, 48.972749119759264],
                        ],
                    },
                },
                516: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.72750703493137, 2.26015897022313],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 651.563967896,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.257355188147784,
                            48.725197641013786,
                            2.263073689251946,
                            48.72964839824706,
                        ),
                        "coordinates": [
                            [2.257355188147784, 48.725197641013786],
                            [2.257778713275225, 48.725547753209774],
                            [2.258437089058175, 48.72609226903183],
                            [2.259125337391235, 48.72666647771476],
                            [2.259658835692192, 48.72711557836338],
                            [2.260258879362076, 48.727610583675755],
                            [2.260709586199597, 48.727990379614496],
                            [2.261194250005631, 48.728392677946474],
                            [2.261434550189701, 48.728589778298236],
                            [2.261592038535468, 48.72871847896838],
                            [2.261847279907502, 48.72892548037518],
                            [2.262065880253492, 48.729093788299494],
                            [2.262255984973359, 48.72922970366661],
                            [2.26236055272001, 48.72929811624791],
                            [2.262497724590652, 48.72937914095845],
                            [2.26269196666858, 48.72947638904561],
                            [2.262848181870324, 48.72955023184723],
                            [2.263073689251946, 48.72964839824706],
                        ],
                    },
                },
                517: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [49.119528029414795, 2.7695464102952547],
                        "indice_lig": "K",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 6344.4941702,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.744686207442424,
                            49.09612080982236,
                            2.79445455010732,
                            49.14288419832467,
                        ),
                        "coordinates": [
                            [2.744686207442424, 49.09612080982236],
                            [2.773384646069196, 49.12318256364633],
                            [2.79445455010732, 49.14288419832467],
                        ],
                    },
                },
                518: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.79561895210037, 2.1457117776728842],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 535.527430639,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.142141851963426,
                            48.795008319405504,
                            2.149209553856219,
                            48.79577385878627,
                        ),
                        "coordinates": [
                            [2.142141851963426, 48.795715917344765],
                            [2.143545354279527, 48.79574977214138],
                            [2.144716461319213, 48.79576745697119],
                            [2.145126997753335, 48.79577385878627],
                            [2.145509491523887, 48.79576736335071],
                            [2.145925753035134, 48.79574480148314],
                            [2.146350271001891, 48.795711667769446],
                            [2.146745880988852, 48.795665217989395],
                            [2.14702908603024, 48.79562999898825],
                            [2.147388032470583, 48.79556492640698],
                            [2.147876801576748, 48.79545438535117],
                            [2.148307251549837, 48.7953366063917],
                            [2.148664217539964, 48.795222988440685],
                            [2.148999626930769, 48.79509505632212],
                            [2.149209553856219, 48.795008319405504],
                        ],
                    },
                },
                519: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.14650771750431, 2.2741864231908275],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 595.523865267,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.270552769414137,
                            49.14528660789949,
                            2.277823190629399,
                            49.14771950559884,
                        ),
                        "coordinates": [
                            [2.277823190629399, 49.14771950559884],
                            [2.274722501708344, 49.1466929168685],
                            [2.272897367866637, 49.14607591620477],
                            [2.272135537078627, 49.14582009680996],
                            [2.271873832060084, 49.14573182144427],
                            [2.270948962714028, 49.145420146775926],
                            [2.270552769414137, 49.14528660789949],
                        ],
                    },
                },
                520: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.37482480188876, 2.875600021721714],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 9994.39269455,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.815956767081606,
                            48.367190895517794,
                            2.936180968314843,
                            48.38576231209905,
                        ),
                        "coordinates": [
                            [2.815956767081606, 48.38235800575609],
                            [2.816424735307878, 48.38260704631034],
                            [2.816686619743611, 48.38274711897492],
                            [2.817732785995672, 48.38330380916832],
                            [2.818247720099427, 48.38357399930214],
                            [2.818701355416031, 48.38381088731778],
                            [2.819172416306831, 48.38406204557408],
                            [2.819534605990315, 48.38422972009238],
                            [2.819915115535525, 48.384400542280574],
                            [2.820225829996955, 48.38452426113052],
                            [2.820514491860014, 48.38463902999724],
                            [2.821149782071103, 48.384859326138624],
                            [2.821484202591806, 48.38496225715613],
                            [2.821828181435355, 48.38506567841368],
                            [2.822163849218797, 48.385158027409496],
                            [2.822403379741653, 48.38521724943301],
                            [2.822747104849736, 48.38530120228682],
                            [2.823056366079861, 48.38536902643884],
                            [2.823293644064093, 48.38541665459795],
                            [2.823789939754715, 48.38550931205613],
                            [2.824378096823145, 48.38559273435663],
                            [2.824769976531524, 48.38564308507773],
                            [2.825281492634446, 48.38568688223101],
                            [2.825905045650505, 48.385734517826],
                            [2.826426367653502, 48.38575474310667],
                            [2.826962416347579, 48.38576231209905],
                            [2.827803356234711, 48.38574697272214],
                            [2.828547590654962, 48.3857046916981],
                            [2.828952865177653, 48.38567093483378],
                            [2.829430281415242, 48.385619395807865],
                            [2.829941288275303, 48.385551522704255],
                            [2.830925178770439, 48.38538356300131],
                            [2.831800814082275, 48.38519088859024],
                            [2.832387858016491, 48.385030946664074],
                            [2.833067574027909, 48.38482293504924],
                            [2.833807491435419, 48.38455979995775],
                            [2.834556405948256, 48.38425165668802],
                            [2.835101479502257, 48.383989346134804],
                            [2.835465911472907, 48.38380251700426],
                            [2.835883477780491, 48.38357226285843],
                            [2.836381328823507, 48.38327061103163],
                            [2.837183663688102, 48.38277247106844],
                            [2.838489090354446, 48.38196095166346],
                            [2.839433734655103, 48.38138842474266],
                            [2.840227675569959, 48.38086691998524],
                            [2.84384326547858, 48.37864038740063],
                            [2.845951723326151, 48.37730450692988],
                            [2.847675446156696, 48.37624100253817],
                            [2.849355979695551, 48.37518486138256],
                            [2.850253379871377, 48.374636737845584],
                            [2.851336325745876, 48.374020319647386],
                            [2.85170721895275, 48.3738302769835],
                            [2.852243571951266, 48.37356047862151],
                            [2.8528904187244, 48.37325773732393],
                            [2.853665494540937, 48.37292249151412],
                            [2.854820101836237, 48.37245678717978],
                            [2.855586807701359, 48.37217789511868],
                            [2.856269820121924, 48.3719474496943],
                            [2.8569066778139, 48.37175227418366],
                            [2.857722982746169, 48.37151271626407],
                            [2.858257315542556, 48.371369069154426],
                            [2.858825911138618, 48.371226849552],
                            [2.859470290627415, 48.371079220039874],
                            [2.860460231875475, 48.370874186211964],
                            [2.861092031287584, 48.370759749310494],
                            [2.861539374687759, 48.37068843136944],
                            [2.861901401257238, 48.370634042437366],
                            [2.862285058996281, 48.37057957767159],
                            [2.86258781687, 48.37053608128211],
                            [2.862851330832802, 48.37049874561821],
                            [2.863133619996968, 48.37045890294477],
                            [2.863621362567767, 48.370397561677],
                            [2.864124443119251, 48.37034412260346],
                            [2.864948172674665, 48.3702606964414],
                            [2.866028112343367, 48.37015380644426],
                            [2.869502385497447, 48.36979779202158],
                            [2.872189339257764, 48.36952791040866],
                            [2.874577611794342, 48.369279632274406],
                            [2.876936191285402, 48.369044009271725],
                            [2.87951785843928, 48.36877985203348],
                            [2.882214043694582, 48.3684997956207],
                            [2.884486948050287, 48.36826758800281],
                            [2.886239425890192, 48.368084627715355],
                            [2.889593405878244, 48.367738247645434],
                            [2.890785086308874, 48.367615510424265],
                            [2.892784229813828, 48.36740875778046],
                            [2.893934110382386, 48.36729068878646],
                            [2.894348067756967, 48.36725807255834],
                            [2.89472686378117, 48.36723291532234],
                            [2.895159330427727, 48.36721305672575],
                            [2.895516362794517, 48.367202332033536],
                            [2.895887216759905, 48.36719381723744],
                            [2.896296104355527, 48.367190895517794],
                            [2.896630829926781, 48.36719373407371],
                            [2.896972393402851, 48.367204631600664],
                            [2.897319276246225, 48.36721998258931],
                            [2.897780581900788, 48.36724684920646],
                            [2.898341649485913, 48.367289131164],
                            [2.898760567895927, 48.367324350745825],
                            [2.899168620433533, 48.367367284286274],
                            [2.899466014569671, 48.36741076766648],
                            [2.899971586675504, 48.36748468706781],
                            [2.900554385518433, 48.3675851963135],
                            [2.901088623459158, 48.36768774223018],
                            [2.901503966466886, 48.36777829135195],
                            [2.901949241889289, 48.367890271749445],
                            [2.902706075460861, 48.368104104309424],
                            [2.903112320908136, 48.36822344095219],
                            [2.903559309957025, 48.36836870673431],
                            [2.904063428026052, 48.368551424995935],
                            [2.9044930906711, 48.36871383194075],
                            [2.904890141905091, 48.368879294350585],
                            [2.905290428340586, 48.3690461471033],
                            [2.906096300471423, 48.36941618275929],
                            [2.907002482536981, 48.369823475445216],
                            [2.907650899539358, 48.37011246104281],
                            [2.908101301584673, 48.370316115869144],
                            [2.909147253230239, 48.37078653274147],
                            [2.909651959922243, 48.37101688433679],
                            [2.910746844181375, 48.37151491553284],
                            [2.911925839557148, 48.372048477853575],
                            [2.91294747502414, 48.37251089107902],
                            [2.913885017897449, 48.372935954214995],
                            [2.916169838504803, 48.373964710637104],
                            [2.918486004377086, 48.375011245657966],
                            [2.919706440050377, 48.37556171379814],
                            [2.920656346519714, 48.37598977790715],
                            [2.92127583874443, 48.37627110906197],
                            [2.922970106203779, 48.37704901359043],
                            [2.92376068324006, 48.377410188137695],
                            [2.924331942854127, 48.37765671745608],
                            [2.924878436399788, 48.377877391369225],
                            [2.925400474669468, 48.37807700840293],
                            [2.925899382666067, 48.37826055662401],
                            [2.926722567216694, 48.37853503866487],
                            [2.927543233443624, 48.378808621808815],
                            [2.928357499789204, 48.379061552283645],
                            [2.92869411293988, 48.37916045507439],
                            [2.929052215263586, 48.379249458040334],
                            [2.92940549484377, 48.37933033837415],
                            [2.929988734516592, 48.37945137755812],
                            [2.930428417366936, 48.37953270078945],
                            [2.930849011442576, 48.37959793585176],
                            [2.931328904293654, 48.37965476393379],
                            [2.931885760246334, 48.3797129838341],
                            [2.932321075490881, 48.37975628624159],
                            [2.932764914470996, 48.3797944412437],
                            [2.933469822259073, 48.37983598023287],
                            [2.933945729794594, 48.37986443321458],
                            [2.934666232192033, 48.3799096381512],
                            [2.936180968314843, 48.37999957527981],
                        ],
                    },
                },
                521: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.37935127537549, 2.8078546326901286],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 1374.7591127,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.799307429283779,
                            48.37816709633966,
                            2.815956767081606,
                            48.38235800575609,
                        ),
                        "coordinates": [
                            [2.799307429283779, 48.37859776792736],
                            [2.799803327928466, 48.378487925384775],
                            [2.800366205602521, 48.37839574452107],
                            [2.800948063452046, 48.37831294951513],
                            [2.801847561834057, 48.37822022703036],
                            [2.802327896533707, 48.378190193475696],
                            [2.803018317163776, 48.37816954367282],
                            [2.803611332627112, 48.37816709633966],
                            [2.8044930312979, 48.37819312775507],
                            [2.805257482986111, 48.37823942142173],
                            [2.805934010057579, 48.378313709972595],
                            [2.806594191757865, 48.37842092050679],
                            [2.806910635712471, 48.3784825524816],
                            [2.807186705936732, 48.37853641579208],
                            [2.807551194220757, 48.3786186737446],
                            [2.807903431398984, 48.378695140179275],
                            [2.808287262620804, 48.378793671789765],
                            [2.808628543499887, 48.37888512406479],
                            [2.808902176344857, 48.37896524732036],
                            [2.809241587874725, 48.37906965466149],
                            [2.809650949017997, 48.379208514074946],
                            [2.809885694672334, 48.379293354367505],
                            [2.810210371582848, 48.37941210222083],
                            [2.810473299640536, 48.379523408186195],
                            [2.810726550726919, 48.37963326581886],
                            [2.811046045893848, 48.37977749273188],
                            [2.811350410874251, 48.37991810047534],
                            [2.811656440634826, 48.38007248502223],
                            [2.812060016684274, 48.380291481722075],
                            [2.812336511570756, 48.380447351580074],
                            [2.812648811678011, 48.38061258812495],
                            [2.812975400167187, 48.380777763598246],
                            [2.813505941425138, 48.38105314749179],
                            [2.814195510599813, 48.38142357181096],
                            [2.814697122491966, 48.38168763282923],
                            [2.815956767081606, 48.38235800575609],
                        ],
                    },
                },
                522: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89294686080906, 2.305586250545477],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1589.87147309,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.297419948146663,
                            48.88822016276462,
                            2.313732451520271,
                            48.89763744791706,
                        ),
                        "coordinates": [
                            [2.313732451520271, 48.88822016276462],
                            [2.312557681116819, 48.888904131906834],
                            [2.311861101364987, 48.88931322918998],
                            [2.310471156153221, 48.89009856750011],
                            [2.307915667206252, 48.89156362940108],
                            [2.305782353427846, 48.892812229255576],
                            [2.304508076579762, 48.89358040663048],
                            [2.302399845234058, 48.894833707686736],
                            [2.301472058910227, 48.89536877831059],
                            [2.300746415528593, 48.895794456467286],
                            [2.29982620296289, 48.896307637273466],
                            [2.299147473198817, 48.89669643774181],
                            [2.298473555854997, 48.89706897752753],
                            [2.297419948146663, 48.89763744791706],
                        ],
                    },
                },
                523: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.88090418895253, 2.353041427063082],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 730.354395858,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.349774443646268,
                            48.87955128443897,
                            2.356995164008545,
                            48.88343618805934,
                        ),
                        "coordinates": [
                            [2.356995164008545, 48.87955128443897],
                            [2.356420332250277, 48.879663918069106],
                            [2.352789393950477, 48.88041550835544],
                            [2.352689404185936, 48.880439339651716],
                            [2.352587248426181, 48.880471224358146],
                            [2.352490320689787, 48.88050955758233],
                            [2.352399559522746, 48.88055397478807],
                            [2.352315832033915, 48.880604045403246],
                            [2.352239952815609, 48.88065928641162],
                            [2.352172645700803, 48.880719167541265],
                            [2.352160009091857, 48.880731920931325],
                            [2.351330952404889, 48.881654636006054],
                            [2.349962444616936, 48.883177105711475],
                            [2.349916251084154, 48.88323101163715],
                            [2.34984146137176, 48.88332986903614],
                            [2.349774443646268, 48.88343618805934],
                        ],
                    },
                },
                524: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.865467355279854, 2.3265590778684055],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 577.361014397,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.322943412243542,
                            48.86434377873391,
                            2.330129877112861,
                            48.8663248618999,
                        ),
                        "coordinates": [
                            [2.330129877112861, 48.86434377873391],
                            [2.324503743357648, 48.8661530785242],
                            [2.324199110743277, 48.866251032422134],
                            [2.32409061285608, 48.86627470298067],
                            [2.323978810073658, 48.866293784297405],
                            [2.323863511087636, 48.866308313954285],
                            [2.32374446334513, 48.866318321991415],
                            [2.32362149213093, 48.86632382809508],
                            [2.323494114521328, 48.8663248618999],
                            [2.323361886088394, 48.86632142807381],
                            [2.323224166401826, 48.86631350858956],
                            [2.323087159080612, 48.86630175546584],
                            [2.322943412243542, 48.866285804583875],
                        ],
                    },
                },
                525: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98051337753165, 2.2710598814546117],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 152.960676604,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.270035426257897,
                            48.980377556311645,
                            2.272084772747633,
                            48.980646100425986,
                        ),
                        "coordinates": [
                            [2.272084772747633, 48.980646100425986],
                            [2.2707762199836, 48.980476521543785],
                            [2.270302760898295, 48.98041676450894],
                            [2.270035426257897, 48.980377556311645],
                        ],
                    },
                },
                526: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.844962125626964, 2.434822443863539],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 832.202691149,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.429205166348,
                            48.844456394569114,
                            2.440439978057246,
                            48.84547070758355,
                        ),
                        "coordinates": [
                            [2.440439978057246, 48.844456394569114],
                            [2.437597722890066, 48.844710370771956],
                            [2.432028202918189, 48.84521462510283],
                            [2.429205166348, 48.84547070758355],
                        ],
                    },
                },
                527: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.20757669204192, 2.397248799007376],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 3221.82531252,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.376601177324503,
                            49.20326573346356,
                            2.417369391049351,
                            49.21385632476746,
                        ),
                        "coordinates": [
                            [2.376601177324503, 49.20326573346356],
                            [2.39457318377227, 49.206215051791595],
                            [2.400372701648916, 49.20755996400313],
                            [2.410290586842202, 49.21110779215862],
                            [2.417369391049351, 49.21385632476746],
                        ],
                    },
                },
                528: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.251784937445464, 2.455921196997508],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 3342.80215691,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.44364447306937,
                            49.23889870640681,
                            2.468914115351039,
                            49.26394414450533,
                        ),
                        "coordinates": [
                            [2.44364447306937, 49.23889870640681],
                            [2.450962253011323, 49.24710198287682],
                            [2.458843796152947, 49.25518165120713],
                            [2.468914115351039, 49.26394414450533],
                        ],
                    },
                },
                529: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.379019778726, 2.7978126302895676],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 242.866386249,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.796343615000022,
                            48.37859776792736,
                            2.799307429283779,
                            48.37952262366741,
                        ),
                        "coordinates": [
                            [2.796343615000022, 48.37952262366741],
                            [2.797000319222841, 48.379261615476885],
                            [2.797352123268005, 48.37914233984695],
                            [2.797712535958334, 48.379027793970415],
                            [2.798227371862114, 48.37887612293043],
                            [2.798788288699348, 48.378724651131996],
                            [2.799307429283779, 48.37859776792736],
                        ],
                    },
                },
                530: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.972350639549376, 2.280401604238342],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2567.31368918,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.274714898034236,
                            48.96358968487314,
                            2.285930718208942,
                            48.98054054067926,
                        ),
                        "coordinates": [
                            [2.285930718208942, 48.96358968487314],
                            [2.284744051392272, 48.96396199485136],
                            [2.28437653540835, 48.96407873331059],
                            [2.283299969841325, 48.96438938548],
                            [2.282834068218389, 48.964545640361884],
                            [2.282768484077399, 48.964568990629104],
                            [2.282727497280722, 48.96458156186698],
                            [2.282686510592002, 48.9645932329233],
                            [2.282623660820599, 48.964614785641366],
                            [2.2820443248147, 48.964833034262234],
                            [2.281769669040365, 48.96495070819779],
                            [2.281284556206615, 48.96517799120564],
                            [2.280888234187712, 48.96538912775556],
                            [2.280464103502219, 48.96564214141344],
                            [2.280054482123014, 48.96591929066568],
                            [2.279936916689496, 48.966010958536216],
                            [2.279833018871305, 48.966092741776464],
                            [2.279718166412136, 48.96619969797987],
                            [2.27947615323957, 48.96642529580836],
                            [2.279264167974465, 48.966666194762205],
                            [2.279009731586088, 48.96699969823211],
                            [2.278800387640981, 48.96731344018246],
                            [2.278671686634194, 48.967577761945904],
                            [2.278567574633555, 48.96783759930862],
                            [2.278482566889066, 48.96811183540651],
                            [2.278416683452642, 48.96838428179962],
                            [2.278393207498531, 48.96860189512554],
                            [2.278390445862359, 48.96862707324314],
                            [2.278389041742323, 48.96865944646126],
                            [2.278377932031889, 48.968813217022834],
                            [2.278384431702869, 48.96909379374354],
                            [2.278399296628258, 48.969229592235784],
                            [2.278404663885103, 48.969310529637504],
                            [2.278434533557881, 48.96946432094654],
                            [2.278456271451519, 48.96956325219488],
                            [2.278483479600466, 48.96965679107245],
                            [2.278512042130103, 48.96976022190393],
                            [2.27854471389659, 48.969854663205616],
                            [2.278585543282225, 48.96998058196329],
                            [2.278678174194398, 48.97019645544442],
                            [2.278774552599062, 48.97037856058188],
                            [2.278890002818901, 48.97054993065341],
                            [2.27898741074612, 48.970697499207944],
                            [2.279120921815418, 48.97087839646164],
                            [2.279416862498563, 48.97123782463948],
                            [2.279958297027355, 48.97183530774685],
                            [2.280544168469102, 48.97249683295363],
                            [2.281246775823954, 48.97328673967318],
                            [2.281600667855334, 48.97370151205668],
                            [2.281766681931098, 48.97392287023888],
                            [2.28193989258352, 48.974172783186255],
                            [2.282051716164722, 48.97437270089093],
                            [2.28218875505389, 48.97465114799701],
                            [2.282278870993692, 48.97487247006428],
                            [2.282354507105204, 48.97511519859585],
                            [2.282430082396942, 48.97541265201185],
                            [2.282455103309107, 48.975667251717205],
                            [2.282462121321247, 48.97585998162858],
                            [2.282454708939005, 48.97602653227489],
                            [2.282436448452967, 48.97619783533109],
                            [2.282410919386101, 48.976404826030446],
                            [2.282363616783094, 48.97669032390202],
                            [2.282308934422777, 48.976841435494855],
                            [2.282231654593548, 48.977028197816985],
                            [2.282174122883822, 48.977167558732155],
                            [2.282113850847086, 48.977314111657144],
                            [2.282056355987138, 48.97742019835361],
                            [2.281994751735471, 48.977535276376976],
                            [2.281685517494606, 48.97797127725441],
                            [2.281487167620754, 48.97820229472917],
                            [2.28135996382107, 48.97833622531282],
                            [2.281324405130109, 48.9783703809979],
                            [2.281275167580637, 48.97842071688438],
                            [2.2810768621806, 48.97860766936787],
                            [2.280869013087103, 48.97877663219963],
                            [2.280678951429134, 48.97891952394524],
                            [2.280538132035738, 48.97901028224878],
                            [2.280352196014253, 48.9791279956272],
                            [2.28014985878131, 48.979251995911085],
                            [2.27985456281361, 48.97942451025561],
                            [2.279631736005457, 48.97954310350527],
                            [2.279400716345353, 48.979656297441934],
                            [2.279105481435691, 48.979772155318614],
                            [2.278791122163645, 48.97988530583007],
                            [2.278423471630917, 48.98000382366384],
                            [2.278088640724288, 48.980095378541805],
                            [2.277707545186733, 48.980178506665645],
                            [2.277316553543077, 48.980241561913665],
                            [2.276361438381218, 48.98034717701068],
                            [2.27545275701002, 48.980463600667505],
                            [2.274714898034236, 48.98054054067926],
                        ],
                    },
                },
                531: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.211842527156136, 1.9133246238964994],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 2370.17439218,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.905299061887723,
                            49.20269360297641,
                            1.920547706067206,
                            49.22080705063383,
                        ),
                        "coordinates": [
                            [1.920547706067206, 49.20269360297641],
                            [1.919863356103738, 49.20626720879595],
                            [1.91858537541633, 49.2081007258882],
                            [1.915620052641178, 49.210387598587296],
                            [1.910685707856781, 49.21321856379709],
                            [1.908419578399681, 49.21569165789381],
                            [1.905299061887723, 49.22080705063383],
                        ],
                    },
                },
                532: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.93233098386442, 2.440228169391454],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2149.90241574,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.425791425559954,
                            48.93073957031752,
                            2.454766382765777,
                            48.93276675757436,
                        ),
                        "coordinates": [
                            [2.425791425559954, 48.93073957031752],
                            [2.428528152212983, 48.93121178102294],
                            [2.430449835739028, 48.931570316835035],
                            [2.431520359358567, 48.931769964868174],
                            [2.433019732132433, 48.93203392978435],
                            [2.433756318582966, 48.93215836933001],
                            [2.434427421807771, 48.93226561039017],
                            [2.435154163202631, 48.93237280145819],
                            [2.436119854435582, 48.93250134014763],
                            [2.436673064985291, 48.932565545240536],
                            [2.437330991420099, 48.93262534376327],
                            [2.438231110321013, 48.932689237300416],
                            [2.439023182895177, 48.932729502346184],
                            [2.439838142529295, 48.93275895904921],
                            [2.440751239867408, 48.93276675757436],
                            [2.441906477903701, 48.93275707894835],
                            [2.443500240424713, 48.93274051079149],
                            [2.446327784323606, 48.932714121405446],
                            [2.447404462303159, 48.93269799355768],
                            [2.448147360264926, 48.932697272787074],
                            [2.448936099679803, 48.93270728607904],
                            [2.450788480793716, 48.93272486113904],
                            [2.453118638538401, 48.93272683062279],
                            [2.454766382765777, 48.93270621869947],
                        ],
                    },
                },
                533: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.84053852951299, 2.2584228907263637],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 596.257184067,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.257122229832621,
                            48.83796121443631,
                            2.260032902225193,
                            48.84293869496324,
                        ),
                        "coordinates": [
                            [2.257122229832621, 48.83796121443631],
                            [2.257180134477699, 48.83803242595932],
                            [2.257228135768131, 48.83810677683106],
                            [2.257265848436255, 48.83818366928417],
                            [2.257272143181162, 48.83819933861754],
                            [2.257343199456321, 48.838382862066304],
                            [2.258050796054621, 48.84021035557994],
                            [2.258421101809776, 48.84075661094537],
                            [2.258918312511774, 48.84153395348918],
                            [2.259447510455384, 48.84221331320571],
                            [2.259608472752572, 48.84241277035873],
                            [2.260032902225193, 48.84293869496324],
                        ],
                    },
                },
                534: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.119528029414795, 2.7695464102952547],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 6344.4941702,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.744686207442424,
                            49.09612080982236,
                            2.79445455010732,
                            49.14288419832467,
                        ),
                        "coordinates": [
                            [2.744686207442424, 49.09612080982236],
                            [2.773384646069196, 49.12318256364633],
                            [2.79445455010732, 49.14288419832467],
                        ],
                    },
                },
                535: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.798210947640875, 2.0691567761066767],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 412.815831932,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.066485347074011,
                            48.79761321151646,
                            2.071847005929401,
                            48.79870763528835,
                        ),
                        "coordinates": [
                            [2.066485347074011, 48.79761321151646],
                            [2.067965653930496, 48.797961639157485],
                            [2.069370074197862, 48.79828149046026],
                            [2.069903062061266, 48.79839604889063],
                            [2.070856322002004, 48.79857633553913],
                            [2.071332370669918, 48.79864848827117],
                            [2.071695582347995, 48.79869339867155],
                            [2.071847005929401, 48.79870763528835],
                        ],
                    },
                },
                536: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.85344982005697, 2.3874719070377526],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 376.545796366,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.385563480833491,
                            48.85231542739917,
                            2.389378127918613,
                            48.854580498181704,
                        ),
                        "coordinates": [
                            [2.385563480833491, 48.854580498181704],
                            [2.387414302643781, 48.85348653654734],
                            [2.389378127918613, 48.85231542739917],
                        ],
                    },
                },
                537: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.53772572523229, 3.270844147915459],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3252.84546959,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.255368150025012,
                            48.52914896682657,
                            3.287312848478531,
                            48.54559534692547,
                        ),
                        "coordinates": [
                            [3.255368150025012, 48.52914896682657],
                            [3.255690089588158, 48.52935320174904],
                            [3.25602354297575, 48.529527262609776],
                            [3.256402560125219, 48.52969681903616],
                            [3.256828379538952, 48.529864684489255],
                            [3.25722493329347, 48.529999473179565],
                            [3.25760322964848, 48.53011537394126],
                            [3.257991717162337, 48.53022664555353],
                            [3.258449791736273, 48.53032274623187],
                            [3.258779947190074, 48.53038391249398],
                            [3.259128806856056, 48.53043143550042],
                            [3.259408141998831, 48.530453443435675],
                            [3.259736182160061, 48.53047325550467],
                            [3.260351691178092, 48.530501323485346],
                            [3.260831410569387, 48.53052168365509],
                            [3.261220347061276, 48.530554687910474],
                            [3.261639775358048, 48.53061062052243],
                            [3.26216968109057, 48.53070971705964],
                            [3.262614429562589, 48.530816701526504],
                            [3.263003723686052, 48.53092683588099],
                            [3.263375522516217, 48.531051995524656],
                            [3.263685421679234, 48.531179368419025],
                            [3.263865596088829, 48.53125703553626],
                            [3.26419871780733, 48.531404497902145],
                            [3.264685907534571, 48.53168199889534],
                            [3.26507928515967, 48.531938683101195],
                            [3.265433872537972, 48.53222086462935],
                            [3.265801567799281, 48.53255240052916],
                            [3.266112738689205, 48.532902386052214],
                            [3.266341225324263, 48.53324765235497],
                            [3.266486174939783, 48.53346949689121],
                            [3.266604146961927, 48.53369695837147],
                            [3.26670492126056, 48.53394614427062],
                            [3.266766783458831, 48.53414169038891],
                            [3.266807417949374, 48.53428794794007],
                            [3.266846566316326, 48.534499867670725],
                            [3.266867794175553, 48.53462200171069],
                            [3.266886030864735, 48.53472887221476],
                            [3.266913195120464, 48.53517021944645],
                            [3.266947965302395, 48.5356564713358],
                            [3.266960754447912, 48.5359072790684],
                            [3.266999987747873, 48.53634223160657],
                            [3.267036133351005, 48.536597119371606],
                            [3.26713823286924, 48.53700390160913],
                            [3.26722358754864, 48.537224435577514],
                            [3.267287562092798, 48.537387588056625],
                            [3.267484065632095, 48.537759196615404],
                            [3.267646285942883, 48.53803485736007],
                            [3.26791320474016, 48.53840588641006],
                            [3.268341580061928, 48.538865520587166],
                            [3.268457313031621, 48.53897158931293],
                            [3.268541383922185, 48.53905003889695],
                            [3.26862956785558, 48.539131152644025],
                            [3.269003452069697, 48.539427554617],
                            [3.269428944902274, 48.539731625092585],
                            [3.269995558012287, 48.54012487618467],
                            [3.270450869254986, 48.540427386365785],
                            [3.270776785868712, 48.54061985476306],
                            [3.271169140056286, 48.540816272784134],
                            [3.271634434834693, 48.54100219405207],
                            [3.272013112575873, 48.541118681519286],
                            [3.272494838702689, 48.54124151111355],
                            [3.272915925673128, 48.541308181205274],
                            [3.273214706008951, 48.5413524779723],
                            [3.273446713134813, 48.541374843174474],
                            [3.273880636760325, 48.54140363282713],
                            [3.274364629843324, 48.54143020669234],
                            [3.275008610449638, 48.54146624726361],
                            [3.275514286412088, 48.54149353723249],
                            [3.275838393964453, 48.54151603337482],
                            [3.276183015119749, 48.54154915076131],
                            [3.276444951197132, 48.54157845632615],
                            [3.27680893660531, 48.54163299505676],
                            [3.277186718020794, 48.54170090856699],
                            [3.277360789644695, 48.541739034748545],
                            [3.277836739944862, 48.54185750584774],
                            [3.278238684146535, 48.541970068945105],
                            [3.278578433637547, 48.5420826306666],
                            [3.278895761533684, 48.54219753609615],
                            [3.279653256206776, 48.54250690293604],
                            [3.280540133744272, 48.542853858477905],
                            [3.281222371344977, 48.5431215727747],
                            [3.281921020027558, 48.54339723955717],
                            [3.282364456002428, 48.543569810059196],
                            [3.282854294994619, 48.54376087785212],
                            [3.283701360478453, 48.54409582488643],
                            [3.284452369935438, 48.5443986445424],
                            [3.285056778986954, 48.544631013290136],
                            [3.286469421507604, 48.545201054831054],
                            [3.286943123611345, 48.54541013667705],
                            [3.287312848478531, 48.54559534692547],
                        ],
                    },
                },
                538: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.73820855442225, 2.443557312087149],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 1845.03556701,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.438344239163614,
                            48.73011683142026,
                            2.446290833250972,
                            48.745230819408114,
                        ),
                        "coordinates": [
                            [2.446135830934545, 48.73011683142026],
                            [2.446160508450207, 48.730246306539605],
                            [2.446222422872905, 48.730584373317015],
                            [2.446248693104217, 48.73078578508506],
                            [2.446269528987294, 48.730988100725234],
                            [2.446269615326568, 48.73102766850042],
                            [2.446272415584877, 48.73106453614594],
                            [2.446273879119162, 48.73111219629473],
                            [2.446282312306956, 48.73123808629105],
                            [2.446290833250972, 48.73140354404188],
                            [2.446288478243837, 48.73156901247847],
                            [2.446287565201259, 48.73177224885048],
                            [2.446281302495835, 48.73201505829245],
                            [2.446276313061863, 48.73221919760409],
                            [2.446266041324861, 48.73249348589149],
                            [2.446236631618638, 48.73278306037673],
                            [2.446215780519422, 48.73300213223851],
                            [2.446167245499712, 48.73337190552676],
                            [2.446119054693386, 48.73387110074781],
                            [2.446088788355104, 48.73425220060114],
                            [2.446034357101834, 48.734706818113786],
                            [2.446017268650283, 48.734973918225386],
                            [2.446004070876241, 48.73515468476403],
                            [2.445977310335536, 48.735350751647665],
                            [2.445939762913628, 48.735587296248184],
                            [2.445860381998591, 48.73596596659345],
                            [2.445774256046163, 48.73636982210687],
                            [2.445666632296345, 48.73689060437912],
                            [2.445607303913415, 48.73711547885987],
                            [2.445570889406429, 48.73724950585651],
                            [2.445510137380059, 48.73744560510114],
                            [2.445462812981973, 48.737565253314656],
                            [2.445383029303381, 48.73776227050722],
                            [2.445289642676271, 48.73795660254881],
                            [2.445154201945167, 48.73819413957204],
                            [2.445018685233024, 48.73839750464062],
                            [2.444904842413411, 48.738563978272616],
                            [2.444744830478017, 48.738757473784304],
                            [2.444580700532257, 48.73893388758578],
                            [2.444396194167901, 48.73911841366572],
                            [2.444231998310451, 48.7392651506375],
                            [2.444055585243407, 48.739420891395646],
                            [2.44383707055715, 48.73959915370179],
                            [2.443611736536056, 48.739768429021964],
                            [2.443360601504762, 48.739953015220834],
                            [2.442567756625349, 48.74050770886944],
                            [2.441554548523095, 48.741237240206225],
                            [2.441230557603763, 48.74148465724214],
                            [2.440953696087649, 48.74172861447228],
                            [2.440766405962939, 48.74189425143231],
                            [2.440610371240031, 48.74205176693014],
                            [2.440486911126692, 48.742182274655434],
                            [2.440334983952946, 48.74235417387515],
                            [2.440150509190862, 48.7425674696153],
                            [2.439631097472172, 48.74322261156942],
                            [2.439130624977952, 48.74383726739878],
                            [2.438931269855138, 48.744093739458705],
                            [2.438784855113378, 48.744306998508705],
                            [2.438679150644873, 48.744480652452346],
                            [2.438584332826893, 48.7446596929051],
                            [2.438505805511379, 48.74482522934107],
                            [2.438443153463417, 48.744956580996465],
                            [2.438393051958888, 48.745087488858424],
                            [2.438344239163614, 48.745230819408114],
                        ],
                    },
                },
                539: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.52158068866654, 3.2505783568111797],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1877.38012346,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.247853391787192,
                            48.51375459097529,
                            3.255368150025012,
                            48.52914896682657,
                        ),
                        "coordinates": [
                            [3.250034982583049, 48.51375459097529],
                            [3.248816277594826, 48.51484858392043],
                            [3.248538546011257, 48.51513397648663],
                            [3.248343744047987, 48.51540646055068],
                            [3.248158972694217, 48.51571742642379],
                            [3.248038534365448, 48.51598727440681],
                            [3.24794704751838, 48.51627354669993],
                            [3.24789796717411, 48.51652854362541],
                            [3.247859672820045, 48.5167858344146],
                            [3.247853391787192, 48.51703096977457],
                            [3.247879556513874, 48.51728774190833],
                            [3.247953746796779, 48.51762502908779],
                            [3.24809120166248, 48.518092677645775],
                            [3.248253179758422, 48.51872669208497],
                            [3.248413599749815, 48.51927505821372],
                            [3.24866377301091, 48.5198345987809],
                            [3.248999511928741, 48.52037203476526],
                            [3.249467595737235, 48.521140494910206],
                            [3.249856056594523, 48.52173001996007],
                            [3.250304241028161, 48.52240179949549],
                            [3.250807649820171, 48.523131588643025],
                            [3.251478328830027, 48.52412352769819],
                            [3.25214477375392, 48.525104705067804],
                            [3.252755550341988, 48.526001792291844],
                            [3.253622488302022, 48.527281715765],
                            [3.253876962577198, 48.527647480229035],
                            [3.254096758049422, 48.527967659279405],
                            [3.254264503322671, 48.52818124055689],
                            [3.254443956038005, 48.52836864583034],
                            [3.2547183540695, 48.52863891875573],
                            [3.25499495153409, 48.52888129493217],
                            [3.255368150025012, 48.52914896682657],
                        ],
                    },
                },
                540: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.551489104389844, 3.2946261826903953],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1653.67622259,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.287312848478531,
                            48.54559534692547,
                            3.302871222591063,
                            48.555591556048306,
                        ),
                        "coordinates": [
                            [3.287312848478531, 48.54559534692547],
                            [3.287568655372128, 48.545741331629586],
                            [3.287781074265248, 48.545871752151996],
                            [3.28805412293034, 48.54605652197306],
                            [3.288350727669155, 48.5462689730041],
                            [3.288585861797545, 48.54645406016901],
                            [3.288813437506623, 48.546668888605055],
                            [3.289182919080543, 48.54700932945987],
                            [3.289633144769486, 48.5474642056814],
                            [3.290091196706864, 48.54790282654034],
                            [3.290595938057459, 48.54837432830119],
                            [3.2911091399494, 48.54886284297508],
                            [3.291656039296536, 48.549413126548004],
                            [3.292305833014094, 48.5500308897694],
                            [3.292758326298606, 48.550459654026724],
                            [3.293304969496752, 48.550994643779305],
                            [3.293691263768697, 48.551361010152284],
                            [3.294175877368175, 48.55183896093851],
                            [3.294671146706245, 48.55230692775362],
                            [3.295108729768593, 48.55273311149466],
                            [3.295594355034449, 48.55312111553125],
                            [3.295987032983331, 48.55339478899385],
                            [3.296443564877925, 48.5536778130241],
                            [3.296984386598901, 48.55397630953523],
                            [3.29748097495064, 48.55422841325643],
                            [3.298102629630461, 48.554502837086645],
                            [3.298666052427576, 48.554707603486236],
                            [3.298989294076225, 48.55482087434832],
                            [3.299546543826789, 48.55498611825275],
                            [3.299866457615405, 48.55506703976932],
                            [3.3002645573872, 48.55516184566639],
                            [3.300777998014327, 48.555268838196255],
                            [3.30156471015599, 48.55538985366729],
                            [3.302871222591063, 48.555591556048306],
                        ],
                    },
                },
                541: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.84075398192878, 2.3821120728587526],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 1562.68275091,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37359365326228,
                            48.83631546891676,
                            2.390345965998709,
                            48.844760171266735,
                        ),
                        "coordinates": [
                            [2.390345965998709, 48.83631546891676],
                            [2.390322929581464, 48.83633675636582],
                            [2.390158249950645, 48.836481616539544],
                            [2.389728192331321, 48.83687839803796],
                            [2.389559430812823, 48.83703135416416],
                            [2.389201465208559, 48.83733277687348],
                            [2.388881582141247, 48.83757842565034],
                            [2.388281229299247, 48.83798786961311],
                            [2.387935402598586, 48.83818406832291],
                            [2.386841850262587, 48.83882705395043],
                            [2.386514484093897, 48.8390122044851],
                            [2.385941336398595, 48.83934528783985],
                            [2.385664407602353, 48.83950159154659],
                            [2.385376154010946, 48.83965646848244],
                            [2.385084960968584, 48.83979923678294],
                            [2.384800338585216, 48.83992541615458],
                            [2.384555820141204, 48.84001845285108],
                            [2.384259637093709, 48.840114886218764],
                            [2.383909724229494, 48.840202786000205],
                            [2.382814975447521, 48.84052178704328],
                            [2.381839650695112, 48.84084715024368],
                            [2.38076957311166, 48.84130074324963],
                            [2.380128429862727, 48.84158422258861],
                            [2.378445931810589, 48.84225835991038],
                            [2.378168448063484, 48.84235839358047],
                            [2.377887353385376, 48.842453669995514],
                            [2.377656724215145, 48.842546547088354],
                            [2.377397272353561, 48.842663227287424],
                            [2.377173867342697, 48.842777516129416],
                            [2.376892820797989, 48.842937031726265],
                            [2.375373218520609, 48.843777162757696],
                            [2.37359365326228, 48.844760171266735],
                        ],
                    },
                },
                542: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.83183879807555, 2.38114917370817],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 902.090274378,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.375748144341913,
                            48.829990281683564,
                            2.386632402066985,
                            48.83333855925167,
                        ),
                        "coordinates": [
                            [2.375748144341913, 48.829990281683564],
                            [2.376310721393016, 48.83025845726653],
                            [2.376810380809641, 48.830496652755166],
                            [2.378217077176232, 48.831151456509495],
                            [2.378932518061864, 48.83148844043203],
                            [2.379124216737295, 48.8315750331676],
                            [2.379340036484644, 48.831664143981996],
                            [2.379561461780087, 48.83174704005745],
                            [2.379788085667216, 48.83182357175771],
                            [2.380019487505275, 48.83189359387484],
                            [2.380255239630969, 48.83195697825505],
                            [2.38049490333657, 48.83201360838195],
                            [2.380738038438207, 48.8320633767283],
                            [2.380984190899064, 48.832106194585045],
                            [2.381232905229213, 48.83214198043385],
                            [2.381483721676319, 48.83217066712795],
                            [2.38155013799762, 48.832177040838246],
                            [2.382735502920089, 48.832286262450296],
                            [2.383848772143312, 48.83237125955077],
                            [2.384576253574028, 48.832489037661844],
                            [2.384769427970171, 48.83252383151999],
                            [2.384965099736502, 48.83256647499484],
                            [2.385157056835221, 48.832615932444995],
                            [2.385344757428483, 48.83267206349928],
                            [2.385527663969169, 48.8327347098243],
                            [2.385705263634134, 48.8328036952289],
                            [2.385877049304994, 48.8328788210694],
                            [2.386042537149214, 48.83295987713201],
                            [2.386201254476601, 48.83304663167708],
                            [2.386352754616824, 48.83313884050877],
                            [2.386496606085657, 48.83323624152281],
                            [2.386632402066985, 48.83333855925167],
                        ],
                    },
                },
                543: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.868449539117535, 2.3300423741335865],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 821.166917381,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325752635286725,
                            48.86590673959416,
                            2.33418954196825,
                            48.87066702089793,
                        ),
                        "coordinates": [
                            [2.33418954196825, 48.86590673959416],
                            [2.330099534460908, 48.86840985943302],
                            [2.327917741500912, 48.86991927650273],
                            [2.327893429485576, 48.8699356986849],
                            [2.327799662279942, 48.869992365819805],
                            [2.327698763608115, 48.87004342769157],
                            [2.327591504701781, 48.87008849290464],
                            [2.327487238149089, 48.87012457331422],
                            [2.326448280241458, 48.87044948161826],
                            [2.325752635286725, 48.87066702089793],
                        ],
                    },
                },
                544: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.828290108876516, 2.3719981536509755],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 658.848481555,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.36803264639416,
                            48.827270836031985,
                            2.375748144341913,
                            48.829990281683564,
                        ),
                        "coordinates": [
                            [2.36803264639416, 48.827270836031985],
                            [2.370702631723116, 48.827597489825266],
                            [2.370716016809882, 48.82759914944894],
                            [2.37088865389694, 48.82762457372849],
                            [2.371058530122557, 48.827657103572065],
                            [2.371224979614628, 48.827696612275474],
                            [2.37138734367386, 48.82774294259691],
                            [2.371544980231354, 48.82779591310213],
                            [2.371697269350272, 48.82785531369598],
                            [2.371843607722308, 48.827920910090086],
                            [2.371968503000702, 48.82798435931473],
                            [2.374759824635495, 48.82948630098483],
                            [2.375748144341913, 48.829990281683564],
                        ],
                    },
                },
                545: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.871775560681975, 2.3410954353160003],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 309.784784839,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.339030546723062,
                            48.87149773935003,
                            2.343154773075233,
                            48.87192545440334,
                        ),
                        "coordinates": [
                            [2.343154773075233, 48.87149773935003],
                            [2.340921764495836, 48.87186888221046],
                            [2.340798309777278, 48.87188748063469],
                            [2.340624139409108, 48.87190733654015],
                            [2.340448436113511, 48.87192001061147],
                            [2.340271875426005, 48.87192545440334],
                            [2.34009514479961, 48.87192364741946],
                            [2.339918925893234, 48.87191459611565],
                            [2.339743901386173, 48.8718983339375],
                            [2.339570748115101, 48.87187492487971],
                            [2.339543233323586, 48.8718705173886],
                            [2.339030546723062, 48.87178660205624],
                        ],
                    },
                },
                546: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.83763493274532, 2.3866635850158873],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 619.564924537,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.383028081146453,
                            48.83631546891676,
                            2.390345965998709,
                            48.83908128024195,
                        ),
                        "coordinates": [
                            [2.383028081146453, 48.83908128024195],
                            [2.38720164624241, 48.83736667927639],
                            [2.387812290802427, 48.83714527097872],
                            [2.390345965998709, 48.83631546891676],
                        ],
                    },
                },
                547: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.18233049428746, 1.927051585410233],
                        "indice_lig": "J",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4789.03517654,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.920111493432765,
                            49.16267058077503,
                            1.936963126849634,
                            49.20269360297641,
                        ),
                        "coordinates": [
                            [1.936928635785827, 49.16267058077503],
                            [1.936963126849634, 49.163675521261766],
                            [1.93691640361495, 49.164196042571255],
                            [1.936853586857697, 49.164671544555986],
                            [1.936632234372513, 49.16558804052991],
                            [1.936480269359919, 49.16606413094077],
                            [1.936288840544083, 49.16667137841608],
                            [1.936221156076793, 49.16690045885496],
                            [1.936094364050522, 49.16731548542977],
                            [1.935918454123258, 49.16786792971006],
                            [1.935855099679006, 49.16807004689457],
                            [1.935751054891891, 49.16831534775284],
                            [1.935668649640234, 49.16853317062894],
                            [1.935571017034716, 49.16876416061875],
                            [1.935343123247464, 49.16918993667314],
                            [1.935207931840512, 49.16941061645384],
                            [1.934967357367741, 49.169783748378876],
                            [1.934733083983348, 49.17003674541137],
                            [1.934566350443587, 49.1702112273786],
                            [1.93338857884256, 49.17134558782178],
                            [1.933264006541073, 49.17148453885352],
                            [1.933028304514656, 49.171795761001526],
                            [1.932825786028799, 49.17207382623494],
                            [1.932701720831058, 49.172317994971195],
                            [1.932652916747922, 49.17241584485284],
                            [1.932482339449547, 49.17281272694295],
                            [1.932295419492284, 49.173362429543715],
                            [1.932161949165087, 49.173749549783395],
                            [1.93196074718093, 49.17436754687089],
                            [1.931799396454741, 49.17480852520891],
                            [1.931775511497547, 49.17487768579857],
                            [1.931729143027445, 49.175012414767],
                            [1.931656073329921, 49.17522528675495],
                            [1.931463516720904, 49.175791155398485],
                            [1.931456488324099, 49.17581181349296],
                            [1.931449475095587, 49.17583067346095],
                            [1.931333092076561, 49.17613961584883],
                            [1.931068825349872, 49.17691836060446],
                            [1.930969163298852, 49.17719498680245],
                            [1.930898962784217, 49.177391681986364],
                            [1.930778213481298, 49.17773028377056],
                            [1.930661770313186, 49.178045520156935],
                            [1.93057052582442, 49.178298795505526],
                            [1.930517323297216, 49.17842990237041],
                            [1.930493544957204, 49.17848557381584],
                            [1.930468292780109, 49.178553829845924],
                            [1.930441824813714, 49.17860319698278],
                            [1.930360935092428, 49.17876478105686],
                            [1.930271747982409, 49.17893442936181],
                            [1.930168724445757, 49.179118418035664],
                            [1.930111648908888, 49.17921983431229],
                            [1.929965642422839, 49.17945942598759],
                            [1.929824039149715, 49.17966396094408],
                            [1.929560492351161, 49.18001734315282],
                            [1.929148942040459, 49.18051858203903],
                            [1.928816881447752, 49.18086182878829],
                            [1.928570726333448, 49.18110106183028],
                            [1.928370275420154, 49.18128739991404],
                            [1.927983452033404, 49.181616060453536],
                            [1.927900571964765, 49.181685010373755],
                            [1.927614746102435, 49.18190971261044],
                            [1.927257339631823, 49.18216383439086],
                            [1.926849075255081, 49.18242946481641],
                            [1.926449209513245, 49.18267444115933],
                            [1.92571319172877, 49.18308997557925],
                            [1.925146747608871, 49.18340359520289],
                            [1.924111891994474, 49.183978731041215],
                            [1.923032542919152, 49.18460364103877],
                            [1.921718928505674, 49.18577842758823],
                            [1.920865292274841, 49.18724587027777],
                            [1.920286613586217, 49.18935766157126],
                            [1.920111493432765, 49.1934928906288],
                            [1.920547706067206, 49.20269360297641],
                        ],
                    },
                },
                548: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.211842527156136, 1.9133246238964994],
                        "indice_lig": "J",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2370.17439218,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.905299061887723,
                            49.20269360297641,
                            1.920547706067206,
                            49.22080705063383,
                        ),
                        "coordinates": [
                            [1.920547706067206, 49.20269360297641],
                            [1.919863356103738, 49.20626720879595],
                            [1.91858537541633, 49.2081007258882],
                            [1.915620052641178, 49.210387598587296],
                            [1.910685707856781, 49.21321856379709],
                            [1.908419578399681, 49.21569165789381],
                            [1.905299061887723, 49.22080705063383],
                        ],
                    },
                },
                549: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.15320650479212, 2.3035317984409707],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 3326.89006872,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.281752268322335,
                            49.148967156548686,
                            2.325754000363327,
                            49.15518985899016,
                        ),
                        "coordinates": [
                            [2.325754000363327, 49.15518985899016],
                            [2.325307868796063, 49.15516138812337],
                            [2.324468798871061, 49.15510194821677],
                            [2.320926077161986, 49.15485600789381],
                            [2.319390543853856, 49.15474966890901],
                            [2.318184057870791, 49.1546658464731],
                            [2.314833337706902, 49.15443323747292],
                            [2.313322508232997, 49.15432862124469],
                            [2.30943852590209, 49.15405887410161],
                            [2.307861912866378, 49.15394787592917],
                            [2.304689518045863, 49.15372131105978],
                            [2.303714773273508, 49.15365178956384],
                            [2.302583735815965, 49.15358221253618],
                            [2.301192231585941, 49.1534846669243],
                            [2.300635629770555, 49.1534458229058],
                            [2.297855381477818, 49.15325157032852],
                            [2.295988185549178, 49.153122325875124],
                            [2.295469985152017, 49.15307807657461],
                            [2.294806489987808, 49.15299959923148],
                            [2.294529577144989, 49.152967123976985],
                            [2.293564544953707, 49.152799500890346],
                            [2.292875072096586, 49.15264726238262],
                            [2.292282938359708, 49.15250225275338],
                            [2.291985510443952, 49.15241940361467],
                            [2.291804588700458, 49.15236807490797],
                            [2.29114945175872, 49.15216278337052],
                            [2.290313421592659, 49.15188457344438],
                            [2.28893878926767, 49.15142628084619],
                            [2.287629964701909, 49.150992280597904],
                            [2.28567292727528, 49.15035204531125],
                            [2.283707787583001, 49.14964522765518],
                            [2.28291845506287, 49.14936428770167],
                            [2.282267541783286, 49.14912837166805],
                            [2.281752268322335, 49.148967156548686],
                        ],
                    },
                },
                550: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.30963528867977, 3.1710741008785193],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 7232.57717758,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.131139534626574,
                            48.28639117963662,
                            3.201893827865916,
                            48.324052274414186,
                        ),
                        "coordinates": [
                            [3.131139534626574, 48.324052274414186],
                            [3.151635862989501, 48.31742149007541],
                            [3.171333894530873, 48.31105779307501],
                            [3.186151923983624, 48.306266384403735],
                            [3.191977008555971, 48.304042265734054],
                            [3.194737552385817, 48.30248240176259],
                            [3.198531838068091, 48.299568040268696],
                            [3.200130098257574, 48.29750395258623],
                            [3.201112051744616, 48.29313622215938],
                            [3.201042599228757, 48.28909714893528],
                            [3.201893827865916, 48.28639117963662],
                        ],
                    },
                },
                551: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.167323151458874, 3.2723847037599447],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 7446.41858092,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.260023864531737,
                            48.137610805280445,
                            3.289741961959439,
                            48.19841749425402,
                        ),
                        "coordinates": [
                            [3.267320028735699, 48.19841749425402],
                            [3.265269705075568, 48.19094182282515],
                            [3.261806151768995, 48.1833614551318],
                            [3.260023864531737, 48.17679314151432],
                            [3.260245009989771, 48.174910489911696],
                            [3.264498928272308, 48.1699169497258],
                            [3.273802587813343, 48.161632612879934],
                            [3.282226608037181, 48.15429530858181],
                            [3.285344689895775, 48.15025092765814],
                            [3.288404188247092, 48.143129226892995],
                            [3.289741961959439, 48.137610805280445],
                        ],
                    },
                },
                552: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.470164386687976, 1.4968953620931291],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 5385.85094651,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.480870932697703,
                            48.448384567932216,
                            1.522357650275546,
                            48.48241050127598,
                        ),
                        "coordinates": [
                            [1.522357650275546, 48.48241050127598],
                            [1.51182011031168, 48.48098483761632],
                            [1.507086604616057, 48.47970246269404],
                            [1.501750000418865, 48.47708445182279],
                            [1.492975769348095, 48.47061401807543],
                            [1.486551862743752, 48.46582430680435],
                            [1.483720519638876, 48.46314102602371],
                            [1.48263603881209, 48.460720424883256],
                            [1.482310482376622, 48.45780641929466],
                            [1.482868769380397, 48.45439996168768],
                            [1.48254182427891, 48.451569137139195],
                            [1.480870932697703, 48.448384567932216],
                        ],
                    },
                },
                553: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.131779746679776, 1.3552095688220822],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 13447.0732993,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.336816230967222,
                            48.07340701010752,
                            1.38624502094351,
                            48.18643720958249,
                        ),
                        "coordinates": [
                            [1.38624502094351, 48.18643720958249],
                            [1.380672572824924, 48.17957806175812],
                            [1.370559216155214, 48.167009754178636],
                            [1.359684228519567, 48.147850963119694],
                            [1.356114720576357, 48.140895001682715],
                            [1.354910823966184, 48.13712282307138],
                            [1.35381824583115, 48.129832154565555],
                            [1.352936810870873, 48.12264307427264],
                            [1.351641807858354, 48.119212043566186],
                            [1.348640541826018, 48.11599400915287],
                            [1.342755454823243, 48.112294492170506],
                            [1.339078973914955, 48.10884225229135],
                            [1.337431402573919, 48.10609187093287],
                            [1.336816230967222, 48.102780697883624],
                            [1.337462075379636, 48.095947040070584],
                            [1.33843476320405, 48.07340701010752],
                        ],
                    },
                },
                554: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.49516785311234, 1.540510491155651],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 4269.65244029,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.522357650275546,
                            48.48241050127598,
                            1.557776370603914,
                            48.510447392863114,
                        ),
                        "coordinates": [
                            [1.557776370603914, 48.510447392863114],
                            [1.548739386427504, 48.504373602568556],
                            [1.544405845094832, 48.50134865191174],
                            [1.540981933373957, 48.496250256245],
                            [1.53818572372492, 48.49107299736957],
                            [1.535491275372989, 48.487393751485456],
                            [1.533397471751798, 48.48529925301461],
                            [1.530292209879972, 48.48386301394478],
                            [1.525804148818641, 48.48283273190347],
                            [1.522357650275546, 48.48241050127598],
                        ],
                    },
                },
                555: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.18700825046705, 2.3672096790769412],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 4459.06423684,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362303528565357,
                            49.166775039807895,
                            2.376601177324503,
                            49.20326573346356,
                        ),
                        "coordinates": [
                            [2.362303528565357, 49.166775039807895],
                            [2.362649382468536, 49.167287545801706],
                            [2.362967793672144, 49.167757791319666],
                            [2.363197003377784, 49.16810485617761],
                            [2.364233101446112, 49.16966974128223],
                            [2.365565516625801, 49.17399735517902],
                            [2.366316858529152, 49.18024681686752],
                            [2.366136105256711, 49.19066294162191],
                            [2.366513203521723, 49.195932151988366],
                            [2.367262656547948, 49.19838279749573],
                            [2.369133976409839, 49.20046550287917],
                            [2.376601177324503, 49.20326573346356],
                        ],
                    },
                },
                556: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.20757669204192, 2.397248799007376],
                        "indice_lig": "H",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 3221.82531252,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.376601177324503,
                            49.20326573346356,
                            2.417369391049351,
                            49.21385632476746,
                        ),
                        "coordinates": [
                            [2.376601177324503, 49.20326573346356],
                            [2.39457318377227, 49.206215051791595],
                            [2.400372701648916, 49.20755996400313],
                            [2.410290586842202, 49.21110779215862],
                            [2.417369391049351, 49.21385632476746],
                        ],
                    },
                },
                557: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [49.04584665313769, 2.058061494538279],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 3860.48915715,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.034294461852662,
                            49.03646398072535,
                            2.079534939997374,
                            49.049647005256354,
                        ),
                        "coordinates": [
                            [2.034294461852662, 49.049647005256354],
                            [2.036699555177008, 49.04940111809993],
                            [2.038032451108977, 49.049271358279974],
                            [2.039600795400978, 49.04911364082945],
                            [2.047377116513116, 49.04834122395781],
                            [2.058365751178554, 49.047238265457736],
                            [2.059271172808136, 49.04715004729796],
                            [2.059825257312942, 49.047101421034434],
                            [2.060339435140608, 49.04706935220961],
                            [2.060795628329488, 49.04704903840108],
                            [2.061280752815287, 49.047033552094234],
                            [2.061878059147017, 49.047023089039115],
                            [2.062395774408933, 49.047005295364976],
                            [2.062804923993119, 49.04698248095369],
                            [2.063081184635633, 49.04696657874804],
                            [2.063513731204735, 49.04693725958154],
                            [2.064189534895152, 49.04687556029884],
                            [2.06492075559411, 49.046755206872064],
                            [2.065552960855347, 49.04662647492233],
                            [2.066165201070163, 49.04648499619211],
                            [2.066727696589304, 49.04633100990429],
                            [2.067278309739992, 49.04614023584278],
                            [2.067800729955743, 49.045920183796795],
                            [2.06830872490457, 49.04567589316136],
                            [2.068595574908552, 49.04550390368852],
                            [2.068856353054068, 49.045346240194384],
                            [2.069205162048956, 49.045099753904125],
                            [2.069577394428554, 49.04482184561982],
                            [2.070226057143948, 49.044271199019086],
                            [2.070869852053202, 49.04360542984601],
                            [2.071277342200432, 49.04312615961311],
                            [2.07152653878889, 49.042828175969404],
                            [2.071773373059466, 49.04246004273258],
                            [2.072131219151798, 49.042051697904476],
                            [2.072394003196743, 49.0417690312393],
                            [2.072757057099989, 49.04140835849702],
                            [2.073216098355186, 49.04100294140987],
                            [2.07331777149287, 49.04091864270687],
                            [2.074036174611757, 49.04035464611563],
                            [2.074828416347525, 49.039792612163396],
                            [2.075037209324431, 49.03962672357928],
                            [2.075186940796591, 49.03950656157843],
                            [2.076020730185133, 49.03884209699288],
                            [2.076296804012054, 49.03862599905197],
                            [2.076508199784972, 49.038483493418305],
                            [2.077215150022583, 49.03800308395509],
                            [2.079534939997374, 49.03646398072535],
                        ],
                    },
                },
                558: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [49.02530767207706, 2.1407440104440876],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2590.05747503,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.128263873923673,
                            49.01913673984224,
                            2.154663485640923,
                            49.033987636271455,
                        ),
                        "coordinates": [
                            [2.154663485640923, 49.01913673984224],
                            [2.153012708040501, 49.01958148730108],
                            [2.1525802036884, 49.01969859749183],
                            [2.15187945004989, 49.01988361913078],
                            [2.150826891488006, 49.020175078735726],
                            [2.149978124031571, 49.020447077518284],
                            [2.149305915162764, 49.020671697973114],
                            [2.148826714662678, 49.02083817803502],
                            [2.148341998062405, 49.021016337694384],
                            [2.147705252554311, 49.02125989135247],
                            [2.147065696758275, 49.02152142255902],
                            [2.146498651858204, 49.021770480878665],
                            [2.14594799358884, 49.022024060222314],
                            [2.145346607428395, 49.02231082549486],
                            [2.144350588173181, 49.02280825434546],
                            [2.144093057933043, 49.02292652594874],
                            [2.143931358634076, 49.0230152822196],
                            [2.143650524185861, 49.02314790214863],
                            [2.143031225952273, 49.02346250313366],
                            [2.142701050689537, 49.023622914676324],
                            [2.142370881211854, 49.02378152687329],
                            [2.140962391049982, 49.0244841602294],
                            [2.139784055706185, 49.0250711659449],
                            [2.139636077743041, 49.02514465214651],
                            [2.139127744838577, 49.025396473601596],
                            [2.13819053882378, 49.02585977871451],
                            [2.137680805934782, 49.02611608728359],
                            [2.137340936435868, 49.026298048944646],
                            [2.137228556776113, 49.026359004402956],
                            [2.137055835991663, 49.026462120063606],
                            [2.136598001860149, 49.02673200308702],
                            [2.136292293463326, 49.02691851828956],
                            [2.135953572336817, 49.02715173687216],
                            [2.135933000988131, 49.02716608896057],
                            [2.13552704267224, 49.02745494442121],
                            [2.1353610539308, 49.02758234935377],
                            [2.13530891614649, 49.02762452376745],
                            [2.135145673271377, 49.027749236079515],
                            [2.134734036963733, 49.02808663965612],
                            [2.134330518977245, 49.02844383931215],
                            [2.133111242287299, 49.029505863609465],
                            [2.132522779267561, 49.03005920334172],
                            [2.131989640429896, 49.030574865619776],
                            [2.13162187645773, 49.03091147979036],
                            [2.131232357216787, 49.03125697622124],
                            [2.130733854692106, 49.03170399224864],
                            [2.13009097662359, 49.03227744575314],
                            [2.129407148815588, 49.03290435640467],
                            [2.129093756160098, 49.03321072338393],
                            [2.128263873923673, 49.033987636271455],
                        ],
                    },
                },
                559: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.85264108758529, 2.2829290553326875],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 582.139134328,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.279487064962566,
                            48.852244619597045,
                            2.286419448213008,
                            48.85364805716894,
                        ),
                        "coordinates": [
                            [2.286419448213008, 48.853033488503854],
                            [2.285796621620032, 48.85262928085654],
                            [2.285660399489906, 48.8525635499946],
                            [2.285500376202803, 48.852504946380414],
                            [2.285281959050423, 48.85243061288087],
                            [2.285041902970752, 48.85236197933479],
                            [2.284873202528443, 48.852326212657104],
                            [2.284741336067407, 48.85230072888726],
                            [2.284632337864564, 48.85228359286626],
                            [2.284490636321752, 48.85226464323339],
                            [2.284361189858992, 48.85225469199297],
                            [2.284237188834877, 48.85224923941597],
                            [2.284100922211517, 48.85224647795981],
                            [2.283971466867833, 48.852244619597045],
                            [2.283798400945888, 48.85224633853385],
                            [2.283682569325693, 48.85224808330548],
                            [2.283532665373111, 48.85225430781955],
                            [2.283404566687152, 48.85225874440302],
                            [2.283246481129349, 48.85226946223325],
                            [2.283099292086696, 48.85228468079375],
                            [2.282931660327877, 48.85230258716652],
                            [2.282803538454569, 48.85232770648341],
                            [2.282656332186916, 48.85235821174271],
                            [2.282408255470531, 48.8524165470169],
                            [2.281871197902879, 48.85255208105997],
                            [2.281443182768892, 48.85266248469554],
                            [2.281334132773428, 48.85269210855454],
                            [2.281201901818647, 48.85273341066626],
                            [2.281042405338812, 48.85278638979378],
                            [2.280938792056676, 48.85282770617837],
                            [2.28078393915913, 48.85289463857518],
                            [2.280634746387634, 48.852967843667884],
                            [2.280525531876965, 48.85302400864467],
                            [2.280430213651343, 48.853076555320634],
                            [2.280212025595497, 48.85320954006952],
                            [2.279957019483357, 48.85336318961356],
                            [2.279487064962566, 48.85364805716894],
                        ],
                    },
                },
                560: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.849636359562275, 2.2815728096200534],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1039.89446243,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.276760967379574,
                            48.84619214048855,
                            2.286419448213008,
                            48.853033488503854,
                        ),
                        "coordinates": [
                            [2.286419448213008, 48.853033488503854],
                            [2.285753551167312, 48.852571864876346],
                            [2.285019573521851, 48.85206883938463],
                            [2.283258945014557, 48.85082522891038],
                            [2.281639998854621, 48.849689573608785],
                            [2.281155290820172, 48.849342217700965],
                            [2.280386028662221, 48.848795080578896],
                            [2.27845814980847, 48.84745419220451],
                            [2.277513320159236, 48.846787341834066],
                            [2.276966092069675, 48.84635720274608],
                            [2.276847666762353, 48.846260918444166],
                            [2.276760967379574, 48.84619214048855],
                        ],
                    },
                },
                561: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.95906967168272, 2.327166879022447],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 237.990985476,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32609015753849,
                            48.958269604608034,
                            2.32824501026232,
                            48.95987163649979,
                        ),
                        "coordinates": [
                            [2.32824501026232, 48.958269604608034],
                            [2.327390056245584, 48.958902276974186],
                            [2.32609015753849, 48.95987163649979],
                        ],
                    },
                },
                562: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.14650771750431, 2.2741864231908275],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 595.523865267,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.270552769414137,
                            49.14528660789949,
                            2.277823190629399,
                            49.14771950559884,
                        ),
                        "coordinates": [
                            [2.277823190629399, 49.14771950559884],
                            [2.274722501708344, 49.1466929168685],
                            [2.272897367866637, 49.14607591620477],
                            [2.272135537078627, 49.14582009680996],
                            [2.271873832060084, 49.14573182144427],
                            [2.270948962714028, 49.145420146775926],
                            [2.270552769414137, 49.14528660789949],
                        ],
                    },
                },
                563: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.842049723598485, 2.3763183460610544],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 653.590327347,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.373014219940096,
                            48.84000138864879,
                            2.37955401121414,
                            48.84398558201753,
                        ),
                        "coordinates": [
                            [2.37955401121414, 48.84000138864879],
                            [2.379121775079775, 48.840302093370006],
                            [2.376592446309371, 48.84192980472627],
                            [2.374642355939451, 48.84308916196176],
                            [2.373014219940096, 48.84398558201753],
                        ],
                    },
                },
                564: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.8567843901924, 2.2721168914665273],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 411.93198632,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.270109138941893,
                            48.855485050404425,
                            2.274154629736559,
                            48.85804605538447,
                        ),
                        "coordinates": [
                            [2.270109138941893, 48.855485050404425],
                            [2.270342224500886, 48.855702186171094],
                            [2.270893406853705, 48.856031505389545],
                            [2.272843766617518, 48.85722961709578],
                            [2.273399350718707, 48.857577681805225],
                            [2.274062770766353, 48.85799329404304],
                            [2.274154629736559, 48.85804605538447],
                        ],
                    },
                },
                565: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.863512608778365, 2.2822280399112014],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 597.556078764,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.278213461559327,
                            48.863065020217924,
                            2.286243169328236,
                            48.8639657074042,
                        ),
                        "coordinates": [
                            [2.278213461559327, 48.8639657074042],
                            [2.278829094953977, 48.86389623211633],
                            [2.2859827637985, 48.86308866762051],
                            [2.286034686907263, 48.8630830353721],
                            [2.28605125605671, 48.86308160352098],
                            [2.286243169328236, 48.863065020217924],
                        ],
                    },
                },
                566: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.87121419765191, 2.3355845681613907],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 521.328631527,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332138599575903,
                            48.87064173324228,
                            2.339030546723062,
                            48.87178660205624,
                        ),
                        "coordinates": [
                            [2.339030546723062, 48.87178660205624],
                            [2.332354639251744, 48.8706776827435],
                            [2.332138599575903, 48.87064173324228],
                        ],
                    },
                },
                567: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.9245077098561, 2.8468226152225604],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 8079.87411278,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.810248220733339,
                            48.903072914208664,
                            2.873448188749959,
                            48.95726886600814,
                        ),
                        "coordinates": [
                            [2.810248220733339, 48.903072914208664],
                            [2.816642664397528, 48.90465929286542],
                            [2.819237861273779, 48.90529936647536],
                            [2.821628060256524, 48.905897420811975],
                            [2.825604225275963, 48.90688910427972],
                            [2.826320019806124, 48.90706775424422],
                            [2.826887460036351, 48.907224099230156],
                            [2.827503213418642, 48.90740347963299],
                            [2.828106061574253, 48.907591478612154],
                            [2.828676409743433, 48.90777747210412],
                            [2.829938075246005, 48.908226021929835],
                            [2.833644947989917, 48.909541948679255],
                            [2.834332888151021, 48.909787363985984],
                            [2.835082987859156, 48.91007533382285],
                            [2.835758314852028, 48.91035719999091],
                            [2.836486058738449, 48.91068166251205],
                            [2.837328335847441, 48.91108699350503],
                            [2.838086159522665, 48.9114926899022],
                            [2.838556590689074, 48.911749741272494],
                            [2.839050095320965, 48.912038811726845],
                            [2.839599332614061, 48.91237688706684],
                            [2.840194537376986, 48.91276186982662],
                            [2.84063293952039, 48.913061882383914],
                            [2.841084602461002, 48.91338753301848],
                            [2.841615007724595, 48.91378778469137],
                            [2.842053950198282, 48.91413918426273],
                            [2.842437318890418, 48.91445656588049],
                            [2.842948817857881, 48.91491257288476],
                            [2.84331957344736, 48.91526641128384],
                            [2.843657647860593, 48.915601121369974],
                            [2.844114113216239, 48.916074497876814],
                            [2.84448233605571, 48.916496871620886],
                            [2.844956202869586, 48.91708152427415],
                            [2.845338183493453, 48.91757664236364],
                            [2.846330051619043, 48.918925624510955],
                            [2.847918470047961, 48.92108568495416],
                            [2.849948589363664, 48.923836923609535],
                            [2.851184550565616, 48.92551026920677],
                            [2.855258938708293, 48.93103180879619],
                            [2.85662705816382, 48.9328758142734],
                            [2.856940012909839, 48.93327484352162],
                            [2.857259094389455, 48.933637438419446],
                            [2.85760740801204, 48.933997757777945],
                            [2.857958616773929, 48.93432380059345],
                            [2.858322539724934, 48.93462194522854],
                            [2.859142193774034, 48.93529276142574],
                            [2.85988963978753, 48.93589537654974],
                            [2.86110915960593, 48.93687485999101],
                            [2.863223908351956, 48.93858687482111],
                            [2.867814423830264, 48.94228964130415],
                            [2.868165483224689, 48.942589956194695],
                            [2.868519959915423, 48.94290524445108],
                            [2.868789392020645, 48.94317167302523],
                            [2.869088611249461, 48.943487216360815],
                            [2.869319085646755, 48.943758108086406],
                            [2.869711451221098, 48.94427023104888],
                            [2.87005217889461, 48.944816855570835],
                            [2.870237982022345, 48.94516504568006],
                            [2.870437595927308, 48.94558812357875],
                            [2.870584575181216, 48.94595362642782],
                            [2.870722495353568, 48.946383417251305],
                            [2.870833810510371, 48.94675765142063],
                            [2.870983009599121, 48.947328724654696],
                            [2.871234541206582, 48.94834474135509],
                            [2.871740286201713, 48.95032108559101],
                            [2.871866355135996, 48.9508558591402],
                            [2.872212910508328, 48.95223762051659],
                            [2.872549802564272, 48.95362584876156],
                            [2.87276740258598, 48.95450496910884],
                            [2.873302139010763, 48.95668263254312],
                            [2.873448188749959, 48.95726886600814],
                        ],
                    },
                },
                568: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.71863684646498, 2.4119979829145652],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 1874.10971295,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.403633104908493,
                            48.71262898747625,
                            2.419565024387933,
                            48.72553530486119,
                        ),
                        "coordinates": [
                            [2.403633104908493, 48.71262898747625],
                            [2.403760218066728, 48.71275338036123],
                            [2.404241855357792, 48.71319103840689],
                            [2.404580737259858, 48.71346305084839],
                            [2.404929819788531, 48.71370077356364],
                            [2.405515012454503, 48.71408234846835],
                            [2.40618558384271, 48.7145297763729],
                            [2.406450802714425, 48.7146923814499],
                            [2.40727093899601, 48.71518467423468],
                            [2.408001281358155, 48.71559428453797],
                            [2.408971029364889, 48.71615211765388],
                            [2.409509679788258, 48.716490797208145],
                            [2.409953157029819, 48.71679536485506],
                            [2.410055184198932, 48.71686544136762],
                            [2.410748939013496, 48.7173137267399],
                            [2.4114739452638, 48.71775029636385],
                            [2.412359454632673, 48.71826858843303],
                            [2.412956645358633, 48.718644083809956],
                            [2.413091319321211, 48.718728524164284],
                            [2.413197428798623, 48.718795897961854],
                            [2.413898110216495, 48.71929361949754],
                            [2.41427228515168, 48.71957213772228],
                            [2.414568002899246, 48.71981418733267],
                            [2.414777186701919, 48.720009736405494],
                            [2.41517597685818, 48.720378162012075],
                            [2.415574830267373, 48.72078165881984],
                            [2.415683744313906, 48.72089938726115],
                            [2.415732769389958, 48.72096050315869],
                            [2.416036479366335, 48.72135597063324],
                            [2.416135926304154, 48.721500683507486],
                            [2.416273513368349, 48.721698426554525],
                            [2.41645742542816, 48.72196717920239],
                            [2.416627760758634, 48.72224403484902],
                            [2.416855273307344, 48.72257660457186],
                            [2.417056940391772, 48.72289480380049],
                            [2.41730288080876, 48.72327181618965],
                            [2.417569179431797, 48.72363094277449],
                            [2.417689018459523, 48.72377384131561],
                            [2.417920500127482, 48.72403176721072],
                            [2.418459628617813, 48.72457274056327],
                            [2.418853008010847, 48.72491777697031],
                            [2.419565024387933, 48.72553530486119],
                        ],
                    },
                },
                569: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.965297910739366, 2.962762494670167],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2477.7645205,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.950060382752808,
                            48.960226490735955,
                            2.973519215077535,
                            48.97436062282584,
                        ),
                        "coordinates": [
                            [2.950060382752808, 48.960226490735955],
                            [2.95175079330588, 48.96024949464454],
                            [2.952303744520137, 48.96025722986969],
                            [2.952895823771479, 48.960273317432076],
                            [2.95341641533515, 48.96029407102819],
                            [2.953986050652563, 48.96033597142898],
                            [2.954660068251468, 48.96040300449745],
                            [2.955184527751131, 48.960472982317285],
                            [2.955673298267127, 48.96054957561234],
                            [2.956250326817945, 48.96066209391428],
                            [2.956736222952542, 48.96076867939837],
                            [2.957320185970004, 48.96091541721596],
                            [2.957904423092041, 48.961083567542964],
                            [2.958426875862008, 48.961252049689094],
                            [2.958965915173825, 48.96144613731513],
                            [2.959413659733209, 48.961621445278276],
                            [2.959858400296315, 48.961816040907166],
                            [2.960329456026285, 48.962034048822304],
                            [2.960830294689846, 48.96229257955372],
                            [2.961308508071661, 48.962561940193304],
                            [2.961682124014346, 48.96278903927934],
                            [2.962062570625729, 48.963041797134],
                            [2.96242356225512, 48.963298943976326],
                            [2.962706102234541, 48.96352439611816],
                            [2.963061110207489, 48.96382226260639],
                            [2.963495554418657, 48.96422890710962],
                            [2.963890760994318, 48.96461863341497],
                            [2.965317276522482, 48.96605845029489],
                            [2.968368402964463, 48.96914894686642],
                            [2.969478976229396, 48.970279941310054],
                            [2.970366764019293, 48.97117657603807],
                            [2.971294691949179, 48.972113709668555],
                            [2.973117102488859, 48.97395169499413],
                            [2.973519215077535, 48.97436062282584],
                        ],
                    },
                },
                570: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80063291549446, 2.1747611810506338],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 496.243990707,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.171389812756379,
                            48.800562566282714,
                            2.178130973726579,
                            48.800720766349464,
                        ),
                        "coordinates": [
                            [2.178130973726579, 48.80066321899656],
                            [2.177821314060172, 48.80063423733164],
                            [2.177472022349711, 48.80060995499961],
                            [2.177065087651669, 48.80059035108217],
                            [2.176654529377904, 48.80057787835856],
                            [2.175919822294987, 48.800562566282714],
                            [2.174282238330508, 48.80061633996727],
                            [2.173064633662477, 48.800682384781815],
                            [2.172336889530995, 48.8007152310616],
                            [2.171903089010338, 48.800720766349464],
                            [2.171400515562385, 48.80071880338744],
                            [2.171389812756379, 48.80071846386355],
                        ],
                    },
                },
                571: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98362554148879, 2.653732769480825],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2394.39688482,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.64240630231019,
                            48.97585875402045,
                            2.665059869307301,
                            48.99139140287414,
                        ),
                        "coordinates": [
                            [2.64240630231019, 48.97585875402045],
                            [2.644168510727709, 48.97706830926519],
                            [2.646324793730389, 48.97854483863396],
                            [2.647533687069544, 48.97937433914831],
                            [2.648557443154792, 48.980073465693806],
                            [2.654911340271517, 48.984434006448296],
                            [2.65855352505687, 48.98693167218184],
                            [2.663826827186031, 48.99055001233438],
                            [2.665059869307301, 48.99139140287414],
                        ],
                    },
                },
                572: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.83261495987958, 1.8955039383782115],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 5629.25943636,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.877504204313639,
                            48.81532862049073,
                            1.924597779359982,
                            48.838772335396015,
                        ),
                        "coordinates": [
                            [1.877504204313639, 48.81532862049073],
                            [1.87787100730415, 48.815726383929736],
                            [1.878421569306398, 48.81634995032969],
                            [1.878651511889975, 48.81663394610838],
                            [1.878892811372323, 48.816964396163435],
                            [1.879045935011556, 48.81719433005968],
                            [1.879158588822934, 48.81738273390282],
                            [1.879423676068235, 48.81787660767603],
                            [1.879615417570198, 48.818350404056055],
                            [1.879892246605241, 48.819197745440434],
                            [1.879938148944577, 48.81938947853934],
                            [1.879965176819042, 48.81956045197007],
                            [1.880008917410456, 48.81983940690308],
                            [1.88004016075747, 48.82029277485367],
                            [1.880044694493354, 48.82113363025723],
                            [1.880036352548925, 48.82189349764664],
                            [1.880020603068876, 48.823311616623634],
                            [1.880015945084784, 48.82381879844969],
                            [1.879999803881867, 48.825427565803096],
                            [1.879999864901178, 48.82616228701768],
                            [1.880006738413766, 48.82645188606749],
                            [1.880001846728486, 48.827132630097005],
                            [1.880002498239201, 48.82720997142658],
                            [1.880003472730375, 48.827252242307544],
                            [1.879990284389749, 48.82794644194013],
                            [1.879981500397308, 48.82905073693857],
                            [1.879977733132066, 48.82960918141672],
                            [1.879977691009625, 48.829613678187904],
                            [1.879984030070301, 48.830702744579845],
                            [1.879995329268325, 48.83095549099647],
                            [1.880053524906276, 48.83144134152736],
                            [1.880133127308516, 48.83182116132579],
                            [1.880251927889158, 48.83223441101881],
                            [1.880291684347071, 48.832355074927676],
                            [1.880408547314741, 48.83268288448552],
                            [1.8805741008108, 48.833048658502804],
                            [1.880679738710653, 48.8332640119926],
                            [1.880952058988127, 48.833722839251514],
                            [1.881227684535757, 48.834118729329596],
                            [1.881441733725005, 48.83439656471265],
                            [1.881496989898135, 48.83446153455297],
                            [1.881544189790246, 48.83451388199198],
                            [1.881677711340868, 48.83466009957169],
                            [1.881923178747562, 48.83492906699741],
                            [1.882334990421441, 48.8353308922992],
                            [1.882627024932562, 48.83557306481658],
                            [1.883082710867936, 48.83594538571947],
                            [1.88341973156075, 48.83618503775586],
                            [1.883777230103803, 48.836420273005004],
                            [1.884134894807137, 48.836637522818314],
                            [1.884477808558082, 48.83682953182274],
                            [1.88490493763266, 48.83704885262108],
                            [1.88572449313217, 48.8374100124786],
                            [1.886046175416951, 48.83754078213053],
                            [1.886401932152393, 48.83766988579632],
                            [1.886893618010836, 48.83783279821918],
                            [1.887547118482255, 48.838029619927084],
                            [1.888210419085543, 48.83819769891052],
                            [1.888535356133755, 48.83827091884642],
                            [1.888884848174625, 48.83834063697214],
                            [1.889182713369399, 48.83839486413132],
                            [1.889477925939689, 48.83844098638236],
                            [1.890033102632028, 48.838514205256836],
                            [1.890887882379865, 48.83860028341749],
                            [1.891330354785899, 48.83863258685505],
                            [1.892768106915908, 48.83873171662893],
                            [1.892838907306756, 48.838736488650476],
                            [1.893333229945059, 48.83875999331609],
                            [1.893732288561841, 48.838772335396015],
                            [1.89415463429514, 48.8387703774405],
                            [1.894882263335759, 48.83875521118525],
                            [1.895224377263014, 48.838736751164426],
                            [1.895618354691325, 48.83870769892675],
                            [1.896036956033603, 48.838667049742455],
                            [1.896793931650778, 48.838568351558564],
                            [1.897171852980187, 48.83850595831437],
                            [1.897749136141255, 48.83839127300515],
                            [1.898240552772194, 48.83828075165187],
                            [1.898867285886277, 48.838119487402],
                            [1.899525726677632, 48.83791517559326],
                            [1.900101056534674, 48.83771144148132],
                            [1.900185809989112, 48.83767849153344],
                            [1.900254160578375, 48.837651774820735],
                            [1.90076001010163, 48.83744777195684],
                            [1.903020266980627, 48.836491449216375],
                            [1.90397433275486, 48.836125464964276],
                            [1.904485326453057, 48.83595294004234],
                            [1.904934782873284, 48.8358071587669],
                            [1.905422385419095, 48.835660620413584],
                            [1.905845727401256, 48.83554081585114],
                            [1.906729122566696, 48.83530853623562],
                            [1.907112667134727, 48.8352218507903],
                            [1.907853722425754, 48.83506546517961],
                            [1.908331301721591, 48.83497373333898],
                            [1.909118439662935, 48.834843591991586],
                            [1.909784036358162, 48.8347480628073],
                            [1.910405830827939, 48.8346766465092],
                            [1.910780743796137, 48.83464207599627],
                            [1.912754655367173, 48.834479464807124],
                            [1.913557538872308, 48.834417697473214],
                            [1.913826074508072, 48.83439711031479],
                            [1.915055662538173, 48.83429644507696],
                            [1.915648648571893, 48.834247376976585],
                            [1.915925378505783, 48.834224117065666],
                            [1.917360778064037, 48.8341088987831],
                            [1.917585712659889, 48.834089041797846],
                            [1.918688504735731, 48.83399956330741],
                            [1.919424625782274, 48.83393750925741],
                            [1.920967741035089, 48.83380825183372],
                            [1.921056342265891, 48.83380137996571],
                            [1.921894688151168, 48.83373158943451],
                            [1.923240103035626, 48.83362226587428],
                            [1.924597779359982, 48.833512070590515],
                        ],
                    },
                },
                573: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.79486075047856, 2.1040231487081065],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 5003.12924709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.071847005929401,
                            48.79197130289541,
                            2.136050489663708,
                            48.798774681352754,
                        ),
                        "coordinates": [
                            [2.071847005929401, 48.79870763528835],
                            [2.071930959217986, 48.79871552851866],
                            [2.072216710538763, 48.7987359766609],
                            [2.072579474675331, 48.79875781412333],
                            [2.072862898980037, 48.79877217510979],
                            [2.07339670251307, 48.798774681352754],
                            [2.073713874486058, 48.798774514434655],
                            [2.074120918822997, 48.79876825942257],
                            [2.074570257201611, 48.79874411437348],
                            [2.075095898700846, 48.79870575443047],
                            [2.075455455431691, 48.79866970976342],
                            [2.075887224661105, 48.79862123822052],
                            [2.076227752121453, 48.79857975186269],
                            [2.076626900075734, 48.798521310787564],
                            [2.07716506105974, 48.79843081224707],
                            [2.07764852043101, 48.798316933934665],
                            [2.078167738891175, 48.798203905116274],
                            [2.078658217708944, 48.798076532368164],
                            [2.079083828515797, 48.79795614915085],
                            [2.07970072398773, 48.79775767757964],
                            [2.08020225629617, 48.79758035736656],
                            [2.080682237327531, 48.79739108945262],
                            [2.082831239058495, 48.79647994934646],
                            [2.08407821011798, 48.79595569704254],
                            [2.084495051075953, 48.79578292818973],
                            [2.084798183357852, 48.795662251920504],
                            [2.085068779097173, 48.79556529741404],
                            [2.085472803759792, 48.795432945457634],
                            [2.085851533812421, 48.795317192821884],
                            [2.086342037093098, 48.795175510300744],
                            [2.086926168987106, 48.795034032056186],
                            [2.087503001665491, 48.794911569452395],
                            [2.088104956144356, 48.79480581469834],
                            [2.088696007853362, 48.794719067792464],
                            [2.089301405013185, 48.794644244904084],
                            [2.089913909264423, 48.794588469047525],
                            [2.09054429876811, 48.794556522554586],
                            [2.091113408132319, 48.79453633626861],
                            [2.09172199049859, 48.79454478562203],
                            [2.092341270622694, 48.79457466828989],
                            [2.093068461780212, 48.79463095098126],
                            [2.093925150711385, 48.79471843643121],
                            [2.094774639817521, 48.794805900752586],
                            [2.098176203113287, 48.7951604600855],
                            [2.101567045015145, 48.79550775765459],
                            [2.10300329181604, 48.795658232499086],
                            [2.103510872100985, 48.79570448052273],
                            [2.103986129960595, 48.795731624861844],
                            [2.104472236811199, 48.795749272395476],
                            [2.104962034435666, 48.79574789032003],
                            [2.105455511439231, 48.79572985839365],
                            [2.105949086909674, 48.79569041070288],
                            [2.106424732283703, 48.79563426936188],
                            [2.106914848316776, 48.7955638785091],
                            [2.107390620647533, 48.795479181062994],
                            [2.107816052636528, 48.795377724667944],
                            [2.108270390515862, 48.79525491057731],
                            [2.108728360406763, 48.79512496420476],
                            [2.109154025991882, 48.79497115721885],
                            [2.109680764025691, 48.79476520547845],
                            [2.110294111936995, 48.794518974053865],
                            [2.110961593718655, 48.79424667472427],
                            [2.111369258162332, 48.794088065982855],
                            [2.111697533309683, 48.79396498860572],
                            [2.112061828922531, 48.79383960199691],
                            [2.112483806336287, 48.79370005213547],
                            [2.112801132518071, 48.793607882006135],
                            [2.113176151228948, 48.79349916875279],
                            [2.11369172125704, 48.793366936094806],
                            [2.114286612721081, 48.79321344201142],
                            [2.114690340145993, 48.79312619386876],
                            [2.115083250085545, 48.79304130261554],
                            [2.115443696458172, 48.792968243717226],
                            [2.11591216526011, 48.79289777277563],
                            [2.116330153700183, 48.792841477695944],
                            [2.11687422424131, 48.79277590713132],
                            [2.117843448911033, 48.79266118584478],
                            [2.120895214199257, 48.79230058968553],
                            [2.12276515961669, 48.79208045968901],
                            [2.123371895057395, 48.792006960314865],
                            [2.123854964587829, 48.79198209806883],
                            [2.124117106316824, 48.79197237837199],
                            [2.124505010430262, 48.79197130289541],
                            [2.124978607028827, 48.791982975227185],
                            [2.125773213019912, 48.79204200359494],
                            [2.126103812899514, 48.792074090135145],
                            [2.126404451834651, 48.79211061667671],
                            [2.126827479735518, 48.79217254796331],
                            [2.127227320272672, 48.79224612597793],
                            [2.12760129539878, 48.792321452990265],
                            [2.127994261423026, 48.792412101522544],
                            [2.128362701359944, 48.79250989839397],
                            [2.128830302441107, 48.79265463765974],
                            [2.129149705918469, 48.79276223361234],
                            [2.129462265955019, 48.792878809983584],
                            [2.130050581171206, 48.79312718041466],
                            [2.130828967598358, 48.7934927980301],
                            [2.13206509185052, 48.79409304530295],
                            [2.132487588843224, 48.794289846410095],
                            [2.133002509056168, 48.794520084339],
                            [2.13335716335117, 48.7946664018369],
                            [2.13369969439922, 48.79478212009287],
                            [2.13399604854809, 48.79487347462278],
                            [2.134304686413588, 48.794956757804414],
                            [2.134637837020887, 48.79503738448375],
                            [2.135009117560278, 48.7951135822115],
                            [2.1359721799146, 48.79526816122795],
                            [2.136050489663708, 48.79528024627206],
                        ],
                    },
                },
                574: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80518233330807, 1.8484705402272763],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 5040.70247754,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.816466794198607,
                            48.80227950685127,
                            1.877504204313639,
                            48.81532862049073,
                        ),
                        "coordinates": [
                            [1.816466794198607, 48.802601980906694],
                            [1.817032818079235, 48.8025335043232],
                            [1.817823666604824, 48.80245720189971],
                            [1.818624898789292, 48.80238530353169],
                            [1.819086762327612, 48.802350530441245],
                            [1.82000609534681, 48.802310634074026],
                            [1.820074188137612, 48.80230824451127],
                            [1.820718350384725, 48.802285081362],
                            [1.821076445753394, 48.80227950685127],
                            [1.821441263605794, 48.80228205495915],
                            [1.821821056380993, 48.80228467041143],
                            [1.822483914054006, 48.80229665411869],
                            [1.82320791904584, 48.802319701459034],
                            [1.823538491128812, 48.802342771761175],
                            [1.823837892918126, 48.80235221246174],
                            [1.824964241420545, 48.802435511383095],
                            [1.826055303175848, 48.802508748765874],
                            [1.826271593266374, 48.80252500527546],
                            [1.827893059945599, 48.80265005864113],
                            [1.82922479761647, 48.80275221770809],
                            [1.829450618797667, 48.80276851053067],
                            [1.829554004320367, 48.8027761645971],
                            [1.830159347084805, 48.80282202154411],
                            [1.834557352977546, 48.80314993013397],
                            [1.837705248178437, 48.80338317567262],
                            [1.838303817284695, 48.80342716060231],
                            [1.838737783527716, 48.80345873373858],
                            [1.839736298611609, 48.8035332339526],
                            [1.842137252339903, 48.803724430707796],
                            [1.843440591975587, 48.8038128103879],
                            [1.844704414875316, 48.80390550164154],
                            [1.846983025185839, 48.80408167887678],
                            [1.849335182132726, 48.804256325846175],
                            [1.851690079303359, 48.80443093648833],
                            [1.854043639604491, 48.80460459368391],
                            [1.85577003475879, 48.8047332918976],
                            [1.857218832070746, 48.804849106204976],
                            [1.857331747852899, 48.80485767455522],
                            [1.858980623305471, 48.804979703596494],
                            [1.859498935581443, 48.805020542924616],
                            [1.859677163506899, 48.80503298013552],
                            [1.860264906717973, 48.805074106096555],
                            [1.861847217251214, 48.80518232598419],
                            [1.862328750917853, 48.80522569814248],
                            [1.86288904744771, 48.80529007787644],
                            [1.863170546078489, 48.80532362203207],
                            [1.863779642244063, 48.80541068270712],
                            [1.864069155035706, 48.805460445227745],
                            [1.864676620353485, 48.8055762719471],
                            [1.865268950380655, 48.80570911975499],
                            [1.865745581680614, 48.80583968759697],
                            [1.866440712724201, 48.806043997862496],
                            [1.867223772337531, 48.806308917685236],
                            [1.867496424041834, 48.80641525673903],
                            [1.868103904531152, 48.806675851831734],
                            [1.868525453291286, 48.8068745276079],
                            [1.868965887020769, 48.80709216469365],
                            [1.869272024340581, 48.80725799047664],
                            [1.86952657099664, 48.80740831568767],
                            [1.870157316082131, 48.807803888443935],
                            [1.870390018599309, 48.80796131687527],
                            [1.870742814372329, 48.808234344494004],
                            [1.871063301534588, 48.80846857023127],
                            [1.871374024220767, 48.80872793515015],
                            [1.871726326190471, 48.80905491568096],
                            [1.872075690908933, 48.809405263831835],
                            [1.872427532637042, 48.80978260058982],
                            [1.873296930715759, 48.81072769521586],
                            [1.874195865176207, 48.81172146349909],
                            [1.874594691971299, 48.81217452445748],
                            [1.874635138465118, 48.812217853840444],
                            [1.874678265947965, 48.812265691291785],
                            [1.875186346180608, 48.81283160391503],
                            [1.875763471882011, 48.8134418584178],
                            [1.876287841852475, 48.814015925602206],
                            [1.876341781856911, 48.814072799075454],
                            [1.876411886775733, 48.81414862286476],
                            [1.876564270028339, 48.814309310792474],
                            [1.877504204313639, 48.81532862049073],
                        ],
                    },
                },
                575: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.76437037389192, 1.9754262052250464],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 5114.58099421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.943835201056777,
                            48.75538926869322,
                            2.006566869057667,
                            48.77480280977951,
                        ),
                        "coordinates": [
                            [1.943835201056777, 48.75538926869322],
                            [1.944667364028943, 48.75559099755985],
                            [1.948089958754974, 48.75630451146039],
                            [1.949761965640149, 48.756630626206295],
                            [1.95098834279538, 48.756882240266435],
                            [1.952070762970246, 48.757136527119066],
                            [1.952832360409277, 48.75730723778661],
                            [1.953986601811341, 48.7575839563403],
                            [1.954719421973728, 48.75775455743983],
                            [1.955667704796042, 48.757986153882165],
                            [1.956716320331152, 48.75827518109275],
                            [1.957348324839237, 48.75845494657275],
                            [1.957817558002823, 48.75858658021936],
                            [1.958387340651808, 48.75874709874267],
                            [1.959028977802339, 48.7589237145464],
                            [1.959890836127262, 48.759167678353315],
                            [1.960465357045865, 48.75933771841221],
                            [1.961490013672851, 48.75962979542499],
                            [1.963711603908849, 48.76028110622803],
                            [1.964640567422104, 48.76054111619817],
                            [1.965665533965252, 48.760798257957504],
                            [1.966455716218026, 48.76101021319322],
                            [1.967217280111452, 48.7611998632285],
                            [1.968953232641303, 48.76164350480127],
                            [1.970096989484728, 48.761931271902014],
                            [1.972363822311808, 48.762495317178804],
                            [1.973067927450299, 48.76267363942385],
                            [1.973477410427192, 48.762784396444744],
                            [1.973861701975016, 48.762895072320156],
                            [1.974156210934549, 48.76297928689983],
                            [1.974608660204442, 48.763121108864894],
                            [1.975000051483632, 48.763246078785315],
                            [1.975477595433308, 48.76340225333082],
                            [1.976016101591305, 48.76358954949254],
                            [1.976525801437547, 48.763779131923826],
                            [1.977049780801759, 48.763985413454215],
                            [1.977548571904761, 48.76419161190875],
                            [1.978083152615097, 48.76442647291585],
                            [1.978606956344336, 48.76465891864899],
                            [1.979378354397805, 48.76499683059387],
                            [1.979963167727697, 48.765255635022584],
                            [1.980558770292436, 48.76551684829816],
                            [1.981279957062491, 48.765833176924154],
                            [1.981983210036676, 48.76614230624942],
                            [1.982568066930035, 48.76639871782676],
                            [1.983063272717583, 48.76660963986517],
                            [1.983709346963289, 48.766863855856535],
                            [1.984341132099917, 48.767103748659196],
                            [1.985030494888863, 48.7673461933727],
                            [1.98565887661744, 48.7675598945088],
                            [1.986423754093624, 48.76781446201408],
                            [1.989239064432506, 48.76876293098881],
                            [1.989673531314358, 48.768916534790684],
                            [1.990079236590753, 48.76906528943964],
                            [1.990459781456195, 48.76920920857999],
                            [1.990750473904049, 48.76933381857678],
                            [1.991134506371609, 48.76949440145146],
                            [1.991547189518956, 48.76967648375796],
                            [1.992006518777412, 48.76988011989825],
                            [1.994963320565364, 48.77122384796468],
                            [1.995709732354749, 48.771561574582485],
                            [1.996108116283379, 48.77173407956733],
                            [1.996470650399578, 48.771885062822726],
                            [1.996901436443583, 48.772057661878335],
                            [1.99727125625033, 48.772196767058944],
                            [1.997691377615981, 48.77235029773417],
                            [1.998107983785947, 48.772491918234685],
                            [1.998564203646575, 48.77263127620023],
                            [1.999006107936467, 48.772758692624365],
                            [1.999451597836565, 48.77288849759675],
                            [2.000008601457484, 48.773030528035186],
                            [2.000486510994423, 48.77315804509535],
                            [2.001219583688146, 48.773348177122166],
                            [2.005718365196384, 48.774574809731874],
                            [2.006480182944973, 48.7747792669428],
                            [2.006566869057667, 48.77480280977951],
                        ],
                    },
                },
                576: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.041791667925565, 2.1187300111148657],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 2180.50810562,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.107233059674136,
                            49.033987636271455,
                            2.128263873923673,
                            49.04558799326531,
                        ),
                        "coordinates": [
                            [2.128263873923673, 49.033987636271455],
                            [2.128129194074634, 49.034113715787555],
                            [2.127001222509834, 49.03514131753568],
                            [2.126554371205225, 49.03555093473141],
                            [2.126148450092699, 49.035907090451964],
                            [2.125911377526481, 49.03612793351793],
                            [2.12554623049908, 49.036468101551904],
                            [2.12521636011758, 49.036808334727496],
                            [2.125137259772239, 49.03689919806773],
                            [2.124921739789295, 49.03715576938806],
                            [2.124701970925326, 49.03741818034744],
                            [2.124508532850205, 49.037707907023204],
                            [2.12440497701337, 49.03785768139787],
                            [2.124326846051249, 49.037970682918875],
                            [2.124059183968403, 49.03838472483637],
                            [2.123776786101228, 49.038804811006315],
                            [2.123509210313695, 49.03921103870588],
                            [2.123276559854186, 49.03955502910891],
                            [2.123100396882108, 49.03980470005338],
                            [2.122898114370557, 49.04008399728096],
                            [2.12250205708275, 49.04057156555514],
                            [2.121908172963902, 49.041253005346746],
                            [2.121542675220651, 49.041629116409815],
                            [2.121276213118279, 49.04187861479338],
                            [2.120950794296375, 49.042158576515476],
                            [2.120635065769966, 49.042411577662996],
                            [2.12029610305886, 49.04265913833664],
                            [2.119932502105776, 49.04290935003786],
                            [2.11951273202694, 49.04317743811158],
                            [2.119077985287255, 49.04342841147821],
                            [2.118628222981144, 49.043671260106215],
                            [2.118168981940748, 49.04389070806361],
                            [2.117752285473035, 49.04407876024903],
                            [2.117253422064275, 49.04428553856905],
                            [2.116779262196315, 49.044473477956316],
                            [2.11632440698335, 49.04462638000719],
                            [2.115877800296, 49.04476940466895],
                            [2.115450420487825, 49.04489537797772],
                            [2.115038154341169, 49.045006091655345],
                            [2.114254838940086, 49.04518712632793],
                            [2.113839944694883, 49.0452726509574],
                            [2.113425656976553, 49.045347331347266],
                            [2.11300892676945, 49.045412217757935],
                            [2.112633856150531, 49.04546364254553],
                            [2.112022053058747, 49.04552899151093],
                            [2.11138984248111, 49.04556911615135],
                            [2.110894539819698, 49.04558612667887],
                            [2.110754998510663, 49.04558675096887],
                            [2.110445627189619, 49.04558799326531],
                            [2.110005283062125, 49.045570484125804],
                            [2.109539658597023, 49.04554626751525],
                            [2.109099345927297, 49.04552209925562],
                            [2.108193440028024, 49.04546705174223],
                            [2.107233059674136, 49.04539401994291],
                        ],
                    },
                },
                577: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.795632177901794, 2.4295745833280105],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1530.4152893,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.426482408484048,
                            48.78891489668918,
                            2.432070116592686,
                            48.80204938032392,
                        ),
                        "coordinates": [
                            [2.432070116592686, 48.78891489668918],
                            [2.431857313997105, 48.78943027009336],
                            [2.431660120323357, 48.78988012947137],
                            [2.431473668068494, 48.79029904713331],
                            [2.431254965732261, 48.79080364752911],
                            [2.430659790727081, 48.792179395721874],
                            [2.430340868570299, 48.79301956358032],
                            [2.430229929071471, 48.79339083026073],
                            [2.430147798354993, 48.793762074000824],
                            [2.430119416877252, 48.79399051350288],
                            [2.43008415009924, 48.79438789111289],
                            [2.430038158688936, 48.7948281059252],
                            [2.429989295476793, 48.79565853383082],
                            [2.429953915578894, 48.795996428041754],
                            [2.429925447488488, 48.796179659568146],
                            [2.429889830398333, 48.796391450447665],
                            [2.429832615912633, 48.79661039544663],
                            [2.429771764490148, 48.796810309873905],
                            [2.429667843333378, 48.79708877668779],
                            [2.429578178412195, 48.79728871353238],
                            [2.429447291688545, 48.797544786007194],
                            [2.429140611158748, 48.79805672309048],
                            [2.429014369083738, 48.79824567307316],
                            [2.42886635520273, 48.79844003572659],
                            [2.42835571706259, 48.799082529760724],
                            [2.428039017466682, 48.79949099821307],
                            [2.427620398081034, 48.800078146945296],
                            [2.4272970635476, 48.80053047876123],
                            [2.427156963907712, 48.800732833785176],
                            [2.426884050436453, 48.80118750326808],
                            [2.426744087931962, 48.80146837501133],
                            [2.42650013095641, 48.80200629831029],
                            [2.426482408484048, 48.80204938032392],
                        ],
                    },
                },
                578: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.798722030786166, 2.161872886568504],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1482.62585436,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.152378660253372,
                            48.79652818117568,
                            2.171389812756379,
                            48.80071846386355,
                        ),
                        "coordinates": [
                            [2.171389812756379, 48.80071846386355],
                            [2.170830357527754, 48.800700720559675],
                            [2.170326695902241, 48.80067533554842],
                            [2.169697168739786, 48.80062819510285],
                            [2.169202898781894, 48.8005843309325],
                            [2.168447606155488, 48.80048769712934],
                            [2.167687736234038, 48.80036640154266],
                            [2.167049172095505, 48.80023603764411],
                            [2.166345438479331, 48.80006859693602],
                            [2.165730297934967, 48.79991052985321],
                            [2.164692812178737, 48.79962773303816],
                            [2.164192683305267, 48.7994818365617],
                            [2.163649432820911, 48.79930969882626],
                            [2.163084630812713, 48.79912087097465],
                            [2.162850799732983, 48.799041995934324],
                            [2.161958736431169, 48.79873738058273],
                            [2.160494482932771, 48.79826508796951],
                            [2.160246219863137, 48.79819570134629],
                            [2.15992599538207, 48.79810716886839],
                            [2.15939704124788, 48.797973103336034],
                            [2.158322075302499, 48.79769604510322],
                            [2.157683680908086, 48.79753481665686],
                            [2.15683568548617, 48.797310081377546],
                            [2.155781306088051, 48.797035313672566],
                            [2.155455648608842, 48.79696194973523],
                            [2.155092696263549, 48.796900697276406],
                            [2.153650330733015, 48.7967032856754],
                            [2.152378660253372, 48.79652818117568],
                        ],
                    },
                },
                579: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.83456161181582, 2.26714065541585],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1119.0257888,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263689648725751,
                            48.830119640157896,
                            2.270458243787242,
                            48.83908975542995,
                        ),
                        "coordinates": [
                            [2.270458243787242, 48.83908975542995],
                            [2.269785380384059, 48.83836404985602],
                            [2.269323566514949, 48.83782621806188],
                            [2.268981743080527, 48.837388216974766],
                            [2.268672504633892, 48.836900536377016],
                            [2.26837402517641, 48.836403075973415],
                            [2.267993049190534, 48.83562004519543],
                            [2.267885248402062, 48.8353844250816],
                            [2.267661327415963, 48.83487388104411],
                            [2.267500638937627, 48.83458208794027],
                            [2.267353175919909, 48.83436072036364],
                            [2.267252457364585, 48.83421789828468],
                            [2.267112139057428, 48.83404412060627],
                            [2.266953785359692, 48.833879849245115],
                            [2.266298799978871, 48.83319419792548],
                            [2.265906533237247, 48.83278708759249],
                            [2.265773372363419, 48.83265376200334],
                            [2.265557462502357, 48.832420452297434],
                            [2.265442328836309, 48.83228475829323],
                            [2.265305600083296, 48.8321276359963],
                            [2.264175608397526, 48.83072037315834],
                            [2.263779952993441, 48.830230914423204],
                            [2.263689648725751, 48.830119640157896],
                        ],
                    },
                },
                580: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.67315556866799, 2.3488048886974147],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 881.966705953,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344492790482471,
                            48.670783940999655,
                            2.352481401048998,
                            48.676446656997726,
                        ),
                        "coordinates": [
                            [2.344492790482471, 48.670783940999655],
                            [2.345057313905659, 48.67094805008256],
                            [2.345549008047062, 48.671109829051694],
                            [2.345980125829444, 48.67126920930853],
                            [2.346332208719983, 48.67140955935653],
                            [2.346517001485164, 48.671491989470326],
                            [2.347168793780418, 48.67180217899401],
                            [2.347782580698658, 48.67213125142602],
                            [2.347968621243447, 48.67224274246058],
                            [2.348525392909058, 48.6725790116448],
                            [2.349311698640001, 48.67314456571711],
                            [2.349766656015362, 48.67349342994597],
                            [2.350101190746646, 48.67377562382039],
                            [2.350349299814329, 48.67400144668846],
                            [2.350591060053158, 48.67424062247734],
                            [2.350984958830975, 48.67468121494793],
                            [2.351504493782131, 48.67535114506738],
                            [2.351748366911131, 48.67566491383806],
                            [2.352067131975409, 48.67603431518159],
                            [2.352328379706742, 48.676298819112354],
                            [2.352481401048998, 48.676446656997726],
                        ],
                    },
                },
                581: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.73430773971939, 2.272325741595113],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 194.675218679,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.271186213048966,
                            48.73385117840906,
                            2.273483464396533,
                            48.734716586800225,
                        ),
                        "coordinates": [
                            [2.271186213048966, 48.73385117840906],
                            [2.271496334618988, 48.73398599406839],
                            [2.271683497278407, 48.73406639087547],
                            [2.271932139426364, 48.73417444558605],
                            [2.272145466301575, 48.734260898063596],
                            [2.272372394705531, 48.73434106221353],
                            [2.272748801728018, 48.73447346776019],
                            [2.273085810156915, 48.73458516686029],
                            [2.273483464396533, 48.734716586800225],
                        ],
                    },
                },
                582: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.71643058349215, 2.277365341765458],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 4518.75826316,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263073689251946,
                            48.702239386903386,
                            2.294557747854634,
                            48.73115415790263,
                        ),
                        "coordinates": [
                            [2.263073689251946, 48.72964839824706],
                            [2.263454077215723, 48.729805117917095],
                            [2.263765178125915, 48.72993661265436],
                            [2.264102090300497, 48.730079812967276],
                            [2.264292283102973, 48.73016086919445],
                            [2.264869665033552, 48.7304031406679],
                            [2.265377766082045, 48.73061568928092],
                            [2.265646764091223, 48.730726468814275],
                            [2.265853282589221, 48.73080213621915],
                            [2.266048939320782, 48.7308688048377],
                            [2.266244608278086, 48.73092737896986],
                            [2.266409026242424, 48.730976042053264],
                            [2.266600634722214, 48.73102202339225],
                            [2.266773226191539, 48.73105810058573],
                            [2.266943113291285, 48.731085183417065],
                            [2.267098053413373, 48.731106861123195],
                            [2.267303291505616, 48.73112856946],
                            [2.267395721167573, 48.73113492122651],
                            [2.267527570695094, 48.731143095182816],
                            [2.267611847285641, 48.731147642803876],
                            [2.267705640511055, 48.73115129712408],
                            [2.267770888455745, 48.73115313474746],
                            [2.267856528925774, 48.731154086430436],
                            [2.267974796152814, 48.73115415790263],
                            [2.268056361471213, 48.73115240855939],
                            [2.268199102637317, 48.73114889803126],
                            [2.268204541280311, 48.73114890079395],
                            [2.268309791562912, 48.731146603004234],
                            [2.268441447227594, 48.731136690241485],
                            [2.268602880317386, 48.73112216298843],
                            [2.268861199717673, 48.73109623834504],
                            [2.269120895590522, 48.73105772465082],
                            [2.269324861518742, 48.73101558082765],
                            [2.269458115929544, 48.73099047947526],
                            [2.269768167057491, 48.73090793013916],
                            [2.270012187904604, 48.73083306951555],
                            [2.27030264099206, 48.730731987004816],
                            [2.270596438795645, 48.73060356268054],
                            [2.270864408039228, 48.730473323945645],
                            [2.271116088278002, 48.73032508949165],
                            [2.27137320654664, 48.730174159633485],
                            [2.271525593190765, 48.73006903273687],
                            [2.271690251058171, 48.72993603521267],
                            [2.271845399621338, 48.72979673629009],
                            [2.272109497057917, 48.729501925735796],
                            [2.272316517085674, 48.72919269361662],
                            [2.272508662798811, 48.72882140299808],
                            [2.27261648025196, 48.728487833240145],
                            [2.272663100737706, 48.72817401401529],
                            [2.272670055934793, 48.72805081768148],
                            [2.272667646939937, 48.72780981133782],
                            [2.272639816036738, 48.727254044534504],
                            [2.272637266073099, 48.72712364935275],
                            [2.272632035005529, 48.7269635753702],
                            [2.272614840187014, 48.726593065007755],
                            [2.272592535279834, 48.725969857211375],
                            [2.272568961716421, 48.725276504818396],
                            [2.272558586842029, 48.72488981185418],
                            [2.272550776333793, 48.72462182400001],
                            [2.272551063595406, 48.72439880465827],
                            [2.272556781900592, 48.72418028421598],
                            [2.272569205836226, 48.724031911525344],
                            [2.272588474409817, 48.72384577336106],
                            [2.272611868589173, 48.72362186752144],
                            [2.272637936363906, 48.72343303545508],
                            [2.272678948083629, 48.72324960666707],
                            [2.272726791663308, 48.72303740512087],
                            [2.272790992079262, 48.72278924274592],
                            [2.272874245404659, 48.72252040704018],
                            [2.273057092058846, 48.72195756523596],
                            [2.27324905046466, 48.721313161754445],
                            [2.273459693589715, 48.720654745274366],
                            [2.273581175931571, 48.72024294626791],
                            [2.273716264871817, 48.7198176658535],
                            [2.273802227674528, 48.71954793150471],
                            [2.273860912163876, 48.71935462070352],
                            [2.274086091444276, 48.718612846021244],
                            [2.274196618352734, 48.71825949308822],
                            [2.274477782896371, 48.717297425928535],
                            [2.274605730930263, 48.71689822698959],
                            [2.27472749537954, 48.7164837217094],
                            [2.274828478910071, 48.716147448990995],
                            [2.274937615575277, 48.715810282096285],
                            [2.275034428018997, 48.71554774743654],
                            [2.275236245819788, 48.71498850982511],
                            [2.27536164427676, 48.714683724821086],
                            [2.27559329097284, 48.7141730634331],
                            [2.275704987159952, 48.71395819759878],
                            [2.275924285554908, 48.71353925501875],
                            [2.276369562678905, 48.71278590250201],
                            [2.276572409393378, 48.71247756026925],
                            [2.276967182917771, 48.71189594000629],
                            [2.277255720528805, 48.711513002472344],
                            [2.27757145000388, 48.71111299128091],
                            [2.277893960552392, 48.71072017819877],
                            [2.278590572756904, 48.70995975311715],
                            [2.278865372167183, 48.70968471721832],
                            [2.279522392734328, 48.70906095593929],
                            [2.28028133036463, 48.708413860737366],
                            [2.280828050274365, 48.707975287662286],
                            [2.281282258133949, 48.70763198933155],
                            [2.281590950582322, 48.70740012789819],
                            [2.282060067167396, 48.70708201345272],
                            [2.282952020634881, 48.706505108122286],
                            [2.283471391940017, 48.706187910662216],
                            [2.284408096998167, 48.705661373721696],
                            [2.284954588723514, 48.70537745559441],
                            [2.28543853413841, 48.70513217423605],
                            [2.285887913471626, 48.70492089380368],
                            [2.286301704526414, 48.704731487226304],
                            [2.28675569447271, 48.70453834475485],
                            [2.287115725821168, 48.70438466226381],
                            [2.287473903969532, 48.704246341481536],
                            [2.287832083353679, 48.70410659305472],
                            [2.288277984538534, 48.70393919258839],
                            [2.289183148212736, 48.70362213379452],
                            [2.289918411799518, 48.70336794685478],
                            [2.290596567138263, 48.703155997074845],
                            [2.291072207384759, 48.70302579539243],
                            [2.292281652979747, 48.70272502141019],
                            [2.292834723029183, 48.70259574246507],
                            [2.293356529837167, 48.70248263548257],
                            [2.293909481649249, 48.70236453317409],
                            [2.294557747854634, 48.702239386903386],
                        ],
                    },
                },
                583: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.79486075047856, 2.1040231487081065],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 5003.12924709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.071847005929401,
                            48.79197130289541,
                            2.136050489663708,
                            48.798774681352754,
                        ),
                        "coordinates": [
                            [2.071847005929401, 48.79870763528835],
                            [2.071930959217986, 48.79871552851866],
                            [2.072216710538763, 48.7987359766609],
                            [2.072579474675331, 48.79875781412333],
                            [2.072862898980037, 48.79877217510979],
                            [2.07339670251307, 48.798774681352754],
                            [2.073713874486058, 48.798774514434655],
                            [2.074120918822997, 48.79876825942257],
                            [2.074570257201611, 48.79874411437348],
                            [2.075095898700846, 48.79870575443047],
                            [2.075455455431691, 48.79866970976342],
                            [2.075887224661105, 48.79862123822052],
                            [2.076227752121453, 48.79857975186269],
                            [2.076626900075734, 48.798521310787564],
                            [2.07716506105974, 48.79843081224707],
                            [2.07764852043101, 48.798316933934665],
                            [2.078167738891175, 48.798203905116274],
                            [2.078658217708944, 48.798076532368164],
                            [2.079083828515797, 48.79795614915085],
                            [2.07970072398773, 48.79775767757964],
                            [2.08020225629617, 48.79758035736656],
                            [2.080682237327531, 48.79739108945262],
                            [2.082831239058495, 48.79647994934646],
                            [2.08407821011798, 48.79595569704254],
                            [2.084495051075953, 48.79578292818973],
                            [2.084798183357852, 48.795662251920504],
                            [2.085068779097173, 48.79556529741404],
                            [2.085472803759792, 48.795432945457634],
                            [2.085851533812421, 48.795317192821884],
                            [2.086342037093098, 48.795175510300744],
                            [2.086926168987106, 48.795034032056186],
                            [2.087503001665491, 48.794911569452395],
                            [2.088104956144356, 48.79480581469834],
                            [2.088696007853362, 48.794719067792464],
                            [2.089301405013185, 48.794644244904084],
                            [2.089913909264423, 48.794588469047525],
                            [2.09054429876811, 48.794556522554586],
                            [2.091113408132319, 48.79453633626861],
                            [2.09172199049859, 48.79454478562203],
                            [2.092341270622694, 48.79457466828989],
                            [2.093068461780212, 48.79463095098126],
                            [2.093925150711385, 48.79471843643121],
                            [2.094774639817521, 48.794805900752586],
                            [2.098176203113287, 48.7951604600855],
                            [2.101567045015145, 48.79550775765459],
                            [2.10300329181604, 48.795658232499086],
                            [2.103510872100985, 48.79570448052273],
                            [2.103986129960595, 48.795731624861844],
                            [2.104472236811199, 48.795749272395476],
                            [2.104962034435666, 48.79574789032003],
                            [2.105455511439231, 48.79572985839365],
                            [2.105949086909674, 48.79569041070288],
                            [2.106424732283703, 48.79563426936188],
                            [2.106914848316776, 48.7955638785091],
                            [2.107390620647533, 48.795479181062994],
                            [2.107816052636528, 48.795377724667944],
                            [2.108270390515862, 48.79525491057731],
                            [2.108728360406763, 48.79512496420476],
                            [2.109154025991882, 48.79497115721885],
                            [2.109680764025691, 48.79476520547845],
                            [2.110294111936995, 48.794518974053865],
                            [2.110961593718655, 48.79424667472427],
                            [2.111369258162332, 48.794088065982855],
                            [2.111697533309683, 48.79396498860572],
                            [2.112061828922531, 48.79383960199691],
                            [2.112483806336287, 48.79370005213547],
                            [2.112801132518071, 48.793607882006135],
                            [2.113176151228948, 48.79349916875279],
                            [2.11369172125704, 48.793366936094806],
                            [2.114286612721081, 48.79321344201142],
                            [2.114690340145993, 48.79312619386876],
                            [2.115083250085545, 48.79304130261554],
                            [2.115443696458172, 48.792968243717226],
                            [2.11591216526011, 48.79289777277563],
                            [2.116330153700183, 48.792841477695944],
                            [2.11687422424131, 48.79277590713132],
                            [2.117843448911033, 48.79266118584478],
                            [2.120895214199257, 48.79230058968553],
                            [2.12276515961669, 48.79208045968901],
                            [2.123371895057395, 48.792006960314865],
                            [2.123854964587829, 48.79198209806883],
                            [2.124117106316824, 48.79197237837199],
                            [2.124505010430262, 48.79197130289541],
                            [2.124978607028827, 48.791982975227185],
                            [2.125773213019912, 48.79204200359494],
                            [2.126103812899514, 48.792074090135145],
                            [2.126404451834651, 48.79211061667671],
                            [2.126827479735518, 48.79217254796331],
                            [2.127227320272672, 48.79224612597793],
                            [2.12760129539878, 48.792321452990265],
                            [2.127994261423026, 48.792412101522544],
                            [2.128362701359944, 48.79250989839397],
                            [2.128830302441107, 48.79265463765974],
                            [2.129149705918469, 48.79276223361234],
                            [2.129462265955019, 48.792878809983584],
                            [2.130050581171206, 48.79312718041466],
                            [2.130828967598358, 48.7934927980301],
                            [2.13206509185052, 48.79409304530295],
                            [2.132487588843224, 48.794289846410095],
                            [2.133002509056168, 48.794520084339],
                            [2.13335716335117, 48.7946664018369],
                            [2.13369969439922, 48.79478212009287],
                            [2.13399604854809, 48.79487347462278],
                            [2.134304686413588, 48.794956757804414],
                            [2.134637837020887, 48.79503738448375],
                            [2.135009117560278, 48.7951135822115],
                            [2.1359721799146, 48.79526816122795],
                            [2.136050489663708, 48.79528024627206],
                        ],
                    },
                },
                584: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.80097656474467, 2.213117185082394],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 4528.45180755,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.183684109854236,
                            48.79863737633212,
                            2.240883069335648,
                            48.80749262578012,
                        ),
                        "coordinates": [
                            [2.240883069335648, 48.80749262578012],
                            [2.240320698555044, 48.80678704468132],
                            [2.240092906273693, 48.806476005367635],
                            [2.240019625386438, 48.80635454104201],
                            [2.239886626967051, 48.80613680349458],
                            [2.239776685821098, 48.805964947942485],
                            [2.239635523373623, 48.80574630367408],
                            [2.239475288795493, 48.80553483740985],
                            [2.239316375513287, 48.805344055684714],
                            [2.239165577561272, 48.80518115741641],
                            [2.238963136330118, 48.80497235194884],
                            [2.238806893375868, 48.804810347579185],
                            [2.238675089807507, 48.80468253749114],
                            [2.23849974967032, 48.8045403004669],
                            [2.238313548339405, 48.80438366553852],
                            [2.238164035122339, 48.80426213404542],
                            [2.23799142403651, 48.804118100397694],
                            [2.237822890045549, 48.803978567012834],
                            [2.23754290363341, 48.803749007977665],
                            [2.2370792599209, 48.80345633861449],
                            [2.236720210267189, 48.80328156382477],
                            [2.236395165437536, 48.80312210617549],
                            [2.236003414869444, 48.80296348853488],
                            [2.235756780566318, 48.802882050936],
                            [2.235475524950392, 48.80280744542746],
                            [2.234780171058944, 48.80266294036302],
                            [2.234577313608959, 48.80262807118488],
                            [2.234337887985154, 48.80258700436088],
                            [2.234184110037434, 48.80256078727876],
                            [2.233841167130502, 48.802504723245505],
                            [2.233470997363747, 48.80244863292458],
                            [2.233045012124602, 48.80239338943316],
                            [2.232184834546844, 48.80230267617639],
                            [2.231556020635476, 48.80224364372678],
                            [2.229507587568691, 48.80206727398585],
                            [2.228318002250498, 48.801966327795014],
                            [2.226061347344496, 48.80177261143904],
                            [2.225526447716622, 48.80172712647114],
                            [2.221341207704024, 48.80136864808362],
                            [2.221232323540725, 48.801359545429825],
                            [2.220701513104539, 48.80131584087513],
                            [2.219299646113744, 48.80119479994797],
                            [2.216840269347992, 48.8009836057611],
                            [2.215771866196214, 48.80089254808984],
                            [2.215615350988152, 48.80087889245937],
                            [2.215520079607423, 48.80087069777654],
                            [2.215400310985341, 48.800859778896296],
                            [2.215254681130944, 48.80084793280485],
                            [2.214142732503124, 48.80075321712257],
                            [2.211356795959032, 48.80049928606813],
                            [2.209187360082731, 48.800318821108746],
                            [2.206556566559994, 48.80010001865402],
                            [2.205972706863281, 48.8000507885488],
                            [2.204611729014256, 48.79993770816375],
                            [2.201183452879624, 48.79965220591762],
                            [2.201105880523553, 48.79964491937094],
                            [2.199857881853771, 48.7995418082242],
                            [2.197843688212044, 48.79937390150759],
                            [2.196850985230035, 48.79928385223194],
                            [2.196006498943287, 48.79919628660919],
                            [2.193981630377544, 48.798962651219036],
                            [2.192857634189156, 48.798828143432225],
                            [2.192533761469411, 48.79879266222908],
                            [2.191766539847763, 48.79870648698661],
                            [2.191145688653347, 48.79865960080871],
                            [2.190534555150434, 48.79863903382209],
                            [2.189945145674272, 48.79863737633212],
                            [2.189107891694344, 48.798669566969984],
                            [2.188658597093236, 48.798698659372846],
                            [2.188256027429874, 48.79873715782228],
                            [2.187936245774292, 48.798784899484275],
                            [2.187655694525374, 48.79884010315162],
                            [2.187308949882079, 48.79891901797551],
                            [2.186336973295001, 48.7991402951749],
                            [2.185480920864058, 48.79932757326997],
                            [2.185267063569635, 48.79937405179657],
                            [2.183684109854236, 48.79972882534396],
                        ],
                    },
                },
                585: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.954907961666095, 1.8302331453303993],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3776.70170125,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.814911934161123,
                            48.93871923993318,
                            1.840517029657971,
                            48.96402029406584,
                        ),
                        "coordinates": [
                            [1.840517029657971, 48.93871923993318],
                            [1.839259456119651, 48.94106112942705],
                            [1.839107683302341, 48.94135723598351],
                            [1.838520471447111, 48.94246350831057],
                            [1.838257589751843, 48.94294708135568],
                            [1.837917818636616, 48.943473485196535],
                            [1.837643696575598, 48.94385179147729],
                            [1.837324203219214, 48.94426137330424],
                            [1.837253646103172, 48.944353692996536],
                            [1.836736138239635, 48.9450384910066],
                            [1.836364629118505, 48.94559532762359],
                            [1.836343805211657, 48.94562941031768],
                            [1.836327122982816, 48.94565901400366],
                            [1.836197924442457, 48.94587967404183],
                            [1.835901999807183, 48.94638648009117],
                            [1.835687619467646, 48.94679471950965],
                            [1.835485103516853, 48.94724437875692],
                            [1.835377351175946, 48.947503801768036],
                            [1.835280583184135, 48.947756979290695],
                            [1.835080565590898, 48.94836402439362],
                            [1.834803321403501, 48.94931606064913],
                            [1.834378140809992, 48.950717991784316],
                            [1.834202786215099, 48.95131435306057],
                            [1.834051651156718, 48.95181099933344],
                            [1.833986956337929, 48.951996869056266],
                            [1.833690264508096, 48.952842699291516],
                            [1.833037119046262, 48.95476881174423],
                            [1.833028624850475, 48.954798450395934],
                            [1.832719100073569, 48.95569458267156],
                            [1.832702220751264, 48.95574307069489],
                            [1.832681079540156, 48.95580772687732],
                            [1.832582642236807, 48.956087872501264],
                            [1.832289121744022, 48.957020045691515],
                            [1.832227033941579, 48.957216717623034],
                            [1.831973144805372, 48.95780227457157],
                            [1.831814951212435, 48.95812318663324],
                            [1.831566309802636, 48.95853486470205],
                            [1.831366522005625, 48.95884244002127],
                            [1.830930875208208, 48.95937829147739],
                            [1.830513697545098, 48.959843179464144],
                            [1.83041992769994, 48.95993179448333],
                            [1.829977234340759, 48.96035340112891],
                            [1.829453775254138, 48.960792634183875],
                            [1.8293779933736, 48.960857945936716],
                            [1.828791907114133, 48.96127711378623],
                            [1.827900609028269, 48.96182441486179],
                            [1.827302515207834, 48.96214819875789],
                            [1.826443219507783, 48.96256973336008],
                            [1.826328009966394, 48.96261688194734],
                            [1.825942562321888, 48.962778832278936],
                            [1.825778066660629, 48.96283745079758],
                            [1.825222869250805, 48.96303730978066],
                            [1.824389860641312, 48.96329077888374],
                            [1.823769628122923, 48.96343907963246],
                            [1.82317407843752, 48.96357759546599],
                            [1.822212088636071, 48.96375492857831],
                            [1.821887795089493, 48.96381282201855],
                            [1.821162938189798, 48.963907579271016],
                            [1.820826650049974, 48.96393663804808],
                            [1.820572389508032, 48.96395797343079],
                            [1.819983363908843, 48.96399308292943],
                            [1.819040677367278, 48.96402029406584],
                            [1.818453476307409, 48.96401133862653],
                            [1.817768008052001, 48.96399563961877],
                            [1.81649320302604, 48.9639143051651],
                            [1.815836663654982, 48.963875344154495],
                            [1.814911934161123, 48.963825577806084],
                        ],
                    },
                },
                586: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.672219398407286, 2.3382785118461307],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1207.65650753,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.333249457132578,
                            48.67035068664662,
                            2.344492790482471,
                            48.676381326172205,
                        ),
                        "coordinates": [
                            [2.333249457132578, 48.676381326172205],
                            [2.33327499324832, 48.67636897589384],
                            [2.33349078609946, 48.676261319289814],
                            [2.333667336763631, 48.676163413882506],
                            [2.333887224359005, 48.67602494296488],
                            [2.334113570669939, 48.67586821917927],
                            [2.334316525951001, 48.67572353451888],
                            [2.334467114848041, 48.67559810772385],
                            [2.334680532026273, 48.675385400749484],
                            [2.334852988773019, 48.67520552760157],
                            [2.33501466729806, 48.67501185338067],
                            [2.335226644484929, 48.67472871852567],
                            [2.335377545418504, 48.674457477725035],
                            [2.33546017913758, 48.674309961413655],
                            [2.335600301503366, 48.67396734094049],
                            [2.33575479324149, 48.673498618044995],
                            [2.335862575997938, 48.673227376311274],
                            [2.335952393178484, 48.67299658366883],
                            [2.336031430936267, 48.67282765224317],
                            [2.336142802653101, 48.67258972228607],
                            [2.336239803436913, 48.67244934268321],
                            [2.336448169287977, 48.672192378391884],
                            [2.336606239593984, 48.67200679139096],
                            [2.336775085197726, 48.671844997341154],
                            [2.33697267072562, 48.67167844532092],
                            [2.337163068378227, 48.67153092684074],
                            [2.337364243424585, 48.67139054699397],
                            [2.337590563512263, 48.67125492453411],
                            [2.337870769217268, 48.67110502456225],
                            [2.338125826713462, 48.67098367739124],
                            [2.338416805485883, 48.67085280993921],
                            [2.33874011669034, 48.670731460601395],
                            [2.339160419186143, 48.670614865808496],
                            [2.339616779537449, 48.67050408394311],
                            [2.340030885225712, 48.67043033263106],
                            [2.340270444287606, 48.670400696937406],
                            [2.340550302803886, 48.67038053232821],
                            [2.340897115540767, 48.67036555675809],
                            [2.341220255844797, 48.67035205497441],
                            [2.341473877979316, 48.67035068664662],
                            [2.341775570891128, 48.67036462100919],
                            [2.342188326473588, 48.67040596802333],
                            [2.342603161083047, 48.67044619259999],
                            [2.34312046918891, 48.67052230187858],
                            [2.343630595927048, 48.670607928323335],
                            [2.344492790482471, 48.670783940999655],
                        ],
                    },
                },
                587: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.01330973476587, 2.1761501915558954],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 3401.85573029,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.154663485640923,
                            49.00742329713069,
                            2.197619813968745,
                            49.01913673984224,
                        ),
                        "coordinates": [
                            [2.197619813968745, 49.00742329713069],
                            [2.197008091251297, 49.00762122621544],
                            [2.195541488379903, 49.008043884046316],
                            [2.193848750432538, 49.00850968595437],
                            [2.193439730674932, 49.00861862390083],
                            [2.191999067670692, 49.009011780942245],
                            [2.188342468293504, 49.0100239728252],
                            [2.187896449261309, 49.01014479582501],
                            [2.187193217458812, 49.01033362619896],
                            [2.184690434061876, 49.01100332858747],
                            [2.183093995563466, 49.01142947821652],
                            [2.182666827481433, 49.01154311184559],
                            [2.181816094022191, 49.01177275870757],
                            [2.180640878382492, 49.012089256590286],
                            [2.178049332489053, 49.01279432270234],
                            [2.178011018908898, 49.01280506074413],
                            [2.177708624539413, 49.01288647504226],
                            [2.177500636811216, 49.012943739858976],
                            [2.17674806297863, 49.01314682586018],
                            [2.175980425213717, 49.013356181143195],
                            [2.175078680235649, 49.013602211686965],
                            [2.174902164377811, 49.01364962398947],
                            [2.173447578949681, 49.01404773584815],
                            [2.173094537525855, 49.01414345457021],
                            [2.173043910225493, 49.01415597212351],
                            [2.172982332209368, 49.014172970655586],
                            [2.172861922373489, 49.01420337340517],
                            [2.172684032000837, 49.01425167940884],
                            [2.17239393191633, 49.014330399893325],
                            [2.172159933807473, 49.01439481122292],
                            [2.172124355370923, 49.01440465172236],
                            [2.169334150834148, 49.015161393541376],
                            [2.169280778493651, 49.015176602617416],
                            [2.168298240149801, 49.01544134684781],
                            [2.168121710485582, 49.015488749087595],
                            [2.16618532079457, 49.01601465458309],
                            [2.165480549707653, 49.01620514827598],
                            [2.163890874453162, 49.016629500666156],
                            [2.162296022835996, 49.01706274690875],
                            [2.161461213926096, 49.017287190064884],
                            [2.161117706484206, 49.01738018850346],
                            [2.157681202315227, 49.01830651546753],
                            [2.157593610267531, 49.018330658660545],
                            [2.156513748668304, 49.018628423148],
                            [2.154943888066075, 49.01906119071421],
                            [2.154663485640923, 49.01913673984224],
                        ],
                    },
                },
                588: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.70154162735394, 2.3012122730639697],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 995.409154433,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.294557747854634,
                            48.700680803710014,
                            2.307841188697314,
                            48.702239386903386,
                        ),
                        "coordinates": [
                            [2.294557747854634, 48.702239386903386],
                            [2.295489875003991, 48.702089552860656],
                            [2.295898527561079, 48.70203227798774],
                            [2.296358114075951, 48.701972960821195],
                            [2.296586380953354, 48.701945164839046],
                            [2.296854046292639, 48.70191828066241],
                            [2.297117635863831, 48.70189049667862],
                            [2.29756736559372, 48.7018456892334],
                            [2.297985843558901, 48.70180626575649],
                            [2.298310570775436, 48.70177490189755],
                            [2.298907024400513, 48.701733736261936],
                            [2.299234458578467, 48.70171496140827],
                            [2.299678736891328, 48.70168902912194],
                            [2.300484420980962, 48.70163443305752],
                            [2.301264285725748, 48.701585218414074],
                            [2.302133822148459, 48.70152523485462],
                            [2.302598483426814, 48.70148850477703],
                            [2.3028675061377, 48.7014635552391],
                            [2.30317048452421, 48.701433819443075],
                            [2.303522382329563, 48.70139615267292],
                            [2.303879717116014, 48.70135578937651],
                            [2.304517310762301, 48.70127737253189],
                            [2.305001995703076, 48.70121312327586],
                            [2.305304982701343, 48.70117363897072],
                            [2.305853897105987, 48.70109375407599],
                            [2.306136507669073, 48.70104976593277],
                            [2.306413686670377, 48.700998582096105],
                            [2.30664602908287, 48.70095547787793],
                            [2.30690826536132, 48.70090159125658],
                            [2.307300941549673, 48.70081536348481],
                            [2.307636554664625, 48.70073631387786],
                            [2.307841188697314, 48.700680803710014],
                        ],
                    },
                },
                589: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.84274008653178, 2.2734880252814365],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 917.935919265,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.270458243787242,
                            48.83908975542995,
                            2.276760967379574,
                            48.84619214048855,
                        ),
                        "coordinates": [
                            [2.276760967379574, 48.84619214048855],
                            [2.27640528039278, 48.845900076003126],
                            [2.276248761905203, 48.84575880632776],
                            [2.276048715764371, 48.84555906146355],
                            [2.275758873341016, 48.84525405204969],
                            [2.27521189487021, 48.8446485459268],
                            [2.274668449793864, 48.84405862639776],
                            [2.274150611499837, 48.84348880290342],
                            [2.273792751069634, 48.84311990317913],
                            [2.273100203459649, 48.84238660911527],
                            [2.272172288952394, 48.84141397065998],
                            [2.271792048236195, 48.841013583918645],
                            [2.271680467423908, 48.840887415272164],
                            [2.27158330340678, 48.84076363398678],
                            [2.271478953749894, 48.84062319384473],
                            [2.271407014557938, 48.84050656491617],
                            [2.271331500660505, 48.84036614014792],
                            [2.271245194079831, 48.84021143408095],
                            [2.271133725710957, 48.840004367835625],
                            [2.27100788249679, 48.839763982014965],
                            [2.270707708565289, 48.839361884557206],
                            [2.270458243787242, 48.83908975542995],
                        ],
                    },
                },
                590: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84607604408277, 2.353216226681086],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 284.242910299,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351623255016012,
                            48.84581647068253,
                            2.354917983707404,
                            48.846656851242656,
                        ),
                        "coordinates": [
                            [2.354917983707404, 48.84615112218132],
                            [2.354823729118982, 48.84614998616999],
                            [2.354820393295646, 48.84614987914396],
                            [2.354711368868046, 48.84614258012518],
                            [2.354604023032868, 48.84612803762798],
                            [2.3544994604544, 48.846106401514085],
                            [2.354398748077879, 48.846077896092176],
                            [2.354302922029714, 48.846042812959745],
                            [2.354261440284364, 48.84602487168644],
                            [2.354098689886726, 48.84595091117049],
                            [2.354085134474475, 48.84594484375396],
                            [2.353987902039159, 48.84590639995672],
                            [2.353885426400299, 48.84587443013215],
                            [2.353778695702904, 48.845849243588646],
                            [2.353668742499887, 48.845831084224145],
                            [2.353556619306361, 48.84582012409904],
                            [2.353443408049593, 48.84581647068253],
                            [2.35333019974534, 48.84582015774928],
                            [2.353218083531528, 48.84583115071644],
                            [2.35310814126627, 48.84584934301694],
                            [2.353001428386035, 48.84587456139192],
                            [2.352898976678402, 48.845906562307945],
                            [2.35280176699862, 48.84594503450714],
                            [2.352710742740347, 48.84598961167031],
                            [2.352709807128563, 48.84599011744452],
                            [2.35205393506584, 48.84634627853194],
                            [2.352019779043459, 48.84636519863373],
                            [2.351903183533692, 48.84643580893002],
                            [2.351794243241762, 48.84651156265241],
                            [2.351693481886526, 48.84659209482081],
                            [2.351623255016012, 48.846656851242656],
                        ],
                    },
                },
                591: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.963561910434706, 1.812005177604735],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 429.428439479,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.809094508773784,
                            48.96334411275807,
                            1.814911934161123,
                            48.963825577806084,
                        ),
                        "coordinates": [
                            [1.814911934161123, 48.963825577806084],
                            [1.813387699003068, 48.963666453558346],
                            [1.812083086767916, 48.96355179040191],
                            [1.811029724209674, 48.96347807079743],
                            [1.809279551877828, 48.963355057024316],
                            [1.809094508773784, 48.96334411275807],
                        ],
                    },
                },
                592: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.46379031496342, 2.177928929975727],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 7181.48869734,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.159530553968522,
                            48.43692392480675,
                            2.194581700525426,
                            48.493644578496685,
                        ),
                        "coordinates": [
                            [2.194581700525426, 48.493644578496685],
                            [2.194543419074386, 48.493594987026995],
                            [2.19386812612035, 48.492697598627814],
                            [2.19369535806391, 48.49245769662619],
                            [2.19353620037991, 48.49224663484257],
                            [2.193320342572003, 48.49191262474706],
                            [2.193108997505592, 48.49159682392375],
                            [2.192961367835239, 48.49134785109848],
                            [2.192670817150971, 48.49079984987994],
                            [2.192427998948882, 48.49032169050033],
                            [2.192244289407768, 48.48992400535016],
                            [2.192108231774393, 48.489621952381235],
                            [2.191834057205762, 48.48894199331298],
                            [2.191718547704176, 48.48863844837211],
                            [2.191621231562116, 48.48835768106503],
                            [2.191523962356255, 48.488060227271866],
                            [2.191368018353368, 48.487536667621356],
                            [2.191232570003851, 48.487028303594066],
                            [2.19114239556813, 48.48664742449082],
                            [2.191070394412842, 48.48629539204412],
                            [2.191009681148663, 48.485985849373876],
                            [2.190964827614459, 48.48571576886458],
                            [2.190915523895594, 48.48540623983601],
                            [2.190857863681299, 48.484832746097645],
                            [2.190825095041492, 48.48433058216103],
                            [2.190818202549043, 48.483562979722606],
                            [2.190837702628597, 48.48313521533578],
                            [2.190884981428005, 48.48257095785033],
                            [2.190918457941776, 48.4820446082621],
                            [2.190935833461991, 48.481562229915006],
                            [2.190912151628022, 48.48107524796437],
                            [2.190881627646101, 48.480586740178275],
                            [2.190816892224509, 48.48009363758695],
                            [2.190731579713918, 48.47961567695922],
                            [2.190609765754252, 48.47913615382692],
                            [2.190469712089758, 48.478653572274354],
                            [2.190320377109413, 48.47822407325918],
                            [2.190232071784556, 48.477991860552564],
                            [2.190007648803434, 48.47749399960764],
                            [2.189835240050399, 48.477155488928645],
                            [2.189565148890984, 48.476672738005774],
                            [2.18930624307895, 48.476267366437924],
                            [2.188974499865674, 48.47580577113297],
                            [2.188622215391327, 48.47534869816884],
                            [2.188178902926873, 48.47481565722992],
                            [2.187890107136834, 48.47449519498137],
                            [2.187455691743657, 48.47404407877586],
                            [2.187200927258417, 48.473790406837786],
                            [2.186702681851548, 48.47332706781113],
                            [2.184891492018988, 48.471739405887874],
                            [2.184010989417532, 48.47096000909176],
                            [2.18311461592798, 48.47015783077591],
                            [2.182093129002886, 48.469250801274555],
                            [2.181067123649507, 48.4683407215684],
                            [2.180079862740005, 48.46745344342042],
                            [2.17905621225424, 48.46654335004898],
                            [2.178023475451607, 48.46563323443981],
                            [2.177318269852653, 48.46502848511294],
                            [2.176760930724013, 48.46455440108023],
                            [2.176485685367064, 48.46431736194953],
                            [2.175428529232595, 48.46336939126355],
                            [2.173894623616079, 48.4620086362487],
                            [2.17185792215845, 48.46018554986862],
                            [2.171437076269545, 48.4597994946336],
                            [2.171091233634467, 48.45945161714462],
                            [2.170788250451087, 48.45912521433166],
                            [2.170367753714354, 48.45863922733031],
                            [2.170029372557282, 48.45820332341595],
                            [2.169716043769795, 48.457765077192754],
                            [2.169427783868999, 48.45731972971461],
                            [2.169164609459721, 48.45686252201312],
                            [2.168930047479853, 48.45640773514199],
                            [2.168702698408111, 48.455936303808436],
                            [2.168514675797192, 48.45547206759342],
                            [2.168348141812741, 48.45500072647826],
                            [2.168213804224895, 48.454529433312935],
                            [2.168079779695552, 48.45396534783869],
                            [2.167985110508597, 48.45339894314668],
                            [2.167929514941433, 48.452913491250484],
                            [2.167892076322361, 48.45234717138155],
                            [2.167879683857191, 48.45177850954229],
                            [2.167899168054893, 48.45130268624724],
                            [2.167957908574104, 48.45085309452079],
                            [2.168070262905442, 48.45041309829173],
                            [2.1682729625501, 48.44969486393411],
                            [2.168605621008508, 48.44861517528609],
                            [2.168898359882763, 48.447704353875274],
                            [2.169043011992373, 48.447226337487045],
                            [2.169148061834316, 48.44682677802512],
                            [2.169210200482683, 48.44642477495407],
                            [2.169243745191482, 48.44601797152589],
                            [2.169259655232927, 48.445537384162456],
                            [2.16922914414058, 48.44503531570836],
                            [2.169180675555472, 48.4445570141486],
                            [2.169107182021758, 48.44407629428191],
                            [2.169022691911299, 48.443676453177346],
                            [2.16890958659707, 48.44327894949447],
                            [2.168739267589838, 48.44288136152311],
                            [2.168551069904824, 48.44248374507548],
                            [2.168337748617728, 48.44211464298877],
                            [2.168077934968886, 48.4417478505528],
                            [2.167803796667628, 48.44138817422252],
                            [2.167518846726141, 48.44105465154642],
                            [2.167180286316096, 48.440713910665636],
                            [2.166809484371037, 48.44039215507512],
                            [2.166374403331347, 48.44004650812693],
                            [2.16591067321179, 48.43971509262026],
                            [2.165418270059344, 48.439405044356505],
                            [2.164804460472121, 48.43904722457116],
                            [2.16427267984389, 48.4387537659448],
                            [2.163722920972505, 48.43849120827206],
                            [2.163348023348412, 48.438331223305916],
                            [2.162919515742157, 48.43816401865183],
                            [2.162251690426061, 48.43792506459682],
                            [2.160783927401713, 48.43739935413783],
                            [2.160051905051923, 48.43711983975931],
                            [2.159530553968522, 48.43692392480675],
                        ],
                    },
                },
                593: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.81509883082487, 2.200502674169532],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 2833.8656305,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.188630276475413,
                            48.80468335617195,
                            2.21485979543755,
                            48.82121703789382,
                        ),
                        "coordinates": [
                            [2.188630276475413, 48.80468335617195],
                            [2.188888364112657, 48.80489180470413],
                            [2.190130396655551, 48.80585445347174],
                            [2.190879114462857, 48.80646960241897],
                            [2.191205078562442, 48.80676817769711],
                            [2.192204894999361, 48.807801977914885],
                            [2.193192280259932, 48.80892389751863],
                            [2.193425587277886, 48.80921685062757],
                            [2.193612218374021, 48.80945739927336],
                            [2.193780838580899, 48.80969792413766],
                            [2.193924347805145, 48.80990272769857],
                            [2.194178998798047, 48.81029325907732],
                            [2.194397752727306, 48.810640916982294],
                            [2.194555512544857, 48.81090284144721],
                            [2.194720431450146, 48.81118143034729],
                            [2.195480288140415, 48.812545739218464],
                            [2.195889001983542, 48.81324577238028],
                            [2.196028913824722, 48.81345532787757],
                            [2.196193895682154, 48.8137172584058],
                            [2.196384071819588, 48.8139887387419],
                            [2.196588702309362, 48.814245959581456],
                            [2.196796935496198, 48.81450318441473],
                            [2.197048312852099, 48.81479377314574],
                            [2.197278188397551, 48.815043885965395],
                            [2.197508112738683, 48.81527734260119],
                            [2.197827911713186, 48.81558228979503],
                            [2.198086683276045, 48.815808641880565],
                            [2.198334703570967, 48.81601594661987],
                            [2.198553994257274, 48.81618990544645],
                            [2.198827224330921, 48.81640199736579],
                            [2.198996217879864, 48.816525928242406],
                            [2.199262285211288, 48.81672373450449],
                            [2.19952842016228, 48.81689774877625],
                            [2.199762176020057, 48.817055066025915],
                            [2.1999887549869, 48.81720285780244],
                            [2.200244133836916, 48.81736020000458],
                            [2.200539106644035, 48.817531866669285],
                            [2.200816120784877, 48.817684474803265],
                            [2.201082351603755, 48.81782755304185],
                            [2.201341410383679, 48.817958724191456],
                            [2.201614877217186, 48.818092292522],
                            [2.201935133243039, 48.81824494923385],
                            [2.202241017817394, 48.818383312179435],
                            [2.202564911898397, 48.81852407529773],
                            [2.202885243873133, 48.818650556517206],
                            [2.203248782978426, 48.81878898545574],
                            [2.203529553085071, 48.818889246473255],
                            [2.203965144916838, 48.819032514286704],
                            [2.204321526519534, 48.81915427587529],
                            [2.204749960902796, 48.81928087768617],
                            [2.205128022534456, 48.81938124766058],
                            [2.20555290731222, 48.819488807011396],
                            [2.206085843546433, 48.81961314551864],
                            [2.206917673573451, 48.81980206331435],
                            [2.208808246226439, 48.82022296562755],
                            [2.210241485326939, 48.8205481551328],
                            [2.211015770086697, 48.82070842748345],
                            [2.211813886409471, 48.82086169087755],
                            [2.212548645199531, 48.82098146094638],
                            [2.213369923332198, 48.82108704380508],
                            [2.214534922067827, 48.821192881756104],
                            [2.214826732024399, 48.82121460828407],
                            [2.21485979543755, 48.82121703789382],
                        ],
                    },
                },
                594: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.758049042899664, 2.4346175166226756],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 2989.06693123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.433437421055713,
                            48.745230819408114,
                            2.438344239163614,
                            48.771266038121055,
                        ),
                        "coordinates": [
                            [2.438344239163614, 48.745230819408114],
                            [2.438273437857284, 48.745438709334884],
                            [2.438184096111448, 48.7457338260805],
                            [2.437969742303037, 48.74647874632876],
                            [2.43783754994237, 48.74693569602271],
                            [2.437733859271531, 48.74725461899908],
                            [2.437619329574165, 48.74755213737636],
                            [2.437508295033156, 48.747799685309374],
                            [2.437375710285186, 48.74806628850716],
                            [2.4371677731604, 48.74843526830044],
                            [2.436992015157528, 48.748704287466246],
                            [2.436823368444851, 48.748932852049585],
                            [2.43662955448261, 48.74917095568656],
                            [2.436371097049091, 48.74947097724524],
                            [2.435477185273351, 48.750480593926376],
                            [2.434870421722178, 48.751149711661746],
                            [2.434626308838914, 48.751435442046734],
                            [2.434403841699777, 48.751752084286196],
                            [2.434256798804391, 48.751999661119584],
                            [2.434131336835575, 48.752242460603284],
                            [2.434016731663686, 48.752518561377215],
                            [2.433952395286144, 48.75273989404596],
                            [2.433902488034662, 48.75298024865708],
                            [2.433874050444429, 48.75315872192501],
                            [2.433852837131601, 48.75335146642632],
                            [2.433846200429141, 48.75363937180893],
                            [2.433843154641313, 48.75392251459625],
                            [2.433851005477436, 48.75425799347498],
                            [2.433867417614227, 48.755292988377406],
                            [2.433871865888324, 48.75572840194772],
                            [2.433875961182599, 48.75598298628363],
                            [2.433876318366639, 48.756166194349106],
                            [2.433873216263952, 48.756420785841875],
                            [2.433817539681058, 48.75739635935004],
                            [2.433782745886303, 48.75800787740011],
                            [2.433713047511272, 48.759176187575164],
                            [2.433674716106457, 48.75982101953141],
                            [2.433619936619943, 48.76126056113242],
                            [2.433583295696, 48.76247957656717],
                            [2.433532294449451, 48.76407382361093],
                            [2.433527186465675, 48.764233480205604],
                            [2.433512045902057, 48.76470669175702],
                            [2.433457583756447, 48.76631516693117],
                            [2.433443893475024, 48.766679216121894],
                            [2.433437421055713, 48.76705277657283],
                            [2.43344875507995, 48.76732876915579],
                            [2.433470809000831, 48.76756430466045],
                            [2.433514528618688, 48.76783551112151],
                            [2.433547208387588, 48.76798300192939],
                            [2.433605313186639, 48.768247058669225],
                            [2.433692268519418, 48.768539642109744],
                            [2.433779131488626, 48.76878463877218],
                            [2.433880422467193, 48.769043900042725],
                            [2.433981629199955, 48.76926033248583],
                            [2.434100817640164, 48.76946723255786],
                            [2.434173058136915, 48.769595653939426],
                            [2.434266951982867, 48.76975261006521],
                            [2.434447454992141, 48.77002131901292],
                            [2.434761484095578, 48.77046360488249],
                            [2.435028593570148, 48.77083930919318],
                            [2.435158556251428, 48.77102954326885],
                            [2.435306339706323, 48.771266038121055],
                        ],
                    },
                },
                595: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.8244578830612, 2.261852181932542],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1281.0515701,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.258759767033708,
                            48.81967448818826,
                            2.263689648725751,
                            48.830119640157896,
                        ),
                        "coordinates": [
                            [2.263689648725751, 48.830119640157896],
                            [2.263346232609672, 48.829696466430924],
                            [2.263161366679126, 48.82944185212201],
                            [2.263040396501341, 48.8292700128134],
                            [2.26298330636689, 48.82919083915351],
                            [2.262803907393523, 48.82892633585935],
                            [2.262634123155269, 48.82860878205818],
                            [2.262556715913852, 48.82845495551708],
                            [2.26248469548901, 48.82829302630381],
                            [2.26240742426411, 48.8280987444057],
                            [2.262308474382768, 48.82777853824987],
                            [2.262280972837698, 48.82764571314718],
                            [2.262232289143338, 48.82742868566543],
                            [2.262194904473243, 48.82721911446792],
                            [2.262176356026218, 48.826872881103455],
                            [2.262172658902515, 48.826613887802544],
                            [2.262176843488879, 48.826548243273066],
                            [2.262178319812067, 48.82647270499077],
                            [2.262204533389988, 48.826248803050674],
                            [2.262274934494922, 48.82590593771449],
                            [2.26240622374005, 48.82526332833843],
                            [2.262473477124769, 48.82491805081996],
                            [2.26251340780637, 48.82462761110604],
                            [2.26254109110546, 48.8243299690432],
                            [2.262532073651375, 48.82398554023579],
                            [2.262526704310095, 48.82393247930002],
                            [2.26251466657006, 48.823785889605745],
                            [2.262482352195592, 48.823537669153],
                            [2.262418754581196, 48.82326244945372],
                            [2.262342828231274, 48.823034883175985],
                            [2.262260124812575, 48.822786628652956],
                            [2.262095834500931, 48.82245468891747],
                            [2.262022496980392, 48.82231884970712],
                            [2.261882889810527, 48.82206638158086],
                            [2.261712713697331, 48.82183753399766],
                            [2.261541451527959, 48.82161709858423],
                            [2.261323935558723, 48.82136605696377],
                            [2.261109068584909, 48.821164476946656],
                            [2.261034274357683, 48.82109338484533],
                            [2.260913247115648, 48.82097729741371],
                            [2.260703789295706, 48.82080269840944],
                            [2.260541928789346, 48.82067309480275],
                            [2.260452156858628, 48.820601992416776],
                            [2.260158312621298, 48.82039945794022],
                            [2.259860361121074, 48.82021220757875],
                            [2.259541961649865, 48.820039331570165],
                            [2.259324922990989, 48.819920739289394],
                            [2.259018063679556, 48.81978088335963],
                            [2.258759767033708, 48.81967448818826],
                        ],
                    },
                },
                596: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.66190377158619, 2.322200272894098],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2465.14936916,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.312736251060262,
                            48.65281140144265,
                            2.332622929210473,
                            48.66948372520816,
                        ),
                        "coordinates": [
                            [2.332622929210473, 48.66948372520816],
                            [2.332296788663631, 48.66942077887969],
                            [2.331653786157174, 48.66928037353886],
                            [2.331075447057345, 48.669137586771726],
                            [2.330665943623719, 48.66902097980732],
                            [2.330159455712163, 48.66887343509477],
                            [2.329821801425992, 48.668759207773284],
                            [2.329530846319508, 48.66865925904621],
                            [2.32921474739847, 48.66854265238589],
                            [2.328837587235284, 48.66840224752502],
                            [2.328438880597015, 48.668235666920424],
                            [2.327979114009102, 48.66803815051555],
                            [2.327720498987738, 48.667921543607704],
                            [2.327447495899119, 48.66779730903096],
                            [2.327120638710932, 48.667642626646305],
                            [2.326859506273298, 48.66750719502109],
                            [2.326337637124598, 48.66722142027909],
                            [2.325849170515177, 48.66694061560865],
                            [2.3253930394761, 48.66665743275124],
                            [2.325001563719769, 48.66639804891961],
                            [2.324523905063941, 48.6660529978715],
                            [2.324218640243014, 48.665826929837294],
                            [2.3238128255912, 48.665505678169986],
                            [2.323457305602836, 48.66517491307018],
                            [2.32303357396238, 48.66473944844091],
                            [2.322796582251215, 48.66446817726983],
                            [2.322625671222706, 48.66424164734318],
                            [2.322408803743226, 48.663949440308826],
                            [2.322243641483214, 48.66372814333286],
                            [2.322046174662046, 48.663440221300185],
                            [2.32176615057892, 48.66297621958201],
                            [2.321529234778441, 48.66250508372967],
                            [2.321339011815816, 48.66205060925855],
                            [2.321163174266132, 48.66154855046111],
                            [2.321026824852032, 48.66112263541551],
                            [2.32091559008354, 48.660787136795584],
                            [2.320782809463491, 48.660442118936366],
                            [2.320499281265241, 48.659799663841724],
                            [2.320226488214007, 48.659295210348226],
                            [2.319863954969306, 48.65866702019617],
                            [2.319372173117989, 48.65794363574333],
                            [2.318787031108134, 48.65721309657624],
                            [2.318603948531011, 48.65699654982629],
                            [2.318410087559867, 48.65679903681781],
                            [2.318079813646202, 48.6564492240343],
                            [2.317706454136176, 48.6560779890666],
                            [2.317318736979355, 48.65570913160594],
                            [2.31685920065073, 48.65533788036833],
                            [2.316360169027436, 48.654964240030665],
                            [2.315770771200066, 48.65453214106824],
                            [2.315295846296393, 48.654227201498145],
                            [2.314931305423895, 48.65398894754283],
                            [2.31456869679336, 48.65376522256193],
                            [2.314055291719007, 48.653481983890515],
                            [2.312992576625995, 48.65293928447645],
                            [2.312736251060262, 48.65281140144265],
                        ],
                    },
                },
                597: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.82924746132682, 1.6861227690356781],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 2594.18157048,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.669010161365564,
                            48.82657842806816,
                            1.703218425476859,
                            48.83074231216928,
                        ),
                        "coordinates": [
                            [1.669010161365564, 48.82942901532876],
                            [1.669552535490319, 48.8295978430664],
                            [1.670307161934505, 48.82980010246816],
                            [1.670855573358035, 48.82994089903769],
                            [1.671405646330195, 48.83007055268127],
                            [1.6721213331017, 48.83022077242586],
                            [1.673303802883533, 48.83041471291954],
                            [1.673763306598018, 48.83048213471682],
                            [1.674703121401377, 48.83058921568764],
                            [1.67535351756511, 48.83064245186013],
                            [1.676411048375846, 48.830707034338346],
                            [1.676763554789907, 48.83072885982571],
                            [1.677379068764591, 48.83074231216928],
                            [1.678665053352695, 48.830733552518375],
                            [1.679178878634652, 48.83071133515903],
                            [1.679589104045875, 48.83069481404013],
                            [1.680104431817055, 48.830661810294934],
                            [1.681325085841878, 48.83054562689286],
                            [1.681866705803939, 48.83048129011324],
                            [1.683175668677035, 48.8302783622613],
                            [1.684810141621017, 48.829973858998216],
                            [1.685304420754806, 48.829883156091505],
                            [1.685461430572626, 48.82985527520535],
                            [1.686424034845003, 48.829679108651675],
                            [1.68848309706375, 48.829296936115625],
                            [1.689142587700028, 48.82917478039558],
                            [1.690557132118364, 48.82891301329351],
                            [1.692263792710037, 48.82860161844907],
                            [1.692768953336082, 48.8285100459288],
                            [1.694033340364509, 48.82827076870544],
                            [1.69518429951968, 48.82805961809246],
                            [1.696085405654453, 48.82789381609272],
                            [1.69614956824781, 48.82788248621767],
                            [1.696204187065305, 48.82787200119313],
                            [1.696462236749577, 48.82782398819324],
                            [1.697880767016839, 48.82756395125347],
                            [1.699098590728624, 48.827340546110285],
                            [1.700341011477919, 48.827110068910876],
                            [1.701029124747011, 48.82698170811411],
                            [1.701338987810995, 48.82692857632825],
                            [1.702408030924794, 48.82672768509554],
                            [1.703218425476859, 48.82657842806816],
                        ],
                    },
                },
                598: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.725276944842705, 2.4433626164472604],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1121.64663173,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.439645733248798,
                            48.72115958316324,
                            2.446135830934545,
                            48.73011683142026,
                        ),
                        "coordinates": [
                            [2.439645733248798, 48.72115958316324],
                            [2.43999873658582, 48.72144716199589],
                            [2.440384148210437, 48.72175374324625],
                            [2.440884786413756, 48.722131597580464],
                            [2.441352983723824, 48.722469032149334],
                            [2.441752777144327, 48.72276607883646],
                            [2.442040937787661, 48.72298946892722],
                            [2.44223548143611, 48.72315584184236],
                            [2.442469725183576, 48.72338879718654],
                            [2.442657165211647, 48.7235956239343],
                            [2.442844687405979, 48.72384051987785],
                            [2.443028625997199, 48.724090176611114],
                            [2.443194594919307, 48.72434460977975],
                            [2.4434291891175, 48.724736978193924],
                            [2.443839778338836, 48.725681117140645],
                            [2.444123624612847, 48.726203326118146],
                            [2.444202786960045, 48.7263543286648],
                            [2.444305117491671, 48.726533186922836],
                            [2.444408805593823, 48.72671114474048],
                            [2.444523377410538, 48.72689268881358],
                            [2.444943425580544, 48.72755208104018],
                            [2.44541690109799, 48.728360348361576],
                            [2.445687086449872, 48.72883670349414],
                            [2.445830415179587, 48.72911084413214],
                            [2.445921963217562, 48.72932658073056],
                            [2.446005440453732, 48.729580994507565],
                            [2.446054793282373, 48.72977069404581],
                            [2.446105500724956, 48.729957693392315],
                            [2.446135830934545, 48.73011683142026],
                        ],
                    },
                },
                599: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.8313405743801, 1.9522089654843893],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 1152.77195771,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.944401758066846,
                            48.83095952864679,
                            1.960026560248269,
                            48.83191618431854,
                        ),
                        "coordinates": [
                            [1.944401758066846, 48.83191618431854],
                            [1.945643641363587, 48.83181188089133],
                            [1.947853050022673, 48.83163957817671],
                            [1.950061074642666, 48.83146812741733],
                            [1.952226981664214, 48.83128408886308],
                            [1.953001650153108, 48.8312160296678],
                            [1.953427913655874, 48.83118105943918],
                            [1.953861171157909, 48.83115360686729],
                            [1.95503036982163, 48.83109097898018],
                            [1.957612195748289, 48.83101595687798],
                            [1.957807038649854, 48.83100851144845],
                            [1.957858798504205, 48.83100868276726],
                            [1.957909210260055, 48.831007051572136],
                            [1.958112184109033, 48.831005028042256],
                            [1.960026560248269, 48.83095952864679],
                        ],
                    },
                },
                600: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.4485479385079, 2.7215062118150843],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 8032.72570966,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.692033259866399,
                            48.416377033006604,
                            2.738210817166725,
                            48.4755230723766,
                        ),
                        "coordinates": [
                            [2.726661533081673, 48.416377033006604],
                            [2.726986658138678, 48.417140693732],
                            [2.727345798186738, 48.41781992946304],
                            [2.72756299250814, 48.418171315205484],
                            [2.727769356616908, 48.418508461065514],
                            [2.728040486983366, 48.41890010574532],
                            [2.728327871012224, 48.4192457453491],
                            [2.728747401941021, 48.419711375333925],
                            [2.72916444440831, 48.42015199572559],
                            [2.729615026131733, 48.420587471154015],
                            [2.731704867667564, 48.422457844225114],
                            [2.732971511748013, 48.42357568931441],
                            [2.733394952468326, 48.42398786445735],
                            [2.733732765200332, 48.42433469227287],
                            [2.734369037023407, 48.42500510323783],
                            [2.734742799502794, 48.42543221475421],
                            [2.735127207635353, 48.425881012242726],
                            [2.735648973640984, 48.42658958823863],
                            [2.736210954113941, 48.4274257138859],
                            [2.736730454016712, 48.42835461167416],
                            [2.737135656378466, 48.42918139628824],
                            [2.737510994353277, 48.430158460754086],
                            [2.73783011986764, 48.43120137002651],
                            [2.738021024736048, 48.43209275809406],
                            [2.73815117113718, 48.432989757189816],
                            [2.738204246230493, 48.433711674231525],
                            [2.738210817166725, 48.43453267473404],
                            [2.738141759308018, 48.4355284000061],
                            [2.73807930659066, 48.435998933932474],
                            [2.737904590944704, 48.436964459468705],
                            [2.737792210896972, 48.43744506188221],
                            [2.737644851044388, 48.43794557219136],
                            [2.737409615252215, 48.43861185773486],
                            [2.737328729907203, 48.438806384111295],
                            [2.73713516648589, 48.43927648216298],
                            [2.736854910517911, 48.43989166840407],
                            [2.736499659938606, 48.44059434617139],
                            [2.73594322006713, 48.4414919727546],
                            [2.735877769268981, 48.44158932353692],
                            [2.735823015788552, 48.44167224811111],
                            [2.735551768498164, 48.44206438251455],
                            [2.735162575327905, 48.44258192873389],
                            [2.734750956827061, 48.443080217028324],
                            [2.73436322948491, 48.44353345843046],
                            [2.733928996334741, 48.44399900105242],
                            [2.733462333564197, 48.44446645460683],
                            [2.732945792565143, 48.44495206555066],
                            [2.732644783463515, 48.445234763087655],
                            [2.732307339435341, 48.44552621654909],
                            [2.731796479442139, 48.44592818242115],
                            [2.730798450089744, 48.446724808273025],
                            [2.730018583174712, 48.4473567337031],
                            [2.7290885349158, 48.448103017909496],
                            [2.728259830237224, 48.448783030154914],
                            [2.724639493027038, 48.451705498734896],
                            [2.722789500915932, 48.453194701843216],
                            [2.721497028570242, 48.45423954633243],
                            [2.720205861987529, 48.455285269735846],
                            [2.718913282743654, 48.456330084394196],
                            [2.715445018169386, 48.45912404962778],
                            [2.713398167495356, 48.460757639459445],
                            [2.712165878245331, 48.461766206352465],
                            [2.709699680779072, 48.46376711696281],
                            [2.708385183253715, 48.46483256670907],
                            [2.707918179574805, 48.46521748545662],
                            [2.707472557188555, 48.465552641976224],
                            [2.706746521306709, 48.4660689450631],
                            [2.70624991460592, 48.46640604810272],
                            [2.705774523643334, 48.46672145861911],
                            [2.703917070452122, 48.46789743379212],
                            [2.702652340069023, 48.46871256264989],
                            [2.701567007157238, 48.46940499589657],
                            [2.701093226192951, 48.46971137063555],
                            [2.700167154487338, 48.470306060098345],
                            [2.699601805454366, 48.470668476723255],
                            [2.698619207161681, 48.471305600481685],
                            [2.698328470599237, 48.47149537441684],
                            [2.697796766943694, 48.471838790344904],
                            [2.697426598303561, 48.472079172956064],
                            [2.696527280390612, 48.47264497231067],
                            [2.69559027026669, 48.4732378607693],
                            [2.695053138658947, 48.473583978661615],
                            [2.694416366210666, 48.47399245821119],
                            [2.694007081165644, 48.47425183793106],
                            [2.693121255546687, 48.47482386183596],
                            [2.692269154612462, 48.47537853176761],
                            [2.692033259866399, 48.4755230723766],
                        ],
                    },
                },
                601: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9245077098561, 2.8468226152225604],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 8079.87411278,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.810248220733339,
                            48.903072914208664,
                            2.873448188749959,
                            48.95726886600814,
                        ),
                        "coordinates": [
                            [2.810248220733339, 48.903072914208664],
                            [2.816642664397528, 48.90465929286542],
                            [2.819237861273779, 48.90529936647536],
                            [2.821628060256524, 48.905897420811975],
                            [2.825604225275963, 48.90688910427972],
                            [2.826320019806124, 48.90706775424422],
                            [2.826887460036351, 48.907224099230156],
                            [2.827503213418642, 48.90740347963299],
                            [2.828106061574253, 48.907591478612154],
                            [2.828676409743433, 48.90777747210412],
                            [2.829938075246005, 48.908226021929835],
                            [2.833644947989917, 48.909541948679255],
                            [2.834332888151021, 48.909787363985984],
                            [2.835082987859156, 48.91007533382285],
                            [2.835758314852028, 48.91035719999091],
                            [2.836486058738449, 48.91068166251205],
                            [2.837328335847441, 48.91108699350503],
                            [2.838086159522665, 48.9114926899022],
                            [2.838556590689074, 48.911749741272494],
                            [2.839050095320965, 48.912038811726845],
                            [2.839599332614061, 48.91237688706684],
                            [2.840194537376986, 48.91276186982662],
                            [2.84063293952039, 48.913061882383914],
                            [2.841084602461002, 48.91338753301848],
                            [2.841615007724595, 48.91378778469137],
                            [2.842053950198282, 48.91413918426273],
                            [2.842437318890418, 48.91445656588049],
                            [2.842948817857881, 48.91491257288476],
                            [2.84331957344736, 48.91526641128384],
                            [2.843657647860593, 48.915601121369974],
                            [2.844114113216239, 48.916074497876814],
                            [2.84448233605571, 48.916496871620886],
                            [2.844956202869586, 48.91708152427415],
                            [2.845338183493453, 48.91757664236364],
                            [2.846330051619043, 48.918925624510955],
                            [2.847918470047961, 48.92108568495416],
                            [2.849948589363664, 48.923836923609535],
                            [2.851184550565616, 48.92551026920677],
                            [2.855258938708293, 48.93103180879619],
                            [2.85662705816382, 48.9328758142734],
                            [2.856940012909839, 48.93327484352162],
                            [2.857259094389455, 48.933637438419446],
                            [2.85760740801204, 48.933997757777945],
                            [2.857958616773929, 48.93432380059345],
                            [2.858322539724934, 48.93462194522854],
                            [2.859142193774034, 48.93529276142574],
                            [2.85988963978753, 48.93589537654974],
                            [2.86110915960593, 48.93687485999101],
                            [2.863223908351956, 48.93858687482111],
                            [2.867814423830264, 48.94228964130415],
                            [2.868165483224689, 48.942589956194695],
                            [2.868519959915423, 48.94290524445108],
                            [2.868789392020645, 48.94317167302523],
                            [2.869088611249461, 48.943487216360815],
                            [2.869319085646755, 48.943758108086406],
                            [2.869711451221098, 48.94427023104888],
                            [2.87005217889461, 48.944816855570835],
                            [2.870237982022345, 48.94516504568006],
                            [2.870437595927308, 48.94558812357875],
                            [2.870584575181216, 48.94595362642782],
                            [2.870722495353568, 48.946383417251305],
                            [2.870833810510371, 48.94675765142063],
                            [2.870983009599121, 48.947328724654696],
                            [2.871234541206582, 48.94834474135509],
                            [2.871740286201713, 48.95032108559101],
                            [2.871866355135996, 48.9508558591402],
                            [2.872212910508328, 48.95223762051659],
                            [2.872549802564272, 48.95362584876156],
                            [2.87276740258598, 48.95450496910884],
                            [2.873302139010763, 48.95668263254312],
                            [2.873448188749959, 48.95726886600814],
                        ],
                    },
                },
                602: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.70493135584528, 2.4957550780486546],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 1905.08113329,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.484245146583624,
                            48.69973243390383,
                            2.506078153203696,
                            48.706922332733605,
                        ),
                        "coordinates": [
                            [2.506078153203696, 48.69973243390383],
                            [2.505745145320041, 48.70008364546341],
                            [2.505458169853371, 48.700389824625006],
                            [2.505268627155721, 48.700583449192436],
                            [2.504923373858342, 48.70093287779881],
                            [2.504690477500286, 48.70116343590352],
                            [2.504349185348173, 48.701481381835514],
                            [2.504033554076357, 48.70175522582166],
                            [2.503735504177569, 48.70200566164785],
                            [2.503426551468336, 48.702247119663234],
                            [2.503139227327695, 48.70245707068949],
                            [2.502870859378354, 48.7026481087932],
                            [2.50259566997229, 48.702831062265126],
                            [2.502294684711937, 48.70302034759522],
                            [2.501955710368601, 48.70322587519803],
                            [2.501596352037629, 48.70343142998489],
                            [2.501257309253161, 48.70361807021821],
                            [2.501013170580755, 48.70374432100351],
                            [2.500592689453328, 48.70395715629899],
                            [2.500187091690275, 48.704151982311856],
                            [2.499770599733922, 48.70433962943603],
                            [2.49933104756179, 48.70453989756031],
                            [2.498850738256552, 48.70474202111995],
                            [2.498272438219328, 48.70499786817003],
                            [2.497756976205028, 48.705199586691556],
                            [2.49728589292057, 48.705365688840196],
                            [2.496777778362628, 48.705524626142605],
                            [2.496357602085642, 48.705657269905046],
                            [2.495905140688834, 48.70581137085952],
                            [2.495457981017143, 48.705938695856666],
                            [2.49485182993184, 48.706093008911125],
                            [2.494230521466974, 48.70622692417664],
                            [2.49378427689202, 48.70632492264173],
                            [2.493216247547589, 48.70644415106452],
                            [2.492855962269108, 48.70651824829253],
                            [2.492530509906904, 48.70657638781094],
                            [2.492034823289559, 48.70665530328682],
                            [2.491681007662905, 48.706709014017626],
                            [2.491323151921987, 48.7067515972716],
                            [2.490713290465763, 48.70681807200212],
                            [2.490015074320439, 48.70687297221346],
                            [2.489429570721313, 48.70690793396414],
                            [2.488857580904597, 48.706919491983996],
                            [2.488077679636427, 48.706922332733605],
                            [2.487486294045567, 48.70690916840046],
                            [2.487095299173275, 48.70689541108302],
                            [2.486634171096035, 48.70687103753567],
                            [2.485930286725826, 48.70681485946992],
                            [2.485358497882252, 48.70675136788186],
                            [2.484584399759925, 48.706656015161144],
                            [2.484245146583624, 48.70661094689584],
                        ],
                    },
                },
                603: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96175326093063, 2.9102059103633984],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 6094.34020908,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.873448188749959,
                            48.95726886600814,
                            2.950060382752808,
                            48.9644576375716,
                        ),
                        "coordinates": [
                            [2.873448188749959, 48.95726886600814],
                            [2.873685039539704, 48.95823220396531],
                            [2.873850690767723, 48.95875496514626],
                            [2.874021169950855, 48.95918245670696],
                            [2.874197809317763, 48.959577796696216],
                            [2.874383369342125, 48.95989600189286],
                            [2.874591905380254, 48.960233371886176],
                            [2.874855982129392, 48.96059403654777],
                            [2.875159087003569, 48.960954517230164],
                            [2.875386143116502, 48.96119971603272],
                            [2.875658941445611, 48.96146397162448],
                            [2.875967535429135, 48.961730199610315],
                            [2.876239944069584, 48.96195805140517],
                            [2.876643180738262, 48.96225381161295],
                            [2.877006883671701, 48.96250264554421],
                            [2.877350705972041, 48.96271730775391],
                            [2.877694321061737, 48.96291269813041],
                            [2.878080355737155, 48.96312073518226],
                            [2.878482465490084, 48.96331156331157],
                            [2.87886808531492, 48.96348105256796],
                            [2.879380868819429, 48.96367991879539],
                            [2.879792160668451, 48.963817162741236],
                            [2.880206566717466, 48.963941540338276],
                            [2.880653471478917, 48.96406362071875],
                            [2.8810447161623, 48.96415170086627],
                            [2.88153032251789, 48.964243613792966],
                            [2.882103714730816, 48.964332964634494],
                            [2.882722427633633, 48.96440282301731],
                            [2.883269240397062, 48.964440899488565],
                            [2.883799558745927, 48.9644576375716],
                            [2.884345946472418, 48.96445716490119],
                            [2.884905108818981, 48.96443521393392],
                            [2.885542037145706, 48.964387190309104],
                            [2.886214620869464, 48.96432828314591],
                            [2.89407699201699, 48.963589990487584],
                            [2.897848846566687, 48.96323105953925],
                            [2.902731745429968, 48.96277015624076],
                            [2.908306509712048, 48.96224349937728],
                            [2.912942305551196, 48.96180481702084],
                            [2.92248003116871, 48.960901968301194],
                            [2.928788459570303, 48.9602998856662],
                            [2.929883164349178, 48.960195711343765],
                            [2.930354198836383, 48.96015258242796],
                            [2.930818883122541, 48.96012233224885],
                            [2.931351805114436, 48.9600874433259],
                            [2.931842579293643, 48.96006347808079],
                            [2.932495946196341, 48.96003866456349],
                            [2.933064919267345, 48.96002713697594],
                            [2.933627464175898, 48.960022063241794],
                            [2.934212851520106, 48.96002329315496],
                            [2.934850319086824, 48.96002853033373],
                            [2.936587224937873, 48.960053705721165],
                            [2.941375029951941, 48.960116317983484],
                            [2.950060382752808, 48.960226490735955],
                        ],
                    },
                },
                604: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.67516040842263, 2.540926256650133],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 1829.78536074,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.533130656571037,
                            48.66790196104987,
                            2.547548045814366,
                            48.681016616342724,
                        ),
                        "coordinates": [
                            [2.547548045814366, 48.66790196104987],
                            [2.547348686316046, 48.66815565279031],
                            [2.546936715185344, 48.66865821031244],
                            [2.546187249572257, 48.66951793741603],
                            [2.545703076215958, 48.670105095825214],
                            [2.545268515695883, 48.67064647776249],
                            [2.544849737351404, 48.67120789293389],
                            [2.544595890033647, 48.67155440833831],
                            [2.544327250061974, 48.671919274446985],
                            [2.543841130820052, 48.67256404023298],
                            [2.543631723390859, 48.6728171170834],
                            [2.542789732901142, 48.67387787296055],
                            [2.542248530670807, 48.6745615186306],
                            [2.54196611267488, 48.67489476031959],
                            [2.541182059662686, 48.675748683993945],
                            [2.540682882707013, 48.67620821032145],
                            [2.540118697984313, 48.67671191427601],
                            [2.539770922870442, 48.677008397381165],
                            [2.538973727723166, 48.67765279794266],
                            [2.538375311458164, 48.678095404188156],
                            [2.537373162911307, 48.67878213970355],
                            [2.536577987693703, 48.67927590337635],
                            [2.535782643729166, 48.67973159245183],
                            [2.535396400589289, 48.67994363163423],
                            [2.53475743599448, 48.68027452171034],
                            [2.53415927174302, 48.68056679224762],
                            [2.533636323913351, 48.6808003978775],
                            [2.533130656571037, 48.681016616342724],
                        ],
                    },
                },
                605: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.99930148736807, 2.673087968220827],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 2180.09646847,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.665059869307301,
                            48.99139140287414,
                            2.680252455973217,
                            49.00811401774285,
                        ),
                        "coordinates": [
                            [2.665059869307301, 48.99139140287414],
                            [2.665250943504244, 48.991521782150706],
                            [2.667302748636683, 48.992921768796684],
                            [2.668040132067271, 48.993428821290266],
                            [2.668403439326552, 48.99368712007222],
                            [2.66872323432271, 48.99392650846737],
                            [2.668974077786951, 48.994128026860345],
                            [2.669268596979791, 48.99437224647582],
                            [2.669537809215702, 48.99461653768957],
                            [2.669770771349431, 48.994846657580645],
                            [2.669981959891061, 48.99506494547527],
                            [2.670175039331194, 48.995278527047006],
                            [2.670590626357085, 48.99577936151701],
                            [2.671571813317128, 48.99703755953977],
                            [2.677923145482296, 49.005146714207676],
                            [2.680252455973217, 49.00811401774285],
                        ],
                    },
                },
                606: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.80414943372159, 2.3303547825686852],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1183.72834337,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.328136923064751,
                            48.79889250008067,
                            2.334354309639648,
                            48.808296588631435,
                        ),
                        "coordinates": [
                            [2.328136923064751, 48.79889250008067],
                            [2.328211439890393, 48.79931616196811],
                            [2.328299837858855, 48.79981076979784],
                            [2.328358315821787, 48.80014080723669],
                            [2.32855280524438, 48.80116869080984],
                            [2.328694265623959, 48.80186114100629],
                            [2.328779948085791, 48.80234675428897],
                            [2.32882755590246, 48.80258146828636],
                            [2.328862916469073, 48.8027919007955],
                            [2.328899640206356, 48.802998736126085],
                            [2.328948613374921, 48.80322085975663],
                            [2.329043353798724, 48.80354725177372],
                            [2.329181623747859, 48.80383706304936],
                            [2.329358795960097, 48.80413972615303],
                            [2.329529496300929, 48.80436101489617],
                            [2.329594320462024, 48.804448102655414],
                            [2.329788798593652, 48.804666536518475],
                            [2.329970314130629, 48.80486498385667],
                            [2.330151833024277, 48.805040588969916],
                            [2.330579710857738, 48.80542320848262],
                            [2.330849842390752, 48.80563736109118],
                            [2.331243157476499, 48.80594288722459],
                            [2.331604061803213, 48.80621414642199],
                            [2.332014675396398, 48.80654679419994],
                            [2.332470679958305, 48.806893718148444],
                            [2.33283769274394, 48.80717066011353],
                            [2.333111330754979, 48.807379299980795],
                            [2.333470742268713, 48.80764189710389],
                            [2.334354309639648, 48.808296588631435],
                        ],
                    },
                },
                607: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [49.02034400368261, 2.68985283486818],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 3061.38658081,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.680252455973217,
                            49.00811401774285,
                            2.69945308646072,
                            49.0325740895669,
                        ),
                        "coordinates": [
                            [2.680252455973217, 49.00811401774285],
                            [2.680413408081984, 49.00831904007297],
                            [2.682980792887934, 49.01158912468828],
                            [2.69531301874826, 49.02730018886574],
                            [2.699074856685854, 49.03209228931005],
                            [2.69945308646072, 49.0325740895669],
                        ],
                    },
                },
                608: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.95762385587798, 2.1081128015687125],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 6854.65103079,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.077657913150019,
                            48.945795934518046,
                            2.144558756800802,
                            48.970665048322616,
                        ),
                        "coordinates": [
                            [2.077731764565598, 48.970665048322616],
                            [2.077713428440962, 48.97020607519221],
                            [2.077666663850801, 48.968780737284256],
                            [2.077657913150019, 48.968380986942186],
                            [2.077663602435409, 48.96798364698958],
                            [2.077672942097042, 48.96757917840914],
                            [2.07770371805565, 48.96722234540526],
                            [2.077760076342673, 48.96681084505308],
                            [2.077830973140419, 48.966382720502864],
                            [2.077919988109309, 48.96594512162838],
                            [2.07803413788236, 48.965538511126155],
                            [2.078148021341955, 48.96518186572114],
                            [2.078280085569287, 48.964803846958326],
                            [2.078466350566502, 48.96436861325265],
                            [2.078702630029098, 48.96388924113729],
                            [2.079039124446443, 48.963310490892766],
                            [2.079935206901635, 48.96177020066142],
                            [2.081269498119995, 48.959486631807394],
                            [2.081576885889697, 48.959014757589514],
                            [2.081962423068169, 48.95842290385134],
                            [2.082204796463363, 48.95808388765979],
                            [2.082491784790015, 48.957758553390214],
                            [2.082785468171426, 48.9574671884172],
                            [2.083092761861423, 48.95720301632429],
                            [2.083527479832346, 48.95689158805297],
                            [2.08402061712912, 48.956582551446964],
                            [2.084572230045801, 48.956264585846434],
                            [2.08502365930724, 48.956043739219396],
                            [2.085533436266342, 48.9558388632136],
                            [2.08606709192164, 48.9556702559415],
                            [2.086528259554914, 48.9555603452975],
                            [2.087023708061739, 48.95546861786422],
                            [2.087549980094023, 48.955399591068044],
                            [2.088234240794546, 48.95535580717803],
                            [2.08881169270236, 48.95536158826986],
                            [2.089392372021006, 48.95541038479252],
                            [2.090049094052679, 48.9555077143591],
                            [2.090965551896499, 48.955759521922786],
                            [2.091629119016726, 48.95600839857278],
                            [2.092616904674272, 48.956453072810454],
                            [2.093748859474221, 48.95697418499068],
                            [2.09476909746265, 48.957440322996504],
                            [2.0955478386849, 48.95778935426055],
                            [2.096056379650619, 48.957978396582085],
                            [2.096619155640453, 48.95816041083464],
                            [2.099321260320342, 48.95903451962543],
                            [2.100024840541383, 48.95924536241682],
                            [2.100526538013056, 48.95936060796886],
                            [2.101533689958154, 48.95956255116235],
                            [2.103576875758549, 48.959975984953374],
                            [2.104114822892135, 48.96006987357507],
                            [2.104667333755934, 48.96013999856306],
                            [2.105472847324208, 48.96019635556919],
                            [2.106864507749246, 48.96027246135338],
                            [2.108998595220719, 48.9603890227399],
                            [2.110207309949713, 48.960435844847396],
                            [2.110982541698929, 48.96044255990134],
                            [2.111836563158214, 48.96043128677169],
                            [2.112702463065718, 48.96040448105194],
                            [2.113261405801899, 48.960377071297685],
                            [2.113993640200212, 48.96031889773775],
                            [2.11465504974062, 48.96025799264028],
                            [2.115422851301998, 48.9601661921512],
                            [2.11619464093085, 48.96006143667261],
                            [2.117053244524919, 48.95990242454472],
                            [2.119688187319351, 48.959394366937204],
                            [2.120653186762333, 48.95919665912094],
                            [2.1214213543062, 48.95901412130886],
                            [2.122550460530804, 48.958699897629074],
                            [2.123184478903895, 48.95850264268088],
                            [2.123808423411372, 48.95828529971081],
                            [2.124663027741345, 48.9579680472141],
                            [2.126128581952765, 48.957370569020895],
                            [2.126812861159789, 48.95704109907121],
                            [2.127580583459889, 48.956628500051835],
                            [2.128210736805959, 48.956277508281566],
                            [2.129363150511995, 48.95558246696145],
                            [2.129364252725261, 48.95558180229322],
                            [2.130186393825507, 48.95510504093087],
                            [2.130918026939952, 48.954668561787386],
                            [2.1323489735282, 48.95373842337728],
                            [2.134018912585963, 48.9526611748752],
                            [2.134996935419867, 48.95202999852488],
                            [2.13705434703725, 48.95069641978865],
                            [2.139423112433903, 48.94916585477055],
                            [2.141654189842415, 48.94770400653005],
                            [2.14260315743467, 48.94706319950211],
                            [2.143302133117028, 48.94660517253894],
                            [2.144558756800802, 48.945795934518046],
                        ],
                    },
                },
                609: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.90603546760243, 2.2016670097080957],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 2824.34173331,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192783100891459,
                            48.90095486955767,
                            2.215110510381832,
                            48.91674629011933,
                        ),
                        "coordinates": [
                            [2.192783100891459, 48.91674629011933],
                            [2.193725735015726, 48.9161839992704],
                            [2.194101940510942, 48.91592274315056],
                            [2.194503568944324, 48.915606791968955],
                            [2.194785931771599, 48.91533589863436],
                            [2.195090149149546, 48.91499603060137],
                            [2.19538003626147, 48.9146156958898],
                            [2.195604952597295, 48.91423052106892],
                            [2.195742977281143, 48.91393327354401],
                            [2.195859462951818, 48.91359317156233],
                            [2.195950690285819, 48.913248279133455],
                            [2.195994967487779, 48.91291046745926],
                            [2.196006627076923, 48.91261782283162],
                            [2.19599290884069, 48.91236321639478],
                            [2.19595772263991, 48.912041961833445],
                            [2.195882915835033, 48.91168972665501],
                            [2.195704434070419, 48.9109828424452],
                            [2.195654588800859, 48.910740087105765],
                            [2.195611954574173, 48.91049972194895],
                            [2.195594480129716, 48.910297455551444],
                            [2.195580801017772, 48.91003095341317],
                            [2.195592509592611, 48.90972165288696],
                            [2.195618607894856, 48.90942902524874],
                            [2.195659120032608, 48.90914593452513],
                            [2.195706809724843, 48.90887712822257],
                            [2.195783549645252, 48.90854649402663],
                            [2.19587843244082, 48.908182572445455],
                            [2.19602037815799, 48.90776874192739],
                            [2.196143991080384, 48.90745482099916],
                            [2.196292990889578, 48.90709810399634],
                            [2.196485401404511, 48.90670574892706],
                            [2.196717567255284, 48.90629440815585],
                            [2.196891643008049, 48.90600196227802],
                            [2.197130799896365, 48.90566914715772],
                            [2.197431391694582, 48.90530785493849],
                            [2.197735422495251, 48.905006050261],
                            [2.198075508941352, 48.904716183715976],
                            [2.198364842109605, 48.904504773816555],
                            [2.198686658119753, 48.904293402445255],
                            [2.199055415927369, 48.90407256929897],
                            [2.199449377132043, 48.90387317886656],
                            [2.199868571987392, 48.90368333569223],
                            [2.200352717387131, 48.903498326002484],
                            [2.200952406116703, 48.903294416912864],
                            [2.201515940545721, 48.903111874664084],
                            [2.202707989957476, 48.902734963218506],
                            [2.205164315518815, 48.90194549484479],
                            [2.206038467192384, 48.90166097580946],
                            [2.206522489156107, 48.90150687183555],
                            [2.206947528712238, 48.9014127716468],
                            [2.207380875064347, 48.9013133307464],
                            [2.207698650455724, 48.90124468847378],
                            [2.20804167088498, 48.901183212676145],
                            [2.208478542460063, 48.901114702882815],
                            [2.209164522398711, 48.90101315758895],
                            [2.209604914832846, 48.900977958332795],
                            [2.210240164004842, 48.90095486955767],
                            [2.210644368392583, 48.900957694328255],
                            [2.211048530461281, 48.90097717393879],
                            [2.211560892668665, 48.90102532287779],
                            [2.212549415032399, 48.901166781474856],
                            [2.21303281400399, 48.90125296143994],
                            [2.213692926322038, 48.90139167569717],
                            [2.214403487491577, 48.901563751336866],
                            [2.215110510381832, 48.90174588638394],
                        ],
                    },
                },
                610: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.90933605194981, 2.214401158156069],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3618.69234236,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192783100891459,
                            48.906318772930035,
                            2.236878028463527,
                            48.91674629011933,
                        ),
                        "coordinates": [
                            [2.192783100891459, 48.91674629011933],
                            [2.193915561241419, 48.91622336999507],
                            [2.195619087440587, 48.91542111950458],
                            [2.200583681399877, 48.91300098223639],
                            [2.205766616901968, 48.91046872340311],
                            [2.207078776833063, 48.90983951859015],
                            [2.20826488470903, 48.90926499397887],
                            [2.208916038325867, 48.90898458381016],
                            [2.209645387921564, 48.90869956889323],
                            [2.210328442301554, 48.90844729986156],
                            [2.211118152610841, 48.908178742960885],
                            [2.211843789736813, 48.90794759651771],
                            [2.212804110778444, 48.907669843799354],
                            [2.213821236911601, 48.907410885171636],
                            [2.214841854740157, 48.90717300926446],
                            [2.215745060978295, 48.90698419743309],
                            [2.216303296889348, 48.90688404392444],
                            [2.217074837322181, 48.906758342074454],
                            [2.21794943210056, 48.90663742525696],
                            [2.218799099304425, 48.90653521810571],
                            [2.219929542608957, 48.90642860870042],
                            [2.220768420154927, 48.90637791965439],
                            [2.221610819313726, 48.90633894333512],
                            [2.222524257991393, 48.906318772930035],
                            [2.223469633201166, 48.906319713687424],
                            [2.224798803220401, 48.90633976445279],
                            [2.225832811763191, 48.90637021566337],
                            [2.226970585991264, 48.90643515480475],
                            [2.228398733302602, 48.906573771226874],
                            [2.229391170253993, 48.90667365826203],
                            [2.230223814786464, 48.906776581474865],
                            [2.231051530430233, 48.90692098714641],
                            [2.231772672864093, 48.90708763450442],
                            [2.232595374004243, 48.90731821074712],
                            [2.233601896691025, 48.90764151294627],
                            [2.235102013580883, 48.90813122937256],
                            [2.236878028463527, 48.90869458435905],
                        ],
                    },
                },
                611: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89109158080235, 2.4721954798482786],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2295.95789598,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461119310778047,
                            48.88230400665456,
                            2.481421258690829,
                            48.89660443742263,
                        ),
                        "coordinates": [
                            [2.461119310778047, 48.89660443742263],
                            [2.461509388952238, 48.896564144824815],
                            [2.461942319234399, 48.896518464178925],
                            [2.462588083726939, 48.89644161661581],
                            [2.463309586236366, 48.896348025332145],
                            [2.464736211707876, 48.8961396272551],
                            [2.46575794919192, 48.89595594168199],
                            [2.466266478813435, 48.89584353822975],
                            [2.466673988232067, 48.89574076403453],
                            [2.46711032183098, 48.89562130052526],
                            [2.467604317266228, 48.89547321674713],
                            [2.468091059302494, 48.895313243107005],
                            [2.4684551646126, 48.89517482194836],
                            [2.468797602632725, 48.895031666723526],
                            [2.46906794191135, 48.894917145066536],
                            [2.469586562636219, 48.8946674619619],
                            [2.469966504422374, 48.89445209207242],
                            [2.470264708692414, 48.89427115822417],
                            [2.470529759151449, 48.894091514130714],
                            [2.470991920934919, 48.89375636188796],
                            [2.471290672819598, 48.89352263557229],
                            [2.471726930019748, 48.89312794489909],
                            [2.471973921861432, 48.89287779812293],
                            [2.472547704070426, 48.892236831521885],
                            [2.472884567031517, 48.891817137298425],
                            [2.473438216363358, 48.89107412219748],
                            [2.473772279787147, 48.89070839675303],
                            [2.474049663126856, 48.89040950291347],
                            [2.47452551469536, 48.889881953956994],
                            [2.474881753233817, 48.88950023007377],
                            [2.47572536852113, 48.888574373860074],
                            [2.477607310168708, 48.88650309680817],
                            [2.478720811781256, 48.88525812621543],
                            [2.479059291873576, 48.884888102203035],
                            [2.479390955409872, 48.88451988389745],
                            [2.479752531767738, 48.88412374931917],
                            [2.480115496258058, 48.88373840328366],
                            [2.48045801797166, 48.88335847745387],
                            [2.480921498927064, 48.88284350718845],
                            [2.481421258690829, 48.88230400665456],
                        ],
                    },
                },
                612: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.90509246219933, 2.226037868662158],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1775.25276675,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.215110510381832,
                            48.90174588638394,
                            2.236878028463527,
                            48.90869458435905,
                        ),
                        "coordinates": [
                            [2.215110510381832, 48.90174588638394],
                            [2.216416094716841, 48.90208220256715],
                            [2.217541439790552, 48.90237366098909],
                            [2.218206139711394, 48.90256887038487],
                            [2.218898540450291, 48.902802761374744],
                            [2.221693564470689, 48.90370023902591],
                            [2.228427206071711, 48.9058958064252],
                            [2.229108909802451, 48.90611297027872],
                            [2.229574228195708, 48.90624902977515],
                            [2.230046795831316, 48.90637319731592],
                            [2.23134186306613, 48.90670988474685],
                            [2.232365737206963, 48.90699991265386],
                            [2.233226625978503, 48.90727352622456],
                            [2.233952822769878, 48.907521632552616],
                            [2.235635930671525, 48.908173485528266],
                            [2.236878028463527, 48.90869458435905],
                        ],
                    },
                },
                613: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.91211793800449, 2.2484188702784476],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1383.85607997,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.239684117127617,
                            48.90963293312601,
                            2.257326023785208,
                            48.91368603630761,
                        ),
                        "coordinates": [
                            [2.239684117127617, 48.90963293312601],
                            [2.239788042200377, 48.90966790803246],
                            [2.241995925431958, 48.91035114100607],
                            [2.242951956154106, 48.91063745113761],
                            [2.244203785933159, 48.91103819851468],
                            [2.247133195820976, 48.91198988774084],
                            [2.24786918081334, 48.912223636908],
                            [2.248457268204739, 48.912402542415116],
                            [2.24904847188424, 48.912568016147056],
                            [2.251135148743024, 48.91304220067703],
                            [2.251888642575547, 48.913191232365605],
                            [2.252310154198805, 48.913265778501135],
                            [2.252630013902792, 48.91331943375086],
                            [2.253654973050055, 48.9134748410163],
                            [2.254391247151798, 48.91356816651697],
                            [2.254994015372873, 48.91362570274493],
                            [2.255578758919305, 48.913666569350404],
                            [2.256192421523689, 48.91368603630761],
                            [2.256759201119487, 48.91367453815565],
                            [2.257019761280649, 48.913659068345126],
                            [2.257326023785208, 48.9136368630564],
                        ],
                    },
                },
                614: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.918559045836986, 2.189066380171806],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 678.061753092,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.185353376302864,
                            48.91674629011933,
                            2.192783100891459,
                            48.920379373924355,
                        ),
                        "coordinates": [
                            [2.185353376302864, 48.920379373924355],
                            [2.186145208575256, 48.9200021067702],
                            [2.186767090397931, 48.919707886644076],
                            [2.188218351335855, 48.9189764806864],
                            [2.191073467000742, 48.917556762960395],
                            [2.192783100891459, 48.91674629011933],
                        ],
                    },
                },
                615: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.841476973220516, 2.323851914074393],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 410.383866547,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.321278562744627,
                            48.840663229299565,
                            2.326384610792847,
                            48.84210220720859,
                        ),
                        "coordinates": [
                            [2.321278562744627, 48.84210220720859],
                            [2.321478024867214, 48.842094971023165],
                            [2.321676577001697, 48.842080491249405],
                            [2.321873623006183, 48.8420588157766],
                            [2.322068559754135, 48.84203000594855],
                            [2.322260794636329, 48.84199415285148],
                            [2.322449744410313, 48.841951361118625],
                            [2.322634836318576, 48.84190176782308],
                            [2.322805177901829, 48.84184895195435],
                            [2.322838298235089, 48.841837981008936],
                            [2.325439316539195, 48.8409763843359],
                            [2.326384610792847, 48.840663229299565],
                        ],
                    },
                },
                616: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.8466625958224, 2.3806526627118165],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 847.035053059,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37496291887346,
                            48.84602764938302,
                            2.386341707704105,
                            48.84730378704746,
                        ),
                        "coordinates": [
                            [2.386341707704105, 48.84730378704746],
                            [2.38506297075243, 48.847158876095826],
                            [2.383504681408783, 48.84698167050688],
                            [2.377023115723786, 48.846254487253],
                            [2.37496291887346, 48.84602764938302],
                        ],
                    },
                },
                617: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.87563212896821, 2.5681045470920836],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2258.39682042,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.552881649780832,
                            48.87414408301457,
                            2.583331158055108,
                            48.877157839702775,
                        ),
                        "coordinates": [
                            [2.552881649780832, 48.877157839702775],
                            [2.556435116941477, 48.8767984829346],
                            [2.570329594400424, 48.87539282571081],
                            [2.583331158055108, 48.87414408301457],
                        ],
                    },
                },
                618: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.72990037025463, 2.2430211143938505],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3164.51926549,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.230961125063006,
                            48.723263625741104,
                            2.257355188147784,
                            48.74018152105127,
                        ),
                        "coordinates": [
                            [2.230961125063006, 48.74018152105127],
                            [2.23098445288411, 48.74005463486085],
                            [2.231005115304485, 48.73992875596402],
                            [2.231143956064053, 48.739213062329064],
                            [2.23133755527186, 48.73831846427792],
                            [2.231389850921934, 48.7380199544629],
                            [2.231517696441473, 48.737323953177906],
                            [2.231656540757419, 48.73663082306813],
                            [2.23175387573255, 48.73620350503682],
                            [2.231882518867669, 48.73584596590882],
                            [2.231963112276722, 48.73566438625252],
                            [2.232008167288357, 48.73557360137358],
                            [2.232162381042306, 48.7352931696553],
                            [2.232291468753221, 48.735099776012866],
                            [2.232432384928964, 48.73490133494148],
                            [2.232580970513968, 48.734709925491316],
                            [2.232719962524376, 48.734554478442746],
                            [2.233078269733759, 48.73418880198645],
                            [2.233252619656834, 48.73402619146521],
                            [2.233488217195298, 48.73382946528655],
                            [2.233493663617743, 48.73382497417502],
                            [2.233814975786007, 48.733594152285214],
                            [2.234179822176415, 48.7333462825014],
                            [2.23445747699121, 48.73318736136455],
                            [2.234524164561867, 48.7331505504603],
                            [2.234906581701936, 48.7329494569221],
                            [2.23551344429274, 48.732678418610355],
                            [2.235737927251701, 48.732591388729304],
                            [2.236144698602173, 48.73244247016402],
                            [2.236439876558312, 48.73235280349404],
                            [2.23672445339913, 48.73227419824006],
                            [2.237072339454767, 48.73218789372844],
                            [2.237458585566031, 48.73210280019247],
                            [2.238297745460487, 48.731937355844046],
                            [2.239506660869996, 48.731698998672464],
                            [2.240586452408943, 48.73148139489881],
                            [2.242645351022293, 48.73107754551703],
                            [2.243045151097771, 48.73100413558205],
                            [2.243447185337184, 48.730914953817745],
                            [2.243808099234809, 48.730826706477956],
                            [2.244069249744639, 48.73074688384464],
                            [2.24447733837877, 48.73059973516143],
                            [2.244689559924687, 48.73051357774977],
                            [2.245111320125024, 48.73032147374634],
                            [2.245474628900737, 48.730126624171746],
                            [2.245652896991881, 48.73002245093449],
                            [2.24599179193542, 48.729795206034034],
                            [2.24615921190782, 48.729674837032434],
                            [2.24635314200479, 48.72951398577489],
                            [2.246534985238619, 48.729348699990396],
                            [2.246725557382419, 48.72917050234812],
                            [2.246882206294474, 48.72902253895129],
                            [2.247004806743087, 48.72886571669419],
                            [2.247130581643116, 48.72871225582383],
                            [2.247255534698821, 48.72853812535572],
                            [2.247360508239191, 48.7283673460726],
                            [2.247455657180291, 48.728183600129476],
                            [2.247554207795166, 48.72798980423787],
                            [2.247625189110651, 48.727823493856256],
                            [2.247698952316081, 48.72762211466232],
                            [2.247816720068468, 48.72713570002597],
                            [2.247923688268346, 48.726606111991224],
                            [2.248059462612094, 48.72592816657213],
                            [2.248141523771741, 48.72565681571391],
                            [2.248253442992088, 48.72538425774568],
                            [2.248376146751459, 48.72517392331163],
                            [2.248573433319804, 48.72491324121412],
                            [2.248760285699882, 48.724701203644926],
                            [2.248977463436584, 48.72449121129155],
                            [2.249179594602076, 48.72432023624486],
                            [2.249470816715983, 48.72411902342145],
                            [2.249684426426722, 48.723995986575076],
                            [2.249831348514707, 48.723922358814995],
                            [2.250004108886166, 48.72384065683768],
                            [2.250199982988584, 48.72375447656998],
                            [2.250391756466418, 48.723680882542254],
                            [2.250590318624253, 48.72361089002413],
                            [2.250806540453934, 48.72354720536321],
                            [2.251005077441467, 48.723491599864325],
                            [2.251185929065367, 48.72344497397882],
                            [2.251381724981873, 48.72340195668006],
                            [2.251546241892341, 48.72336880703061],
                            [2.251756971269742, 48.72333659092265],
                            [2.251967689741116, 48.72330977027565],
                            [2.252167523828399, 48.72328923578491],
                            [2.252394532148593, 48.72327411688374],
                            [2.252633760854183, 48.723266201454905],
                            [2.252799584788732, 48.723263625741104],
                            [2.253034710853136, 48.72327099364352],
                            [2.253263039090381, 48.72327925579161],
                            [2.253449218798233, 48.723295579308655],
                            [2.253653057733224, 48.723318210298274],
                            [2.253923472638647, 48.72335617751241],
                            [2.254143593632019, 48.723395905764946],
                            [2.25427946238483, 48.72342567987217],
                            [2.254377288750736, 48.723446434658825],
                            [2.25465035817131, 48.723523969927996],
                            [2.254898956319499, 48.7236041841998],
                            [2.255139382657151, 48.72369608317356],
                            [2.255375729495687, 48.72378887814956],
                            [2.25556723002587, 48.723878941868506],
                            [2.255810318625587, 48.72400591273784],
                            [2.25595289990442, 48.724089647034596],
                            [2.256095466996484, 48.72418147445492],
                            [2.256247523073326, 48.724289494542674],
                            [2.256410423948143, 48.724415508337785],
                            [2.256653404848118, 48.72461352009172],
                            [2.257151574885914, 48.725027535307994],
                            [2.257355188147784, 48.725197641013786],
                        ],
                    },
                },
                619: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96819576829251, 1.7618663504148935],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 7402.88524229,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.716985230225326,
                            48.96309520715419,
                            1.809094508773784,
                            48.98294677854624,
                        ),
                        "coordinates": [
                            [1.716985230225326, 48.98294677854624],
                            [1.717594407918111, 48.982703772839415],
                            [1.718462645660327, 48.98237410203644],
                            [1.71949191677146, 48.98201047192969],
                            [1.720264259571234, 48.98172269510186],
                            [1.72246249361554, 48.98082320878138],
                            [1.723319687472679, 48.98049469202141],
                            [1.72402769662093, 48.98024389026234],
                            [1.725298437784954, 48.979796223139395],
                            [1.726086328698559, 48.979514904576845],
                            [1.72683809647815, 48.979231005763666],
                            [1.727503048619697, 48.97895140103639],
                            [1.728113742786351, 48.978673882942175],
                            [1.728862982753179, 48.97829954063289],
                            [1.730103599862883, 48.977647032933106],
                            [1.731923671988704, 48.97660497542186],
                            [1.732666373100019, 48.97616871062862],
                            [1.733569628129071, 48.97560717877947],
                            [1.7341272785774, 48.975227033636926],
                            [1.734546623902395, 48.97492467822281],
                            [1.735060972266274, 48.97453716214809],
                            [1.735447806546557, 48.9742322545396],
                            [1.736155971960294, 48.97365777816402],
                            [1.736714214009256, 48.97322527819537],
                            [1.737406942404305, 48.97272923479087],
                            [1.737986331490821, 48.97233966732065],
                            [1.738569093653484, 48.97196915082827],
                            [1.739136988581911, 48.97163186407823],
                            [1.739671949524783, 48.9713277163682],
                            [1.740257613960113, 48.97101431042357],
                            [1.740999302518121, 48.9706493696809],
                            [1.742260283059671, 48.97007773759341],
                            [1.743081221101059, 48.969732229617016],
                            [1.744414288685574, 48.969172843744644],
                            [1.746223205312962, 48.968408892905884],
                            [1.747472689567889, 48.96788235148487],
                            [1.74843494005744, 48.96749946352447],
                            [1.749258897543363, 48.96719675619359],
                            [1.749948321962167, 48.96696235705018],
                            [1.750789935183282, 48.96669304138924],
                            [1.751747233380135, 48.96641955140475],
                            [1.752479520296583, 48.9662258061199],
                            [1.754762826784092, 48.965666393247496],
                            [1.755712131011992, 48.96545469591098],
                            [1.757320044285388, 48.9651654299684],
                            [1.758261546780888, 48.96500126089294],
                            [1.759315143228286, 48.96483050902828],
                            [1.760611090710833, 48.964639556318616],
                            [1.762174483775721, 48.964445174002414],
                            [1.763343221870768, 48.96431541627785],
                            [1.764417700490392, 48.964211345998606],
                            [1.765629489902814, 48.96410795388584],
                            [1.767235389594588, 48.963985097537076],
                            [1.769672844099819, 48.96382589443027],
                            [1.772211191739051, 48.963690935560294],
                            [1.773613949196232, 48.96363360909356],
                            [1.775099652863674, 48.963590948124676],
                            [1.776948362263403, 48.96355337477295],
                            [1.782026620456471, 48.96345915675499],
                            [1.792204806172105, 48.96326539029052],
                            [1.79934146825186, 48.963108244055825],
                            [1.801692782735805, 48.96309520715419],
                            [1.803191036621014, 48.963110230415914],
                            [1.805456304559444, 48.96316890655146],
                            [1.80751423281709, 48.96325064241118],
                            [1.809094508773784, 48.96334411275807],
                        ],
                    },
                },
                620: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.543401472036884, 2.0975435985117445],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 4563.09665636,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.069381524887472,
                            48.535806509243706,
                            2.125707269059876,
                            48.551091975575105,
                        ),
                        "coordinates": [
                            [2.069381524887472, 48.535806509243706],
                            [2.069759543359357, 48.535998299504776],
                            [2.070460925418069, 48.536369885165314],
                            [2.070989667570149, 48.536651883101214],
                            [2.072040039916783, 48.53720871623102],
                            [2.073273757490746, 48.5378560219729],
                            [2.07383404555529, 48.538140458443806],
                            [2.074244342878502, 48.5383329422697],
                            [2.074504543504812, 48.53845346124114],
                            [2.074882417699546, 48.53861255718317],
                            [2.075520628197743, 48.53886718701092],
                            [2.076148916434266, 48.53910180412147],
                            [2.076584528721693, 48.539252699498405],
                            [2.077142904990033, 48.53942885759285],
                            [2.077816578558207, 48.53962026619161],
                            [2.078492848664502, 48.53979502098793],
                            [2.07918925769334, 48.539956493749614],
                            [2.079885784087626, 48.540096310235015],
                            [2.080594929150033, 48.54022116316257],
                            [2.081259068524918, 48.54031926103049],
                            [2.082103700714306, 48.54043608076878],
                            [2.082938309794534, 48.54055120683898],
                            [2.083775407841583, 48.54067132830402],
                            [2.084610016941602, 48.54078810776433],
                            [2.085449655022675, 48.540903226017186],
                            [2.086294287222878, 48.54102334529376],
                            [2.087121402124146, 48.541136758602526],
                            [2.087963534321341, 48.54125686024295],
                            [2.088803187270259, 48.54137195477327],
                            [2.089637837299403, 48.541485365922625],
                            [2.090477481826369, 48.54160377798841],
                            [2.091289542246929, 48.54172212442475],
                            [2.092126727902933, 48.54183219167525],
                            [2.092961376831942, 48.54194890973271],
                            [2.093806044482454, 48.542068972864186],
                            [2.094630588693342, 48.54220231167277],
                            [2.095462530899476, 48.54236230816707],
                            [2.096279439256296, 48.542520601194106],
                            [2.097096303734741, 48.542688882096584],
                            [2.098923014614802, 48.543060805047304],
                            [2.105237765577978, 48.544356312859044],
                            [2.106871638908124, 48.54469107235334],
                            [2.109898878629026, 48.545310074744734],
                            [2.110374998751922, 48.54541262325007],
                            [2.11083602775469, 48.545525130891],
                            [2.111289473372245, 48.545650946541386],
                            [2.111735345169215, 48.54578840336501],
                            [2.112103473540647, 48.54592237318674],
                            [2.112531692645639, 48.546081444263166],
                            [2.112944775749895, 48.54626046947401],
                            [2.113340272653671, 48.54644611999209],
                            [2.113728165332595, 48.546650075415435],
                            [2.114090970456488, 48.54685564545722],
                            [2.114456218741776, 48.547076208413365],
                            [2.114808930623826, 48.547296747042324],
                            [2.115098771644708, 48.547477918343304],
                            [2.115589080466254, 48.547780126908684],
                            [2.115918661708137, 48.54798220358367],
                            [2.116650168299203, 48.54842788229872],
                            [2.117113052054024, 48.54869859196749],
                            [2.117688679037721, 48.54900282726212],
                            [2.118086738149973, 48.54918513555765],
                            [2.1185074053828, 48.549360823372425],
                            [2.118945678752854, 48.54952655183586],
                            [2.119381549984429, 48.54966895550533],
                            [2.119814972604467, 48.549798029663535],
                            [2.120266013129358, 48.5499138112294],
                            [2.120729628888395, 48.550022954037395],
                            [2.121193283228171, 48.55012376579669],
                            [2.122007822832604, 48.550298523815634],
                            [2.12363441164031, 48.55064801806724],
                            [2.125268550437647, 48.55099750216395],
                            [2.125707269059876, 48.551091975575105],
                        ],
                    },
                },
                621: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.53264201027134, 2.039154529180674],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 4574.23576267,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.008771813873437,
                            48.531057764508006,
                            2.069381524887472,
                            48.535806509243706,
                        ),
                        "coordinates": [
                            [2.008771813873437, 48.533732833977226],
                            [2.009746723385014, 48.53358378240689],
                            [2.011869678074811, 48.53325916163322],
                            [2.015236933939557, 48.532745314411315],
                            [2.019354185981668, 48.53211398400631],
                            [2.022193845468613, 48.5316778888953],
                            [2.02260723095999, 48.53161130087928],
                            [2.023214673083323, 48.5315184892104],
                            [2.023670815982834, 48.53145954217455],
                            [2.024043762041415, 48.53141625145539],
                            [2.024650979608317, 48.53135855339382],
                            [2.025259341134543, 48.531319251116294],
                            [2.026418113602109, 48.53127563808936],
                            [2.028202574348773, 48.53120199200792],
                            [2.02917633428576, 48.531167155766155],
                            [2.030399106889527, 48.531110397103575],
                            [2.031467828521446, 48.53106723654237],
                            [2.032058045877617, 48.531057764508006],
                            [2.032624002192012, 48.531066422234225],
                            [2.033010784651196, 48.5310841133706],
                            [2.033440498993227, 48.53111143655763],
                            [2.033820046760105, 48.53114100351547],
                            [2.034307006004498, 48.53118037160835],
                            [2.034880059997846, 48.53124453523164],
                            [2.037253168215208, 48.53153081143649],
                            [2.03928303293862, 48.531755050901516],
                            [2.041627626351697, 48.53202307463431],
                            [2.043452979452916, 48.53222025369867],
                            [2.045450314709484, 48.53241514656364],
                            [2.047512600058372, 48.53262006222356],
                            [2.050392546171845, 48.532906684239336],
                            [2.054463524084015, 48.533309477590954],
                            [2.057123821747188, 48.53357541338937],
                            [2.06013862941511, 48.53387546257729],
                            [2.062637892602588, 48.5341194627232],
                            [2.063786840836441, 48.53422519456175],
                            [2.064764729226511, 48.534338720800676],
                            [2.065090490805462, 48.53438470895088],
                            [2.065455572632191, 48.534447445125856],
                            [2.066010244684644, 48.534562976503615],
                            [2.066597006980077, 48.53470713422527],
                            [2.067151427027445, 48.53487024594024],
                            [2.06772718091878, 48.535064336412646],
                            [2.068267037200189, 48.535272615052605],
                            [2.068781704386639, 48.53550224539504],
                            [2.069234232328339, 48.53573177922848],
                            [2.069381524887472, 48.535806509243706],
                        ],
                    },
                },
                622: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9016978943315, 2.290539692171141],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1351.92438677,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.283628702682815,
                            48.89763744791706,
                            2.297419948146663,
                            48.90570604953261,
                        ),
                        "coordinates": [
                            [2.297419948146663, 48.89763744791706],
                            [2.297395280401841, 48.897650756172794],
                            [2.296393968719668, 48.89823136374865],
                            [2.295318006130621, 48.89886388299613],
                            [2.294724849962381, 48.899224388455764],
                            [2.294311359645943, 48.89946780578177],
                            [2.293698791446777, 48.89984879511778],
                            [2.292359132250744, 48.900671534563216],
                            [2.29167304108838, 48.90108765149402],
                            [2.290109474898639, 48.90199355263667],
                            [2.289546150383618, 48.902313343551604],
                            [2.289069498124001, 48.9025713045086],
                            [2.288661449960847, 48.90279241218691],
                            [2.286371892257679, 48.90413788792124],
                            [2.285796569144198, 48.90446606543778],
                            [2.285020552053906, 48.90491105086764],
                            [2.284279755159278, 48.9053356067742],
                            [2.283628702682815, 48.90570604953261],
                        ],
                    },
                },
                623: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.993278736485884, 2.0846622086240383],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1552.7197956,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.074499463834352,
                            48.99192549246806,
                            2.094643978492074,
                            48.9957468339842,
                        ),
                        "coordinates": [
                            [2.074499463834352, 48.99192549246806],
                            [2.074928583126531, 48.991938731425776],
                            [2.079367802644813, 48.992096327653385],
                            [2.080004004540704, 48.992126309643055],
                            [2.080596786708784, 48.99216332956366],
                            [2.081344879520058, 48.99223162440971],
                            [2.081941046576137, 48.992313851860224],
                            [2.082475721629355, 48.9924006986824],
                            [2.082970593798657, 48.992494592226464],
                            [2.083617069148672, 48.992638785780315],
                            [2.084241757262916, 48.99280196304223],
                            [2.084920539558528, 48.992993807257555],
                            [2.086397256823127, 48.9934134357019],
                            [2.087581556012936, 48.99374675171935],
                            [2.093929315140013, 48.99554491624509],
                            [2.094500636238049, 48.99570855071274],
                            [2.094643978492074, 48.9957468339842],
                        ],
                    },
                },
                624: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [49.1612641882742, 2.4723459696047416],
                        "indice_lig": "D",
                        "idf": 0,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 5972.03303925,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.459520081112193,
                            49.13828637527201,
                            2.490178985421196,
                            49.1873335365493,
                        ),
                        "coordinates": [
                            [2.459520081112193, 49.1873335365493],
                            [2.461836468528622, 49.1801828036466],
                            [2.467035849576074, 49.16706500976759],
                            [2.469862503286604, 49.16035541205852],
                            [2.470996521965048, 49.15817425749942],
                            [2.472832002408762, 49.15601757063088],
                            [2.47890791783622, 49.150525112054396],
                            [2.48286309441142, 49.14666464133141],
                            [2.485386608474283, 49.143733606577776],
                            [2.488861887593484, 49.13978485710428],
                            [2.490178985421196, 49.13828637527201],
                        ],
                    },
                },
                625: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98330064304362, 1.716098108336436],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 151.854398319,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.715210986447546,
                            48.98294677854624,
                            1.716985230225326,
                            48.983654507541004,
                        ),
                        "coordinates": [
                            [1.716985230225326, 48.98294677854624],
                            [1.715210986447546, 48.983654507541004],
                        ],
                    },
                },
                626: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.0924694061026, 2.3120933777191293],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 6794.94954186,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.287258769653332,
                            49.068530235211696,
                            2.332268008349061,
                            49.114061951542226,
                        ),
                        "coordinates": [
                            [2.327669570460789, 49.068530235211696],
                            [2.328038899836222, 49.06872774835301],
                            [2.328379264756656, 49.06892525848934],
                            [2.328676176403118, 49.0691180065254],
                            [2.328983949716981, 49.069344065005964],
                            [2.329179472928231, 49.069508251543276],
                            [2.329360515503158, 49.06966767941749],
                            [2.329570522942775, 49.06986755607332],
                            [2.329791390118977, 49.07010312444122],
                            [2.330052085913148, 49.0704053156475],
                            [2.331366468790297, 49.07199240033275],
                            [2.331598215740878, 49.07227555195412],
                            [2.331797367797573, 49.07257059859203],
                            [2.331974874701607, 49.07288350252421],
                            [2.332072550278713, 49.0731249944843],
                            [2.332152201816522, 49.07337244835855],
                            [2.332210122745445, 49.07362703948198],
                            [2.332253554719168, 49.07392445752204],
                            [2.332268008349061, 49.07427421970068],
                            [2.332249873440238, 49.07455260085012],
                            [2.332199141035724, 49.07487380898436],
                            [2.332104944450692, 49.07520691156585],
                            [2.332003508792088, 49.0754733920773],
                            [2.331891212154573, 49.07570656170569],
                            [2.331731827631216, 49.07596828054261],
                            [2.331586934681513, 49.07617051788867],
                            [2.331402195507324, 49.07641082086371],
                            [2.331173993251632, 49.076653501839004],
                            [2.330956659677541, 49.07686049282034],
                            [2.330703102629793, 49.077072238785995],
                            [2.33040245962997, 49.077298259623554],
                            [2.330032994790309, 49.07753141222436],
                            [2.329685266863023, 49.07772173705681],
                            [2.329304938153184, 49.077902542004274],
                            [2.328913740944432, 49.078080965199966],
                            [2.327544539625985, 49.07866379666528],
                            [2.326972218059813, 49.078908820056334],
                            [2.326526667687847, 49.07911578259786],
                            [2.32615718191176, 49.07930847483493],
                            [2.325769572659676, 49.07953923205923],
                            [2.325439914253079, 49.07976761573263],
                            [2.325092128031762, 49.0800554789994],
                            [2.324795044868954, 49.08035286494631],
                            [2.324555917373287, 49.08062646195659],
                            [2.324367503040595, 49.08088340951281],
                            [2.324208063182895, 49.081137980376795],
                            [2.324084847082168, 49.08138065820567],
                            [2.323961613812705, 49.081687577457664],
                            [2.32387097522335, 49.08200639774618],
                            [2.323809316133887, 49.08230618644279],
                            [2.323773011066654, 49.08262263349091],
                            [2.323776560397654, 49.082896256295385],
                            [2.323809089985613, 49.08316750370957],
                            [2.323859736651423, 49.08341496039041],
                            [2.323968307335626, 49.083793286764646],
                            [2.324304910881321, 49.084883057344186],
                            [2.324384526902926, 49.08518999925676],
                            [2.324438794128032, 49.08546600680521],
                            [2.324456849662571, 49.085699183355786],
                            [2.324449529474076, 49.08599421976928],
                            [2.324420468931485, 49.086310667915676],
                            [2.324358816301413, 49.08659142136787],
                            [2.324260928579596, 49.08689834430137],
                            [2.324141313024478, 49.087174333422304],
                            [2.323978216497334, 49.087476489767546],
                            [2.323797014644475, 49.0877453344385],
                            [2.323532472532622, 49.088073650486805],
                            [2.323286061206933, 49.088328209241745],
                            [2.323017914702043, 49.08857086967374],
                            [2.322659186377886, 49.08885396502554],
                            [2.322300466766626, 49.08908947316159],
                            [2.321909144200667, 49.08930832103963],
                            [2.321543189002131, 49.08948672189342],
                            [2.321130136024855, 49.08966749560844],
                            [2.320496066400167, 49.089917235937584],
                            [2.319909095900716, 49.09014080680531],
                            [2.319470672121568, 49.09031681137767],
                            [2.319053977121199, 49.09050947290653],
                            [2.318680751811855, 49.09070451931201],
                            [2.318314760308707, 49.090925737747284],
                            [2.317992236460335, 49.09115410084827],
                            [2.317676946315405, 49.091411015453765],
                            [2.317383377388297, 49.09169648473053],
                            [2.317136908957664, 49.09197006595916],
                            [2.316897659499486, 49.0923007507611],
                            [2.316705517562842, 49.09260765121393],
                            [2.316393703437106, 49.093178634344675],
                            [2.315944115231108, 49.09396135228037],
                            [2.31575558789445, 49.094253974798654],
                            [2.315617833207036, 49.09443239938168],
                            [2.31529159262215, 49.094796375333104],
                            [2.314990745456496, 49.09507707870352],
                            [2.314613802878118, 49.095369663231516],
                            [2.314135393244986, 49.0956883996003],
                            [2.313754856675624, 49.09589770375553],
                            [2.313309102135331, 49.09609985552999],
                            [2.312827117190319, 49.09628772234868],
                            [2.312374142862541, 49.09642324801372],
                            [2.311924795135436, 49.096544497095486],
                            [2.311431969449966, 49.09665859543148],
                            [2.310663748524728, 49.09681069934106],
                            [2.310134687678268, 49.09691764676506],
                            [2.309601992084954, 49.09704124577252],
                            [2.309112768342545, 49.09717437055678],
                            [2.308648892987908, 49.09733129218884],
                            [2.308235735716148, 49.09749536344521],
                            [2.307815309184519, 49.097695121025225],
                            [2.307423853696543, 49.09791391987519],
                            [2.307054125715642, 49.09815175628827],
                            [2.306785867107673, 49.09835630909926],
                            [2.306532099380311, 49.09856800139231],
                            [2.306300063428488, 49.098786837262374],
                            [2.306038993923108, 49.09907704603832],
                            [2.305291999580416, 49.09995243468669],
                            [2.305081680377242, 49.10019030885264],
                            [2.304798854149685, 49.1004828876242],
                            [2.304458037442235, 49.100787346106834],
                            [2.304091867467211, 49.10106800201921],
                            [2.303693105388029, 49.101312957952814],
                            [2.303239987405854, 49.10155313781977],
                            [2.302736141883567, 49.10178140392713],
                            [2.302181580935156, 49.10197872163898],
                            [2.301583534711548, 49.102171264216075],
                            [2.301047118536595, 49.102320995709675],
                            [2.30048169412737, 49.102492128441526],
                            [2.299992367569859, 49.10265852509547],
                            [2.299528387918171, 49.10284634213778],
                            [2.298999124016957, 49.103100757077414],
                            [2.298426343445829, 49.10339084484059],
                            [2.297788292845123, 49.10372373478782],
                            [2.297237256779659, 49.1039947901187],
                            [2.296805869213364, 49.10418022711995],
                            [2.296450619117983, 49.10431810433001],
                            [2.296015637627256, 49.10446070995024],
                            [2.295551675648676, 49.10458902852821],
                            [2.29509136199417, 49.10468403441923],
                            [2.294591193483939, 49.10476950760368],
                            [2.293946063870054, 49.10485730352573],
                            [2.292655796160776, 49.1050376432397],
                            [2.29210487482149, 49.10513260378288],
                            [2.291535796595178, 49.105265622732006],
                            [2.29099931184523, 49.105420066293966],
                            [2.29046751074561, 49.105616198851294],
                            [2.290089364589656, 49.105778977768985],
                            [2.289603502431451, 49.106040504616054],
                            [2.289204635662977, 49.10627827300051],
                            [2.28887461105024, 49.10652558512761],
                            [2.28860984965019, 49.106739614745834],
                            [2.288323277790877, 49.10701549549874],
                            [2.28804391394789, 49.107331826676855],
                            [2.287789876320268, 49.10768623844484],
                            [2.287608354024446, 49.10800499104566],
                            [2.28744853917153, 49.108357062918465],
                            [2.28734311246677, 49.10868298594598],
                            [2.287281163547714, 49.109020822939414],
                            [2.28725910135174, 49.10933726367102],
                            [2.287258769653332, 49.10966799009189],
                            [2.287298282229797, 49.11002014801475],
                            [2.287651213665814, 49.11227828073427],
                            [2.28782761206601, 49.11348705357541],
                            [2.287915343526005, 49.114061951542226],
                        ],
                    },
                },
                627: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.82045315566213, 2.4098158841455564],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4770.25128044,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.390345965998709,
                            48.80204938032392,
                            2.426482408484048,
                            48.83631546891676,
                        ),
                        "coordinates": [
                            [2.426482408484048, 48.80204938032392],
                            [2.426213233389943, 48.80270366871429],
                            [2.426059067224202, 48.803103518578126],
                            [2.425865562558176, 48.803662814109195],
                            [2.425636975576803, 48.80424292499913],
                            [2.425500067919798, 48.804575763236556],
                            [2.425308930865491, 48.80503813993732],
                            [2.425131451195494, 48.805526583980225],
                            [2.424802040965552, 48.80632899240994],
                            [2.424661066987416, 48.806678919456175],
                            [2.424301888093021, 48.807594657790766],
                            [2.423945340007631, 48.808306202909264],
                            [2.4238066071551, 48.808545570792425],
                            [2.423630072802756, 48.80881009275069],
                            [2.423363810386366, 48.80915291901504],
                            [2.423071675265067, 48.809494865161774],
                            [2.422746842177166, 48.80982694379628],
                            [2.422361495815938, 48.81015720195034],
                            [2.422000423766193, 48.81045160176861],
                            [2.421588397441904, 48.810760360786645],
                            [2.420092448473936, 48.81182171041226],
                            [2.419617867358986, 48.812192557978705],
                            [2.419166456889185, 48.812581372445564],
                            [2.418674308593593, 48.81304215600817],
                            [2.418183542880156, 48.813520922732344],
                            [2.417734967710867, 48.81399336146604],
                            [2.417430592583147, 48.814349552081005],
                            [2.417261333276494, 48.81455065586815],
                            [2.417069037353589, 48.814788792325686],
                            [2.416913692091962, 48.8149964479154],
                            [2.416488893695249, 48.815597648120736],
                            [2.416210377872471, 48.815994422632],
                            [2.415946794225707, 48.81636510731462],
                            [2.415627652920495, 48.81683921532513],
                            [2.415503595505816, 48.817020435180275],
                            [2.415415890548352, 48.81714513857545],
                            [2.415322964685196, 48.81727594562042],
                            [2.415219942191224, 48.81742585543538],
                            [2.415157444171279, 48.817516725902586],
                            [2.415055535950904, 48.817658881174786],
                            [2.414972657548998, 48.81777854160697],
                            [2.414770182636784, 48.818052060328704],
                            [2.414647887813147, 48.818221207331455],
                            [2.414471216694762, 48.818451542308544],
                            [2.414260533010118, 48.818704381847574],
                            [2.414051194292975, 48.81894642965178],
                            [2.413811905866178, 48.819196590093426],
                            [2.413563072631133, 48.819441360909316],
                            [2.413301987130172, 48.81968883662897],
                            [2.413047690982288, 48.81992641596042],
                            [2.412797443495975, 48.820140611055436],
                            [2.412571657662627, 48.820322415163034],
                            [2.412408434024621, 48.82045201896428],
                            [2.412256093224649, 48.82057352229208],
                            [2.412062951465379, 48.82073192221927],
                            [2.411867079403589, 48.820885827704885],
                            [2.411616784560575, 48.821075739547794],
                            [2.411408651811768, 48.82122965227109],
                            [2.411192349967435, 48.821385368109524],
                            [2.410966520478706, 48.82154558654308],
                            [2.410733875941399, 48.821703110602364],
                            [2.410510741612263, 48.8218462398296],
                            [2.41029985096752, 48.821981268089914],
                            [2.41025903292298, 48.82200737347515],
                            [2.410216854174392, 48.82203347932984],
                            [2.410004588052336, 48.82216041400117],
                            [2.409652173980301, 48.822374667383436],
                            [2.409324239749755, 48.82256642227976],
                            [2.409031663100444, 48.82272488081891],
                            [2.408762210604572, 48.82286533778582],
                            [2.408490031842356, 48.82300489746526],
                            [2.40826410815419, 48.8231102547108],
                            [2.407759182536653, 48.82334977727461],
                            [2.407214732646087, 48.823572236719585],
                            [2.406283665804337, 48.82391902962454],
                            [2.405445158717418, 48.82423788137506],
                            [2.405170194371788, 48.82434416166671],
                            [2.404959205661507, 48.82442612226807],
                            [2.404618913210112, 48.82456751146986],
                            [2.404335797561936, 48.82469177985944],
                            [2.403960143470646, 48.8248718564924],
                            [2.40354230146633, 48.825078935613554],
                            [2.403144882580885, 48.825284202222214],
                            [2.402831854855952, 48.82545254881691],
                            [2.402535171598737, 48.82562448198626],
                            [2.402282053415619, 48.82578290055115],
                            [2.402033024959504, 48.82594671096045],
                            [2.401808498266836, 48.82609971603596],
                            [2.401569009892957, 48.82626981570265],
                            [2.401195832664583, 48.82655819275876],
                            [2.400834284691245, 48.82685386050075],
                            [2.400681893009959, 48.8269735496221],
                            [2.400393433755833, 48.82719853013525],
                            [2.40008456050687, 48.827437908965805],
                            [2.399740320857572, 48.827717774478614],
                            [2.399426035559518, 48.82799222677444],
                            [2.39920974592434, 48.82821176934364],
                            [2.399007073190293, 48.82843040410095],
                            [2.398865662351821, 48.8286256237548],
                            [2.398755540165808, 48.82879025107601],
                            [2.398610096929417, 48.8290304365512],
                            [2.398516340179615, 48.82921394000908],
                            [2.398428028740589, 48.82939474207146],
                            [2.398315283707336, 48.82964390175761],
                            [2.398171359476316, 48.83001538039786],
                            [2.398050486906158, 48.83030411238482],
                            [2.397982572837722, 48.83046062305791],
                            [2.397895604868111, 48.83062973322914],
                            [2.3977882157148, 48.83080784749022],
                            [2.397679433512619, 48.83096168157907],
                            [2.39758152642139, 48.83109752451698],
                            [2.39748769902434, 48.831228868591225],
                            [2.397406686186359, 48.83132460463281],
                            [2.397206507880598, 48.83153198292341],
                            [2.397008812813349, 48.831712034404575],
                            [2.396902670816615, 48.8317993206339],
                            [2.396687665879538, 48.83197749002836],
                            [2.396521636604763, 48.832105274481506],
                            [2.396312047021417, 48.83225826123725],
                            [2.396079307259286, 48.83241755489672],
                            [2.395794823378921, 48.83259306130089],
                            [2.395480393429601, 48.832788367203605],
                            [2.395118318527763, 48.83301337211617],
                            [2.394700414833012, 48.83325908818281],
                            [2.394240295775539, 48.83351921264995],
                            [2.393707998818727, 48.833800054192515],
                            [2.393257381108426, 48.83403858692467],
                            [2.392719658517632, 48.834349102510636],
                            [2.392361129475945, 48.83457498027207],
                            [2.39205402873903, 48.83479457005944],
                            [2.391799493674758, 48.834977246579015],
                            [2.391557244840326, 48.83518599466781],
                            [2.391221095491382, 48.83548291743034],
                            [2.390852317628658, 48.835843702378234],
                            [2.390569255563208, 48.83610912347908],
                            [2.390345965998709, 48.83631546891676],
                        ],
                    },
                },
                628: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.517452740740175, 2.6717553450146014],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 2006.24086467,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.662762979853312,
                            48.510265175268025,
                            2.678973982691401,
                            48.52299439391623,
                        ),
                        "coordinates": [
                            [2.678973982691401, 48.510265175268025],
                            [2.678911291052324, 48.51039935542868],
                            [2.678763318402873, 48.51072893292476],
                            [2.67845977049246, 48.51146454797857],
                            [2.67811919409925, 48.512328869420735],
                            [2.677701082223583, 48.51333640606802],
                            [2.677217392589403, 48.51445564697227],
                            [2.676929918424447, 48.51517322428874],
                            [2.676558364092724, 48.51586857141742],
                            [2.67631680741913, 48.51617504567932],
                            [2.676111236956814, 48.516399578671184],
                            [2.675948612545475, 48.51657002642979],
                            [2.675758167470161, 48.516741401991915],
                            [2.675522027847842, 48.516938202565726],
                            [2.675178614034519, 48.51719641849439],
                            [2.674638038419924, 48.517523565324325],
                            [2.674103743156945, 48.517779648710196],
                            [2.67359477384754, 48.517976749450064],
                            [2.673344975375998, 48.51806131790666],
                            [2.673001827777494, 48.51816270140315],
                            [2.67268436024891, 48.51824789910001],
                            [2.672310857742187, 48.51832328171358],
                            [2.67200160784018, 48.518385693924834],
                            [2.671481017418396, 48.51846816688819],
                            [2.671196992563666, 48.51850317695549],
                            [2.670305797335057, 48.51862900186174],
                            [2.669428120814302, 48.51875298114754],
                            [2.668970904237088, 48.51882483871247],
                            [2.668541688093856, 48.51890937130873],
                            [2.668143162394347, 48.51899830425915],
                            [2.667768152150849, 48.51909776288853],
                            [2.666922521697137, 48.51936191474642],
                            [2.66648647829863, 48.51954123801786],
                            [2.666181508125755, 48.51968600684416],
                            [2.665927997608471, 48.51983422279796],
                            [2.665711057975537, 48.51998592889472],
                            [2.66543894853341, 48.52018927473443],
                            [2.665173758709285, 48.52041373918773],
                            [2.664877975944047, 48.52072214430546],
                            [2.664336313793262, 48.52131272894271],
                            [2.663599879910186, 48.52214062155105],
                            [2.662762979853312, 48.52299439391623],
                        ],
                    },
                },
                629: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.75467867609251, 2.2038294013060167],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1985.18553797,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192135811302312,
                            48.751023275119756,
                            2.215860857351649,
                            48.759188983210805,
                        ),
                        "coordinates": [
                            [2.192135811302312, 48.759188983210805],
                            [2.192320295965514, 48.75912019839031],
                            [2.192735754017968, 48.75895476520949],
                            [2.193001263151286, 48.75884133884353],
                            [2.193287060346749, 48.758711876895596],
                            [2.193599060163824, 48.75856523638349],
                            [2.193978336575828, 48.758363430093056],
                            [2.194410190890567, 48.758123061830254],
                            [2.194880593796777, 48.757850620377695],
                            [2.195338822175807, 48.75758619182713],
                            [2.196180252821235, 48.75709872601463],
                            [2.196490461734187, 48.75691976667476],
                            [2.196847284302947, 48.75671944964583],
                            [2.197212207914581, 48.75651646336663],
                            [2.197858828330062, 48.75619202905052],
                            [2.198262146184473, 48.75600916260317],
                            [2.198740407447174, 48.75580764841711],
                            [2.199277369976179, 48.75560486464357],
                            [2.199650165152142, 48.755476830508016],
                            [2.199996568122687, 48.75537686915249],
                            [2.200387541905624, 48.75526223753631],
                            [2.20075215605973, 48.75516497194742],
                            [2.201137008433436, 48.75506773090279],
                            [2.202749322800128, 48.7546587579631],
                            [2.203421791543456, 48.75448689809706],
                            [2.204171207126212, 48.75430173895138],
                            [2.204651240043608, 48.754181844062494],
                            [2.2052750772666, 48.75402463735915],
                            [2.206903515335009, 48.753616964132846],
                            [2.209643863433497, 48.75292410213543],
                            [2.210739572781773, 48.752648277623415],
                            [2.211800839615893, 48.75238177236793],
                            [2.212465136522924, 48.7522152025814],
                            [2.213097016310792, 48.75206063988817],
                            [2.213532642345973, 48.75194076297731],
                            [2.21385655596099, 48.7518421927508],
                            [2.213968158913719, 48.751807241817914],
                            [2.214093372846426, 48.75176780936496],
                            [2.214335654850682, 48.75168263839982],
                            [2.214620230422876, 48.75157278451845],
                            [2.214799847905534, 48.75149968568269],
                            [2.215860857351649, 48.751023275119756],
                        ],
                    },
                },
                630: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.97660283337612, 2.300035279742222],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 1320.83868052,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.292477128819507,
                            48.972749119759264,
                            2.307137032071533,
                            48.9794479829515,
                        ),
                        "coordinates": [
                            [2.307137032071533, 48.972749119759264],
                            [2.306894158072118, 48.972913200039194],
                            [2.306451383665558, 48.97321434113163],
                            [2.305326661217574, 48.97397482562643],
                            [2.304248387110239, 48.974680455821535],
                            [2.303272628965902, 48.97525391322202],
                            [2.302027637899256, 48.9759531795682],
                            [2.30107647610827, 48.976444790948634],
                            [2.300390459437297, 48.97675572500292],
                            [2.299588440994141, 48.97711234527124],
                            [2.298772732575371, 48.97745327439792],
                            [2.297903298149639, 48.97779447069571],
                            [2.297140757257672, 48.97807928049051],
                            [2.296019737740486, 48.97847734767796],
                            [2.295284316545156, 48.97871406598963],
                            [2.29446429243953, 48.978962169468424],
                            [2.293514126699586, 48.9792173559293],
                            [2.292830739502113, 48.979375363324145],
                            [2.292477128819507, 48.9794479829515],
                        ],
                    },
                },
                631: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98032802023021, 2.283622370250369],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 1314.1096605,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.274714898034236,
                            48.9794479829515,
                            2.292477128819507,
                            48.98058979917034,
                        ),
                        "coordinates": [
                            [2.292477128819507, 48.9794479829515],
                            [2.291789698218523, 48.979589155286604],
                            [2.290222213839165, 48.979863539420045],
                            [2.289567691458342, 48.97997747994914],
                            [2.288836657909453, 48.98009048584478],
                            [2.288119301114432, 48.9801864052716],
                            [2.287041234559017, 48.980307345441915],
                            [2.285992792470875, 48.98040960927644],
                            [2.285262248269383, 48.98046663029194],
                            [2.283920717443852, 48.980544858469564],
                            [2.282988168044092, 48.98057511540684],
                            [2.282271280009533, 48.98058820378442],
                            [2.28159811695532, 48.98058979917034],
                            [2.28027131584125, 48.98056499761469],
                            [2.277954290835895, 48.98048379678582],
                            [2.2771755585253, 48.98046990494057],
                            [2.276747150227587, 48.98046968153068],
                            [2.276251981472504, 48.9804775149285],
                            [2.276096224327892, 48.980483726890874],
                            [2.27545269804132, 48.98051036253481],
                            [2.274714898034236, 48.98054054067926],
                        ],
                    },
                },
                632: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.76262564815412, 2.178164023862933],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2178.90646637,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.163947085881832,
                            48.759188983210805,
                            2.192135811302312,
                            48.764776012952915,
                        ),
                        "coordinates": [
                            [2.163947085881832, 48.764776012952915],
                            [2.165808565692433, 48.76474682827451],
                            [2.16636636533764, 48.764725182138726],
                            [2.166711951730226, 48.76470501582243],
                            [2.167008588533025, 48.76467847995979],
                            [2.167267146073519, 48.76464918911724],
                            [2.169603889605043, 48.76432081087228],
                            [2.171324116990315, 48.76407512337822],
                            [2.173382013116744, 48.763727377125676],
                            [2.174532676696627, 48.76352954063185],
                            [2.17558009481833, 48.76334651926196],
                            [2.176790738675328, 48.76313773937385],
                            [2.177907114911465, 48.76295159402869],
                            [2.17899150692073, 48.762770902003666],
                            [2.179941107105414, 48.762610671609615],
                            [2.180426597314621, 48.762521447666686],
                            [2.181280003145922, 48.762350855004804],
                            [2.181835356775912, 48.7622302099448],
                            [2.18228727129237, 48.762128306431066],
                            [2.182871248356519, 48.761987011506676],
                            [2.184046176126185, 48.76166726152205],
                            [2.185325858203075, 48.7612846337467],
                            [2.188120020256358, 48.76043309274623],
                            [2.189276966459176, 48.76007992739549],
                            [2.190494666869141, 48.75971344431436],
                            [2.19161970551149, 48.75937261692995],
                            [2.19196971349315, 48.75925091425239],
                            [2.192135811302312, 48.759188983210805],
                        ],
                    },
                },
                633: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96309571623342, 2.3213338503637733],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 1000.01148057,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.3165820711557,
                            48.95987163649979,
                            2.32609015753849,
                            48.966326544842126,
                        ),
                        "coordinates": [
                            [2.32609015753849, 48.95987163649979],
                            [2.325514520974648, 48.96026447734647],
                            [2.324223720051144, 48.9611322848029],
                            [2.32393960916588, 48.96131660512335],
                            [2.323703300567215, 48.9614739519506],
                            [2.322263560000611, 48.96246208458023],
                            [2.319349758639264, 48.96444818215012],
                            [2.317871598635294, 48.96544614451625],
                            [2.317073748346804, 48.965986476118985],
                            [2.3165820711557, 48.966326544842126],
                        ],
                    },
                },
                634: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.75272752082853, 1.4405264439085566],
                        "indice_lig": "N",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 11587.0232382,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.369974234117775,
                            48.73095466998517,
                            1.513333052350337,
                            48.76842177662328,
                        ),
                        "coordinates": [
                            [1.513333052350337, 48.76842177662328],
                            [1.465087663005076, 48.75628477235596],
                            [1.453261783992116, 48.75423281718814],
                            [1.446780135690037, 48.75393724152336],
                            [1.439360958395429, 48.75424666912322],
                            [1.432504311525692, 48.75419242763463],
                            [1.424917643412635, 48.7535191730065],
                            [1.413293012822981, 48.750729351540116],
                            [1.401502801422001, 48.74695655934176],
                            [1.396905322603665, 48.74508042925141],
                            [1.388290529355104, 48.740106922724124],
                            [1.383530027802968, 48.7371259191559],
                            [1.369974234117775, 48.73095466998517],
                        ],
                    },
                },
                635: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.379909393743745, 2.9393628830651086],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 476.033427847,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.936180968314843,
                            48.37952610418487,
                            2.94252341270237,
                            48.38004841334399,
                        ),
                        "coordinates": [
                            [2.94252341270237, 48.37952610418487],
                            [2.941970327788975, 48.37962642828399],
                            [2.941460098137519, 48.37971729379121],
                            [2.940931959914021, 48.379805869296995],
                            [2.940525101059726, 48.37986997552031],
                            [2.939971731722615, 48.379942007947484],
                            [2.939550282439154, 48.37998236820579],
                            [2.939189472191447, 48.380010493721166],
                            [2.938846325386872, 48.380028017386],
                            [2.938538049320152, 48.38004196664145],
                            [2.938188668747306, 48.38004507507702],
                            [2.937833464348154, 48.38004841334399],
                            [2.937551595785191, 48.38004230483279],
                            [2.936854495968621, 48.380025737774496],
                            [2.936180968314843, 48.37999957527981],
                        ],
                    },
                },
                636: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.87215890573533, 2.3494715466878078],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2383.56014927,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345430546578709,
                            48.861822272798115,
                            2.357115334947971,
                            48.88076895833307,
                        ),
                        "coordinates": [
                            [2.347012687238757, 48.861822272798115],
                            [2.346139950534157, 48.86386291966857],
                            [2.345636988821748, 48.86531838987238],
                            [2.345557722441634, 48.86568232681121],
                            [2.345522355293041, 48.865997287939436],
                            [2.345482191727732, 48.86627516707191],
                            [2.345453618065505, 48.86658002326778],
                            [2.345441380929341, 48.866759879030795],
                            [2.345437319872033, 48.866928043946544],
                            [2.345430546578709, 48.86717264717367],
                            [2.345437983713143, 48.867400407823276],
                            [2.345444249176205, 48.867599802139644],
                            [2.345459272257531, 48.867767065829796],
                            [2.345478390228793, 48.8679694010646],
                            [2.34550295806468, 48.86815105240558],
                            [2.345535809422007, 48.868338646891864],
                            [2.345582320764311, 48.86849683109246],
                            [2.345653412169549, 48.868684934039884],
                            [2.345736183005508, 48.86887944650945],
                            [2.345823453089305, 48.86903771212665],
                            [2.345989418474129, 48.869313639539946],
                            [2.346169802910834, 48.8696123196003],
                            [2.346423420956653, 48.869966612439036],
                            [2.346563867742066, 48.87016623878365],
                            [2.34683112753148, 48.87054211184874],
                            [2.346978707051198, 48.870755475257596],
                            [2.347148845854515, 48.870995316639934],
                            [2.347291782533406, 48.87119926333222],
                            [2.347413389762284, 48.8713756852506],
                            [2.347525209254973, 48.87153664437751],
                            [2.347620664123193, 48.8716733246529],
                            [2.347812940357576, 48.871949383184464],
                            [2.347889305541526, 48.87205908782341],
                            [2.347988853327868, 48.872200263339515],
                            [2.347991580985481, 48.87220475960292],
                            [2.348117039735388, 48.87238460199915],
                            [2.348223677774877, 48.87253583271807],
                            [2.348327049504371, 48.87268403904699],
                            [2.348438874629225, 48.872844997129704],
                            [2.348565700165098, 48.873023939841445],
                            [2.348793443130341, 48.87334855400916],
                            [2.348914816201521, 48.87352030156975],
                            [2.349120741423353, 48.873807148208115],
                            [2.349242116960456, 48.873977996929256],
                            [2.34937304071208, 48.87416503150311],
                            [2.349493054517679, 48.87433587969868],
                            [2.349629434954679, 48.874534603476704],
                            [2.349892649886407, 48.87490417492728],
                            [2.350011172639738, 48.87505591606561],
                            [2.350147675855348, 48.875222488499574],
                            [2.350300411336523, 48.87538164119075],
                            [2.350391782008514, 48.87547875183336],
                            [2.350496784902015, 48.87557496148159],
                            [2.350659063038761, 48.87572422147292],
                            [2.350900428930991, 48.87591663572261],
                            [2.351025884203083, 48.87601194310479],
                            [2.351115884397448, 48.876075780178056],
                            [2.351241336677679, 48.87615759816922],
                            [2.351519512826296, 48.87633381927517],
                            [2.351627237619566, 48.87640214970282],
                            [2.351722691737228, 48.87646148947573],
                            [2.351914961644672, 48.87657926872294],
                            [2.352019960308049, 48.876644001966824],
                            [2.352115414232821, 48.8767024420729],
                            [2.352268140687587, 48.87679594589649],
                            [2.353010576106873, 48.877242747218865],
                            [2.353466110615679, 48.877536326382575],
                            [2.354125305776175, 48.87800155410312],
                            [2.354773056677193, 48.87850528865128],
                            [2.355374585563331, 48.878979859670146],
                            [2.356321622424064, 48.87975798181816],
                            [2.356458336773375, 48.87988471140258],
                            [2.356680756385788, 48.880127307226694],
                            [2.356875876646691, 48.880369270286586],
                            [2.357066538030486, 48.88067080499799],
                            [2.357115334947971, 48.88076895833307],
                        ],
                    },
                },
                637: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.7425820689349, 2.744175510506277],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2304.5739703,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.729481333043577,
                            48.73948720730179,
                            2.758824548674894,
                            48.74472077575101,
                        ),
                        "coordinates": [
                            [2.758824548674894, 48.73948720730179],
                            [2.757463153104825, 48.73992300184102],
                            [2.755815676866813, 48.740457855891115],
                            [2.755213628316272, 48.740653415483834],
                            [2.753632277764686, 48.74116286995946],
                            [2.752746065101737, 48.74144687524047],
                            [2.751953159560979, 48.74170436051471],
                            [2.751124289360127, 48.74196434953959],
                            [2.750342140477953, 48.74221940453988],
                            [2.749793146582966, 48.74239271141803],
                            [2.74940920181095, 48.742513070996154],
                            [2.749107760020873, 48.74260457858254],
                            [2.74882064994764, 48.74268889594417],
                            [2.748498111428065, 48.7427786199245],
                            [2.74822812030214, 48.74285063912414],
                            [2.748034078807947, 48.74289900239088],
                            [2.747778961740407, 48.74296107384181],
                            [2.747518547365853, 48.743020849027594],
                            [2.74724286191312, 48.743081712886344],
                            [2.746940721709728, 48.74313655151526],
                            [2.746653441037735, 48.743189669748624],
                            [2.746365778130365, 48.74324044619832],
                            [2.746113191513724, 48.74328002417393],
                            [2.745942068107599, 48.743304919344126],
                            [2.745659538454691, 48.74334100586608],
                            [2.745469357047838, 48.74336327124011],
                            [2.745272370539994, 48.74338466105186],
                            [2.745107971776274, 48.74340053834247],
                            [2.744942205102114, 48.74341552116371],
                            [2.74476147497997, 48.74342965779589],
                            [2.744542688273962, 48.74344572922272],
                            [2.744357878048428, 48.74345987989882],
                            [2.744162139971035, 48.743467774823486],
                            [2.743808747418527, 48.74348522480896],
                            [2.743519571546724, 48.743490109272265],
                            [2.743284480852506, 48.743491593525064],
                            [2.743085420140631, 48.74349230310473],
                            [2.742783528808296, 48.74348888380099],
                            [2.742458485902403, 48.7434810489327],
                            [2.742199233724328, 48.74346781575678],
                            [2.741850157497902, 48.74344966320503],
                            [2.741617806472173, 48.743437276614756],
                            [2.741342441262852, 48.74341626183757],
                            [2.740945726052493, 48.743392000722906],
                            [2.739929502656484, 48.74333085272223],
                            [2.738226255276761, 48.74322535702782],
                            [2.73715831957738, 48.74315807112082],
                            [2.736823660136452, 48.74313766457197],
                            [2.73647403012768, 48.743115510654086],
                            [2.736142112869119, 48.743097789404686],
                            [2.735773547631447, 48.74308828954061],
                            [2.735526069480017, 48.743087357539466],
                            [2.735254144235954, 48.74309010789132],
                            [2.734942895406095, 48.7431064837264],
                            [2.734656121499252, 48.74312277373787],
                            [2.734321880609803, 48.743154516442054],
                            [2.734056968219893, 48.74318421718361],
                            [2.733798876921888, 48.74321659211917],
                            [2.733578834398465, 48.743246136400366],
                            [2.73333435331182, 48.74328026128418],
                            [2.733073626086733, 48.74332343524674],
                            [2.732876741095101, 48.74335829248691],
                            [2.732612006844383, 48.74341047222009],
                            [2.732362235230184, 48.74346349797909],
                            [2.732098950879702, 48.74352736233483],
                            [2.731842479611189, 48.743593000667566],
                            [2.731595561497767, 48.743663101238646],
                            [2.731420558593534, 48.74371406792822],
                            [2.731195428804425, 48.74378858873805],
                            [2.730935075927499, 48.74387941889811],
                            [2.730537964968577, 48.74404356246989],
                            [2.730262986426534, 48.74417670801468],
                            [2.730022118880164, 48.74432502224007],
                            [2.729844987446206, 48.74445153356572],
                            [2.729481333043577, 48.74472077575101],
                        ],
                    },
                },
                638: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.87654430546382, 1.8746361954415827],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3763.39871863,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.871738475714576,
                            48.85999873043875,
                            1.876621027777829,
                            48.893238595694605,
                        ),
                        "coordinates": [
                            [1.875595590302068, 48.85999873043875],
                            [1.874880820213616, 48.86244429064873],
                            [1.874580974869085, 48.863468270304544],
                            [1.874283843954937, 48.864492259515984],
                            [1.874183412365938, 48.8648848434657],
                            [1.874111886872333, 48.865246968269304],
                            [1.874074818909281, 48.86571445051405],
                            [1.874086586387671, 48.866207310000384],
                            [1.874135124085862, 48.86655733182802],
                            [1.874217791610205, 48.866902095563844],
                            [1.874323731208806, 48.8672361619518],
                            [1.874414178336782, 48.867477538316244],
                            [1.874535725449866, 48.86774602001969],
                            [1.874688400167162, 48.86803890809279],
                            [1.874868079522875, 48.868359782827206],
                            [1.875343338755898, 48.86914588782847],
                            [1.875661292764052, 48.869697538916235],
                            [1.875882416828523, 48.870107610418955],
                            [1.875976285955063, 48.87027525713336],
                            [1.876093784683952, 48.870541022702206],
                            [1.876176600246217, 48.870724812156496],
                            [1.876309517011832, 48.87109225994167],
                            [1.876376764341849, 48.87133803804185],
                            [1.876425577564684, 48.87151359684397],
                            [1.876466395389776, 48.87166933872067],
                            [1.876545859990483, 48.872068045523136],
                            [1.876567410917636, 48.87224349395396],
                            [1.876586392538174, 48.87240184584358],
                            [1.876598700597584, 48.872544883063846],
                            [1.876619542662846, 48.87279676915366],
                            [1.876621027777829, 48.87293076921606],
                            [1.876620028281249, 48.8730386804738],
                            [1.876585927458329, 48.87362937845243],
                            [1.876525525666442, 48.874115652027186],
                            [1.876203590550863, 48.87545969493346],
                            [1.87609168511961, 48.87591248694666],
                            [1.875933096011904, 48.8765476461318],
                            [1.875875028707326, 48.8767812279449],
                            [1.875735953892318, 48.87736970308648],
                            [1.875718884625771, 48.8774460741056],
                            [1.875461207272405, 48.878472923773025],
                            [1.875321001136322, 48.87903531445905],
                            [1.874990452540816, 48.88041888871282],
                            [1.874777696210153, 48.88130383044288],
                            [1.874692985675026, 48.881615542353664],
                            [1.874412000536258, 48.88279787424524],
                            [1.873883280038885, 48.88495583203371],
                            [1.873516619753718, 48.88640130698061],
                            [1.873086913904117, 48.88817026990819],
                            [1.872724878826941, 48.889661283870936],
                            [1.872657170238704, 48.8899401304465],
                            [1.87222602216343, 48.89171088381271],
                            [1.872009582966879, 48.8925418488953],
                            [1.8718654852751, 48.89292885676782],
                            [1.871738475714576, 48.893238595694605],
                        ],
                    },
                },
                639: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.84075398192878, 2.3821120728587526],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 1562.68275091,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37359365326228,
                            48.83631546891676,
                            2.390345965998709,
                            48.844760171266735,
                        ),
                        "coordinates": [
                            [2.390345965998709, 48.83631546891676],
                            [2.390322929581464, 48.83633675636582],
                            [2.390158249950645, 48.836481616539544],
                            [2.389728192331321, 48.83687839803796],
                            [2.389559430812823, 48.83703135416416],
                            [2.389201465208559, 48.83733277687348],
                            [2.388881582141247, 48.83757842565034],
                            [2.388281229299247, 48.83798786961311],
                            [2.387935402598586, 48.83818406832291],
                            [2.386841850262587, 48.83882705395043],
                            [2.386514484093897, 48.8390122044851],
                            [2.385941336398595, 48.83934528783985],
                            [2.385664407602353, 48.83950159154659],
                            [2.385376154010946, 48.83965646848244],
                            [2.385084960968584, 48.83979923678294],
                            [2.384800338585216, 48.83992541615458],
                            [2.384555820141204, 48.84001845285108],
                            [2.384259637093709, 48.840114886218764],
                            [2.383909724229494, 48.840202786000205],
                            [2.382814975447521, 48.84052178704328],
                            [2.381839650695112, 48.84084715024368],
                            [2.38076957311166, 48.84130074324963],
                            [2.380128429862727, 48.84158422258861],
                            [2.378445931810589, 48.84225835991038],
                            [2.378168448063484, 48.84235839358047],
                            [2.377887353385376, 48.842453669995514],
                            [2.377656724215145, 48.842546547088354],
                            [2.377397272353561, 48.842663227287424],
                            [2.377173867342697, 48.842777516129416],
                            [2.376892820797989, 48.842937031726265],
                            [2.375373218520609, 48.843777162757696],
                            [2.37359365326228, 48.844760171266735],
                        ],
                    },
                },
                640: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98853238427416, 2.9890235170340156],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3841.8942451,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.973519215077535,
                            48.97436062282584,
                            3.007953055749719,
                            48.99841539320162,
                        ),
                        "coordinates": [
                            [3.007953055749719, 48.99841539320162],
                            [3.007125728100396, 48.99802739127617],
                            [3.006450656574785, 48.997711544616415],
                            [3.004797499726691, 48.99694502991142],
                            [2.99974153111668, 48.99459298037562],
                            [2.995681704351054, 48.99270557937993],
                            [2.994920354698954, 48.9923618452237],
                            [2.994530902278736, 48.9921958567157],
                            [2.994113703333233, 48.99203668785531],
                            [2.993803484381748, 48.991928537900534],
                            [2.993473043308315, 48.99182216916534],
                            [2.993018263179704, 48.99169152718738],
                            [2.992617028580308, 48.991590557076],
                            [2.992122022095117, 48.99148012970509],
                            [2.98948221174346, 48.9909692205317],
                            [2.989104850145396, 48.99088607651864],
                            [2.988696124984179, 48.99079179884357],
                            [2.988231286540687, 48.990664526767176],
                            [2.987853238373825, 48.99054952062019],
                            [2.987487950910211, 48.99043604685454],
                            [2.987138251901406, 48.99030430528466],
                            [2.986770647104063, 48.990155186166724],
                            [2.986346761424596, 48.989970680978416],
                            [2.985743031677043, 48.98967262948967],
                            [2.985328415704607, 48.98944150573327],
                            [2.98507226498396, 48.98929007400256],
                            [2.984579605773865, 48.98895801037631],
                            [2.984334245705464, 48.98877451700547],
                            [2.984058043713823, 48.98855455328085],
                            [2.98376670862844, 48.988305517109964],
                            [2.983471528923542, 48.988021543458395],
                            [2.983137837055643, 48.98766199199822],
                            [2.982901828257867, 48.987366633848374],
                            [2.982545690659099, 48.98688916352555],
                            [2.982185304420239, 48.98638542167882],
                            [2.981800663532403, 48.98584070305271],
                            [2.981123236656392, 48.9849284372329],
                            [2.980896336654976, 48.984604921388105],
                            [2.980509657124992, 48.98405911382655],
                            [2.978669153023966, 48.981459451784694],
                            [2.978081563790149, 48.98063660731409],
                            [2.977506774347654, 48.97982368190999],
                            [2.976246890619957, 48.978046509836474],
                            [2.975092197812238, 48.976405677170035],
                            [2.974597437043156, 48.975708883057294],
                            [2.974345299848863, 48.975383830566564],
                            [2.974027816182958, 48.975010784370674],
                            [2.973519215077535, 48.97436062282584],
                        ],
                    },
                },
                641: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.88807321421946, 2.3656839612278047],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2462.435463,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.359456616944207,
                            48.877375619879636,
                            2.37412297552969,
                            48.89667381116845,
                        ),
                        "coordinates": [
                            [2.359456616944207, 48.877375619879636],
                            [2.359812092572549, 48.877962273326986],
                            [2.360064276433283, 48.878386746095494],
                            [2.36042280758036, 48.878983408628955],
                            [2.360583852309661, 48.87926772577507],
                            [2.360825675702478, 48.8797388019523],
                            [2.360950727590288, 48.88005499726818],
                            [2.361037416069371, 48.8803326302404],
                            [2.361082530912409, 48.880544994411764],
                            [2.361139955494417, 48.88084379592806],
                            [2.361249935984651, 48.881251176902275],
                            [2.361368498320344, 48.881557335241546],
                            [2.361510281666975, 48.88185311843682],
                            [2.361737381049066, 48.88228022486055],
                            [2.362135024314978, 48.882974413779664],
                            [2.362743466558654, 48.884021183150494],
                            [2.363097360205704, 48.88464924555404],
                            [2.363393513000418, 48.88523449373252],
                            [2.363657162285453, 48.88574360918681],
                            [2.364025519188199, 48.88638594226535],
                            [2.364675543719203, 48.8874469673656],
                            [2.365661339747672, 48.889113515421656],
                            [2.366650972292101, 48.89078355226665],
                            [2.367304735218245, 48.89187311439831],
                            [2.367532275645794, 48.89222043533884],
                            [2.36772729270491, 48.892484488590725],
                            [2.367958405126996, 48.89276518683221],
                            [2.368175059060795, 48.893000681279],
                            [2.368395324960341, 48.893238553239556],
                            [2.368662524410929, 48.89350972307389],
                            [2.368886387850427, 48.8937237998869],
                            [2.369222175483918, 48.89402825834659],
                            [2.36947851715923, 48.894239946434915],
                            [2.369720419303542, 48.89443736128105],
                            [2.370034521737102, 48.894675202977886],
                            [2.370355832276493, 48.89489638673899],
                            [2.37066630726123, 48.89509853702541],
                            [2.370937066742667, 48.89526500964294],
                            [2.371344995508631, 48.8954909227114],
                            [2.371684334318134, 48.89567402759272],
                            [2.372001710155025, 48.89584075304363],
                            [2.372312457870593, 48.895985525618165],
                            [2.372698712991364, 48.896163854314324],
                            [2.373030811637182, 48.896301749106065],
                            [2.37332680343868, 48.896411103953625],
                            [2.373727472580184, 48.896551354743856],
                            [2.37412297552969, 48.89667381116845],
                        ],
                    },
                },
                642: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.74433066931617, 2.363257434582341],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1695.05968517,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35330589785325,
                            48.740586107900334,
                            2.373111940704935,
                            48.74834968236464,
                        ),
                        "coordinates": [
                            [2.35330589785325, 48.740586107900334],
                            [2.353307044734945, 48.740586398336916],
                            [2.353414466434745, 48.74061515883646],
                            [2.354003247487515, 48.7407652486571],
                            [2.354804165995392, 48.740990840915295],
                            [2.355670376940542, 48.74126857451371],
                            [2.35616128189506, 48.74143485667468],
                            [2.35679226208796, 48.74166136263422],
                            [2.35790194501933, 48.74209550893488],
                            [2.358802224598667, 48.74246583725283],
                            [2.359357089785589, 48.74270133676104],
                            [2.360926400648249, 48.74334798768189],
                            [2.362408915943983, 48.74394797669073],
                            [2.362884931398351, 48.744147505868405],
                            [2.364741405272006, 48.74489165967841],
                            [2.365639069459852, 48.74526643089964],
                            [2.366342249064091, 48.74556121050418],
                            [2.367650703426875, 48.74610941748587],
                            [2.369199929076181, 48.74674117237808],
                            [2.37068107684206, 48.74737448341556],
                            [2.371660000479114, 48.74779294690864],
                            [2.372288619188905, 48.748043375061656],
                            [2.373111940704935, 48.74834968236464],
                        ],
                    },
                },
                643: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.85271772861036, 2.3596112415216393],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2832.62444026,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347012687238757,
                            48.84413934985302,
                            2.373259976710645,
                            48.861822272798115,
                        ),
                        "coordinates": [
                            [2.373259976710645, 48.84413934985302],
                            [2.372461836166853, 48.8446213297083],
                            [2.371949288631041, 48.844943454292626],
                            [2.37148486699435, 48.84528015354964],
                            [2.370671617570643, 48.84585352628388],
                            [2.367969300349362, 48.84767451617495],
                            [2.366373660414324, 48.84879669155776],
                            [2.361663912287947, 48.85224582041532],
                            [2.361140847505953, 48.85262905923144],
                            [2.360841827743596, 48.852829662151564],
                            [2.360521344701473, 48.85303362739262],
                            [2.36002715159804, 48.85332578238206],
                            [2.358951186066298, 48.85385106726358],
                            [2.358347662850251, 48.85411428361651],
                            [2.357482039856472, 48.85447285471544],
                            [2.356656897995536, 48.85481173988781],
                            [2.355746527158751, 48.85513534994395],
                            [2.354787178237725, 48.855442261395396],
                            [2.353615835699875, 48.85578538552734],
                            [2.3525018319543, 48.85610920618555],
                            [2.351780423971029, 48.856343669006286],
                            [2.351165299418861, 48.85654974829082],
                            [2.35074298074319, 48.85672954658536],
                            [2.35041859858395, 48.85689721219578],
                            [2.350192508071292, 48.85702786190461],
                            [2.349484214156639, 48.857540921752864],
                            [2.349177502467835, 48.85784950927827],
                            [2.348890950526438, 48.85820535587663],
                            [2.348387994662607, 48.85901820264864],
                            [2.347970423861637, 48.85971563273594],
                            [2.347663212781215, 48.86030109116217],
                            [2.347012687238757, 48.861822272798115],
                        ],
                    },
                },
                644: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.84746663935479, 2.3674156329241813],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 1154.63620648,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.36198522500636,
                            48.84398558201753,
                            2.373014219940096,
                            48.85123760888376,
                        ),
                        "coordinates": [
                            [2.373014219940096, 48.84398558201753],
                            [2.372744961770306, 48.84413382394736],
                            [2.372372936412954, 48.84436731603358],
                            [2.371108266176607, 48.845522296306484],
                            [2.370252510680592, 48.8459893031229],
                            [2.367438108385448, 48.84712427550948],
                            [2.366569347457524, 48.84758334896176],
                            [2.363852566865234, 48.84971272767722],
                            [2.363359710780903, 48.85009733449953],
                            [2.36198522500636, 48.85123760888376],
                        ],
                    },
                },
                645: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.83763493274532, 2.3866635850158873],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 619.564924537,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.383028081146453,
                            48.83631546891676,
                            2.390345965998709,
                            48.83908128024195,
                        ),
                        "coordinates": [
                            [2.383028081146453, 48.83908128024195],
                            [2.38720164624241, 48.83736667927639],
                            [2.387812290802427, 48.83714527097872],
                            [2.390345965998709, 48.83631546891676],
                        ],
                    },
                },
                646: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.78250069049023, 2.151917430606534],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3084.50284027,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.14680807930341,
                            48.77042520300475,
                            2.155740387874207,
                            48.795008319405504,
                        ),
                        "coordinates": [
                            [2.149209553856219, 48.795008319405504],
                            [2.14944767007486, 48.794894501458444],
                            [2.149848676245521, 48.794682438584495],
                            [2.150245665875757, 48.7944336043699],
                            [2.15051320141176, 48.79424954345916],
                            [2.150723377624055, 48.79409427859728],
                            [2.150866488559904, 48.79396031639317],
                            [2.151059472477405, 48.79377932488097],
                            [2.151220013406822, 48.79360637012334],
                            [2.151433426481253, 48.79335450728213],
                            [2.151578218157759, 48.793154878389416],
                            [2.151737627470081, 48.79289816768626],
                            [2.151870265621723, 48.79263198018042],
                            [2.152002653832152, 48.79232279732381],
                            [2.15209373432383, 48.79203980382375],
                            [2.152148835903813, 48.791747234197466],
                            [2.152174918633007, 48.79151172138697],
                            [2.152183216929127, 48.79121669601401],
                            [2.152116802155595, 48.790676476985084],
                            [2.15200029386702, 48.79005052147761],
                            [2.151802393228999, 48.78904135818668],
                            [2.151710779370541, 48.788501099293484],
                            [2.15167922313514, 48.78827263028487],
                            [2.151677587476256, 48.78799566782838],
                            [2.151681375661874, 48.78769445295941],
                            [2.151714604999674, 48.78747322809194],
                            [2.151784047387822, 48.78719733754593],
                            [2.151874140692271, 48.78692460566026],
                            [2.151975780013553, 48.78667387196914],
                            [2.152179860423669, 48.78630096796104],
                            [2.152493302301057, 48.78583748328845],
                            [2.152697374785452, 48.78559514020506],
                            [2.1530096371665, 48.7853176359647],
                            [2.153348222971903, 48.78502231979472],
                            [2.153829690133343, 48.78462857085377],
                            [2.154172628453482, 48.78435638042654],
                            [2.154354227103978, 48.78419120463191],
                            [2.154694294520612, 48.7838581170639],
                            [2.154932057726413, 48.78359051204928],
                            [2.155137188566615, 48.78331476078697],
                            [2.155291819339782, 48.78307939724403],
                            [2.15543023049908, 48.78281343169025],
                            [2.155564860395365, 48.78246472657438],
                            [2.155643817506279, 48.78218263096899],
                            [2.155709824261317, 48.781893016227194],
                            [2.155733705197933, 48.78160041261842],
                            [2.155740387874207, 48.78134720397285],
                            [2.155707557096589, 48.78102071360327],
                            [2.155676921516368, 48.7808390113641],
                            [2.155600339504245, 48.780570005598946],
                            [2.155530296022794, 48.78037385145658],
                            [2.15544525524001, 48.78018576797299],
                            [2.155316909149342, 48.77993286636306],
                            [2.155199274788353, 48.779727643726815],
                            [2.154962370953934, 48.77939363381439],
                            [2.154836367968398, 48.77924505184884],
                            [2.154272411213293, 48.778674008089325],
                            [2.152359254525248, 48.77684719200691],
                            [2.1509952375805, 48.775566203335885],
                            [2.150460888628286, 48.775104901133574],
                            [2.150204525137417, 48.77489494961334],
                            [2.149823301015048, 48.77460205949364],
                            [2.149459620422139, 48.77434876482795],
                            [2.148659100911393, 48.77376291547719],
                            [2.148371486823045, 48.77354571414232],
                            [2.148176193250039, 48.773380823415714],
                            [2.147976883954436, 48.77319883952385],
                            [2.147796640038623, 48.77301238973648],
                            [2.147666590898345, 48.772864693085886],
                            [2.147454036837616, 48.77258916096176],
                            [2.147305328798392, 48.772339813527616],
                            [2.147153960034657, 48.77207517434332],
                            [2.147075741346882, 48.7719102853402],
                            [2.14699213483155, 48.77169900688727],
                            [2.146947437652643, 48.77154228387909],
                            [2.146892852986458, 48.77133373546093],
                            [2.146846019122964, 48.77112862243513],
                            [2.146823463881327, 48.77095621376757],
                            [2.14680807930341, 48.770731977376606],
                            [2.146831644750671, 48.77042520300475],
                        ],
                    },
                },
                647: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.068221426069414, 2.1978835203495612],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2447.39113016,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.191244759191911,
                            49.058047811766336,
                            2.205446725524735,
                            49.07769904281828,
                        ),
                        "coordinates": [
                            [2.205446725524735, 49.07769904281828],
                            [2.204806727457009, 49.076869223928355],
                            [2.204322398107003, 49.07626255546574],
                            [2.203960892017576, 49.07579901173805],
                            [2.203532532177559, 49.07525625346355],
                            [2.202823274165091, 49.07431838432103],
                            [2.201955752901646, 49.07320047018822],
                            [2.201905277492038, 49.073138361020604],
                            [2.201551951653985, 49.072703595241045],
                            [2.201285864157705, 49.07240292447033],
                            [2.201053799286954, 49.07217513339117],
                            [2.200840933229804, 49.07199714229422],
                            [2.200585334631, 49.07180497681357],
                            [2.199721874369569, 49.07123200988989],
                            [2.199231398855944, 49.07090858371576],
                            [2.198981381682828, 49.07074371599094],
                            [2.198411674778181, 49.070368932452475],
                            [2.198201305190892, 49.07022209627837],
                            [2.197996237373011, 49.07006409660289],
                            [2.197836720840645, 49.06991590232351],
                            [2.197479085492922, 49.069573744650654],
                            [2.197339987685086, 49.069393720721195],
                            [2.197237709526699, 49.06926140263168],
                            [2.197018298629368, 49.06892660566757],
                            [2.196791150255154, 49.06849227104825],
                            [2.196597907141723, 49.068034912117156],
                            [2.196364166987325, 49.06744740008892],
                            [2.196182006672561, 49.06701282765043],
                            [2.19570086437753, 49.065838684046795],
                            [2.195464448275426, 49.065237678375695],
                            [2.194906996078088, 49.06396091947925],
                            [2.194683838791784, 49.0635146037255],
                            [2.194418348118311, 49.06303855851216],
                            [2.194090139366126, 49.0624832980704],
                            [2.193606484260956, 49.06173719645499],
                            [2.193211377727299, 49.06113418879083],
                            [2.192827330256025, 49.0604961220893],
                            [2.192339642569011, 49.05973831951797],
                            [2.191980077380003, 49.059158732968434],
                            [2.191557772949955, 49.05851162012874],
                            [2.191283914193455, 49.05810839809772],
                            [2.191244759191911, 49.058047811766336],
                        ],
                    },
                },
                648: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.99698913811343, 1.8738592005046046],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 4515.99165634,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.845134443502388,
                            48.99164222314708,
                            1.901781979947734,
                            49.00576253682855,
                        ),
                        "coordinates": [
                            [1.845134443502388, 48.99224128128681],
                            [1.845339087123361, 48.99224086589612],
                            [1.845700787429356, 48.99222814250953],
                            [1.846142147031367, 48.992203862759595],
                            [1.846779077664176, 48.99214710785623],
                            [1.847506679950353, 48.99206218562052],
                            [1.848661500415534, 48.991919596860875],
                            [1.849385524748993, 48.99182988690912],
                            [1.85007691425945, 48.991749553433515],
                            [1.850608913195878, 48.99169946969111],
                            [1.851198621556033, 48.991663903258484],
                            [1.851752007198012, 48.99164483658432],
                            [1.852258232083401, 48.99164222314708],
                            [1.852847519263956, 48.991649475741035],
                            [1.853219781521623, 48.991665326061096],
                            [1.853754602460592, 48.991696138749646],
                            [1.854325374562137, 48.99174851320475],
                            [1.85484179610291, 48.99181255535857],
                            [1.855307604280293, 48.99187638040057],
                            [1.855903180377851, 48.9919812001807],
                            [1.856863101136969, 48.99217320040876],
                            [1.857757924756603, 48.99236730343216],
                            [1.860716730700712, 48.99300305412534],
                            [1.86521459617215, 48.99397224754316],
                            [1.86649912593623, 48.99425830404563],
                            [1.867516535439773, 48.994498040678145],
                            [1.868295697228804, 48.994696342855555],
                            [1.868980965812998, 48.99488235987542],
                            [1.869778014771005, 48.995102141410214],
                            [1.870542529055708, 48.995321782169064],
                            [1.871869487437434, 48.995717401946784],
                            [1.874884157415533, 48.99660760533309],
                            [1.880095191668224, 48.998144193394246],
                            [1.883564543120176, 48.99917160441385],
                            [1.885375041519575, 48.99970460772858],
                            [1.886067544090376, 48.99990482628303],
                            [1.886619497887749, 49.00005214180135],
                            [1.887200494476583, 49.000187672653006],
                            [1.888034278400627, 49.00036226040809],
                            [1.888831933160587, 49.00053432248424],
                            [1.889593448734819, 49.00070385861547],
                            [1.890149081528058, 49.00084641373231],
                            [1.890740603746297, 49.001020036597545],
                            [1.89137522315858, 49.00122713678664],
                            [1.892013120835908, 49.00147231542071],
                            [1.892524714765811, 49.00168844528113],
                            [1.893176495006172, 49.002000295681974],
                            [1.893676802220116, 49.002266345534316],
                            [1.894148097076464, 49.002541799488334],
                            [1.894727106680992, 49.00290570286618],
                            [1.895694387118233, 49.00353045452068],
                            [1.89635634216309, 49.00392322439009],
                            [1.896741463756091, 49.00413171180254],
                            [1.897396921971946, 49.004443551173836],
                            [1.898088781938588, 49.00472935218384],
                            [1.898744884645162, 49.004969804545574],
                            [1.899455286756341, 49.005205700766005],
                            [1.900176791469935, 49.00541308188115],
                            [1.900797541551485, 49.00556297174352],
                            [1.901781979947734, 49.00576253682855],
                        ],
                    },
                },
                649: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.15805354346948, 2.3454425245741204],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 3226.15142055,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325754000363327,
                            49.15518985899016,
                            2.362303528565357,
                            49.166775039807895,
                        ),
                        "coordinates": [
                            [2.362303528565357, 49.166775039807895],
                            [2.362074335113662, 49.16643696546545],
                            [2.361145248304282, 49.16507027734741],
                            [2.360559262285351, 49.16417832460106],
                            [2.36042615428348, 49.16398590872949],
                            [2.359792184544679, 49.16306158890005],
                            [2.359085588562511, 49.16219573169913],
                            [2.358634238179042, 49.161721003962164],
                            [2.358060837577972, 49.16119863531541],
                            [2.357571138925571, 49.16078596061517],
                            [2.357364013773477, 49.16061153924471],
                            [2.356726217456314, 49.16014942667068],
                            [2.356373729826281, 49.15992197148472],
                            [2.356066507421358, 49.15972238550927],
                            [2.355454822592649, 49.159355584167365],
                            [2.354918592556862, 49.15907599666608],
                            [2.354271284751071, 49.15873887048782],
                            [2.353700796897448, 49.158483562406815],
                            [2.353569148969973, 49.15843052477954],
                            [2.352925995959269, 49.15816443189816],
                            [2.352762808685056, 49.15809790916314],
                            [2.35165207152717, 49.157705974886845],
                            [2.350937654292909, 49.15748934028898],
                            [2.350855380406839, 49.15746776797479],
                            [2.350427560239149, 49.157352712141254],
                            [2.350238332465005, 49.157302375655206],
                            [2.349462234237527, 49.157117212820076],
                            [2.34874236608105, 49.15696531264447],
                            [2.348089693506714, 49.156844875312416],
                            [2.347679721029882, 49.15679005931988],
                            [2.346540308926389, 49.156639981641455],
                            [2.346041220522346, 49.156592360868],
                            [2.343873498391758, 49.156434240075015],
                            [2.343522496725693, 49.156410879536146],
                            [2.339776666408477, 49.15615743750605],
                            [2.338804565435459, 49.15609181080169],
                            [2.337495183825846, 49.15600369622208],
                            [2.336527202450748, 49.15593804948208],
                            [2.336077490970535, 49.15590657252303],
                            [2.331282878488239, 49.15556830987274],
                            [2.330709777837645, 49.15552601429727],
                            [2.326469136718663, 49.155236139583884],
                            [2.326027662738145, 49.15520732252403],
                            [2.325754000363327, 49.15518985899016],
                        ],
                    },
                },
                650: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.07807574390078, 2.0143100562528713],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 1636.96989927,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.003715373018928,
                            49.07584288482138,
                            2.024952931375388,
                            49.08049370702575,
                        ),
                        "coordinates": [
                            [2.024952931375388, 49.07584288482138],
                            [2.023876796508751, 49.0760735064212],
                            [2.022097690787036, 49.07643644322721],
                            [2.021382177249325, 49.0765864552848],
                            [2.02088872097804, 49.07668941305134],
                            [2.020829778358793, 49.07670184095788],
                            [2.019291810340124, 49.077024930744074],
                            [2.017753820460642, 49.07734799892939],
                            [2.016214442683926, 49.077671044223536],
                            [2.014134975889603, 49.07810316119402],
                            [2.013620932385088, 49.07820962686544],
                            [2.012845053373147, 49.078372006317174],
                            [2.012052723256836, 49.0785370312914],
                            [2.009970453092824, 49.078968165865255],
                            [2.006277297645017, 49.07974535050034],
                            [2.005510793293748, 49.07993266371232],
                            [2.004783856294224, 49.08013672002951],
                            [2.00394695756873, 49.080406775960846],
                            [2.003715373018928, 49.08049370702575],
                        ],
                    },
                },
                651: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.11166451211457, 3.277469024397062],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 6659.74307515,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.267390137550688,
                            48.0851844944416,
                            3.289741961959439,
                            48.137610805280445,
                        ),
                        "coordinates": [
                            [3.289741961959439, 48.137610805280445],
                            [3.287829170720696, 48.132960506973504],
                            [3.283787220914219, 48.128549011882136],
                            [3.276389913488509, 48.12219914265896],
                            [3.271588648694591, 48.118050050008875],
                            [3.268595731058987, 48.11499718471143],
                            [3.267390137550688, 48.11192947123798],
                            [3.267969965469105, 48.10876148826007],
                            [3.269947264048139, 48.105239951082574],
                            [3.274687313690596, 48.09930161609379],
                            [3.280687793450366, 48.0925830980392],
                            [3.286256499458407, 48.0851844944416],
                        ],
                    },
                },
                652: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.45058071054939, 1.788031764715653],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1721.47370328,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.779583709723208,
                            48.4452537046015,
                            1.796479819708098,
                            48.45590771649728,
                        ),
                        "coordinates": [
                            [1.796479819708098, 48.45590771649728],
                            [1.779583709723208, 48.4452537046015],
                        ],
                    },
                },
                653: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98157569154329, 1.7658630585593014],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2705.71434164,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.747786182906161,
                            48.979292248544446,
                            1.783973407729849,
                            48.98417275530591,
                        ),
                        "coordinates": [
                            [1.747786182906161, 48.98417275530591],
                            [1.759122520798526, 48.98252977029969],
                            [1.767128730690744, 48.981370708786486],
                            [1.772770149784534, 48.98055397986733],
                            [1.775760987262731, 48.98011898427532],
                            [1.778114472372165, 48.9797807330306],
                            [1.779200418719123, 48.97964802640779],
                            [1.780492421408916, 48.97951393367839],
                            [1.780984520853248, 48.97947111849838],
                            [1.781733441623526, 48.9794128910443],
                            [1.782576340971883, 48.97935511455806],
                            [1.783397339540274, 48.97931626028895],
                            [1.783973407729849, 48.979292248544446],
                        ],
                    },
                },
                654: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.24655488190348, 3.24076620887701],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 11158.9676168,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.201893827865916,
                            48.19841749425402,
                            3.267320028735699,
                            48.28639117963662,
                        ),
                        "coordinates": [
                            [3.201893827865916, 48.28639117963662],
                            [3.204132102401484, 48.28439262663271],
                            [3.210780467481162, 48.27998110547718],
                            [3.223866926116513, 48.27032496043971],
                            [3.228219628701663, 48.26663576128721],
                            [3.234894290543435, 48.258567720020594],
                            [3.248674093418942, 48.24005450554902],
                            [3.257410817447238, 48.229660087774306],
                            [3.261979386469758, 48.22237706720993],
                            [3.264027745965229, 48.2137681038588],
                            [3.267320028735699, 48.19841749425402],
                        ],
                    },
                },
                655: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [47.96280239618504, 3.453150058408733],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 9471.67707238,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.39286472633588,
                            47.95742785371423,
                            3.514336465015477,
                            47.97347764530846,
                        ),
                        "coordinates": [
                            [3.39286472633588, 47.97343031566925],
                            [3.397502181661056, 47.97347764530846],
                            [3.403479297355547, 47.9731644775579],
                            [3.408799982236927, 47.97191687135039],
                            [3.419414954186868, 47.96822427838517],
                            [3.44431193397045, 47.95994496783594],
                            [3.456729689607853, 47.95742785371423],
                            [3.474171932540078, 47.95767970497448],
                            [3.514336465015477, 47.96111824702738],
                        ],
                    },
                },
                656: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.98935751527942, 2.2458746664321008],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1954.61314817,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.234276393996537,
                            48.98500470125915,
                            2.25747415725031,
                            48.99371348038584,
                        ),
                        "coordinates": [
                            [2.25747415725031, 48.98500470125915],
                            [2.256667529466798, 48.98530179983275],
                            [2.256537648249651, 48.98534937040701],
                            [2.256406397970248, 48.98539873895597],
                            [2.256324367152076, 48.98542925655962],
                            [2.25483957933873, 48.98598395673322],
                            [2.254752076836709, 48.98601716760732],
                            [2.254065722420399, 48.98627566499257],
                            [2.252697094129654, 48.986791752504],
                            [2.252152919385233, 48.98699548761377],
                            [2.250853987138239, 48.98748372667994],
                            [2.25052446527544, 48.98760757845762],
                            [2.250302957914854, 48.987691044437135],
                            [2.250069147044349, 48.987778097556905],
                            [2.248828968929537, 48.98824477512492],
                            [2.248735984251072, 48.98828247410205],
                            [2.248689496718009, 48.98829862493679],
                            [2.248644373466953, 48.988315676355626],
                            [2.248578741899453, 48.988339906642],
                            [2.248519944991161, 48.988362343427454],
                            [2.248182205336202, 48.9884897792397],
                            [2.247942915503344, 48.98857952129495],
                            [2.244431417603644, 48.98989778089434],
                            [2.244312450985003, 48.98994174964649],
                            [2.244241341042742, 48.98996956972559],
                            [2.244168866746831, 48.98999648911002],
                            [2.244036222252495, 48.9900476409717],
                            [2.243727181301108, 48.99016159795455],
                            [2.243554620207485, 48.99022882178484],
                            [2.242902227019158, 48.99047741455814],
                            [2.24162140823175, 48.990954603971424],
                            [2.239750755235367, 48.99166921656483],
                            [2.237898175127222, 48.99236001975328],
                            [2.23664981377814, 48.99283004478473],
                            [2.235958195596444, 48.99308036887799],
                            [2.234276393996537, 48.99371348038584],
                        ],
                    },
                },
                657: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.83612245224618, 2.3709797496470864],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 1633.0200525,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.36543338335276,
                            48.82987504460341,
                            2.376695892125261,
                            48.84252802768357,
                        ),
                        "coordinates": [
                            [2.376695892125261, 48.82987504460341],
                            [2.376310721393016, 48.83025845726653],
                            [2.376100014738509, 48.83046820031477],
                            [2.375626127836013, 48.83091781447308],
                            [2.375338031873506, 48.83120343387657],
                            [2.374884282692759, 48.831662798476835],
                            [2.374419729928119, 48.83214833839203],
                            [2.373872342705136, 48.83272193878771],
                            [2.37311965846401, 48.83350498377089],
                            [2.372788769485438, 48.833858984985916],
                            [2.372485827398598, 48.83420233131875],
                            [2.372262562137141, 48.83447602439655],
                            [2.372037483182515, 48.8347782794699],
                            [2.371583980405342, 48.835380689434714],
                            [2.371185475209688, 48.83587116095093],
                            [2.370504782526067, 48.8366470294828],
                            [2.370256258108027, 48.83691120950934],
                            [2.369928494955805, 48.83726582637737],
                            [2.369625807359515, 48.83760216261029],
                            [2.369382701363923, 48.8378996043211],
                            [2.369145006859776, 48.838208986095495],
                            [2.368972138117524, 48.83843507294346],
                            [2.368828076526018, 48.838620701620826],
                            [2.368485911818896, 48.83903718179771],
                            [2.36823737643977, 48.83931801243641],
                            [2.367801531073584, 48.83981303439403],
                            [2.36709924870718, 48.84064170283554],
                            [2.365581702747743, 48.842360082466925],
                            [2.36543338335276, 48.84252802768357],
                        ],
                    },
                },
                658: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.86045276179413, 2.2736420038232623],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 932.361874381,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272120621598503,
                            48.8565315515406,
                            2.27516715468514,
                            48.86446175107751,
                        ),
                        "coordinates": [
                            [2.27516715468514, 48.8565315515406],
                            [2.275127581654939, 48.85657289637881],
                            [2.274911974657924, 48.856797598953634],
                            [2.274714017434229, 48.857075367707694],
                            [2.274571983031301, 48.8573135984634],
                            [2.274505045217647, 48.85744036010534],
                            [2.27445857531699, 48.857545549685206],
                            [2.274436700562293, 48.857600393912705],
                            [2.274410722392584, 48.857667824949914],
                            [2.274377906466341, 48.85775323854759],
                            [2.274331269945568, 48.857990621846746],
                            [2.274312071537305, 48.85808413575567],
                            [2.274330895518769, 48.85828828177093],
                            [2.274406751583312, 48.85865702678876],
                            [2.2745030713875, 48.85901139356529],
                            [2.274541010887684, 48.85918767267281],
                            [2.274565205829267, 48.85945656869903],
                            [2.274540482814241, 48.85960853328147],
                            [2.274498071642023, 48.8597371062693],
                            [2.274428352062174, 48.85990433346786],
                            [2.274321813228827, 48.860088626557165],
                            [2.274239895461006, 48.86020189111965],
                            [2.274119765810449, 48.86035380299627],
                            [2.274046047027673, 48.8604490850527],
                            [2.273893151057292, 48.86064414414644],
                            [2.273796225290937, 48.86076819050592],
                            [2.273704758567289, 48.860885945639666],
                            [2.273646056813958, 48.86096145179053],
                            [2.273273355228753, 48.861443257152736],
                            [2.273090454216617, 48.86164998906515],
                            [2.272692143198706, 48.8621917838564],
                            [2.272603290629512, 48.86238173519964],
                            [2.272455219402724, 48.86268370435763],
                            [2.272351534370337, 48.86292236511484],
                            [2.272269898210913, 48.86323898808757],
                            [2.272120938930815, 48.86421815969464],
                            [2.272120621598503, 48.86446175107751],
                        ],
                    },
                },
                659: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96326967418847, 2.623331986674454],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3881.11035797,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.603135305118449,
                            48.9531483875826,
                            2.64240630231019,
                            48.97585875402045,
                        ),
                        "coordinates": [
                            [2.603135305118449, 48.9531483875826],
                            [2.605000289162331, 48.95358023622196],
                            [2.606667981536762, 48.953976045436235],
                            [2.60843332667294, 48.95438587455402],
                            [2.609996191861178, 48.954762848286016],
                            [2.610564286872323, 48.954918527856364],
                            [2.610987737600818, 48.95505075694514],
                            [2.611407665895066, 48.955199648801525],
                            [2.611737170967245, 48.9553297236263],
                            [2.612157252560272, 48.95550478508058],
                            [2.612526701935252, 48.95567044971302],
                            [2.612852742036049, 48.95582670175315],
                            [2.613182453497493, 48.95599245990038],
                            [2.613454237727346, 48.95613694387159],
                            [2.613813069025569, 48.9563407001603],
                            [2.614150249870269, 48.95654926678368],
                            [2.614560028989912, 48.95681714106856],
                            [2.61516573517021, 48.957229677317436],
                            [2.615546578415751, 48.957490478786184],
                            [2.615989121755064, 48.95779871768538],
                            [2.616384480709172, 48.95806899772281],
                            [2.616765337560406, 48.95832979781849],
                            [2.617204238868017, 48.95863090006522],
                            [2.618865618889549, 48.95977604693423],
                            [2.620848305052638, 48.96113672398326],
                            [2.623788406543668, 48.963147256113665],
                            [2.627376631213806, 48.96560559525237],
                            [2.629031207469668, 48.966743473580635],
                            [2.633236858467855, 48.969623578526125],
                            [2.633995347296979, 48.97014982880753],
                            [2.635112976436022, 48.970896419788794],
                            [2.636905798974081, 48.972125430531804],
                            [2.637998180871814, 48.97286611020394],
                            [2.639061483617493, 48.97357473575402],
                            [2.64030279661989, 48.974425640339135],
                            [2.64240630231019, 48.97585875402045],
                        ],
                    },
                },
                660: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.82969224108443, 2.4019075183702085],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 1145.18151413,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.398658517073882,
                            48.82605499744055,
                            2.406742224555687,
                            48.83316292950388,
                        ),
                        "coordinates": [
                            [2.406742224555687, 48.82605499744055],
                            [2.402584463169918, 48.82870994270322],
                            [2.401540552599932, 48.8294003565791],
                            [2.399057892377401, 48.830989433353906],
                            [2.399000723094988, 48.8310283845975],
                            [2.398923265044174, 48.83109007059002],
                            [2.398854758604278, 48.83115621202144],
                            [2.398795789263911, 48.831226244348485],
                            [2.398746858439722, 48.831299570227145],
                            [2.398708384806241, 48.831375562216586],
                            [2.398680693251728, 48.83145357531458],
                            [2.39866402445348, 48.8315329434076],
                            [2.398658517073882, 48.83161298727531],
                            [2.39866422264876, 48.83169302275964],
                            [2.398681089115048, 48.83177237147426],
                            [2.398708973150517, 48.831850353671726],
                            [2.398747634526606, 48.83192630530339],
                            [2.398796749727882, 48.83199957808806],
                            [2.398855894169176, 48.83206954571866],
                            [2.398924565268829, 48.83213561117362],
                            [2.399002179650229, 48.83219721299903],
                            [2.39908807043758, 48.832253823496934],
                            [2.399181510277909, 48.832304960533484],
                            [2.399281693632672, 48.832350187450565],
                            [2.399323684941379, 48.83236661572346],
                            [2.401448054218978, 48.83316292950388],
                        ],
                    },
                },
                661: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.86785107035018, 2.2734975381145786],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 777.471132319,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272120138879799,
                            48.86446175107751,
                            2.275574526847743,
                            48.870974138193766,
                        ),
                        "coordinates": [
                            [2.272120621598503, 48.86446175107751],
                            [2.272120138879799, 48.864832008903306],
                            [2.272127086099549, 48.86516816878753],
                            [2.272163569125495, 48.86550434450914],
                            [2.272214899155489, 48.86578206710471],
                            [2.272288388108724, 48.866054931140674],
                            [2.272369331895322, 48.86627420847161],
                            [2.272457630000423, 48.86651784975745],
                            [2.272538613999333, 48.86670789551702],
                            [2.272619611938358, 48.866888198604066],
                            [2.272884906318504, 48.867317067758115],
                            [2.273400973685293, 48.86798966628254],
                            [2.273998189559551, 48.86874025664755],
                            [2.27455946771283, 48.869459209571225],
                            [2.274571714316648, 48.86947720241366],
                            [2.27497038321126, 48.870072738979324],
                            [2.275170399511087, 48.87037230540044],
                            [2.275179923655839, 48.870386699575334],
                            [2.27543166144265, 48.87075463855705],
                            [2.275574526847743, 48.870974138193766],
                        ],
                    },
                },
                662: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.172320180311495, 2.8157959846365297],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 7248.48251592,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.79445455010732,
                            49.14288419832467,
                            2.838108478036551,
                            49.20087707910112,
                        ),
                        "coordinates": [
                            [2.79445455010732, 49.14288419832467],
                            [2.802800121956027, 49.15070810043967],
                            [2.815235703365665, 49.17192867407871],
                            [2.824344157673586, 49.18728512797439],
                            [2.826825157962253, 49.19079937819332],
                            [2.829674821226445, 49.19401262586999],
                            [2.833701241275337, 49.197556556515536],
                            [2.838108478036551, 49.20087707910112],
                        ],
                    },
                },
                663: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.80588702268953, 2.4407166092233155],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 1164.13991092,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.434509895923941,
                            48.80263769071178,
                            2.446927482880671,
                            48.80914436183541,
                        ),
                        "coordinates": [
                            [2.446927482880671, 48.80263769071178],
                            [2.446779051707035, 48.80271928508582],
                            [2.446547837910622, 48.8028434273062],
                            [2.446247060065098, 48.80300491671275],
                            [2.438924054946441, 48.8068165852787],
                            [2.435956517187135, 48.80837259798452],
                            [2.434509895923941, 48.80914436183541],
                        ],
                    },
                },
                664: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.86863877473321, 2.323918508247122],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 473.029624682,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32208284867617,
                            48.86681836985008,
                            2.326272274027749,
                            48.86963317302491,
                        ),
                        "coordinates": [
                            [2.326272274027749, 48.86963317302491],
                            [2.325501630303191, 48.869499791385806],
                            [2.325492495040058, 48.86949821012305],
                            [2.324578628614143, 48.86934003161609],
                            [2.324500380998892, 48.86932511061046],
                            [2.324374291164252, 48.869295034473616],
                            [2.324252338414111, 48.869258276952955],
                            [2.324135330731308, 48.86921508454617],
                            [2.324024051028472, 48.869165744082274],
                            [2.323919238050349, 48.86911058351288],
                            [2.323821589123534, 48.869049970128366],
                            [2.323731754726337, 48.868984308727896],
                            [2.32365033175456, 48.86891403528561],
                            [2.323577862170402, 48.86883961604282],
                            [2.323518776674078, 48.86876691819585],
                            [2.32208284867617, 48.86681836985008],
                        ],
                    },
                },
                665: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.86397007659767, 2.278163010684923],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 7.46599151689,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.278112559810519,
                            48.8639657074042,
                            2.278213461559327,
                            48.86397444579114,
                        ),
                        "coordinates": [
                            [2.278112559810519, 48.86397444579114],
                            [2.278213461559327, 48.8639657074042],
                        ],
                    },
                },
                666: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.645351614736484, 2.307411639049155],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2066.85597679,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.305618513847831,
                            48.63587586133943,
                            2.312736251060262,
                            48.65281140144265,
                        ),
                        "coordinates": [
                            [2.312736251060262, 48.65281140144265],
                            [2.311434035743083, 48.652161697821754],
                            [2.311161595518889, 48.6520157161731],
                            [2.310773880653907, 48.65179435262542],
                            [2.310282075275412, 48.65148968842449],
                            [2.309905157465262, 48.65123739338836],
                            [2.309513900617501, 48.65094702475268],
                            [2.308695550578756, 48.65026396415496],
                            [2.308354595249252, 48.649947432901875],
                            [2.308045958245556, 48.64963804509417],
                            [2.307805508604246, 48.6494024323972],
                            [2.307547136214757, 48.64911922858859],
                            [2.307335429984876, 48.64885982948018],
                            [2.307188323680806, 48.64866468837927],
                            [2.307005358878571, 48.64838864007318],
                            [2.306614328612295, 48.64779133136349],
                            [2.3063561210502, 48.6472582976048],
                            [2.305983255727477, 48.646346922119776],
                            [2.305882926907937, 48.64601141233609],
                            [2.305761120993855, 48.645571207113846],
                            [2.305699667711305, 48.64525269049801],
                            [2.305650202835725, 48.64494898766603],
                            [2.305621792958605, 48.644445756042174],
                            [2.305618513847831, 48.643950858997094],
                            [2.3056367819289, 48.643446449839544],
                            [2.305741434903754, 48.64259230671794],
                            [2.305820799508666, 48.64195418536201],
                            [2.306083837795694, 48.640419602194584],
                            [2.306278577144555, 48.639001587767794],
                            [2.306502055920804, 48.63753361350995],
                            [2.30680878358536, 48.63603047056848],
                            [2.306833164014825, 48.63587586133943],
                        ],
                    },
                },
                667: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9532968217241, 2.3326248119904904],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 1312.83800405,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32824501026232,
                            48.94783369425153,
                            2.336418315320437,
                            48.958269604608034,
                        ),
                        "coordinates": [
                            [2.336418315320437, 48.94783369425153],
                            [2.336361852815723, 48.94789582213892],
                            [2.33608007716816, 48.948240824593505],
                            [2.33576578286533, 48.948645311354845],
                            [2.335559862419661, 48.948945106049166],
                            [2.335364777086415, 48.94924966000805],
                            [2.335194977619876, 48.94954469646904],
                            [2.334429046671183, 48.95092946083693],
                            [2.334259234623968, 48.9512268749831],
                            [2.334093034053209, 48.951529047154985],
                            [2.333901541167026, 48.95184549567271],
                            [2.333724500337994, 48.952126252789114],
                            [2.33246349174877, 48.95389882173151],
                            [2.332004592777578, 48.95454836445361],
                            [2.331675770706241, 48.95498852971],
                            [2.331328881441106, 48.955393000881635],
                            [2.331010897605432, 48.955735611255236],
                            [2.330743501400027, 48.95601160089214],
                            [2.330407443727636, 48.956354208445674],
                            [2.329955748658342, 48.95680863701481],
                            [2.329579937771228, 48.957148859850385],
                            [2.328972850049945, 48.957681793189806],
                            [2.328322390158605, 48.958212340049705],
                            [2.32824501026232, 48.958269604608034],
                        ],
                    },
                },
                668: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.21788212247294, 2.861952038330218],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 5032.92100367,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.838108478036551,
                            49.20087707910112,
                            2.887366704975861,
                            49.23101806016452,
                        ),
                        "coordinates": [
                            [2.838108478036551, 49.20087707910112],
                            [2.844183521054062, 49.20540513205603],
                            [2.856747697064284, 49.21449898355462],
                            [2.869207547703421, 49.22369286039603],
                            [2.873402401867243, 49.226808969590174],
                            [2.875137133045359, 49.228084527008036],
                            [2.876469927580216, 49.228888680908966],
                            [2.877721599922062, 49.229457255755875],
                            [2.878842915672854, 49.22986869761287],
                            [2.880541550898866, 49.230362764675235],
                            [2.881630604801776, 49.230606456143505],
                            [2.882910408116714, 49.23082534800725],
                            [2.883833112929981, 49.23091153752207],
                            [2.884680712875338, 49.230973338334756],
                            [2.885803093887545, 49.230942296144725],
                            [2.887366704975861, 49.23101806016452],
                        ],
                    },
                },
                669: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.27029130734809, 1.8448977258575994],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 4855.39474203,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.81808238249243,
                            49.26132229816068,
                            1.872589469227938,
                            49.282589735816124,
                        ),
                        "coordinates": [
                            [1.872589469227938, 49.26132229816068],
                            [1.866591683846971, 49.261849809993684],
                            [1.859983755434342, 49.26264977743305],
                            [1.854355912639473, 49.26372920672908],
                            [1.85125017105705, 49.26537048341902],
                            [1.848977757729374, 49.26793429560031],
                            [1.847123713821226, 49.27077556950726],
                            [1.845004135512743, 49.272053241265894],
                            [1.841338501949477, 49.273416135304615],
                            [1.835990875334875, 49.27440397229955],
                            [1.832331404558238, 49.275123251309225],
                            [1.830217868878203, 49.27575732272755],
                            [1.826688213122693, 49.27748798496614],
                            [1.823295908810192, 49.279494877556864],
                            [1.81808238249243, 49.282589735816124],
                        ],
                    },
                },
                670: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.8665430011832, 2.305298355219332],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 774.260616927,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.300991003495585,
                            48.86473953056316,
                            2.309505157337887,
                            48.86869984735294,
                        ),
                        "coordinates": [
                            [2.300991003495585, 48.86476684497177],
                            [2.301117993839215, 48.86475045399604],
                            [2.301246650589604, 48.86474132676827],
                            [2.301376020054441, 48.86473953056316],
                            [2.301505143838379, 48.864745076872296],
                            [2.301633066947187, 48.864757926847524],
                            [2.301758843346247, 48.864777983239115],
                            [2.301881541290224, 48.86480509942031],
                            [2.302000248845994, 48.8648390740231],
                            [2.302114094288235, 48.86487965465424],
                            [2.302222226955543, 48.864926542279846],
                            [2.302271979803015, 48.86495124697728],
                            [2.308853064262776, 48.868361676352905],
                            [2.309395935050725, 48.86864296403794],
                            [2.309505157337887, 48.86869984735294],
                        ],
                    },
                },
                671: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.93220401222064, 2.485593854073034],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1453.79505853,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.475674370833512,
                            48.93212901293364,
                            2.495513142584314,
                            48.93230541606912,
                        ),
                        "coordinates": [
                            [2.475674370833512, 48.93230541606912],
                            [2.476163709743931, 48.93230003707236],
                            [2.477409636592118, 48.93228483173492],
                            [2.478716297186294, 48.9322688686431],
                            [2.480597999968426, 48.932242802188085],
                            [2.485909369257553, 48.93219180371595],
                            [2.488602667950408, 48.93216023242055],
                            [2.490988334468279, 48.93212901293364],
                            [2.493681829925758, 48.932162007084386],
                            [2.49440185171253, 48.932173955094534],
                            [2.495513142584314, 48.93219600596196],
                        ],
                    },
                },
                672: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.60289558454278, 2.300017632252716],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 906.589358564,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.297950577822679,
                            48.599059348508746,
                            2.302059691582639,
                            48.60674494894811,
                        ),
                        "coordinates": [
                            [2.302059691582639, 48.60674494894811],
                            [2.301456351484172, 48.60564591805656],
                            [2.301071583273852, 48.60487918759537],
                            [2.30073749090788, 48.604218587925644],
                            [2.300483377229273, 48.60372737741824],
                            [2.300194995583214, 48.60318495650788],
                            [2.299895189861859, 48.60263494538337],
                            [2.299609673323274, 48.602102005344875],
                            [2.299064336053399, 48.60110818765012],
                            [2.298593267081924, 48.6002281678049],
                            [2.298396264401124, 48.5998810876414],
                            [2.297950577822679, 48.599059348508746],
                        ],
                    },
                },
                673: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.85683540286246, 2.429271325370339],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 955.525340135,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.422983216145875,
                            48.855726428633155,
                            2.435555718419773,
                            48.85796559117888,
                        ),
                        "coordinates": [
                            [2.422983216145875, 48.855726428633155],
                            [2.424252554350508, 48.85594637657169],
                            [2.427215561812221, 48.856450816685346],
                            [2.431014491186206, 48.85715075858216],
                            [2.435555718419773, 48.85796559117888],
                        ],
                    },
                },
                674: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.84573799213403, 2.3885214424350885],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 376.608572747,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.387025242098631,
                            48.84440867207195,
                            2.390075111457481,
                            48.84712872224062,
                        ),
                        "coordinates": [
                            [2.390075111457481, 48.84440867207195],
                            [2.38833161482728, 48.845878573552184],
                            [2.387949564825782, 48.84619841745831],
                            [2.387529345863324, 48.84659398832165],
                            [2.387226076856504, 48.846917302545585],
                            [2.387025242098631, 48.84712872224062],
                        ],
                    },
                },
                675: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.856013999270196, 2.383139273989902],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 477.954513837,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.38071878585627,
                            48.854580498181704,
                            2.385563480833491,
                            48.85745372268132,
                        ),
                        "coordinates": [
                            [2.38071878585627, 48.85745372268132],
                            [2.381472218315027, 48.85699843664585],
                            [2.384889315643438, 48.85497895742596],
                            [2.385563480833491, 48.854580498181704],
                        ],
                    },
                },
                676: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.78330278836103, 1.557959721404166],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 7349.53843059,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.513333052350337,
                            48.76842177662328,
                            1.602701692990599,
                            48.796318150417065,
                        ),
                        "coordinates": [
                            [1.513333052350337, 48.76842177662328],
                            [1.530235391978185, 48.77355432460681],
                            [1.548384785396549, 48.7799301986718],
                            [1.548581052360553, 48.779996308995685],
                            [1.550562845284013, 48.78065482392585],
                            [1.550985183639332, 48.780796235375085],
                            [1.552213053017217, 48.781201302830844],
                            [1.55292207986148, 48.781457996539615],
                            [1.552941015866866, 48.781465321406884],
                            [1.554481626185669, 48.781975039422214],
                            [1.55524096565038, 48.78223566042545],
                            [1.558308845210969, 48.783245928793306],
                            [1.563495662375764, 48.78496389642468],
                            [1.563781347824285, 48.78505846645894],
                            [1.56647704875338, 48.78595626675818],
                            [1.56798694158851, 48.786445807471836],
                            [1.570828906068965, 48.78740024841214],
                            [1.572135447622024, 48.787843399636664],
                            [1.572515694509206, 48.787986245521914],
                            [1.572937907797496, 48.78814376065562],
                            [1.573374818740625, 48.78831935921934],
                            [1.574083518199571, 48.78861098999951],
                            [1.574713458738051, 48.788891297403204],
                            [1.575178451031452, 48.789100350739645],
                            [1.576076172015337, 48.78949305698947],
                            [1.578127899112504, 48.7904330385426],
                            [1.580698743112527, 48.791611151214994],
                            [1.583271095586056, 48.79278741673831],
                            [1.585842223194829, 48.79396271478883],
                            [1.58638430500226, 48.79421090102901],
                            [1.586558697510138, 48.79429029063243],
                            [1.58684122951289, 48.79441985373194],
                            [1.58703862574551, 48.79450838654141],
                            [1.587586204255666, 48.79475390563928],
                            [1.58795123795239, 48.794919082250885],
                            [1.588319251915359, 48.79506718954354],
                            [1.588546651767766, 48.7951523196056],
                            [1.588852628956593, 48.79526224750694],
                            [1.589196621972004, 48.79537871850116],
                            [1.58948109556084, 48.79547051664924],
                            [1.589711491353154, 48.79553767782329],
                            [1.589851101653075, 48.79557726406157],
                            [1.590095149936224, 48.79564181687393],
                            [1.590482946172726, 48.79574238292753],
                            [1.590903463973901, 48.79583956546203],
                            [1.590978040427842, 48.79585893965311],
                            [1.591147650107343, 48.79589512347828],
                            [1.591318566381321, 48.79593491241535],
                            [1.59149364842103, 48.795969333336735],
                            [1.591721703950386, 48.79601129460757],
                            [1.591933507502587, 48.79604775323074],
                            [1.592168410282592, 48.796087059796946],
                            [1.592415617063088, 48.79612284980171],
                            [1.592707712963614, 48.79616073125764],
                            [1.593266275556596, 48.79622103534825],
                            [1.59355039323903, 48.79624627172361],
                            [1.593868527257183, 48.79627262907262],
                            [1.594186781687725, 48.796290892280346],
                            [1.594428895203967, 48.79630326235087],
                            [1.59474047827648, 48.79631248737807],
                            [1.595018101366116, 48.79631699379198],
                            [1.595316195758208, 48.79631803509326],
                            [1.59533388976602, 48.796318150417065],
                            [1.595608911590666, 48.79631454457132],
                            [1.595882640009979, 48.79630643343509],
                            [1.596157754895825, 48.79629653174077],
                            [1.596441064020632, 48.7962848834532],
                            [1.596825119805168, 48.79627209130351],
                            [1.597246045650499, 48.79625144350542],
                            [1.598700603848344, 48.79619972510762],
                            [1.599284885850794, 48.7961783301367],
                            [1.599630844288678, 48.796164381731614],
                            [1.600215216871904, 48.79613668580825],
                            [1.601238148944774, 48.79609202985972],
                            [1.601894695267072, 48.79606209055192],
                            [1.602559407145686, 48.79603220085211],
                            [1.602701692990599, 48.79602536780062],
                        ],
                    },
                },
                677: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.73820855442225, 2.443557312087149],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 1845.03556701,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.438344239163614,
                            48.73011683142026,
                            2.446290833250972,
                            48.745230819408114,
                        ),
                        "coordinates": [
                            [2.446135830934545, 48.73011683142026],
                            [2.446160508450207, 48.730246306539605],
                            [2.446222422872905, 48.730584373317015],
                            [2.446248693104217, 48.73078578508506],
                            [2.446269528987294, 48.730988100725234],
                            [2.446269615326568, 48.73102766850042],
                            [2.446272415584877, 48.73106453614594],
                            [2.446273879119162, 48.73111219629473],
                            [2.446282312306956, 48.73123808629105],
                            [2.446290833250972, 48.73140354404188],
                            [2.446288478243837, 48.73156901247847],
                            [2.446287565201259, 48.73177224885048],
                            [2.446281302495835, 48.73201505829245],
                            [2.446276313061863, 48.73221919760409],
                            [2.446266041324861, 48.73249348589149],
                            [2.446236631618638, 48.73278306037673],
                            [2.446215780519422, 48.73300213223851],
                            [2.446167245499712, 48.73337190552676],
                            [2.446119054693386, 48.73387110074781],
                            [2.446088788355104, 48.73425220060114],
                            [2.446034357101834, 48.734706818113786],
                            [2.446017268650283, 48.734973918225386],
                            [2.446004070876241, 48.73515468476403],
                            [2.445977310335536, 48.735350751647665],
                            [2.445939762913628, 48.735587296248184],
                            [2.445860381998591, 48.73596596659345],
                            [2.445774256046163, 48.73636982210687],
                            [2.445666632296345, 48.73689060437912],
                            [2.445607303913415, 48.73711547885987],
                            [2.445570889406429, 48.73724950585651],
                            [2.445510137380059, 48.73744560510114],
                            [2.445462812981973, 48.737565253314656],
                            [2.445383029303381, 48.73776227050722],
                            [2.445289642676271, 48.73795660254881],
                            [2.445154201945167, 48.73819413957204],
                            [2.445018685233024, 48.73839750464062],
                            [2.444904842413411, 48.738563978272616],
                            [2.444744830478017, 48.738757473784304],
                            [2.444580700532257, 48.73893388758578],
                            [2.444396194167901, 48.73911841366572],
                            [2.444231998310451, 48.7392651506375],
                            [2.444055585243407, 48.739420891395646],
                            [2.44383707055715, 48.73959915370179],
                            [2.443611736536056, 48.739768429021964],
                            [2.443360601504762, 48.739953015220834],
                            [2.442567756625349, 48.74050770886944],
                            [2.441554548523095, 48.741237240206225],
                            [2.441230557603763, 48.74148465724214],
                            [2.440953696087649, 48.74172861447228],
                            [2.440766405962939, 48.74189425143231],
                            [2.440610371240031, 48.74205176693014],
                            [2.440486911126692, 48.742182274655434],
                            [2.440334983952946, 48.74235417387515],
                            [2.440150509190862, 48.7425674696153],
                            [2.439631097472172, 48.74322261156942],
                            [2.439130624977952, 48.74383726739878],
                            [2.438931269855138, 48.744093739458705],
                            [2.438784855113378, 48.744306998508705],
                            [2.438679150644873, 48.744480652452346],
                            [2.438584332826893, 48.7446596929051],
                            [2.438505805511379, 48.74482522934107],
                            [2.438443153463417, 48.744956580996465],
                            [2.438393051958888, 48.745087488858424],
                            [2.438344239163614, 48.745230819408114],
                        ],
                    },
                },
                678: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80176382222756, 2.053380890324718],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 2321.68204867,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.040519204703665,
                            48.79732506967021,
                            2.066485347074011,
                            48.807246612101615,
                        ),
                        "coordinates": [
                            [2.040519204703665, 48.807246612101615],
                            [2.041192976220792, 48.80714535065465],
                            [2.042427465284648, 48.80697768194369],
                            [2.04279948671281, 48.80692018848258],
                            [2.043392284347026, 48.806825493155365],
                            [2.043910194796925, 48.80673150103106],
                            [2.044177344232738, 48.806680028894135],
                            [2.044392733368044, 48.80663292015054],
                            [2.044650399385934, 48.80657332847251],
                            [2.045105773933606, 48.80646298438009],
                            [2.045622600116632, 48.80632042063562],
                            [2.04605006579162, 48.80618877835486],
                            [2.046479621219892, 48.806035215989795],
                            [2.046917294493745, 48.805861489588445],
                            [2.047352649442775, 48.805680041310005],
                            [2.047512326698659, 48.805613001355496],
                            [2.048087153166116, 48.805326688422326],
                            [2.048603358009649, 48.80505281472314],
                            [2.049275641527573, 48.804626454563284],
                            [2.049438247958287, 48.80452254798157],
                            [2.049550359208598, 48.804440096679166],
                            [2.049605064818826, 48.8043970685931],
                            [2.049661119540862, 48.80435584286759],
                            [2.049670680669816, 48.8043504710469],
                            [2.049751354549552, 48.804289523173274],
                            [2.049873031359331, 48.80420080123756],
                            [2.04995780453566, 48.804137165034135],
                            [2.050171266780792, 48.803948852740874],
                            [2.050689894255028, 48.803486127159786],
                            [2.051098358838669, 48.803084705835275],
                            [2.051631781798463, 48.802568522506846],
                            [2.051812389057314, 48.802409801191565],
                            [2.052180439090405, 48.8020869793518],
                            [2.052660491123719, 48.80169788905792],
                            [2.053319470205989, 48.8012031270199],
                            [2.054377481369481, 48.800435968477544],
                            [2.054883262586163, 48.80006491810069],
                            [2.0552031522012, 48.7998265004729],
                            [2.055342586137571, 48.79972342780654],
                            [2.055762068442829, 48.79944568562206],
                            [2.05591236876153, 48.79934623648076],
                            [2.056290723078192, 48.799118750635174],
                            [2.05680953814243, 48.798845746474605],
                            [2.057557562345262, 48.798478876900475],
                            [2.057995513361116, 48.798301891796704],
                            [2.058220577319807, 48.79821970801082],
                            [2.058422454232756, 48.79814556103973],
                            [2.058970661123973, 48.79796794246049],
                            [2.059479172941588, 48.79782889323918],
                            [2.060061156693806, 48.79769541604137],
                            [2.06066344561544, 48.79758176887924],
                            [2.060935938750183, 48.797536565915664],
                            [2.061761449133004, 48.7974252515452],
                            [2.062334822776733, 48.79736997956536],
                            [2.062951668340983, 48.79733009677424],
                            [2.063479844712087, 48.79732506967021],
                            [2.064028362920984, 48.79733357858281],
                            [2.064250187280952, 48.797343101930764],
                            [2.064912794623935, 48.797397742283074],
                            [2.065560704539495, 48.79747301751546],
                            [2.065985368655327, 48.79753113122936],
                            [2.066485347074011, 48.79761321151646],
                        ],
                    },
                },
                679: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84942539455681, 2.302858797672696],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 912.932102174,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.298301401728378,
                            48.84706613315245,
                            2.307402240619641,
                            48.850947952418394,
                        ),
                        "coordinates": [
                            [2.307402240619641, 48.84706613315245],
                            [2.301588701383856, 48.85076871773069],
                            [2.30155677350233, 48.850790312075176],
                            [2.301483679422224, 48.85083206988248],
                            [2.301403854110722, 48.85086805581693],
                            [2.301318331385595, 48.85089780283878],
                            [2.301228228535807, 48.85092092084336],
                            [2.301134718873124, 48.850937110891245],
                            [2.301039020864895, 48.85094616244737],
                            [2.300942387242717, 48.850947952418394],
                            [2.300846069316626, 48.850942463831004],
                            [2.300751332263525, 48.8509297634375],
                            [2.300659401726604, 48.850910020289895],
                            [2.30057148310759, 48.85088348966423],
                            [2.300488723349744, 48.85085051733321],
                            [2.30041219464331, 48.850811534973765],
                            [2.300366480868596, 48.850783349712046],
                            [2.298862339812689, 48.84973975840741],
                            [2.298301401728378, 48.84935055362092],
                        ],
                    },
                },
                680: {
                    "attributes": {
                        "reseau": "ORLYVAL",
                        "val": 1,
                        "metro": 0,
                        "res_com": "ORLYVAL",
                        "rer": 0,
                        "extcode": "100110200:ORLYVAL",
                        "geo_point_2d": [48.74191098014789, 2.334355246940206],
                        "indice_lig": "ORL",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Navette",
                        "tramway": 0,
                        "idrefligc": "C01388",
                        "navette": 1,
                        "idrefliga": "A01551",
                        "shape_leng": 6137.69747339,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.30074347316864,
                            48.72964735584993,
                            2.363902659822692,
                            48.75494652553112,
                        ),
                        "coordinates": [
                            [2.300986855734952, 48.75494652553112],
                            [2.300809770185388, 48.75433084937844],
                            [2.300767464736527, 48.75418751554417],
                            [2.300754286313233, 48.75408321963667],
                            [2.30074347316864, 48.75396320100467],
                            [2.300755943868815, 48.75383076974404],
                            [2.300793758466192, 48.75366565198155],
                            [2.300848603375619, 48.75351524436897],
                            [2.300927888394813, 48.75334871615067],
                            [2.301050381974792, 48.75313699305175],
                            [2.301183656101172, 48.75294668825311],
                            [2.301392099114131, 48.7527494000027],
                            [2.301612104885972, 48.7525923002563],
                            [2.301864086278558, 48.75244723804602],
                            [2.302213247077824, 48.752261755773276],
                            [2.302515389954895, 48.75212085466494],
                            [2.302849071450008, 48.75198058214187],
                            [2.303243409686416, 48.75183030108646],
                            [2.303759348370084, 48.75164700512039],
                            [2.312749133066108, 48.748514506710464],
                            [2.313222378474159, 48.74834553629006],
                            [2.313569671545086, 48.74823962382198],
                            [2.313863529670765, 48.748156410993495],
                            [2.314248978284308, 48.74804798060049],
                            [2.314603892399389, 48.7479471133801],
                            [2.315538877996429, 48.74769242499321],
                            [2.316416636762177, 48.74738725241043],
                            [2.317313491193609, 48.747006373107524],
                            [2.318492743010434, 48.74649431374505],
                            [2.321908238760596, 48.74502618186408],
                            [2.324304697285652, 48.74395654146078],
                            [2.326006581039418, 48.74319716490938],
                            [2.32649500095914, 48.742990290547866],
                            [2.326956702431876, 48.74282378529979],
                            [2.327399315994054, 48.74269512905832],
                            [2.327956390588799, 48.742561431050554],
                            [2.328521087166032, 48.742458013520604],
                            [2.329116300833139, 48.742377304881025],
                            [2.329650466339455, 48.74230163728547],
                            [2.330329617619008, 48.742205785825895],
                            [2.330856152396551, 48.742102354572644],
                            [2.331348347334782, 48.74197368455547],
                            [2.331817653346882, 48.74182482410249],
                            [2.332164860667565, 48.7416961450619],
                            [2.333011892639425, 48.741332804273235],
                            [2.33510271255695, 48.740434517843845],
                            [2.337452886999057, 48.73942516120362],
                            [2.337952670213226, 48.73922580778391],
                            [2.338383776795858, 48.73909963283227],
                            [2.338673724830175, 48.739028971638874],
                            [2.339028528075507, 48.73896335585521],
                            [2.339345183297672, 48.738925497974535],
                            [2.33973050983548, 48.73889268271105],
                            [2.34010057442433, 48.738892671872826],
                            [2.340489719942684, 48.73891284812319],
                            [2.340917017070906, 48.73895572977293],
                            [2.34131379783072, 48.73903141698525],
                            [2.341783073191064, 48.739144949204764],
                            [2.343335885767869, 48.739528425379184],
                            [2.343747932247244, 48.73960410294251],
                            [2.34425536136626, 48.73966715584981],
                            [2.344644512146576, 48.73967469932373],
                            [2.345083255196582, 48.73965447880892],
                            [2.34552199181741, 48.73960902452887],
                            [2.34602176380311, 48.73951561812513],
                            [2.34645666910565, 48.73938941247072],
                            [2.346716081564227, 48.73929349981823],
                            [2.348322100918673, 48.73859688527438],
                            [2.349264326700685, 48.73819051720346],
                            [2.349535172315133, 48.738097120692075],
                            [2.349878505601587, 48.738008762185245],
                            [2.350218026525063, 48.7379405897808],
                            [2.350500329003676, 48.73790017950666],
                            [2.350932181253926, 48.73785813618667],
                            [2.352789291231795, 48.737687912649385],
                            [2.358738190628009, 48.737152699045815],
                            [2.358992105121892, 48.73712971027283],
                            [2.359197963479076, 48.73710606905018],
                            [2.359401652088861, 48.7370752751337],
                            [2.359602598697057, 48.737037414509494],
                            [2.359800243071427, 48.736992591220655],
                            [2.359994036969716, 48.73694093006512],
                            [2.360183438701881, 48.73688257656623],
                            [2.36036791727602, 48.736817691598134],
                            [2.360546963210842, 48.73674645683993],
                            [2.360720074983444, 48.73666907110523],
                            [2.360886771267116, 48.736585750407016],
                            [2.361046585515068, 48.736496726129765],
                            [2.361199074085842, 48.73640224777051],
                            [2.361343812252535, 48.73630257572197],
                            [2.361480396801345, 48.73619799117958],
                            [2.361608442095466, 48.736088784427515],
                            [2.361727600414997, 48.73597525944426],
                            [2.361837529335496, 48.73585773282826],
                            [2.361937931158061, 48.735736534008545],
                            [2.362028520375815, 48.73561199697531],
                            [2.362109047993152, 48.73548447300186],
                            [2.362179286788604, 48.73535431257676],
                            [2.362255034948055, 48.73518985595653],
                            [2.363668747046314, 48.73206359472081],
                            [2.363802923595355, 48.73172250317944],
                            [2.3638840143927, 48.73144550298015],
                            [2.363902659822692, 48.731255331042895],
                            [2.363871309769345, 48.73106724019779],
                            [2.363774326518601, 48.730844022265536],
                            [2.363642996696728, 48.73066835759936],
                            [2.363508570427205, 48.730540232864136],
                            [2.363330398356986, 48.73041211927613],
                            [2.363139743755753, 48.730308812196824],
                            [2.362892848471801, 48.73020965149732],
                            [2.362611592773495, 48.73013116954168],
                            [2.362233480315199, 48.730056842964906],
                            [2.361661631363251, 48.729953617838845],
                            [2.361537221297242, 48.72993050213219],
                            [2.360013412858126, 48.72964735584993],
                        ],
                    },
                },
                681: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.82974976174606, 2.5009613591628375],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2304.08009043,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.494188055346116,
                            48.82484856949889,
                            2.511855553451007,
                            48.839341939180265,
                        ),
                        "coordinates": [
                            [2.494188055346116, 48.839341939180265],
                            [2.494247766895406, 48.838846953662475],
                            [2.49428634106946, 48.83850665376865],
                            [2.494335041496361, 48.83794981945879],
                            [2.49440876096613, 48.83732632879831],
                            [2.49444007068898, 48.83696938300809],
                            [2.494492824963791, 48.83655530353588],
                            [2.494553057041376, 48.83622687146399],
                            [2.494606625712022, 48.83600754436564],
                            [2.494677919395311, 48.835757614148676],
                            [2.494785088492835, 48.83545528867773],
                            [2.494874454512325, 48.83522198901582],
                            [2.494988959541596, 48.83496010230668],
                            [2.495092814994253, 48.834750575106625],
                            [2.495250507616648, 48.83446959352472],
                            [2.495401095686161, 48.83422193256743],
                            [2.496322846076571, 48.832809693311546],
                            [2.496712946261206, 48.83219844504028],
                            [2.497140330411507, 48.831552605217134],
                            [2.497320489863974, 48.83129060209894],
                            [2.49768548971296, 48.830733342726056],
                            [2.497893531093397, 48.83042849144205],
                            [2.4981267353821, 48.83010457095283],
                            [2.498321673575904, 48.82986671831846],
                            [2.498521609160343, 48.82962576369708],
                            [2.49869037660845, 48.82943755598253],
                            [2.499101887977773, 48.829023344577465],
                            [2.499323720496731, 48.828814886859284],
                            [2.499628931941801, 48.828544098368724],
                            [2.499934239976472, 48.82830409190573],
                            [2.500267467584421, 48.82804497023481],
                            [2.500646486652083, 48.82778552795893],
                            [2.501191511108631, 48.82743672379359],
                            [2.501691788944037, 48.82715003217035],
                            [2.502106461696296, 48.826926411390446],
                            [2.502574264952994, 48.82670720837081],
                            [2.502874036656867, 48.82657485091107],
                            [2.50319948682061, 48.826442221633926],
                            [2.503541299313914, 48.826302924058766],
                            [2.504073190058934, 48.826109700224784],
                            [2.504311268842221, 48.8260293155916],
                            [2.504535748512162, 48.82595929506318],
                            [2.504858178104163, 48.82586103227905],
                            [2.505331909786763, 48.825726674456156],
                            [2.505642006799357, 48.82564965816218],
                            [2.506225849975233, 48.825518398747874],
                            [2.506561054164337, 48.82545323751325],
                            [2.507099534828155, 48.82535528254552],
                            [2.50754384646785, 48.82528963736865],
                            [2.507984529348589, 48.825229805287194],
                            [2.508844977549582, 48.825138583558406],
                            [2.509435855385033, 48.82507654159762],
                            [2.509914257207523, 48.82502670696369],
                            [2.510482958774583, 48.82497528756578],
                            [2.511177234201497, 48.82491292453119],
                            [2.511855553451007, 48.82484856949889],
                        ],
                    },
                },
                682: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.82662512935481, 2.561416453473115],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 3060.8398722,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.542679794015853,
                            48.823151855834304,
                            2.579837253911679,
                            48.82891571807522,
                        ),
                        "coordinates": [
                            [2.542679794015853, 48.823266634124074],
                            [2.54319738223279, 48.82338471744232],
                            [2.543768420899775, 48.823522702070726],
                            [2.544135028007035, 48.823620902156875],
                            [2.544519516486454, 48.82372389086675],
                            [2.544909853942727, 48.82383934236116],
                            [2.545704764477432, 48.82409216533853],
                            [2.546404616029224, 48.824334809483716],
                            [2.546729249941615, 48.82445112001773],
                            [2.547585891862722, 48.82476698733664],
                            [2.550071962898491, 48.82572584429529],
                            [2.55133196244352, 48.82619076630898],
                            [2.552655102877416, 48.826692469934414],
                            [2.554434357872877, 48.82738363684643],
                            [2.555078456953258, 48.8276222441678],
                            [2.555655915997571, 48.82781862551826],
                            [2.556139496028702, 48.827972356133905],
                            [2.556662675469705, 48.82811649061705],
                            [2.557279454291553, 48.82826487072206],
                            [2.557957044876824, 48.828411042333876],
                            [2.558610088654659, 48.828537438840264],
                            [2.55932468798049, 48.828660963895196],
                            [2.560034359742709, 48.82875412311142],
                            [2.56059443107277, 48.828812379401555],
                            [2.561050894207676, 48.82885015310555],
                            [2.561606775303715, 48.828885031160354],
                            [2.562196656524036, 48.828908148790205],
                            [2.562875590550873, 48.82891571807522],
                            [2.563639072825642, 48.828904393445136],
                            [2.564257328554799, 48.828877083955135],
                            [2.5648196817397, 48.82883729344595],
                            [2.565429590017577, 48.828772224897726],
                            [2.56603944629848, 48.828696361668],
                            [2.566601596526989, 48.82861339741075],
                            [2.567301127896613, 48.82849058427833],
                            [2.567927089355076, 48.82836431845818],
                            [2.568374753950253, 48.828267189121206],
                            [2.56885377192259, 48.82814690297063],
                            [2.56932022524758, 48.82801976331371],
                            [2.569992099984153, 48.827811558659405],
                            [2.570618989808419, 48.82759624746719],
                            [2.571215913056742, 48.827381893966056],
                            [2.571856173993155, 48.82711618819398],
                            [2.572448720058697, 48.82684248486357],
                            [2.572864563004583, 48.826645582308366],
                            [2.573401306854942, 48.82638278014],
                            [2.573918951437667, 48.82611462014532],
                            [2.574482801824951, 48.825831879093215],
                            [2.577113247823859, 48.824509017813746],
                            [2.579837253911679, 48.823151855834304],
                        ],
                    },
                },
                683: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.78640256771013, 2.6730783577754096],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 4320.77534872,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.65038766844115,
                            48.7707789170597,
                            2.690252782195758,
                            48.795654821412064,
                        ),
                        "coordinates": [
                            [2.65038766844115, 48.795654821412064],
                            [2.653738082681988, 48.79456375969959],
                            [2.654293578544201, 48.794374264997444],
                            [2.655001273111905, 48.79414657249452],
                            [2.658862788945834, 48.79288483318345],
                            [2.66130748957195, 48.79207754218481],
                            [2.664499211726753, 48.79104593321487],
                            [2.666678938297153, 48.79033011518671],
                            [2.66885860370027, 48.78961425604855],
                            [2.671039561150659, 48.78889745204991],
                            [2.673504313525253, 48.78809433686021],
                            [2.675968967318145, 48.78728847025629],
                            [2.678434915405753, 48.786484345712665],
                            [2.679329631706581, 48.78617500629736],
                            [2.67981579165295, 48.78598582565908],
                            [2.680244371035857, 48.78581074330536],
                            [2.680636457320475, 48.78563510048336],
                            [2.681036778289391, 48.7854373615558],
                            [2.681452903633455, 48.78522885817877],
                            [2.681987531079078, 48.78491838524668],
                            [2.682455316941921, 48.784623086557026],
                            [2.682716109257094, 48.784450545926546],
                            [2.683063902704594, 48.784209585365055],
                            [2.683291287444024, 48.784031735674226],
                            [2.683610598937456, 48.78376637584698],
                            [2.683786439475538, 48.78361296259848],
                            [2.68398524881878, 48.78343609805765],
                            [2.68420824317259, 48.78321509402277],
                            [2.684478486418863, 48.78293998847224],
                            [2.684633707729437, 48.78275785956092],
                            [2.684821297129882, 48.782534265014235],
                            [2.685072111464724, 48.78220615978139],
                            [2.68538060446695, 48.7817591718489],
                            [2.685609637853775, 48.781376197417686],
                            [2.685838907521479, 48.78094301828567],
                            [2.686183085204097, 48.780154190155315],
                            [2.686498103258331, 48.779430693919146],
                            [2.686821822981746, 48.778684598663126],
                            [2.68800829622975, 48.775976801836975],
                            [2.688231903163656, 48.775464419760496],
                            [2.688709847845154, 48.77436222134508],
                            [2.689292442230653, 48.77305466097908],
                            [2.689696578735758, 48.77205903973373],
                            [2.689989370966271, 48.77137533830717],
                            [2.690252782195758, 48.7707789170597],
                        ],
                    },
                },
                684: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.87386698137083, 2.2941352116312825],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 410.753963113,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.293493453658602,
                            48.87211245133871,
                            2.295560256213147,
                            48.87479926011288,
                        ),
                        "coordinates": [
                            [2.293865549369417, 48.87211245133871],
                            [2.293891623288738, 48.87215409190303],
                            [2.29394049265818, 48.87223685093728],
                            [2.293978837589133, 48.87232198868849],
                            [2.294006393223973, 48.87240892532619],
                            [2.294022971260519, 48.87249706528073],
                            [2.294028455742714, 48.8725858062118],
                            [2.294022817985068, 48.87267454449219],
                            [2.29400608797004, 48.87276267324055],
                            [2.293978381542984, 48.872849587877674],
                            [2.293939887985313, 48.87293469774497],
                            [2.293890875555019, 48.873017419841844],
                            [2.293831669542105, 48.87309718858948],
                            [2.293762682200753, 48.87317346050452],
                            [2.293756230457868, 48.873179914799096],
                            [2.293721182096412, 48.873216320276335],
                            [2.293657343626188, 48.873292814064364],
                            [2.293603432577126, 48.87337256266536],
                            [2.293559828756791, 48.873455008042484],
                            [2.293526837280615, 48.87353957103118],
                            [2.293504684395391, 48.87362565760981],
                            [2.293493529637381, 48.87371266706473],
                            [2.293493453658602, 48.87379998472403],
                            [2.293504455241829, 48.87388700082564],
                            [2.29352645820084, 48.87397310426289],
                            [2.293559301713568, 48.87405769152089],
                            [2.293602763459012, 48.87414016951131],
                            [2.293656536391401, 48.874219959033084],
                            [2.293720242285871, 48.87429650114804],
                            [2.2937934344516, 48.87436925809676],
                            [2.293875599021207, 48.87443771870281],
                            [2.29396616168034, 48.87450140470821],
                            [2.294064484966081, 48.874559868959714],
                            [2.294169880450054, 48.874612701776364],
                            [2.294281611490558, 48.874659529167985],
                            [2.294398887584393, 48.87470002719163],
                            [2.294520891792121, 48.874733910422464],
                            [2.294646765657667, 48.87476093816095],
                            [2.294775626774413, 48.874780926227935],
                            [2.294906573108057, 48.874793729903324],
                            [2.295038682778632, 48.87479926011288],
                            [2.295171033186162, 48.874797480843284],
                            [2.295302691578207, 48.8747884009924],
                            [2.29543273533137, 48.874772087079656],
                            [2.295560256213147, 48.874748650679905],
                        ],
                    },
                },
                685: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.89109158080235, 2.4721954798482786],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2295.95789598,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461119310778047,
                            48.88230400665456,
                            2.481421258690829,
                            48.89660443742263,
                        ),
                        "coordinates": [
                            [2.461119310778047, 48.89660443742263],
                            [2.461509388952238, 48.896564144824815],
                            [2.461942319234399, 48.896518464178925],
                            [2.462588083726939, 48.89644161661581],
                            [2.463309586236366, 48.896348025332145],
                            [2.464736211707876, 48.8961396272551],
                            [2.46575794919192, 48.89595594168199],
                            [2.466266478813435, 48.89584353822975],
                            [2.466673988232067, 48.89574076403453],
                            [2.46711032183098, 48.89562130052526],
                            [2.467604317266228, 48.89547321674713],
                            [2.468091059302494, 48.895313243107005],
                            [2.4684551646126, 48.89517482194836],
                            [2.468797602632725, 48.895031666723526],
                            [2.46906794191135, 48.894917145066536],
                            [2.469586562636219, 48.8946674619619],
                            [2.469966504422374, 48.89445209207242],
                            [2.470264708692414, 48.89427115822417],
                            [2.470529759151449, 48.894091514130714],
                            [2.470991920934919, 48.89375636188796],
                            [2.471290672819598, 48.89352263557229],
                            [2.471726930019748, 48.89312794489909],
                            [2.471973921861432, 48.89287779812293],
                            [2.472547704070426, 48.892236831521885],
                            [2.472884567031517, 48.891817137298425],
                            [2.473438216363358, 48.89107412219748],
                            [2.473772279787147, 48.89070839675303],
                            [2.474049663126856, 48.89040950291347],
                            [2.47452551469536, 48.889881953956994],
                            [2.474881753233817, 48.88950023007377],
                            [2.47572536852113, 48.888574373860074],
                            [2.477607310168708, 48.88650309680817],
                            [2.478720811781256, 48.88525812621543],
                            [2.479059291873576, 48.884888102203035],
                            [2.479390955409872, 48.88451988389745],
                            [2.479752531767738, 48.88412374931917],
                            [2.480115496258058, 48.88373840328366],
                            [2.48045801797166, 48.88335847745387],
                            [2.480921498927064, 48.88284350718845],
                            [2.481421258690829, 48.88230400665456],
                        ],
                    },
                },
                686: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.8461568832383, 2.3956624626196197],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 621.100494707,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.393736423753699,
                            48.84524823225362,
                            2.398743260868829,
                            48.84759160661527,
                        ),
                        "coordinates": [
                            [2.398743260868829, 48.84524823225362],
                            [2.398276655957432, 48.845293449648324],
                            [2.397731687680505, 48.84532289985713],
                            [2.397280404333459, 48.84536360828222],
                            [2.395639565662987, 48.84548348429006],
                            [2.395326201619361, 48.84549713595854],
                            [2.395269161755904, 48.845508406174744],
                            [2.395233405203066, 48.84551741684879],
                            [2.395198507854614, 48.845533172530715],
                            [2.395167877691839, 48.845555669765304],
                            [2.394933125910318, 48.84579845465595],
                            [2.394593977917443, 48.84618130350375],
                            [2.394368428810569, 48.84645029420095],
                            [2.394103882213938, 48.84670882888009],
                            [2.393869096711505, 48.84693137761884],
                            [2.393814140450246, 48.84698512074815],
                            [2.393761062781062, 48.84703702609401],
                            [2.393736423753699, 48.84708649887625],
                            [2.393743267539098, 48.84711340358849],
                            [2.393767147656123, 48.847144866220184],
                            [2.393851513794833, 48.84719653174215],
                            [2.393971663853638, 48.84725935059861],
                            [2.394280992995781, 48.84743223429362],
                            [2.394534932572623, 48.8475714231319],
                            [2.394632893503794, 48.84759160661527],
                            [2.394727419764303, 48.84759155874741],
                            [2.394833006767843, 48.847580263664256],
                            [2.394938550777923, 48.84753299768314],
                            [2.394978663568936, 48.84751509653132],
                            [2.395092484739262, 48.84747025556022],
                            [2.395211528686996, 48.84743177233871],
                            [2.395334977549263, 48.847399906229086],
                            [2.395412601817719, 48.84738461107548],
                            [2.39546199483274, 48.84737487872934],
                        ],
                    },
                },
                687: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.82350969214343, 2.52727402884048],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2287.98565054,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.511855553451007,
                            48.8226267426856,
                            2.542679794015853,
                            48.82484856949889,
                        ),
                        "coordinates": [
                            [2.511855553451007, 48.82484856949889],
                            [2.512217423074874, 48.824814209134196],
                            [2.512766104006487, 48.824761206978174],
                            [2.513779054037772, 48.82466431774589],
                            [2.514398530826373, 48.82460490286682],
                            [2.515277862235902, 48.8245217806584],
                            [2.516086782843057, 48.82444758916252],
                            [2.517586244095618, 48.82430360031815],
                            [2.519199053721701, 48.824154236778675],
                            [2.521241312349522, 48.823960514265316],
                            [2.524109452066047, 48.823686052109736],
                            [2.525845360479719, 48.823526472729434],
                            [2.527401006831997, 48.82336915348054],
                            [2.529221956706923, 48.8231825061319],
                            [2.530345099939552, 48.82307089557032],
                            [2.533322450370636, 48.822780738035966],
                            [2.534735677133574, 48.82267308066506],
                            [2.53526263108855, 48.8226478853317],
                            [2.535856350601355, 48.822630665180206],
                            [2.536557711833274, 48.8226267426856],
                            [2.537180108559238, 48.82262924851815],
                            [2.537611893034019, 48.822644677351896],
                            [2.538214618943187, 48.82267325433027],
                            [2.538975174795262, 48.822733773378026],
                            [2.539696134074657, 48.822803874373214],
                            [2.54044406314881, 48.8228917732283],
                            [2.541219710124115, 48.822995674472836],
                            [2.54197740742918, 48.82312792268585],
                            [2.542679794015853, 48.823266634124074],
                        ],
                    },
                },
                688: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.933183846538626, 2.357756552829699],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 777.725089707,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356035794172797,
                            48.92993588967869,
                            2.359398261032672,
                            48.93652685258673,
                        ),
                        "coordinates": [
                            [2.356035794172797, 48.92993588967869],
                            [2.356205485336793, 48.930040189252374],
                            [2.356300763565885, 48.93012387914171],
                            [2.356399622228132, 48.93022212430579],
                            [2.356489111983262, 48.93032419141283],
                            [2.356568897715923, 48.93042969468671],
                            [2.356638674482309, 48.930538235922036],
                            [2.356698177120449, 48.930649400038845],
                            [2.356747181471141, 48.930762766779715],
                            [2.356780378125427, 48.930860339849865],
                            [2.357515309951479, 48.93266896453394],
                            [2.358516550034332, 48.93500333424754],
                            [2.358925895390543, 48.9357358030794],
                            [2.358963889015679, 48.93580823780817],
                            [2.359098460963958, 48.936050421014514],
                            [2.359243288587993, 48.93629002213375],
                            [2.359398261032672, 48.93652685258673],
                        ],
                    },
                },
                689: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.839302409809555, 2.392661102493384],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 450.085522923,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.389620014061439,
                            48.83904114371397,
                            2.395703289436394,
                            48.839549645568674,
                        ),
                        "coordinates": [
                            [2.389620014061439, 48.83904114371397],
                            [2.394648429548544, 48.83947559184164],
                            [2.395703289436394, 48.839549645568674],
                        ],
                    },
                },
                690: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.68661811975293, 2.7670889329581394],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 14077.1554893,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.729481333043577,
                            48.64437362491682,
                            2.825169932970373,
                            48.74472077575101,
                        ),
                        "coordinates": [
                            [2.825169932970373, 48.64437362491682],
                            [2.825117696515625, 48.64439914860716],
                            [2.823496840242104, 48.645178593959585],
                            [2.821874584697003, 48.645958922320666],
                            [2.820254983810116, 48.64673831648759],
                            [2.819574150450681, 48.64706405674784],
                            [2.818415257598208, 48.64763552839771],
                            [2.817226627793429, 48.648222402401736],
                            [2.816063479394435, 48.6487803779819],
                            [2.813788402842773, 48.64986730221834],
                            [2.812261790861088, 48.65060392438641],
                            [2.810736499704717, 48.651341420098895],
                            [2.809208433866786, 48.652077107785914],
                            [2.8053442084936, 48.65394294837771],
                            [2.802790323211953, 48.655165693855764],
                            [2.799943177985535, 48.65654065758471],
                            [2.799297228351776, 48.656850842950064],
                            [2.796932216431252, 48.65797915129158],
                            [2.795886268824165, 48.65848877873689],
                            [2.795191642720393, 48.65882521637912],
                            [2.793994223815369, 48.6594001852802],
                            [2.793200818753637, 48.65977387841077],
                            [2.792293986443532, 48.66021456853259],
                            [2.790523433108257, 48.66106517836583],
                            [2.788754168730758, 48.66191485520677],
                            [2.786984851358499, 48.662765404664015],
                            [2.785494015154736, 48.6634916257155],
                            [2.78485190976048, 48.66379631707029],
                            [2.784393728459598, 48.66402144095147],
                            [2.783963938325626, 48.66424775142953],
                            [2.783635731604783, 48.664425207186454],
                            [2.783307604607718, 48.66462254054954],
                            [2.783046100590704, 48.66478735772437],
                            [2.782732588264209, 48.66499350481364],
                            [2.782349477022271, 48.66526749005375],
                            [2.782054210877877, 48.66549706571446],
                            [2.781709249484484, 48.66578708689376],
                            [2.781491355036558, 48.66599288302623],
                            [2.781332586280571, 48.66614757208109],
                            [2.781170878004105, 48.66631167749327],
                            [2.780994850659576, 48.666500099702496],
                            [2.780819967744134, 48.666697043537106],
                            [2.780614440787319, 48.66694335133204],
                            [2.780298876569061, 48.66733487282282],
                            [2.779874898545251, 48.66790217676214],
                            [2.779425556448623, 48.668519038778406],
                            [2.777975124804106, 48.670466235782264],
                            [2.77724627782877, 48.67141780884133],
                            [2.776980522191153, 48.67176686112896],
                            [2.776234462842174, 48.67277245109426],
                            [2.775648057634928, 48.67356249080601],
                            [2.774924836798414, 48.674546401883596],
                            [2.773943658838933, 48.675847847865775],
                            [2.772870074822791, 48.67730251945651],
                            [2.771213704019179, 48.679518405375376],
                            [2.7697504655931, 48.68147183983985],
                            [2.769332772232794, 48.6820085052128],
                            [2.769061409054049, 48.68235036637321],
                            [2.768803334507701, 48.682658902362],
                            [2.768462719453608, 48.683002824185195],
                            [2.768172228141294, 48.68327074081385],
                            [2.767845612849305, 48.68356901691351],
                            [2.767492209728382, 48.68384913458479],
                            [2.767189717959314, 48.68406249277007],
                            [2.766856407964228, 48.68429758562561],
                            [2.766468784706438, 48.68454815340436],
                            [2.766079661167236, 48.684782537451525],
                            [2.765589025582491, 48.685063443125564],
                            [2.76514537510212, 48.68528877531804],
                            [2.764705088014628, 48.68548791930636],
                            [2.764236176877805, 48.685676174668686],
                            [2.763812409269565, 48.68583244376893],
                            [2.762926677176741, 48.686126234108656],
                            [2.761879597440152, 48.68645389318209],
                            [2.758384652914698, 48.68753974602893],
                            [2.757347528975372, 48.687859651664915],
                            [2.756327147083079, 48.68818297158534],
                            [2.755671451252733, 48.688409484241674],
                            [2.755004758277538, 48.688664636373076],
                            [2.754397506837519, 48.68890607620955],
                            [2.753670930566782, 48.6892414765325],
                            [2.752935111263798, 48.6895917634978],
                            [2.752377757974552, 48.689880203811],
                            [2.75184791114504, 48.69018340750379],
                            [2.751288421117146, 48.69052088459583],
                            [2.750778247623626, 48.690857327830365],
                            [2.750395412661966, 48.691114952536715],
                            [2.749597733265244, 48.691728464750206],
                            [2.749321191393923, 48.69195968508854],
                            [2.747096162755428, 48.6937645037213],
                            [2.746502358959065, 48.694236970019325],
                            [2.745483706343688, 48.69508236517169],
                            [2.742846687132863, 48.697208725070176],
                            [2.742270661278355, 48.69770538644625],
                            [2.741674817272218, 48.698272259808],
                            [2.741259812566582, 48.69869280225192],
                            [2.740756468444926, 48.699277327718264],
                            [2.740284476727836, 48.699876128557754],
                            [2.739944903354887, 48.700388125067825],
                            [2.73964987923887, 48.70086579034941],
                            [2.739298072109031, 48.70154689371933],
                            [2.739117634042364, 48.70191533942363],
                            [2.738957739862195, 48.70230439466664],
                            [2.738815597955051, 48.70270305945618],
                            [2.738717448597016, 48.70300129003301],
                            [2.738559548908253, 48.70363854022837],
                            [2.738450842054682, 48.70414252339305],
                            [2.738439077757731, 48.70420011880874],
                            [2.738422190998628, 48.704296402548536],
                            [2.738393823546856, 48.7044853516894],
                            [2.738228043974364, 48.70549493387133],
                            [2.738147339810723, 48.70593406899578],
                            [2.738046792880056, 48.70660888667897],
                            [2.737739171207388, 48.70839864748905],
                            [2.737556929618997, 48.70939209911832],
                            [2.737351878628549, 48.71059156770303],
                            [2.737183556229141, 48.71162813526213],
                            [2.737060846788115, 48.712253569390924],
                            [2.736587042420871, 48.71501963607373],
                            [2.736353367469476, 48.71638377221482],
                            [2.736246066377876, 48.71706940303441],
                            [2.736018526257642, 48.71835348110869],
                            [2.735908620606001, 48.719054409505105],
                            [2.735791794113421, 48.71974007395691],
                            [2.735709795202926, 48.72019270161116],
                            [2.735631930372989, 48.720652509377494],
                            [2.735557805867888, 48.72106731937025],
                            [2.735473180556589, 48.72153526327249],
                            [2.735382633103439, 48.72210932411769],
                            [2.735105348616268, 48.7236372805973],
                            [2.734879746481517, 48.725001385886365],
                            [2.734741669724737, 48.72575277214805],
                            [2.734549702813608, 48.72690542691385],
                            [2.734433838994908, 48.72754612252524],
                            [2.734265041297676, 48.72853772481095],
                            [2.734146688983983, 48.72920810560002],
                            [2.73394509378695, 48.73035000173071],
                            [2.733767519783255, 48.73143695734663],
                            [2.733573490469702, 48.732506883945625],
                            [2.733420763224158, 48.73347234981333],
                            [2.73332028898587, 48.73400057980367],
                            [2.73321869028409, 48.734558490610226],
                            [2.733106449878491, 48.73520761467232],
                            [2.733053629111172, 48.735513207452804],
                            [2.732892461155463, 48.73644542758566],
                            [2.732786981612087, 48.73702943117864],
                            [2.732691072686723, 48.737620594519825],
                            [2.732565048748073, 48.73835754805241],
                            [2.732416908234033, 48.73922047804262],
                            [2.732327218551144, 48.739735881499605],
                            [2.73222919612983, 48.74023732229124],
                            [2.73214791922954, 48.74061800222027],
                            [2.732075380938231, 48.740900629960485],
                            [2.731959323584673, 48.741271364878955],
                            [2.731851616784648, 48.74158388285163],
                            [2.731718964525705, 48.74190636859668],
                            [2.731534096457797, 48.7422559323722],
                            [2.731314044676415, 48.742627200456035],
                            [2.731100690136974, 48.74295436044052],
                            [2.73087568397883, 48.74324742651045],
                            [2.730657489573668, 48.74351077276526],
                            [2.730262604008351, 48.74395638453341],
                            [2.730035925174012, 48.7441792906083],
                            [2.729481333043577, 48.74472077575101],
                        ],
                    },
                },
                691: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.59215579265243, 2.952014767881464],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 10976.0690939,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.888252894073074,
                            48.562124835009335,
                            3.011769326340159,
                            48.61401524181304,
                        ),
                        "coordinates": [
                            [3.011769326340159, 48.562124835009335],
                            [3.011226891509093, 48.56253092583289],
                            [3.010795465472182, 48.56284826556181],
                            [3.009993230798577, 48.56344027043157],
                            [3.008925378979757, 48.56423079076438],
                            [3.007976790278708, 48.56492526843745],
                            [3.00717185256031, 48.56552266512501],
                            [3.006647470419285, 48.56590790301021],
                            [3.00617761987365, 48.56625247085581],
                            [3.005702256953254, 48.56660219499814],
                            [3.005206164306193, 48.56696504688912],
                            [3.004547424324002, 48.5674554464708],
                            [3.003848469906697, 48.56797935238775],
                            [3.00269584278038, 48.56882876540765],
                            [3.001888033314354, 48.569423442986384],
                            [3.000880228979461, 48.570163172870124],
                            [2.999784569293052, 48.57096327081697],
                            [2.999343380860185, 48.57127199960639],
                            [2.998246225738218, 48.57202481813805],
                            [2.997071123265755, 48.572829340514495],
                            [2.995682638928761, 48.573795164671495],
                            [2.994352896535735, 48.57469768048869],
                            [2.993866704902402, 48.57503143801881],
                            [2.992552049907145, 48.57595273031148],
                            [2.991314022441687, 48.57679716831864],
                            [2.990805794164422, 48.57713999018386],
                            [2.989891205325824, 48.57777836341677],
                            [2.989175638877831, 48.57827127291864],
                            [2.988640681185174, 48.5786398876568],
                            [2.987873659028496, 48.57916588424166],
                            [2.986719801444277, 48.57996208197389],
                            [2.986085809194948, 48.58040277036514],
                            [2.985422239778113, 48.58086220417641],
                            [2.984868732975652, 48.58124067938653],
                            [2.98428767728862, 48.58164362186359],
                            [2.983876040481968, 48.58192981072165],
                            [2.982489620112649, 48.582884668047136],
                            [2.981818761639758, 48.58334349957637],
                            [2.980439307674015, 48.584285730565036],
                            [2.97857981096076, 48.58556607105648],
                            [2.977864572533398, 48.586030429504724],
                            [2.977335764572858, 48.58636821846457],
                            [2.97685282678557, 48.586653817831944],
                            [2.976026577722111, 48.587108180905624],
                            [2.975350612933426, 48.58744133712915],
                            [2.97482595851147, 48.587700711618716],
                            [2.974336663394183, 48.58793234092389],
                            [2.973834731479977, 48.588154907149345],
                            [2.973059350183268, 48.58847401174176],
                            [2.972388337442415, 48.588729745743585],
                            [2.971704809436496, 48.5889760494858],
                            [2.970946293093624, 48.58923046450041],
                            [2.970112381183803, 48.5894864910627],
                            [2.969443855387594, 48.58968343558977],
                            [2.968678602728465, 48.58990229487591],
                            [2.967938385347133, 48.590112354082],
                            [2.966539013256185, 48.59051222316226],
                            [2.964797968828982, 48.59101738517702],
                            [2.963001913166871, 48.59152320607119],
                            [2.96150437312926, 48.59195023519319],
                            [2.960085326570524, 48.59234588005332],
                            [2.957795055602938, 48.59300380491686],
                            [2.956063256816088, 48.593503385862036],
                            [2.953049554471621, 48.59438401711514],
                            [2.95136087829297, 48.59486074500292],
                            [2.949898922877148, 48.595273402112134],
                            [2.948891095303162, 48.59556391987036],
                            [2.948050787617785, 48.59580676278953],
                            [2.945006760697396, 48.59666935700941],
                            [2.943147708199963, 48.59720539479138],
                            [2.939248183658887, 48.59830891642245],
                            [2.935906847545137, 48.59927806190474],
                            [2.933626003623716, 48.59993397622023],
                            [2.931647749610685, 48.60050012986618],
                            [2.927774708145882, 48.60159322795373],
                            [2.924480136697615, 48.60254111006643],
                            [2.922036645378133, 48.603228211184515],
                            [2.921005433979269, 48.60351770225044],
                            [2.917502320940796, 48.60451141907943],
                            [2.913782875368526, 48.60557177625513],
                            [2.912017741368709, 48.606078047491245],
                            [2.910274154084748, 48.60657428981424],
                            [2.908434112596616, 48.60709652361592],
                            [2.907355922451583, 48.607403760755325],
                            [2.905909667304607, 48.607816236894244],
                            [2.903799596169402, 48.60841620606059],
                            [2.902812779368984, 48.60869271848928],
                            [2.900770309436264, 48.609277536455295],
                            [2.899844320120906, 48.609539332669044],
                            [2.898023436898308, 48.6100564489932],
                            [2.896829788457083, 48.61039688024103],
                            [2.896417476453498, 48.61051402290028],
                            [2.896006692213395, 48.61064644457216],
                            [2.89561075042617, 48.6107724966874],
                            [2.89528223538252, 48.61088284104059],
                            [2.894933007532868, 48.61100491832953],
                            [2.894555761699582, 48.61114549522509],
                            [2.89360916395734, 48.6115107581527],
                            [2.892552313811294, 48.61196288508396],
                            [2.889773096807634, 48.61327413369311],
                            [2.888252894073074, 48.61401524181304],
                        ],
                    },
                },
                692: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.62919225914879, 2.8567102938759077],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 5744.83419298,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.825169932970373,
                            48.61401524181304,
                            2.888252894073074,
                            48.64437362491682,
                        ),
                        "coordinates": [
                            [2.888252894073074, 48.61401524181304],
                            [2.886894329621075, 48.61467212955065],
                            [2.885802317321128, 48.61519792185732],
                            [2.884880059891243, 48.615639616576274],
                            [2.884159618753315, 48.61598752074155],
                            [2.883563242397453, 48.616270973318805],
                            [2.882606602077116, 48.61672612166928],
                            [2.881949900321334, 48.61704089305603],
                            [2.880835011533278, 48.61757456245426],
                            [2.879272266403292, 48.61832752838799],
                            [2.87791919514967, 48.618978801419274],
                            [2.877912453382639, 48.61898243031329],
                            [2.876548261970104, 48.61963911086706],
                            [2.875769655387975, 48.62001241831445],
                            [2.875041009341235, 48.62036569963416],
                            [2.874257033209312, 48.620746216183136],
                            [2.873541783875754, 48.621085934149065],
                            [2.872571551481486, 48.62155544986569],
                            [2.871624187098022, 48.622008662459784],
                            [2.870265275666224, 48.6226670409903],
                            [2.869701179774353, 48.62293947766398],
                            [2.868608063444103, 48.62346798988264],
                            [2.86808172890078, 48.6237213558296],
                            [2.867582412812167, 48.62396470109709],
                            [2.867068189275765, 48.62420991204925],
                            [2.866516171316349, 48.624473282519865],
                            [2.86540945176939, 48.62500452540267],
                            [2.864614544869241, 48.62539132070537],
                            [2.863802010421292, 48.62577999108498],
                            [2.862932793456428, 48.626197695762535],
                            [2.862024477801295, 48.62663985559059],
                            [2.86146834654885, 48.62690411941979],
                            [2.860789435827009, 48.62723279792947],
                            [2.860396639573331, 48.62742076289445],
                            [2.859860792860715, 48.62768042930123],
                            [2.859342498743579, 48.62793281813051],
                            [2.858756654882549, 48.62821249366439],
                            [2.858164039487893, 48.62849399677434],
                            [2.857493197231982, 48.6288199195482],
                            [2.856896526487096, 48.629104132360744],
                            [2.85629585489467, 48.62939555398004],
                            [2.855661428273114, 48.62970331328564],
                            [2.855048579863479, 48.62999928048711],
                            [2.854539659587769, 48.630244410337454],
                            [2.85396457744671, 48.63052041491203],
                            [2.853443446221091, 48.63076649467456],
                            [2.852960138199263, 48.630997112360504],
                            [2.852331050965338, 48.63130033298677],
                            [2.850974292855363, 48.63195307373588],
                            [2.847555928052476, 48.63359891203457],
                            [2.844758429879055, 48.63494600552501],
                            [2.841962128583143, 48.63629212510461],
                            [2.839165686108111, 48.63763907524106],
                            [2.837655994248148, 48.63836517449139],
                            [2.837110458282423, 48.6386292720264],
                            [2.835968161034107, 48.63919275697193],
                            [2.834989031718132, 48.63965659344312],
                            [2.83387742919385, 48.64017315956778],
                            [2.833306136576159, 48.64044364648118],
                            [2.832272303940632, 48.64094103812035],
                            [2.831580240455728, 48.64127852410644],
                            [2.829917742016724, 48.642080726200255],
                            [2.829470702230033, 48.64229579755986],
                            [2.829088472563825, 48.64247821246111],
                            [2.828280821868661, 48.642867505358204],
                            [2.827461026259217, 48.64326493795237],
                            [2.826534447300731, 48.64370689060596],
                            [2.825169932970373, 48.64437362491682],
                        ],
                    },
                },
                693: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.81809137071078, 2.339632345428724],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 675.993382459,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.338913052113992,
                            48.81522993471632,
                            2.340891132444595,
                            48.82108965061529,
                        ),
                        "coordinates": [
                            [2.340891132444595, 48.81522993471632],
                            [2.34078523758537, 48.81558683859994],
                            [2.340713915940976, 48.81578242226884],
                            [2.340638269495257, 48.8159737234266],
                            [2.340553976981318, 48.81616074251736],
                            [2.340458873299537, 48.816342051051464],
                            [2.340348637515069, 48.81654334666515],
                            [2.340186523792991, 48.816814595990905],
                            [2.339894713278028, 48.81726905761276],
                            [2.339588485688529, 48.817725898552425],
                            [2.33937190397088, 48.818085166925584],
                            [2.339276587235671, 48.8182560312351],
                            [2.339194888506565, 48.81842329852579],
                            [2.339136339232601, 48.81857887399637],
                            [2.339087320440368, 48.818710169293865],
                            [2.339051918387862, 48.818828873818966],
                            [2.338970224135455, 48.81914542043063],
                            [2.33893697312147, 48.819357501659816],
                            [2.338918490265195, 48.81953300836916],
                            [2.338913052113992, 48.81975063328303],
                            [2.338975180940006, 48.82026761228005],
                            [2.339008115677011, 48.820490390380876],
                            [2.339001721318587, 48.820773795069584],
                            [2.338978472013182, 48.82108965061529],
                        ],
                    },
                },
                694: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.849903586134594, 2.3426045994946363],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 974.869126001,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.339927999738678,
                            48.845743071427194,
                            2.346034983092227,
                            48.85333579557522,
                        ),
                        "coordinates": [
                            [2.339927999738678, 48.845743071427194],
                            [2.34030659683882, 48.84645364552481],
                            [2.340574741571417, 48.84690225605868],
                            [2.341004313914517, 48.84762177789105],
                            [2.341301396462033, 48.84809748145307],
                            [2.341557599599108, 48.848502143571544],
                            [2.34195690596424, 48.84914420789373],
                            [2.342209033896033, 48.849565055792034],
                            [2.3424952482479, 48.85012708705416],
                            [2.342617916442071, 48.85039506445207],
                            [2.342774662064564, 48.85074127682958],
                            [2.342962751906148, 48.851100076626544],
                            [2.343172636728855, 48.85137704091163],
                            [2.34351812506777, 48.85174392447808],
                            [2.343846567902419, 48.85200064668518],
                            [2.344439240694036, 48.852388061361125],
                            [2.345332284092638, 48.852915588612255],
                            [2.346034983092227, 48.85333579557522],
                        ],
                    },
                },
                695: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.8744169970249, 2.295032535653884],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 90.335661048,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.294490592832005,
                            48.874238476656075,
                            2.295567369745454,
                            48.874613927042155,
                        ),
                        "coordinates": [
                            [2.294490592832005, 48.874238476656075],
                            [2.294562149389444, 48.87427674360387],
                            [2.294650101547289, 48.87431446498794],
                            [2.294743548722953, 48.87434591608907],
                            [2.294841467569564, 48.87437075091532],
                            [2.294927807215376, 48.87438651324289],
                            [2.295045513628099, 48.874408001982125],
                            [2.295160279015744, 48.87443646117662],
                            [2.2952707140584, 48.874471592167254],
                            [2.295375930975369, 48.87451311004398],
                            [2.295475082145169, 48.87456068336976],
                            [2.295567369745454, 48.874613927042155],
                        ],
                    },
                },
                696: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.883416204799836, 2.347360725575412],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 487.71489393,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344130633722553,
                            48.88286864756839,
                            2.350612999325322,
                            48.88380394240112,
                        ),
                        "coordinates": [
                            [2.344130633722553, 48.88286864756839],
                            [2.345402279134807, 48.88311551691324],
                            [2.346572519112321, 48.883346945217134],
                            [2.347500903790015, 48.883480629694894],
                            [2.349303072346237, 48.883706823660866],
                            [2.349636148269586, 48.88373446574697],
                            [2.350055678576005, 48.88376928075625],
                            [2.350612999325322, 48.88380394240112],
                        ],
                    },
                },
                697: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.82538961110207, 2.276327681484181],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 579.35925996,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.273041523780413,
                            48.82410503068069,
                            2.279411682050421,
                            48.82708544889643,
                        ),
                        "coordinates": [
                            [2.273041523780413, 48.82410503068069],
                            [2.275911852947982, 48.8250442640196],
                            [2.277875035958083, 48.82600951748116],
                            [2.278778959036113, 48.82662435098704],
                            [2.279411682050421, 48.82708544889643],
                        ],
                    },
                },
                698: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.52877528612839, 3.2548922135943776],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 110.601025501,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.254443956038005,
                            48.52836864583034,
                            3.255368150025012,
                            48.52914896682657,
                        ),
                        "coordinates": [
                            [3.254443956038005, 48.52836864583034],
                            [3.2547183540695, 48.52863891875573],
                            [3.25499495153409, 48.52888129493217],
                            [3.255368150025012, 48.52914896682657],
                        ],
                    },
                },
                699: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.06741885629995, 2.325290399828083],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 427.358013077,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.322920457193825,
                            49.06628869769713,
                            2.327669570460789,
                            49.068530235211696,
                        ),
                        "coordinates": [
                            [2.322920457193825, 49.06628869769713],
                            [2.323226884488961, 49.0664502544886],
                            [2.323614289009766, 49.06663826779407],
                            [2.327669570460789, 49.068530235211696],
                        ],
                    },
                },
                700: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.88347693775859, 2.3685809749762896],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 524.150205583,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.365881358169887,
                            48.88149859591725,
                            2.370262128023678,
                            48.88427894428395,
                        ),
                        "coordinates": [
                            [2.365881358169887, 48.88427894428395],
                            [2.366774819624561, 48.88421964808257],
                            [2.367833850287432, 48.88415274428226],
                            [2.368092098162404, 48.88413275662563],
                            [2.368261827294032, 48.88411141914166],
                            [2.36841322319777, 48.8840797539604],
                            [2.368494014055761, 48.88405297816604],
                            [2.36857209787172, 48.884022051134714],
                            [2.368648094998615, 48.88398563074888],
                            [2.368703266873047, 48.88395333634125],
                            [2.368748025567635, 48.883922418734876],
                            [2.368788628235825, 48.88389427970605],
                            [2.368975384282304, 48.88371369172985],
                            [2.369062786353647, 48.88360240820099],
                            [2.369181408439018, 48.88345746448048],
                            [2.369277145124632, 48.88335510644881],
                            [2.36939892148606, 48.88325892177647],
                            [2.369876346044897, 48.88295127880139],
                            [2.36996413042077, 48.8828899578429],
                            [2.370055713864155, 48.882808889573376],
                            [2.370122312281105, 48.88273813278425],
                            [2.370162893711581, 48.88269210641602],
                            [2.370202421616014, 48.88262753753518],
                            [2.370229447815184, 48.882555417767406],
                            [2.370242935151342, 48.88248055397058],
                            [2.370248087930149, 48.88239882582022],
                            [2.370249062838294, 48.88230061617613],
                            [2.370260166926005, 48.881775227338025],
                            [2.370262128023678, 48.88149859591725],
                        ],
                    },
                },
                701: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.871881959939316, 2.293693833913567],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 57.2212990245,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.293524290329624,
                            48.871649770042794,
                            2.293865549369417,
                            48.87211245133871,
                        ),
                        "coordinates": [
                            [2.293865549369417, 48.87211245133871],
                            [2.293842330680222, 48.87208506513087],
                            [2.293829454419726, 48.87206803113101],
                            [2.293524290329624, 48.871649770042794],
                        ],
                    },
                },
                702: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.74038297792885, 2.352471335391776],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 130.499852424,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351633198171911,
                            48.74019544820276,
                            2.35330589785325,
                            48.740586107900334,
                        ),
                        "coordinates": [
                            [2.351633198171911, 48.74019544820276],
                            [2.352236916922279, 48.74032036530058],
                            [2.353077245479699, 48.74052887785052],
                            [2.353113958939442, 48.740537865249046],
                            [2.35315747031416, 48.74054775113523],
                            [2.353207781560344, 48.74056123294213],
                            [2.35330589785325, 48.740586107900334],
                        ],
                    },
                },
                703: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.87496032824761, 2.373756929745924],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 730.768921839,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.370811395312745,
                            48.872310113783094,
                            2.376702144728945,
                            48.87761018741785,
                        ),
                        "coordinates": [
                            [2.370811395312745, 48.87761018741785],
                            [2.371288835703618, 48.87718126352543],
                            [2.376702144728945, 48.872310113783094],
                        ],
                    },
                },
                704: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.79686336284212, 2.1546180551523735],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 339.677156218,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.152378660253372,
                            48.79652818117568,
                            2.15683568548617,
                            48.797310081377546,
                        ),
                        "coordinates": [
                            [2.15683568548617, 48.797310081377546],
                            [2.155781306088051, 48.797035313672566],
                            [2.155455648608842, 48.79696194973523],
                            [2.155092696263549, 48.796900697276406],
                            [2.153650330733015, 48.7967032856754],
                            [2.152378660253372, 48.79652818117568],
                        ],
                    },
                },
                705: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.879481583410595, 2.3891699892512066],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 7.94767264742,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.389115807376888,
                            48.87948139490827,
                            2.389224171125526,
                            48.87948177191293,
                        ),
                        "coordinates": [
                            [2.389115807376888, 48.87948177191293],
                            [2.389224171125526, 48.87948139490827],
                        ],
                    },
                },
                706: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.52107763481256, 3.250276727388294],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1766.77909796,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.247853391787192,
                            48.51375459097529,
                            3.254443956038005,
                            48.52836864583034,
                        ),
                        "coordinates": [
                            [3.250034982583049, 48.51375459097529],
                            [3.248816277594826, 48.51484858392043],
                            [3.248538546011257, 48.51513397648663],
                            [3.248343744047987, 48.51540646055068],
                            [3.248158972694217, 48.51571742642379],
                            [3.248038534365448, 48.51598727440681],
                            [3.24794704751838, 48.51627354669993],
                            [3.24789796717411, 48.51652854362541],
                            [3.247859672820045, 48.5167858344146],
                            [3.247853391787192, 48.51703096977457],
                            [3.247879556513874, 48.51728774190833],
                            [3.247953746796779, 48.51762502908779],
                            [3.24809120166248, 48.518092677645775],
                            [3.248253179758422, 48.51872669208497],
                            [3.248413599749815, 48.51927505821372],
                            [3.24866377301091, 48.5198345987809],
                            [3.248999511928741, 48.52037203476526],
                            [3.249467595737235, 48.521140494910206],
                            [3.249856056594523, 48.52173001996007],
                            [3.250304241028161, 48.52240179949549],
                            [3.250807649820171, 48.523131588643025],
                            [3.251478328830027, 48.52412352769819],
                            [3.25214477375392, 48.525104705067804],
                            [3.252755550341988, 48.526001792291844],
                            [3.253622488302022, 48.527281715765],
                            [3.253876962577198, 48.527647480229035],
                            [3.254096758049422, 48.527967659279405],
                            [3.254264503322671, 48.52818124055689],
                            [3.254443956038005, 48.52836864583034],
                        ],
                    },
                },
                707: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.81914000784931, 2.296300029207499],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 910.703251165,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.295297684747765,
                            48.81530753120022,
                            2.298464191958535,
                            48.82258370773707,
                        ),
                        "coordinates": [
                            [2.297077796972985, 48.81530753120022],
                            [2.296726515460497, 48.815665041427806],
                            [2.296501161263785, 48.81591903883802],
                            [2.296319129993078, 48.8161403713176],
                            [2.296194052717627, 48.81630045309076],
                            [2.296090021324099, 48.81644338405627],
                            [2.295972354445856, 48.8166173561796],
                            [2.295869546537233, 48.81677417708838],
                            [2.295774150524282, 48.81694080350932],
                            [2.295673797074839, 48.81712049932377],
                            [2.295580855588444, 48.817309184911984],
                            [2.295516401602666, 48.81746030082234],
                            [2.295456878316689, 48.817629391223555],
                            [2.295412206154741, 48.81779195139096],
                            [2.295373712823515, 48.81796186625079],
                            [2.295343891741174, 48.81811789527129],
                            [2.295320242703335, 48.81828944989109],
                            [2.29530649416651, 48.81845692205112],
                            [2.295297684747765, 48.818635018076655],
                            [2.295300025999126, 48.818795144381646],
                            [2.295309771417282, 48.81897488046446],
                            [2.295318312511609, 48.819118669920975],
                            [2.295342500036077, 48.81928149624893],
                            [2.295371229332428, 48.81945282872886],
                            [2.295419338436052, 48.81962032346759],
                            [2.295482295899499, 48.81978864134495],
                            [2.295565044484876, 48.819957783574374],
                            [2.295657700837729, 48.820117941652256],
                            [2.295757789430107, 48.82026584969932],
                            [2.295883851296781, 48.82042438573288],
                            [2.296007456292403, 48.8205616807414],
                            [2.296159514321305, 48.82070552062738],
                            [2.296302926372822, 48.82082893383951],
                            [2.29645163887561, 48.82094849630159],
                            [2.296580863692278, 48.821055795029935],
                            [2.29690505430651, 48.82131278976607],
                            [2.297300714589766, 48.82162255764315],
                            [2.298464191958535, 48.82258370773707],
                        ],
                    },
                },
                708: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.87412669089637, 2.610452466832867],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3992.07205924,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.583331158055108,
                            48.873371395535315,
                            2.637590717167975,
                            48.87520826545471,
                        ),
                        "coordinates": [
                            [2.583331158055108, 48.87414408301457],
                            [2.585207558695742, 48.873954442853965],
                            [2.585510387322357, 48.873923668498286],
                            [2.586323765709928, 48.873841008135635],
                            [2.58841899418083, 48.87365331474768],
                            [2.589324219151641, 48.87358189178765],
                            [2.589854110628206, 48.8735470495907],
                            [2.590571671217689, 48.87350581800877],
                            [2.59134977905419, 48.87346725117777],
                            [2.592208167334582, 48.87343080360643],
                            [2.592735079834614, 48.87341120715678],
                            [2.59340507342645, 48.873388985527676],
                            [2.593904110134702, 48.87337865475599],
                            [2.594525981654122, 48.873371395535315],
                            [2.59531395576001, 48.873376241105404],
                            [2.596024942027703, 48.87338319679672],
                            [2.596830117163757, 48.87339849915184],
                            [2.597560626610289, 48.87341396687035],
                            [2.598430785469064, 48.87343981727825],
                            [2.599125643294948, 48.87346606367441],
                            [2.599690649112652, 48.873492603904495],
                            [2.601340211186603, 48.87357017043353],
                            [2.603622561980809, 48.873675412130865],
                            [2.607039420624726, 48.873834409481375],
                            [2.611011574659458, 48.874019276925736],
                            [2.615896285505255, 48.87424741244236],
                            [2.618256815721966, 48.87435225607318],
                            [2.623245817549538, 48.87458636034341],
                            [2.62535912649922, 48.87467809073089],
                            [2.627551798882467, 48.874754052580975],
                            [2.62981148833539, 48.87485443246263],
                            [2.631172890821067, 48.87490486500882],
                            [2.63248189675449, 48.87496461168814],
                            [2.634268630284971, 48.87505993357167],
                            [2.636043476594933, 48.87513487798265],
                            [2.637590717167975, 48.87520826545471],
                        ],
                    },
                },
                709: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.81142457017141, 2.3381834034259117],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 937.520309434,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.334354309639648,
                            48.808296588631435,
                            2.340953779259072,
                            48.81522993471632,
                        ),
                        "coordinates": [
                            [2.334354309639648, 48.808296588631435],
                            [2.334836265187177, 48.8086599029405],
                            [2.335715488500308, 48.809309284529526],
                            [2.33601159920033, 48.80953912921633],
                            [2.336359587977572, 48.809798953575154],
                            [2.337435404360155, 48.81062932039016],
                            [2.337818008643139, 48.81090988934959],
                            [2.338099858734377, 48.81111492074692],
                            [2.339078862789421, 48.81184421353573],
                            [2.339442424798591, 48.812158051515624],
                            [2.339909481412428, 48.81260407793736],
                            [2.340070163551846, 48.81277583423832],
                            [2.340289401459783, 48.81303841516465],
                            [2.340534520126635, 48.813395418417855],
                            [2.340677509128252, 48.81362562714476],
                            [2.340736070099896, 48.81374882518937],
                            [2.340828679970531, 48.81397993494192],
                            [2.340874987834802, 48.8141346085989],
                            [2.3408940568626, 48.81421104644117],
                            [2.34091176469662, 48.81428118916189],
                            [2.34094079110636, 48.81444903522641],
                            [2.340953771954295, 48.814593222603605],
                            [2.340953779259072, 48.814694581642634],
                            [2.340949470986788, 48.81487017647215],
                            [2.34092354505222, 48.815055766601375],
                            [2.340891132444595, 48.81522993471632],
                        ],
                    },
                },
                710: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.85946030676676, 2.3142363247456843],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 650.112113488,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313909577847757,
                            48.85687137924918,
                            2.315134845412371,
                            48.86236469962951,
                        ),
                        "coordinates": [
                            [2.315056637317088, 48.85687137924918],
                            [2.315133485210907, 48.85766079195326],
                            [2.315134845412371, 48.857688894653215],
                            [2.315129162735144, 48.85774585598041],
                            [2.315112260680734, 48.857801839348625],
                            [2.315084429828856, 48.8578558886048],
                            [2.315046142998975, 48.85790707831522],
                            [2.314998059092723, 48.85795453267433],
                            [2.314940999737922, 48.857997439761405],
                            [2.314875940923972, 48.858035065883456],
                            [2.314803993779368, 48.85806676625824],
                            [2.314798366821888, 48.85806888439283],
                            [2.314400752179974, 48.85821684939915],
                            [2.314333977824969, 48.85824413721876],
                            [2.314251393839643, 48.85828553519523],
                            [2.314176077746005, 48.8583325822362],
                            [2.314108911836952, 48.85838472671206],
                            [2.314050683795899, 48.85844135709393],
                            [2.314002075699046, 48.85850180908463],
                            [2.313963658444318, 48.85856537457961],
                            [2.313935880752351, 48.85863130879806],
                            [2.313919071795221, 48.858698837492206],
                            [2.313913425288205, 48.85876691582915],
                            [2.313911591539704, 48.86048150897511],
                            [2.313909577847757, 48.86236469962951],
                        ],
                    },
                },
                711: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.825329580065954, 2.3019057816345843],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 780.899952064,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.298464191958535,
                            48.82258370773707,
                            2.305534669653895,
                            48.82779554349536,
                        ),
                        "coordinates": [
                            [2.298464191958535, 48.82258370773707],
                            [2.302132706731414, 48.82559510753183],
                            [2.302635953728601, 48.82599974987615],
                            [2.303007798907427, 48.82628510740243],
                            [2.303387886162435, 48.826565694607154],
                            [2.303776071139922, 48.82684140894485],
                            [2.303980447367471, 48.826982384699086],
                            [2.304248720410467, 48.82713893854389],
                            [2.304560074343728, 48.82731158215518],
                            [2.30487833605845, 48.8274786448481],
                            [2.305203279658155, 48.827640004740985],
                            [2.3053409321726, 48.82770461172973],
                            [2.305534669653895, 48.82779554349536],
                        ],
                    },
                },
                712: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.98018510759822, 2.3459656582574127],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1425.13783518,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.338524070645141,
                            48.9760542531305,
                            2.353407245869684,
                            48.984315962065935,
                        ),
                        "coordinates": [
                            [2.338524070645141, 48.9760542531305],
                            [2.353407245869684, 48.984315962065935],
                        ],
                    },
                },
                713: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.84292365258463, 2.3384251363043025],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 669.156046068,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.337096430880091,
                            48.84003378741809,
                            2.339927999738678,
                            48.845743071427194,
                        ),
                        "coordinates": [
                            [2.337096430880091, 48.84003378741809],
                            [2.337238120357314, 48.840559862383195],
                            [2.33737844805122, 48.84101129735711],
                            [2.337422046229704, 48.84111021718831],
                            [2.337476542450414, 48.84123161852058],
                            [2.337517416081292, 48.84132334447538],
                            [2.337768105072942, 48.84175589245925],
                            [2.338178209087903, 48.8425049832543],
                            [2.338646916387185, 48.84336378201552],
                            [2.338954854178092, 48.84393121742948],
                            [2.3393363805758, 48.84463264308811],
                            [2.339927999738678, 48.845743071427194],
                        ],
                    },
                },
                714: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.88414566166771, 2.355550854569304],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 728.077529025,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350612999325322,
                            48.88380394240112,
                            2.360491318526145,
                            48.88440744407851,
                        ),
                        "coordinates": [
                            [2.350612999325322, 48.88380394240112],
                            [2.352447344489099, 48.88393393354399],
                            [2.355839591706058, 48.88417361761378],
                            [2.357853886365862, 48.88430927909012],
                            [2.35874036460908, 48.88438725088699],
                            [2.359069498002264, 48.88440744407851],
                            [2.359723357514925, 48.884401524763554],
                            [2.360491318526145, 48.88439879515334],
                        ],
                    },
                },
                715: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.86498349574394, 2.313906426883672],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 582.38985407,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313894130481615,
                            48.86236469962951,
                            2.313909577847757,
                            48.867602145221504,
                        ),
                        "coordinates": [
                            [2.313909577847757, 48.86236469962951],
                            [2.313908906380806, 48.86290184423484],
                            [2.313904498987494, 48.867112590736234],
                            [2.313902279652939, 48.86737352241913],
                            [2.313894130481615, 48.867602145221504],
                        ],
                    },
                },
                716: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.88359105586918, 2.3374126134940036],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 241.467329503,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.337072240817018,
                            48.88251938564386,
                            2.33794977569207,
                            48.884594208027806,
                        ),
                        "coordinates": [
                            [2.337081683878512, 48.88251938564386],
                            [2.337072373249535, 48.88266730738856],
                            [2.337072240817018, 48.882719486760514],
                            [2.337075191034228, 48.88277277588641],
                            [2.337081226742327, 48.88282727370799],
                            [2.337090362688065, 48.88288310801124],
                            [2.337118013452952, 48.88299929101622],
                            [2.337158592243669, 48.88312323845397],
                            [2.337206175918384, 48.88324206518029],
                            [2.337266737103405, 48.88337442489363],
                            [2.337503396659294, 48.88383987468213],
                            [2.337601626394126, 48.88403513398613],
                            [2.337688314868762, 48.88419586969736],
                            [2.337773374059661, 48.88434043265061],
                            [2.33785899955118, 48.884472347780864],
                            [2.337900810763416, 48.88453080431368],
                            [2.33794977569207, 48.884594208027806],
                        ],
                    },
                },
                717: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.83228110373481, 2.330723324531426],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 299.855987207,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.329705012620185,
                            48.831112660375325,
                            2.331740130985349,
                            48.833450858213496,
                        ),
                        "coordinates": [
                            [2.329705012620185, 48.831112660375325],
                            [2.330241642198707, 48.83172714897007],
                            [2.33049660673154, 48.832019100089184],
                            [2.331740130985349, 48.833450858213496],
                        ],
                    },
                },
                718: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.87692295234225, 2.338631074871193],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 404.384522684,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.337595081445481,
                            48.875972872704345,
                            2.339390876994124,
                            48.87842525852037,
                        ),
                        "coordinates": [
                            [2.337886487705904, 48.87602621160099],
                            [2.33869337948182, 48.875985709504455],
                            [2.338939099835031, 48.87597337518748],
                            [2.33895917605049, 48.875972872704345],
                            [2.339005138062764, 48.8759755232344],
                            [2.339049704411859, 48.87598339928086],
                            [2.339091520185705, 48.8759962595371],
                            [2.339129314152552, 48.876013714769734],
                            [2.339161940965452, 48.87603523254763],
                            [2.339188405394788, 48.876060161657215],
                            [2.339207905828734, 48.87608774223482],
                            [2.33921621231446, 48.87610576582398],
                            [2.339250935790114, 48.87619889222604],
                            [2.339372156236573, 48.87652401122268],
                            [2.339377814324398, 48.87653918726843],
                            [2.339385317255342, 48.8765637086037],
                            [2.339390876994124, 48.87661028802361],
                            [2.339385321824862, 48.87665686815882],
                            [2.339368787634895, 48.876702300406286],
                            [2.339341679872847, 48.876745468225465],
                            [2.339311419129575, 48.876779011029306],
                            [2.339158686489484, 48.87692551069394],
                            [2.337595081445481, 48.87842525852037],
                        ],
                    },
                },
                719: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.88077924368274, 2.391313573841747],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 422.374404723,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.389224171125526,
                            48.87948139490827,
                            2.393445455116349,
                            48.88194543314214,
                        ),
                        "coordinates": [
                            [2.389224171125526, 48.87948139490827],
                            [2.389299276930478, 48.87948882610411],
                            [2.389371864640577, 48.87950355685442],
                            [2.389440312811661, 48.879525258732805],
                            [2.389503090460619, 48.87955344639486],
                            [2.389552983597866, 48.879583430835204],
                            [2.389627084148343, 48.87963430238526],
                            [2.392793085478602, 48.88180770358434],
                            [2.39282669493192, 48.8818292402494],
                            [2.392894967610398, 48.8818650928013],
                            [2.392969631151437, 48.881894893769854],
                            [2.393049459941649, 48.881918152193066],
                            [2.393133142521498, 48.88193448819291],
                            [2.393219306140963, 48.88194363220087],
                            [2.393306534393117, 48.88194543314214],
                            [2.393393398525321, 48.88193986309088],
                            [2.393445455116349, 48.88193199962059],
                        ],
                    },
                },
                720: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.83812700596429, 2.3514918995451555],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 553.717288615,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350803687505295,
                            48.83586348597116,
                            2.352588924250765,
                            48.8404866526412,
                        ),
                        "coordinates": [
                            [2.352588924250765, 48.83586348597116],
                            [2.350951395720319, 48.83819854827188],
                            [2.35094116337473, 48.83821137706968],
                            [2.350892254855964, 48.83828210224076],
                            [2.350853753826413, 48.83835557567075],
                            [2.350826009214732, 48.838431132832376],
                            [2.350809270771856, 48.83850808707298],
                            [2.350803687505295, 48.838585745794326],
                            [2.350809313249234, 48.838663400589475],
                            [2.350826094076255, 48.838740353256085],
                            [2.350853882064929, 48.83881590417955],
                            [2.350892424196072, 48.83888936846132],
                            [2.350919457242961, 48.83893059007664],
                            [2.351691285300295, 48.84039532628757],
                            [2.351739487166927, 48.8404866526412],
                        ],
                    },
                },
                721: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.855366777576776, 2.3524531660915673],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 795.196665944,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347711884033997,
                            48.853575472503586,
                            2.357162571618337,
                            48.8570599654128,
                        ),
                        "coordinates": [
                            [2.357162571618337, 48.853575472503586],
                            [2.356606530398036, 48.853777942032615],
                            [2.355900449400084, 48.85403503931471],
                            [2.354754021183277, 48.85446972542454],
                            [2.353618931626662, 48.85491938289058],
                            [2.351167069224505, 48.85588610747462],
                            [2.34932810333448, 48.856598008168355],
                            [2.348475624046129, 48.856846923843264],
                            [2.348147481005499, 48.85694273615948],
                            [2.347711884033997, 48.8570599654128],
                        ],
                    },
                },
                722: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.84537454252045, 2.325364219653698],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 401.253384636,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.324234991940294,
                            48.84378130573585,
                            2.326792785027681,
                            48.84687823885142,
                        ),
                        "coordinates": [
                            [2.324397012385794, 48.84378130573585],
                            [2.324344301201763, 48.84383294002798],
                            [2.324301213038712, 48.84388832503459],
                            [2.324268354780968, 48.8439466862435],
                            [2.324246179964637, 48.84400720150749],
                            [2.32423500892101, 48.84406902364187],
                            [2.324234991940294, 48.84413128381334],
                            [2.324246132233162, 48.844193106958706],
                            [2.32426827616872, 48.844253628817675],
                            [2.324301105108529, 48.844311994987535],
                            [2.32432910601717, 48.844349788811975],
                            [2.326792785027681, 48.84687823885142],
                        ],
                    },
                },
                723: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.89386635814544, 2.3597706223952297],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 752.938340014,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.359507868815594,
                            48.8904854547466,
                            2.359995766394621,
                            48.897245288093046,
                        ),
                        "coordinates": [
                            [2.359995766394621, 48.8904854547466],
                            [2.359983515577365, 48.89113660402866],
                            [2.359969490292211, 48.89188193210318],
                            [2.359965878452801, 48.89205470845476],
                            [2.359697944225983, 48.89433665118581],
                            [2.359633851502375, 48.89494118804532],
                            [2.359656736512066, 48.89538214221667],
                            [2.359507868815594, 48.897245288093046],
                        ],
                    },
                },
                724: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.85285971363068, 2.332418611911799],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 303.995593002,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.331256291381555,
                            48.851672244720596,
                            2.333776138218468,
                            48.853718934000206,
                        ),
                        "coordinates": [
                            [2.331256291381555, 48.851672244720596],
                            [2.332732449554726, 48.85329711781628],
                            [2.332769144025247, 48.853335235680646],
                            [2.332840766269678, 48.85339906480271],
                            [2.33292088723283, 48.85345833206131],
                            [2.333008842709126, 48.85351254448819],
                            [2.333103906559353, 48.85356125553677],
                            [2.333205286692245, 48.85360405966438],
                            [2.333312146730925, 48.85364060324572],
                            [2.333423599233997, 48.85367058183781],
                            [2.33353872194686, 48.85369374836509],
                            [2.333656560562757, 48.85370991043735],
                            [2.333776138218468, 48.853718934000206],
                        ],
                    },
                },
                725: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.78562005046485, 2.456024496525634],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 1395.26384966,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.450453177915302,
                            48.77990531695967,
                            2.459368396259053,
                            48.78997831034893,
                        ),
                        "coordinates": [
                            [2.459368396259053, 48.77990531695967],
                            [2.459153791321934, 48.78265869925769],
                            [2.459088806839484, 48.783453426828615],
                            [2.459057003410789, 48.78363099987774],
                            [2.458999848529865, 48.78391643829739],
                            [2.458905509623497, 48.784204648380666],
                            [2.45883561779189, 48.78435219139879],
                            [2.458755384610257, 48.78449564921201],
                            [2.458679236484353, 48.78461998533908],
                            [2.458590731069158, 48.78476072172819],
                            [2.458481588407506, 48.78491240194177],
                            [2.458374448391813, 48.78503813805026],
                            [2.458238414357467, 48.785178924011014],
                            [2.458098248736953, 48.785319714450274],
                            [2.457931229368935, 48.785464628956184],
                            [2.457784806945265, 48.785582213106345],
                            [2.457605355496489, 48.78571348619841],
                            [2.457421742926656, 48.78583384030251],
                            [2.457190654045242, 48.785974725787206],
                            [2.456969845074753, 48.7860951179652],
                            [2.456806810935674, 48.7861813128192],
                            [2.456610727780951, 48.78627300448626],
                            [2.456226777492434, 48.78643589636276],
                            [2.455417514221175, 48.786752160221454],
                            [2.454042603387124, 48.78730249411845],
                            [2.453394355490889, 48.787559864019556],
                            [2.453074410905601, 48.7877090249167],
                            [2.452812304813186, 48.78784993341147],
                            [2.452667850183734, 48.78793337271654],
                            [2.452531655216379, 48.78801543763017],
                            [2.452403727400125, 48.78809749439961],
                            [2.452296455366897, 48.788175433825046],
                            [2.452178880040816, 48.788267038127294],
                            [2.452050995299157, 48.78836821049113],
                            [2.451949951669083, 48.78845979772167],
                            [2.451877774760019, 48.78852404608805],
                            [2.451760226680612, 48.788627938543165],
                            [2.450453177915302, 48.78997831034893],
                        ],
                    },
                },
                726: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.876525173157034, 2.484881107387862],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1461.41150809,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.481421258690829,
                            48.86991241918608,
                            2.48624016101661,
                            48.88230400665456,
                        ),
                        "coordinates": [
                            [2.481421258690829, 48.88230400665456],
                            [2.482002110276723, 48.88167667369007],
                            [2.482400360106924, 48.88124631151913],
                            [2.482536273619913, 48.881097757575006],
                            [2.482896410749996, 48.880692622043405],
                            [2.483300285140525, 48.880235879488275],
                            [2.483961905991979, 48.87950457051255],
                            [2.484256765404425, 48.879182977480575],
                            [2.484468884423603, 48.878940011218695],
                            [2.484702474556856, 48.878639910392906],
                            [2.484878905805151, 48.87839870704009],
                            [2.485048557720638, 48.87813859564237],
                            [2.485198031495068, 48.87788025697987],
                            [2.485346909474769, 48.87760313675325],
                            [2.485459426487179, 48.87738716326004],
                            [2.485547415677536, 48.877175718432],
                            [2.485670460790816, 48.876833832459134],
                            [2.485760458163955, 48.876568504929374],
                            [2.485814032566226, 48.876389983656146],
                            [2.485906886925282, 48.8760781686341],
                            [2.485963930603088, 48.87585443509884],
                            [2.486017418568939, 48.8756473624002],
                            [2.486070768650098, 48.875395081796675],
                            [2.486120447842253, 48.87512139221512],
                            [2.486184326312482, 48.874771543890645],
                            [2.486226431624454, 48.87437889660741],
                            [2.48624016101661, 48.87414570285082],
                            [2.486239460219678, 48.87391252805102],
                            [2.486227988061312, 48.87369602184562],
                            [2.48610475195852, 48.87229474845391],
                            [2.486056305620401, 48.87177611417295],
                            [2.486011674208813, 48.8713264762644],
                            [2.485916040919188, 48.870707970752974],
                            [2.485761140611789, 48.86991241918608],
                        ],
                    },
                },
                727: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.862011753167764, 2.486683183549044],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1774.87225707,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.485192413733974,
                            48.85426899363537,
                            2.489167460948015,
                            48.86991241918608,
                        ),
                        "coordinates": [
                            [2.485761140611789, 48.86991241918608],
                            [2.485403140820869, 48.86804852924353],
                            [2.485296894981928, 48.867494280596155],
                            [2.485237977223209, 48.86708748898079],
                            [2.485204566862315, 48.86676869949371],
                            [2.48519291070255, 48.86648795169036],
                            [2.485192413733974, 48.86632139865094],
                            [2.485195565335754, 48.866169116595756],
                            [2.485205832004424, 48.86598351428096],
                            [2.485219795221389, 48.86582883789328],
                            [2.485237338016089, 48.86566464035502],
                            [2.48525851491468, 48.86550995537428],
                            [2.485286891217929, 48.86535050159098],
                            [2.485322444662407, 48.86517914269481],
                            [2.48536163207203, 48.865017296347084],
                            [2.485400847911842, 48.864864966831185],
                            [2.485454390657542, 48.86467930842683],
                            [2.485511551502227, 48.86449840411123],
                            [2.485575917800938, 48.86431511060469],
                            [2.485650961964073, 48.86408421531657],
                            [2.485915670629444, 48.86336292829613],
                            [2.486530753394955, 48.861634717413814],
                            [2.487149450555291, 48.859923154078274],
                            [2.487764484693475, 48.858206834380155],
                            [2.488286436263018, 48.8567238098652],
                            [2.488872799812502, 48.85509079809266],
                            [2.489137306418753, 48.85435309723007],
                            [2.489167460948015, 48.85426899363537],
                        ],
                    },
                },
                728: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.70154162735394, 2.3012122730639697],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 995.409154433,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.294557747854634,
                            48.700680803710014,
                            2.307841188697314,
                            48.702239386903386,
                        ),
                        "coordinates": [
                            [2.294557747854634, 48.702239386903386],
                            [2.295489875003991, 48.702089552860656],
                            [2.295898527561079, 48.70203227798774],
                            [2.296358114075951, 48.701972960821195],
                            [2.296586380953354, 48.701945164839046],
                            [2.296854046292639, 48.70191828066241],
                            [2.297117635863831, 48.70189049667862],
                            [2.29756736559372, 48.7018456892334],
                            [2.297985843558901, 48.70180626575649],
                            [2.298310570775436, 48.70177490189755],
                            [2.298907024400513, 48.701733736261936],
                            [2.299234458578467, 48.70171496140827],
                            [2.299678736891328, 48.70168902912194],
                            [2.300484420980962, 48.70163443305752],
                            [2.301264285725748, 48.701585218414074],
                            [2.302133822148459, 48.70152523485462],
                            [2.302598483426814, 48.70148850477703],
                            [2.3028675061377, 48.7014635552391],
                            [2.30317048452421, 48.701433819443075],
                            [2.303522382329563, 48.70139615267292],
                            [2.303879717116014, 48.70135578937651],
                            [2.304517310762301, 48.70127737253189],
                            [2.305001995703076, 48.70121312327586],
                            [2.305304982701343, 48.70117363897072],
                            [2.305853897105987, 48.70109375407599],
                            [2.306136507669073, 48.70104976593277],
                            [2.306413686670377, 48.700998582096105],
                            [2.30664602908287, 48.70095547787793],
                            [2.30690826536132, 48.70090159125658],
                            [2.307300941549673, 48.70081536348481],
                            [2.307636554664625, 48.70073631387786],
                            [2.307841188697314, 48.700680803710014],
                        ],
                    },
                },
                729: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.53251645557031, 2.638670022197026],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2355.97399916,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.625522155066302,
                            48.5277977343036,
                            2.652441044420506,
                            48.538775256627815,
                        ),
                        "coordinates": [
                            [2.652441044420506, 48.5277977343036],
                            [2.651811198282233, 48.527929944006594],
                            [2.650964790072547, 48.528107648819606],
                            [2.649877643332884, 48.528326480112945],
                            [2.648970394125592, 48.5285196253129],
                            [2.648041592983785, 48.52873170790309],
                            [2.646964303886952, 48.52901612918054],
                            [2.646087244964201, 48.52927841262732],
                            [2.645104865128238, 48.52958985389654],
                            [2.644227958615014, 48.5298787821565],
                            [2.64308156242943, 48.530282957076125],
                            [2.642288253494157, 48.53060392470094],
                            [2.641480867215042, 48.530967751740775],
                            [2.640805811554372, 48.53129790876197],
                            [2.640173563304269, 48.5315993950506],
                            [2.639544829852352, 48.531891350354464],
                            [2.638498231610322, 48.53239617430495],
                            [2.638027283354891, 48.532624691505994],
                            [2.636290729471906, 48.53340715551677],
                            [2.635863317546536, 48.53358832560296],
                            [2.635274563263848, 48.533830618538126],
                            [2.634908946248339, 48.53397373548194],
                            [2.633888629708109, 48.53437365345555],
                            [2.632919252629083, 48.534741809195076],
                            [2.63187330765147, 48.53513902812013],
                            [2.631071995193906, 48.53546834053523],
                            [2.630307385170337, 48.535822459476606],
                            [2.629675126113145, 48.53615652577562],
                            [2.629127210173015, 48.536467967457895],
                            [2.628483252127347, 48.536853701990076],
                            [2.626960072940523, 48.537820721361946],
                            [2.625522155066302, 48.538775256627815],
                        ],
                    },
                },
                730: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.800711270491334, 2.634891262577311],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2539.14660211,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.619395781719303,
                            48.795654821412064,
                            2.65038766844115,
                            48.80577037511879,
                        ),
                        "coordinates": [
                            [2.619395781719303, 48.80577037511879],
                            [2.62033659854746, 48.80546362845502],
                            [2.621418866793547, 48.80511830671614],
                            [2.624032578818235, 48.80424805111126],
                            [2.62658189777989, 48.80342286165644],
                            [2.627735511136074, 48.8030467235935],
                            [2.62950461280818, 48.80246845608912],
                            [2.631356544562773, 48.80186117094648],
                            [2.633205707528341, 48.80125386191333],
                            [2.635982862887326, 48.80035812165081],
                            [2.638420196546505, 48.79956123480164],
                            [2.640854733538161, 48.798765202380544],
                            [2.643290547448431, 48.79796821457687],
                            [2.647533065612068, 48.79659072762],
                            [2.648570874623787, 48.796248865871185],
                            [2.64934378727576, 48.79599405234788],
                            [2.65038766844115, 48.795654821412064],
                        ],
                    },
                },
                731: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.83022547217457, 2.346959391064203],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 546.473357167,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.343511657749776,
                            48.82955605574841,
                            2.350414872010464,
                            48.831129548026645,
                        ),
                        "coordinates": [
                            [2.343511657749776, 48.831129548026645],
                            [2.345264121603792, 48.83064270532403],
                            [2.348224930879139, 48.829845095176246],
                            [2.348662493795602, 48.829727102384574],
                            [2.348931450694918, 48.82965153463511],
                            [2.349098044487036, 48.8296064573786],
                            [2.349242561128774, 48.829574636142475],
                            [2.349369016066424, 48.829560043798516],
                            [2.349479416929341, 48.82955605574841],
                            [2.34962996463348, 48.829566639918966],
                            [2.349748397961894, 48.82958650530671],
                            [2.349856799037626, 48.82961299748332],
                            [2.349923044223247, 48.829632868582216],
                            [2.350151894370042, 48.829707055045574],
                            [2.350414872010464, 48.82979051369296],
                        ],
                    },
                },
                732: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.832084879857426, 2.3594845412859646],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 556.144831519,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356121938797104,
                            48.8309272410005,
                            2.362856399519012,
                            48.833216719709846,
                        ),
                        "coordinates": [
                            [2.356121938797104, 48.8309272410005],
                            [2.356242740959475, 48.83096620451339],
                            [2.356358258423316, 48.83101162123166],
                            [2.356362490165701, 48.8310134517417],
                            [2.356480903626637, 48.83106265139008],
                            [2.356651575502041, 48.83112628094385],
                            [2.356712073934793, 48.83114690336898],
                            [2.357086752718896, 48.83127160845885],
                            [2.359293717022334, 48.8320290847024],
                            [2.36237988764187, 48.83305779985715],
                            [2.362856399519012, 48.833216719709846],
                        ],
                    },
                },
                733: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.84369032967814, 2.315144576551058],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 434.831049473,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.312447513065986,
                            48.84287127500633,
                            2.317852783041332,
                            48.84447014129586,
                        ),
                        "coordinates": [
                            [2.312447513065986, 48.84287127500633],
                            [2.312607051012364, 48.842920619092425],
                            [2.313311995961023, 48.843138650194796],
                            [2.315408668049834, 48.84377730788989],
                            [2.316994791744452, 48.844250898602056],
                            [2.317852783041332, 48.84447014129586],
                        ],
                    },
                },
                734: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.85569968061094, 2.2875775027214145],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 467.740802837,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.285812444146408,
                            48.85394260621378,
                            2.289334532778807,
                            48.8574486900758,
                        ),
                        "coordinates": [
                            [2.285812444146408, 48.8574486900758],
                            [2.28758710331801, 48.85569815212426],
                            [2.289334532778807, 48.85394260621378],
                        ],
                    },
                },
                735: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.92597657591952, 2.347894984251233],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1911.66686144,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345604378196291,
                            48.91756717658463,
                            2.350389537889768,
                            48.93445554506131,
                        ),
                        "coordinates": [
                            [2.350389537889768, 48.91756717658463],
                            [2.350342314076203, 48.91772961853044],
                            [2.350147572995856, 48.91853147990211],
                            [2.350032161666563, 48.9189835689119],
                            [2.349880647907257, 48.91944280003035],
                            [2.349725516327031, 48.9198877536472],
                            [2.34962876261022, 48.92012699342345],
                            [2.349377376763388, 48.92070151550807],
                            [2.349135603843973, 48.921220238976524],
                            [2.348994880841532, 48.921577155113006],
                            [2.348854186780369, 48.922060176981844],
                            [2.348768465522529, 48.92240132913136],
                            [2.348602377838885, 48.92310495920607],
                            [2.348377223838913, 48.92403258160752],
                            [2.348085590837943, 48.92511602811331],
                            [2.347753317643256, 48.92626277785316],
                            [2.347557632219622, 48.92690554426731],
                            [2.347432100906438, 48.92735109569436],
                            [2.34734718790273, 48.9276870841212],
                            [2.347243819834142, 48.92810828689276],
                            [2.347085068572845, 48.9287498309092],
                            [2.346824778539624, 48.929780925648814],
                            [2.346512776343114, 48.93097514614477],
                            [2.346221077323989, 48.93214258298946],
                            [2.345918274910239, 48.93328202093088],
                            [2.345604378196291, 48.93445554506131],
                        ],
                    },
                },
                736: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.87072904405946, 2.3138574075437206],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 722.195204492,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.31311086545987,
                            48.867602145221504,
                            2.314715787877462,
                            48.87376998959543,
                        ),
                        "coordinates": [
                            [2.313894130481615, 48.867602145221504],
                            [2.313888435201036, 48.86771504343545],
                            [2.31388193904531, 48.867799734463226],
                            [2.313867650203792, 48.867985988884094],
                            [2.313852160255969, 48.86810610931151],
                            [2.313826052448716, 48.8682320910427],
                            [2.313789087515332, 48.86836511893382],
                            [2.313740642368179, 48.868507468341114],
                            [2.313689100414522, 48.86863951594361],
                            [2.313626163096676, 48.86878633195912],
                            [2.313382538854067, 48.86930993255665],
                            [2.313291001373269, 48.86951877481587],
                            [2.313246800298191, 48.86963000754128],
                            [2.313209608887596, 48.86973349573756],
                            [2.313178708262747, 48.86983124082556],
                            [2.31315377690772, 48.86992426352067],
                            [2.313130803742065, 48.87003450638842],
                            [2.31311653270808, 48.870139657630936],
                            [2.31311086545987, 48.870240459546125],
                            [2.313113776501159, 48.87033740213211],
                            [2.313125299743219, 48.8704310188944],
                            [2.313145472616665, 48.87052147282715],
                            [2.313174357264304, 48.87060901699865],
                            [2.313212015187481, 48.87069384961144],
                            [2.31413589715911, 48.87174311608866],
                            [2.314582890945368, 48.87237920914802],
                            [2.314629515095839, 48.87245026242021],
                            [2.31466705235438, 48.872525377232506],
                            [2.314694075928008, 48.87260243017232],
                            [2.314710367790594, 48.8726807877611],
                            [2.314715787877462, 48.87275979717874],
                            [2.314710297027049, 48.872838804381274],
                            [2.314709563142658, 48.872843912037304],
                            [2.314467989568736, 48.87368521063635],
                            [2.31445603617697, 48.87376998959543],
                        ],
                    },
                },
                737: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.921614381160495, 2.374410385257585],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1880.72628955,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362665598830465,
                            48.9181138030661,
                            2.386388291064694,
                            48.92435387966092,
                        ),
                        "coordinates": [
                            [2.362665598830465, 48.9181138030661],
                            [2.363478143656108, 48.91855141330591],
                            [2.36405306968269, 48.918812641663706],
                            [2.36451170589102, 48.91899959963967],
                            [2.365139271643608, 48.9192362595873],
                            [2.365832607695872, 48.91949305336527],
                            [2.366612598408511, 48.91974506184772],
                            [2.36714514342469, 48.919891589139716],
                            [2.367702052962826, 48.92003153025176],
                            [2.369381165336558, 48.92044744485632],
                            [2.374833951750855, 48.921787697589636],
                            [2.379077229578892, 48.9228450042737],
                            [2.381294626002303, 48.92338188875586],
                            [2.381998846325951, 48.92353864835505],
                            [2.382645281011191, 48.923676390866945],
                            [2.383505430681238, 48.92384717430447],
                            [2.384730442788796, 48.92406508965816],
                            [2.386215731473625, 48.924325531484065],
                            [2.386388291064694, 48.92435387966092],
                        ],
                    },
                },
                738: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.87455493971564, 2.3873463893450135],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 337.879852514,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.385316215101792,
                            48.87388185415816,
                            2.389415032035528,
                            48.87511181695599,
                        ),
                        "coordinates": [
                            [2.385316215101792, 48.87388185415816],
                            [2.385370479970393, 48.873902101612806],
                            [2.385560102381248, 48.873981193948865],
                            [2.385743611588691, 48.87406632870779],
                            [2.385920571049807, 48.87415729952792],
                            [2.38595565953379, 48.87417646446263],
                            [2.386301077486567, 48.87434194066266],
                            [2.386363562499587, 48.87437948171358],
                            [2.386469784208579, 48.87443528213954],
                            [2.386582546263036, 48.87448518577764],
                            [2.386701102696688, 48.874528859632385],
                            [2.386824659309511, 48.87456601363128],
                            [2.386952396812668, 48.87459640344174],
                            [2.387083465482964, 48.87461982145114],
                            [2.387216990405727, 48.87463611478046],
                            [2.387352085225885, 48.87464517546241],
                            [2.387487852128542, 48.87464694224015],
                            [2.387556847502658, 48.87464503703159],
                            [2.387933512269206, 48.87466557075438],
                            [2.387952065928689, 48.87466784650275],
                            [2.388139021233736, 48.87469483974398],
                            [2.388323306112195, 48.87472889050274],
                            [2.388504312486073, 48.874769888663515],
                            [2.388681438052141, 48.87481769626428],
                            [2.388854094354817, 48.874872156530806],
                            [2.389021708233122, 48.87493308668917],
                            [2.389126534326161, 48.87497557915087],
                            [2.389389486798256, 48.87509975430826],
                            [2.389415032035528, 48.87511181695599],
                        ],
                    },
                },
                739: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.91577432979234, 2.338609090914488],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 1090.45330158,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.333924890479715,
                            48.911964897880885,
                            2.343305929159434,
                            48.919573073151824,
                        ),
                        "coordinates": [
                            [2.333924890479715, 48.911964897880885],
                            [2.334008448012597, 48.91206150201879],
                            [2.334101318271287, 48.912154337596455],
                            [2.334203113315469, 48.91224301573478],
                            [2.334313402671717, 48.912327165303815],
                            [2.334384938278545, 48.91237630884501],
                            [2.336177340425487, 48.91380735381973],
                            [2.336650473977627, 48.91418508216692],
                            [2.337086580272143, 48.91453561544542],
                            [2.342330995102701, 48.91878394083584],
                            [2.343305929159434, 48.919573073151824],
                        ],
                    },
                },
                740: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.891686890332686, 2.4962094717582097],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2467.88253877,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.479793329961401,
                            48.88907659470566,
                            2.512566821462173,
                            48.89401251501928,
                        ),
                        "coordinates": [
                            [2.479793329961401, 48.89401251501928],
                            [2.481197722405834, 48.893804725496125],
                            [2.482784825989295, 48.89358618952957],
                            [2.486294326270926, 48.89306533586322],
                            [2.489865193721433, 48.892576412576965],
                            [2.49315463000745, 48.8921163153306],
                            [2.496267288843588, 48.89168611101783],
                            [2.499755003990543, 48.891207702729695],
                            [2.501755019254608, 48.89093049383821],
                            [2.506235894697583, 48.89031483248706],
                            [2.50687858796131, 48.89022644904722],
                            [2.50855849299117, 48.88998777777983],
                            [2.508957648940871, 48.88992236626066],
                            [2.509392246574917, 48.88985137720946],
                            [2.509862766838769, 48.889763963817956],
                            [2.510292260577928, 48.88967870192147],
                            [2.510730698786668, 48.88958666904331],
                            [2.511151789939301, 48.889487047296036],
                            [2.511647841755376, 48.88936256437549],
                            [2.512112092573541, 48.88922480279171],
                            [2.512566821462173, 48.88907659470566],
                        ],
                    },
                },
                741: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.886415433638916, 2.5190042434335185],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1115.16191874,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.512566821462173,
                            48.88373428097723,
                            2.525434250765843,
                            48.88907659470566,
                        ),
                        "coordinates": [
                            [2.512566821462173, 48.88907659470566],
                            [2.512998832387353, 48.888924515379514],
                            [2.51336355369073, 48.888784347605245],
                            [2.514432503756536, 48.88834352057677],
                            [2.515351998005951, 48.88794826774535],
                            [2.517499182084499, 48.88705597118021],
                            [2.521107305737947, 48.885521719400764],
                            [2.52210153410764, 48.885103250811575],
                            [2.525434250765843, 48.88373428097723],
                        ],
                    },
                },
                742: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.87563212896821, 2.5681045470920836],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2258.39682042,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.552881649780832,
                            48.87414408301457,
                            2.583331158055108,
                            48.877157839702775,
                        ),
                        "coordinates": [
                            [2.552881649780832, 48.877157839702775],
                            [2.556435116941477, 48.8767984829346],
                            [2.570329594400424, 48.87539282571081],
                            [2.583331158055108, 48.87414408301457],
                        ],
                    },
                },
                743: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.903477647148335, 2.3607179345501166],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 1405.42124788,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358874539761223,
                            48.897245288093046,
                            2.365920319400959,
                            48.90656714598029,
                        ),
                        "coordinates": [
                            [2.359507868815594, 48.897245288093046],
                            [2.359393901115884, 48.89839295328538],
                            [2.358931659124667, 48.90304725192177],
                            [2.358876653912763, 48.903659537612434],
                            [2.358874539761223, 48.90401527072913],
                            [2.358884468849992, 48.9041074817506],
                            [2.358905127747048, 48.90422324291277],
                            [2.35894332027041, 48.904365722019605],
                            [2.359001871377624, 48.9045217745373],
                            [2.359070887108022, 48.90466334743078],
                            [2.359153874956335, 48.90480162170363],
                            [2.359250474037543, 48.90493600005313],
                            [2.359369734738461, 48.90507622002897],
                            [2.3595002851132, 48.90520721754912],
                            [2.35965202713586, 48.90533815193673],
                            [2.359822048466119, 48.9054643572103],
                            [2.359960913696003, 48.9055546994168],
                            [2.360164656911964, 48.90566771700894],
                            [2.360400650494299, 48.90578367183097],
                            [2.360634989666246, 48.90587768946059],
                            [2.360833854026208, 48.90594263238679],
                            [2.361030408881043, 48.90599904798938],
                            [2.36126691835574, 48.90605467359872],
                            [2.361512950095505, 48.906101779070895],
                            [2.361883325385529, 48.90614950155433],
                            [2.362344160004368, 48.90619838615801],
                            [2.365920319400959, 48.90656714598029],
                        ],
                    },
                },
                744: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.946460846311155, 2.345551039937488],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 376.773111705,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.343251343552804,
                            48.94555553922783,
                            2.347440773814149,
                            48.94698706127986,
                        ),
                        "coordinates": [
                            [2.343251343552804, 48.94698706127986],
                            [2.344344606934788, 48.94676851039621],
                            [2.344907401520615, 48.946654522795484],
                            [2.345292227771014, 48.946559548073935],
                            [2.345609832805901, 48.94646706039627],
                            [2.34660947465429, 48.94625694446812],
                            [2.34716145909295, 48.946140033059315],
                            [2.34718336779928, 48.946134478824675],
                            [2.347204406836592, 48.94612816175886],
                            [2.347224565891754, 48.94612114205785],
                            [2.347243834618056, 48.94611348261514],
                            [2.347262201303641, 48.9461052463169],
                            [2.347279655624592, 48.94609649425814],
                            [2.347296187246051, 48.94608728843322],
                            [2.347311785810629, 48.94607769263485],
                            [2.347326439640791, 48.946067767051396],
                            [2.347340139755882, 48.9460575745838],
                            [2.347352874445038, 48.946047178118064],
                            [2.347364633384963, 48.946036638749206],
                            [2.347375406241362, 48.94602601847143],
                            [2.347385181303621, 48.94601538017071],
                            [2.34739394960258, 48.94600478584861],
                            [2.347401699438916, 48.94599429749189],
                            [2.347413427073591, 48.9459758056313],
                            [2.347422793615133, 48.945957682210135],
                            [2.347429985734801, 48.945939957021984],
                            [2.347435191502564, 48.94592265717011],
                            [2.347438600308023, 48.945905813361904],
                            [2.347440398855276, 48.94588945269295],
                            [2.347440773814149, 48.94587360495642],
                            [2.347439915961243, 48.9458582990684],
                            [2.347438010623131, 48.94584356301614],
                            [2.347435247210418, 48.94582942570828],
                            [2.347431813768436, 48.945815916046065],
                            [2.347427895600383, 48.94580306381509],
                            [2.347423684869059, 48.9457908961405],
                            [2.347419365512218, 48.945779442800486],
                            [2.347415126939196, 48.94576873270382],
                            [2.347411157205657, 48.94575879385258],
                            [2.347312925167514, 48.94555553922783],
                        ],
                    },
                },
                745: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78267316047241, 2.227912004414311],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 575.74336597,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.225280295281189,
                            48.78192762199101,
                            2.230983558938873,
                            48.78353933276511,
                        ),
                        "coordinates": [
                            [2.225280295281189, 48.78353933276511],
                            [2.225506029340988, 48.78317907713057],
                            [2.225914620837527, 48.78262962846797],
                            [2.226237492991995, 48.78222621386814],
                            [2.226325095508345, 48.78214682149328],
                            [2.226385170198153, 48.7821074469591],
                            [2.226446994388014, 48.782071881087184],
                            [2.22651052415313, 48.78204014967408],
                            [2.226575704643051, 48.7820122811438],
                            [2.226642493402687, 48.78198829410693],
                            [2.226710791875572, 48.781968227497735],
                            [2.226780511219013, 48.78195210772154],
                            [2.226851528556176, 48.78193996186287],
                            [2.226924935211534, 48.78193171243485],
                            [2.226999329563727, 48.78192762199101],
                            [2.227074458242067, 48.78192770687882],
                            [2.227149917072941, 48.78193196538194],
                            [2.227226396679616, 48.78194054227635],
                            [2.227301621048641, 48.78195328343011],
                            [2.227374701026329, 48.781970126431936],
                            [2.22743745087748, 48.781989187130755],
                            [2.227621725996419, 48.78205716609673],
                            [2.22789088936169, 48.78216742121082],
                            [2.228216989595515, 48.78232373419276],
                            [2.228308420073816, 48.78237477518864],
                            [2.228711340804205, 48.78259631167837],
                            [2.229202478727115, 48.782891711627364],
                            [2.229519875429502, 48.78305272449647],
                            [2.229704136307834, 48.78313196801819],
                            [2.229949488927253, 48.78322302674857],
                            [2.230200089668296, 48.783296985680074],
                            [2.230983558938873, 48.783500975704136],
                        ],
                    },
                },
                746: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.43036962537994, 2.145997616833984],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 729.354631061,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.144428010315732,
                            48.42736258418355,
                            2.149101178683954,
                            48.43222560109566,
                        ),
                        "coordinates": [
                            [2.149101178683954, 48.43222560109566],
                            [2.14843893449645, 48.43202094667984],
                            [2.147486715825734, 48.43170635300949],
                            [2.146234166359035, 48.43125166350922],
                            [2.145993668239178, 48.43114688014556],
                            [2.145758118318193, 48.43103798792152],
                            [2.145563334408602, 48.43092914677682],
                            [2.145434944526419, 48.43084613146194],
                            [2.145308716061275, 48.4307588373365],
                            [2.145176128104334, 48.430651545661576],
                            [2.145007254958966, 48.43049708416356],
                            [2.144753142248362, 48.43019543988386],
                            [2.144633833450861, 48.42998253199227],
                            [2.144555094174176, 48.42981822909702],
                            [2.14449347316116, 48.42966537670236],
                            [2.144455388048322, 48.42952826677235],
                            [2.144428010315732, 48.42939545809034],
                            [2.144428945779243, 48.42915134819845],
                            [2.144477098032969, 48.428900179660104],
                            [2.144537917697532, 48.42870185326943],
                            [2.144639558250449, 48.42848646602372],
                            [2.144762713816887, 48.42825398391233],
                            [2.144872908557404, 48.428044320747304],
                            [2.145246592903116, 48.42736258418355],
                        ],
                    },
                },
                747: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78850312721716, 2.258954277642736],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 766.907373471,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.254502152039991,
                            48.78671618223311,
                            2.263389166015155,
                            48.79033300192819,
                        ),
                        "coordinates": [
                            [2.254502152039991, 48.78671618223311],
                            [2.254846947551883, 48.7868534819221],
                            [2.256090269514041, 48.78732648064166],
                            [2.257074323522094, 48.787719543223886],
                            [2.258197818672654, 48.78818485516211],
                            [2.259461088964046, 48.78869956841772],
                            [2.260857477331442, 48.789276487198045],
                            [2.262724209511419, 48.79006047049547],
                            [2.263389166015155, 48.79033300192819],
                        ],
                    },
                },
                748: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.95572448019186, 2.298900729140075],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 489.110219332,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.295591694903069,
                            48.9555044771186,
                            2.302222741813793,
                            48.95584304745806,
                        ),
                        "coordinates": [
                            [2.295591694903069, 48.9555044771186],
                            [2.296056340196676, 48.955609994040664],
                            [2.296257445983467, 48.955646864109255],
                            [2.296553985124074, 48.95568001142898],
                            [2.296807423226072, 48.95569434690431],
                            [2.297518306726579, 48.95570565153995],
                            [2.298942145345972, 48.95573539961563],
                            [2.300871005032745, 48.955770930867004],
                            [2.301356534465423, 48.95577518901054],
                            [2.301709589149372, 48.95579723206327],
                            [2.302222741813793, 48.95584304745806],
                        ],
                    },
                },
                749: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.95441759832187, 2.3133867552826954],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 416.579786729,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.311526308692633,
                            48.95316824676445,
                            2.315403612112168,
                            48.95587687488741,
                        ),
                        "coordinates": [
                            [2.311526308692633, 48.95587687488741],
                            [2.311746362156541, 48.955660972718725],
                            [2.312300073784309, 48.955118057874316],
                            [2.312743600913763, 48.95474623143322],
                            [2.313065272159672, 48.954518231137456],
                            [2.313176648615538, 48.954456054892006],
                            [2.315166667748353, 48.95330108790927],
                            [2.315403612112168, 48.95316824676445],
                        ],
                    },
                },
                750: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.95082242242213, 2.3245241696036745],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 661.05078463,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.320216521669494,
                            48.94993773565708,
                            2.328832171353944,
                            48.951708783590085,
                        ),
                        "coordinates": [
                            [2.320216521669494, 48.951708783590085],
                            [2.320514275314754, 48.951648370193595],
                            [2.32156198814164, 48.95142445944038],
                            [2.324063532603471, 48.950914659280016],
                            [2.327667529326848, 48.95018378613135],
                            [2.328832171353944, 48.94993773565708],
                        ],
                    },
                },
                751: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.8266656737584, 2.310018080646005],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 520.718530799,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.306656073914123,
                            48.82592054607216,
                            2.313380087377887,
                            48.82741080144464,
                        ),
                        "coordinates": [
                            [2.306656073914123, 48.82741080144464],
                            [2.313380087377887, 48.82592054607216],
                        ],
                    },
                },
                752: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.74414247683922, 2.352752769963859],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 668.831486368,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351800049626334,
                            48.741684493136425,
                            2.353468670624079,
                            48.74656858663953,
                        ),
                        "coordinates": [
                            [2.352795381310017, 48.741684493136425],
                            [2.352621305168711, 48.74200807436784],
                            [2.352594727450052, 48.74206218908865],
                            [2.352588959087819, 48.74208013855375],
                            [2.352586170836494, 48.74209793958101],
                            [2.352586076885385, 48.742115500676555],
                            [2.352588390085876, 48.74213272854014],
                            [2.352592825997267, 48.74214953078552],
                            [2.352599098818588, 48.742165815019085],
                            [2.35260692274846, 48.74218148884707],
                            [2.352616012006993, 48.74219645807703],
                            [2.352626080758456, 48.74221063301351],
                            [2.352636841873359, 48.74222391855732],
                            [2.352648012256806, 48.742236223229185],
                            [2.352659303385333, 48.74224745462095],
                            [2.352670432174541, 48.74225752035407],
                            [2.352681111471254, 48.74226632712861],
                            [2.352691054099677, 48.74227378344351],
                            [2.352699976997167, 48.74227979512172],
                            [2.352811631525395, 48.742328947813355],
                            [2.353106057751575, 48.74243763373231],
                            [2.353147928230579, 48.74245550674263],
                            [2.353183039559438, 48.742474824499],
                            [2.353211833519598, 48.742495383428526],
                            [2.353234749227903, 48.74251697544526],
                            [2.353252225756441, 48.742539396059556],
                            [2.353264702188038, 48.742562439881304],
                            [2.353272620336699, 48.742585900634886],
                            [2.353276417914897, 48.74260957382076],
                            [2.353276536748674, 48.742633252262856],
                            [2.353273413192069, 48.74265673145336],
                            [2.353267490421628, 48.74267980512231],
                            [2.353259206152948, 48.74270226876897],
                            [2.353249000867197, 48.74272391430972],
                            [2.35323731497968, 48.74274453905741],
                            [2.353224586253705, 48.74276393491381],
                            [2.353211255117878, 48.74278189829263],
                            [2.351851834981521, 48.74430723804985],
                            [2.351833080560964, 48.744338247877586],
                            [2.351818526648952, 48.744369189662805],
                            [2.351808172096142, 48.74439993747902],
                            [2.351802014382114, 48.744430366291525],
                            [2.351800049626334, 48.744460351057604],
                            [2.35180227394818, 48.74448976673425],
                            [2.351808686186727, 48.74451848829272],
                            [2.351819282460489, 48.744546390689145],
                            [2.35183406161874, 48.74457334799452],
                            [2.351853017059256, 48.74459923514931],
                            [2.351876150338866, 48.74462392713788],
                            [2.351903454842514, 48.7446472997992],
                            [2.351934929427716, 48.7446692263032],
                            [2.351970571557681, 48.74468958251018],
                            [2.35201037735662, 48.74470824247382],
                            [2.352054344285488, 48.74472508205355],
                            [2.352913807870971, 48.74505957950873],
                            [2.353115754109186, 48.74514063491436],
                            [2.353229343476557, 48.74520835927514],
                            [2.353291280135744, 48.74526295346229],
                            [2.353367833479243, 48.7453576077588],
                            [2.353409844664734, 48.745452074038205],
                            [2.353468670624079, 48.74575795457817],
                            [2.353465432706535, 48.74584503692272],
                            [2.353436412817855, 48.74592198418229],
                            [2.353338256613354, 48.74604393909092],
                            [2.35287534133574, 48.74656858663953],
                        ],
                    },
                },
                753: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.721883875995495, 2.370709019406022],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 1739.75526394,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368264128619581,
                            48.71451272529017,
                            2.372662875036854,
                            48.72955072266277,
                        ),
                        "coordinates": [
                            [2.371747143464364, 48.71451272529017],
                            [2.372558249211176, 48.71521139972783],
                            [2.372625632380759, 48.71529028776452],
                            [2.372657126558265, 48.715363038042256],
                            [2.372662875036854, 48.71548324971863],
                            [2.372484131317532, 48.71599278340732],
                            [2.372229274408236, 48.716700630304324],
                            [2.372054504851846, 48.71717805597676],
                            [2.371888936526229, 48.717637680780165],
                            [2.371862990037206, 48.7177017988655],
                            [2.371805902372483, 48.7178133505814],
                            [2.37174176588454, 48.71791296530757],
                            [2.371666898194067, 48.71800776445034],
                            [2.371572134891433, 48.71811197683875],
                            [2.371397278212881, 48.71829668256702],
                            [2.371300716926105, 48.71840088614785],
                            [2.371218553051045, 48.71850397552347],
                            [2.371167245990424, 48.71858342867106],
                            [2.371084379774368, 48.718744819831926],
                            [2.37103360872259, 48.71892898886712],
                            [2.371011766252735, 48.719100220522336],
                            [2.370995856279661, 48.71937619651393],
                            [2.370965173853159, 48.71998288807879],
                            [2.370788829600129, 48.72304872381179],
                            [2.370753064170782, 48.72333663336679],
                            [2.370606026148048, 48.72393150835329],
                            [2.370365514592978, 48.724576377018835],
                            [2.368264128619581, 48.72955072266277],
                        ],
                    },
                },
                754: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.132272564662394, 2.497950740042826],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1736.16476318,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.490178985421196,
                            49.12678094198271,
                            2.506143689252232,
                            49.13828637527201,
                        ),
                        "coordinates": [
                            [2.490178985421196, 49.13828637527201],
                            [2.490349291561337, 49.13809403642042],
                            [2.490996953887674, 49.13739531446677],
                            [2.491242397352285, 49.13714515520918],
                            [2.491953530408366, 49.1364580011712],
                            [2.492361045727361, 49.136089368274625],
                            [2.492918001003793, 49.13562060039208],
                            [2.493404151972852, 49.13524019941674],
                            [2.493791562554617, 49.13494154196967],
                            [2.494196757930338, 49.13464951961561],
                            [2.494642485778367, 49.1343341248341],
                            [2.495402343475325, 49.13383008963637],
                            [2.497071506114415, 49.13274185163363],
                            [2.498489816409119, 49.131805504662964],
                            [2.499872647718742, 49.13090083560325],
                            [2.501379539620796, 49.12992102235472],
                            [2.502731858205192, 49.129031350774675],
                            [2.504165156232819, 49.12808658330806],
                            [2.50511726379409, 49.12745395682368],
                            [2.505884114233885, 49.12695040939013],
                            [2.506143689252232, 49.12678094198271],
                        ],
                    },
                },
                755: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.73147579688002, 2.3705740597144715],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 729.831309096,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368097171511247,
                            48.72955072266277,
                            2.372299520904232,
                            48.73408816211109,
                        ),
                        "coordinates": [
                            [2.368264128619581, 48.72955072266277],
                            [2.368116924606354, 48.729959055650625],
                            [2.368102865227689, 48.7300071188825],
                            [2.368097171511247, 48.73005710085383],
                            [2.368099629262048, 48.7301085021362],
                            [2.368110022937293, 48.73016082239312],
                            [2.368128138353491, 48.73021356129373],
                            [2.368153758584919, 48.73026622029028],
                            [2.368186672175297, 48.73031829816452],
                            [2.368226662216529, 48.73036929456768],
                            [2.36827351312453, 48.730418711855506],
                            [2.368327012084924, 48.730466047900414],
                            [2.368386944886625, 48.73051080326503],
                            [2.368453093224626, 48.730552479389296],
                            [2.368525245629366, 48.730590574151066],
                            [2.368603186492826, 48.73062458990316],
                            [2.368686700255072, 48.73065402450125],
                            [2.368775572654854, 48.73067838030488],
                            [2.369226652543437, 48.73075962505876],
                            [2.369686359499327, 48.73083229962793],
                            [2.370206490709541, 48.73090067258128],
                            [2.371949003850754, 48.731232601437554],
                            [2.372050136579072, 48.73125883527463],
                            [2.372153221111227, 48.73130221378706],
                            [2.37221954497628, 48.73135111126959],
                            [2.372255722403326, 48.73139413777388],
                            [2.372278984239589, 48.731434240594496],
                            [2.372295701812431, 48.73148002049158],
                            [2.372299520904232, 48.731521448482056],
                            [2.372281173281796, 48.73161130852375],
                            [2.372172239358762, 48.731874892752394],
                            [2.371869764578157, 48.73260262501928],
                            [2.371250376223923, 48.73408816211109],
                        ],
                    },
                },
                756: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.89774509584506, 2.387198109649301],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1943.41763871,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37412297552969,
                            48.89667381116845,
                            2.400361703159176,
                            48.898112306280396,
                        ),
                        "coordinates": [
                            [2.37412297552969, 48.89667381116845],
                            [2.374818930611102, 48.896865708299686],
                            [2.375445584326413, 48.89702902838996],
                            [2.375900379373193, 48.89714783915272],
                            [2.376293810477423, 48.89724763452135],
                            [2.376658360513129, 48.89732840342263],
                            [2.377022904332032, 48.89740203420142],
                            [2.377362172688801, 48.8974566387352],
                            [2.377878289584649, 48.897532591757866],
                            [2.378289728606982, 48.89758002777298],
                            [2.378683120433279, 48.89762033249879],
                            [2.379152292562753, 48.89765584784654],
                            [2.37957454059956, 48.89767948292994],
                            [2.380108662674742, 48.897705452903956],
                            [2.381418698487198, 48.89775728944898],
                            [2.382472507283918, 48.89780207738675],
                            [2.382992194458232, 48.89782328181689],
                            [2.383591271275544, 48.897842069683506],
                            [2.384064042196673, 48.89786090918635],
                            [2.384442970317296, 48.8978655095026],
                            [2.384789418078747, 48.89786774294937],
                            [2.387925444273986, 48.89784733806379],
                            [2.388820421101058, 48.89784217277669],
                            [2.389628789129359, 48.897839420144976],
                            [2.390422717423798, 48.89783191032933],
                            [2.391483710550859, 48.89783854166949],
                            [2.394341940227716, 48.89789185470043],
                            [2.39740225604469, 48.89793309172566],
                            [2.397979671764541, 48.89793991938611],
                            [2.398355011671776, 48.89795875222289],
                            [2.398683432624051, 48.89797522863239],
                            [2.399051570105814, 48.89800595970357],
                            [2.400361703159176, 48.898112306280396],
                        ],
                    },
                },
                757: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89774509584506, 2.387198109649301],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1943.41763871,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37412297552969,
                            48.89667381116845,
                            2.400361703159176,
                            48.898112306280396,
                        ),
                        "coordinates": [
                            [2.37412297552969, 48.89667381116845],
                            [2.374818930611102, 48.896865708299686],
                            [2.375445584326413, 48.89702902838996],
                            [2.375900379373193, 48.89714783915272],
                            [2.376293810477423, 48.89724763452135],
                            [2.376658360513129, 48.89732840342263],
                            [2.377022904332032, 48.89740203420142],
                            [2.377362172688801, 48.8974566387352],
                            [2.377878289584649, 48.897532591757866],
                            [2.378289728606982, 48.89758002777298],
                            [2.378683120433279, 48.89762033249879],
                            [2.379152292562753, 48.89765584784654],
                            [2.37957454059956, 48.89767948292994],
                            [2.380108662674742, 48.897705452903956],
                            [2.381418698487198, 48.89775728944898],
                            [2.382472507283918, 48.89780207738675],
                            [2.382992194458232, 48.89782328181689],
                            [2.383591271275544, 48.897842069683506],
                            [2.384064042196673, 48.89786090918635],
                            [2.384442970317296, 48.8978655095026],
                            [2.384789418078747, 48.89786774294937],
                            [2.387925444273986, 48.89784733806379],
                            [2.388820421101058, 48.89784217277669],
                            [2.389628789129359, 48.897839420144976],
                            [2.390422717423798, 48.89783191032933],
                            [2.391483710550859, 48.89783854166949],
                            [2.394341940227716, 48.89789185470043],
                            [2.39740225604469, 48.89793309172566],
                            [2.397979671764541, 48.89793991938611],
                            [2.398355011671776, 48.89795875222289],
                            [2.398683432624051, 48.89797522863239],
                            [2.399051570105814, 48.89800595970357],
                            [2.400361703159176, 48.898112306280396],
                        ],
                    },
                },
                758: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.97226529581088, 2.3662002825221293],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 312.453364861,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.366003889114339,
                            48.97088340423817,
                            2.366338086327771,
                            48.97366053367439,
                        ),
                        "coordinates": [
                            [2.366054619001163, 48.97366053367439],
                            [2.366097746583938, 48.97344846861068],
                            [2.366151430701664, 48.9731953588977],
                            [2.366215641287352, 48.972894124509814],
                            [2.366289452017645, 48.972546544617124],
                            [2.366324173297078, 48.97236649775393],
                            [2.366338086327771, 48.97218872034775],
                            [2.366325791956662, 48.972011398860786],
                            [2.366289074362396, 48.97183632773102],
                            [2.36621102650234, 48.97156824586038],
                            [2.366052972496796, 48.971044562956976],
                            [2.366003889114339, 48.97088340423817],
                        ],
                    },
                },
                759: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.74828427274209, 2.3532825866969596],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 458.704211944,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352325890857491,
                            48.74656858663953,
                            2.354367279157914,
                            48.750174036206914,
                        ),
                        "coordinates": [
                            [2.35287534133574, 48.74656858663953],
                            [2.352506751186235, 48.74697983621254],
                            [2.352406110749745, 48.7470863802119],
                            [2.352377512231219, 48.74712906083758],
                            [2.352346560574356, 48.74718743557816],
                            [2.352328739809292, 48.747231602057894],
                            [2.352325890857491, 48.74728727350972],
                            [2.352350488184088, 48.74739306840625],
                            [2.352390605103832, 48.747466107190284],
                            [2.352488379511292, 48.747590861515626],
                            [2.352594718204044, 48.747721373610766],
                            [2.352705888702956, 48.74781050348258],
                            [2.352828191500607, 48.74787256384844],
                            [2.353277301803636, 48.74804634096684],
                            [2.353420982448037, 48.74812565077382],
                            [2.353506319069232, 48.74820892943341],
                            [2.353574046627406, 48.74831924061475],
                            [2.353671879403322, 48.7486139094937],
                            [2.353959210868517, 48.74947360691502],
                            [2.354032817008859, 48.749632497465896],
                            [2.354104602112217, 48.749764249311504],
                            [2.354261301831485, 48.750013543485885],
                            [2.354367279157914, 48.750174036206914],
                        ],
                    },
                },
                760: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.95042276187964, 2.35772197492978],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 494.061815122,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35746152627313,
                            48.94820812758011,
                            2.357978331080607,
                            48.95263788257678,
                        ),
                        "coordinates": [
                            [2.357978331080607, 48.95263788257678],
                            [2.357954248302418, 48.952423137943306],
                            [2.357907232741731, 48.952017448528416],
                            [2.357772773374525, 48.950852760303675],
                            [2.357678692613753, 48.95004613863043],
                            [2.357482621640219, 48.94837193930814],
                            [2.35746152627313, 48.94820812758011],
                        ],
                    },
                },
                761: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.97890088358145, 2.382626801743036],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 364.370642576,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.380204254325136,
                            48.9785246242919,
                            2.385049192009276,
                            48.97927612626855,
                        ),
                        "coordinates": [
                            [2.385049192009276, 48.9785246242919],
                            [2.384796871470337, 48.978564232779256],
                            [2.380396640156688, 48.9792469063249],
                            [2.380204254325136, 48.97927612626855],
                        ],
                    },
                },
                762: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.019346630068554, 1.6061956471845904],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 6084.48648559,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.581532102335019,
                            48.99739200091919,
                            1.63016762729846,
                            49.03894771561846,
                        ),
                        "coordinates": [
                            [1.63016762729846, 48.99739200091919],
                            [1.629615692017885, 48.997560837011484],
                            [1.629460504632378, 48.99761293770859],
                            [1.628593555301599, 48.99791173604998],
                            [1.627811844925676, 48.99820670406024],
                            [1.627051447103467, 48.998527972797795],
                            [1.626590581322135, 48.99873908518356],
                            [1.625833792703765, 48.99909141201894],
                            [1.624705919394252, 48.99968064198069],
                            [1.623875953985121, 49.00017729075291],
                            [1.623064757456155, 49.00069833229609],
                            [1.622288690439635, 49.001246566472055],
                            [1.621762115174275, 49.00164886765004],
                            [1.621161612675615, 49.0021504294707],
                            [1.620626207879674, 49.002597733912765],
                            [1.62019127016299, 49.00299430655519],
                            [1.619274705909445, 49.00389507108065],
                            [1.618877743323862, 49.00431076202242],
                            [1.618826428898806, 49.00436170069768],
                            [1.61876533818036, 49.00442696746323],
                            [1.617979797419733, 49.005244008365665],
                            [1.616819444509274, 49.00645348575051],
                            [1.615903376863251, 49.007405487999655],
                            [1.615853395871856, 49.0074582321737],
                            [1.615784030318514, 49.00752794171759],
                            [1.615416186179481, 49.007911429165254],
                            [1.614883064429518, 49.008472836913484],
                            [1.614460649988764, 49.00894141134471],
                            [1.614116641390115, 49.009376306620545],
                            [1.613716072504004, 49.00993944518545],
                            [1.612246992817986, 49.012052534321796],
                            [1.612090623412661, 49.01227457501104],
                            [1.611697670786939, 49.01287462592438],
                            [1.611476254545599, 49.01324374063732],
                            [1.611259054096735, 49.01360478717779],
                            [1.610957338419534, 49.01404173977259],
                            [1.610508517641199, 49.01462704438992],
                            [1.610494609991183, 49.01464314325722],
                            [1.610173086730092, 49.01503140489684],
                            [1.609101422182481, 49.016317810261654],
                            [1.608888430987631, 49.016576358383375],
                            [1.60834145057359, 49.01723207585954],
                            [1.608317758696369, 49.01726250150898],
                            [1.607870972987262, 49.01779834678812],
                            [1.60743113219538, 49.01832613999689],
                            [1.607244629524408, 49.0185488806476],
                            [1.607195864303764, 49.018610622852194],
                            [1.607159694354645, 49.0186526603572],
                            [1.607112348797088, 49.01871081359914],
                            [1.6070567067536, 49.0187752098984],
                            [1.60702189051834, 49.01881815519702],
                            [1.606928617176198, 49.01893087349594],
                            [1.606208332707137, 49.01974465529506],
                            [1.606052603434265, 49.01991992689994],
                            [1.605847956882135, 49.02016683069421],
                            [1.605726855871133, 49.020311746176425],
                            [1.605522206202155, 49.02055865022237],
                            [1.60489716127549, 49.02130918033011],
                            [1.60471481793337, 49.02152654747718],
                            [1.604260971283995, 49.02207222626804],
                            [1.604079950089932, 49.022292299401016],
                            [1.603655322379698, 49.022803088918664],
                            [1.603385256245901, 49.023126011369136],
                            [1.602626468474463, 49.02403844871774],
                            [1.602148917490556, 49.02461184590749],
                            [1.601075428533441, 49.025900865404694],
                            [1.600234392771734, 49.026912582232974],
                            [1.600109077139743, 49.027062860749005],
                            [1.59887813610613, 49.02854060299173],
                            [1.597534301366289, 49.03015519836505],
                            [1.595833825220453, 49.032199142506805],
                            [1.595299011081934, 49.0328413896036],
                            [1.593914566486216, 49.03450334490145],
                            [1.593839351155919, 49.034593687952174],
                            [1.59382262945704, 49.03461426361393],
                            [1.59339638389231, 49.03512770478363],
                            [1.593308615812961, 49.035234152840665],
                            [1.592990420852731, 49.03559079461748],
                            [1.592495485444969, 49.03609519244363],
                            [1.592073905054099, 49.036480675782855],
                            [1.591888497856948, 49.036621561973774],
                            [1.591625767104305, 49.03681050776459],
                            [1.591186573572399, 49.037090933978995],
                            [1.591135453970383, 49.03712477525534],
                            [1.591089872044565, 49.03715415523627],
                            [1.591025074916945, 49.03718790794046],
                            [1.590200486537125, 49.03762679694639],
                            [1.589762549291128, 49.037812807503855],
                            [1.589204173200386, 49.03804076380119],
                            [1.588571185036308, 49.038272665428934],
                            [1.587880403683471, 49.03846358777291],
                            [1.587189533526433, 49.038640444370174],
                            [1.586528302021865, 49.038766515443584],
                            [1.586413165277728, 49.0387819495076],
                            [1.585577184505887, 49.0388852866932],
                            [1.584968189887681, 49.03892915752503],
                            [1.58421529283523, 49.03894771561846],
                            [1.583631096623415, 49.0389471491973],
                            [1.583427382428863, 49.038940413527115],
                            [1.583145734183793, 49.038931365929116],
                            [1.582244135991481, 49.03885168604373],
                            [1.582147148993589, 49.03884295350847],
                            [1.582072045693136, 49.038834365064766],
                            [1.581756641855026, 49.03879631297051],
                            [1.581532102335019, 49.0387620447533],
                        ],
                    },
                },
                763: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.82806042094254, 2.387282999198636],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 1054.36701498,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.381166157724425,
                            48.82556915500199,
                            2.393449698306368,
                            48.83038859059281,
                        ),
                        "coordinates": [
                            [2.381166157724425, 48.82556915500199],
                            [2.381554968712785, 48.82569749775247],
                            [2.383059246549121, 48.8261962911258],
                            [2.383746708979513, 48.82642470761166],
                            [2.383974508947365, 48.82651392623816],
                            [2.384352713244623, 48.826684825432245],
                            [2.384795325150025, 48.82689531772844],
                            [2.386128378297761, 48.827544657451405],
                            [2.386968655980597, 48.82795944700966],
                            [2.388307253383034, 48.82860165166759],
                            [2.388791231112168, 48.82882185825152],
                            [2.389770415277593, 48.82922781922213],
                            [2.390263638155271, 48.8294290307783],
                            [2.391251883567401, 48.82983264574828],
                            [2.391644898526697, 48.8299738507837],
                            [2.392077837175763, 48.830091461935965],
                            [2.392485100385279, 48.830184225526146],
                            [2.393069930290754, 48.83030843510403],
                            [2.393449698306368, 48.83038859059281],
                        ],
                    },
                },
                764: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.899711959422206, 2.2398777297019676],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 682.310288436,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.239539059703579,
                            48.896664397218075,
                            2.240119005281564,
                            48.90276840056811,
                        ),
                        "coordinates": [
                            [2.240079252038273, 48.896664397218075],
                            [2.240021752340487, 48.89705508967944],
                            [2.240006605561989, 48.897147182028526],
                            [2.239998401457595, 48.89721470737861],
                            [2.239995784462297, 48.89729511779874],
                            [2.239999232577905, 48.8973555782097],
                            [2.24001066853312, 48.89741275819259],
                            [2.240096010200701, 48.89764839247532],
                            [2.240113004393371, 48.89772036029325],
                            [2.240119005281564, 48.89780368072824],
                            [2.240104826899041, 48.897934462003015],
                            [2.240062261245733, 48.898229723015895],
                            [2.24002292985501, 48.89850121003117],
                            [2.239941522935237, 48.899034172182084],
                            [2.239906146845589, 48.89930663555752],
                            [2.23986663650968, 48.89956550985925],
                            [2.239852174372578, 48.899740309376604],
                            [2.239862862659373, 48.89989813631106],
                            [2.239879953324192, 48.8999881882945],
                            [2.239902031655614, 48.90010754052198],
                            [2.23990458098366, 48.900155383812795],
                            [2.239889983319141, 48.900339462534575],
                            [2.239626421556993, 48.90214951983436],
                            [2.239595660060533, 48.90237757510363],
                            [2.239539059703579, 48.90276840056811],
                        ],
                    },
                },
                765: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.831083358075176, 2.284421807812614],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 525.030659838,
                    },
                    "geometry": {
                        "type": "LineString",
                        "coordinates": [
                            [2.284521215631707, 48.83053433130243],
                            [2.284699947997562, 48.830463063364896],
                            [2.28472763282205, 48.83045276286844],
                            [2.284760191811853, 48.830443453850215],
                            [2.284793974791838, 48.83043617934272],
                            [2.284828580677662, 48.83043098191541],
                            [2.284862971400352, 48.83042796328599],
                            [2.284897455907047, 48.83042704525713],
                            [2.284931847538549, 48.830428230310254],
                            [2.284966031891229, 48.83043151686205],
                            [2.284999347183158, 48.830436785835786],
                            [2.285032301140417, 48.83044406634935],
                            [2.285064835391852, 48.830453343664004],
                            [2.285096906487828, 48.83046460762711],
                            [2.285128467015663, 48.83047783906859],
                            [2.285159496669614, 48.83049302887365],
                            [2.285219863271789, 48.83052923171299],
                            [2.286905195187981, 48.83166838501062],
                            [2.287207137822909, 48.83187246749725],
                        ],
                        "bbox": (
                            2.284521215631707,
                            48.83042704525713,
                            2.287207137822909,
                            48.83187246749725,
                        ),
                    },
                },
                766: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.89427844899489, 2.239107258770925],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 585.83824593,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.237213536457713,
                            48.89212336383249,
                            2.240324139541801,
                            48.896664526224924,
                        ),
                        "coordinates": [
                            [2.237213536457713, 48.89212336383249],
                            [2.237294777438664, 48.89224112926534],
                            [2.237409431844714, 48.892398801312076],
                            [2.237549407499594, 48.892585256637396],
                            [2.237704932269371, 48.89278747533295],
                            [2.237863133011169, 48.892988844754925],
                            [2.238019633560556, 48.893183919465216],
                            [2.238168601703382, 48.89336543263433],
                            [2.238306494088, 48.893529075540755],
                            [2.238472126639319, 48.893690766849375],
                            [2.238664313407516, 48.89387258290913],
                            [2.23867390193557, 48.89387994195131],
                            [2.238758997226112, 48.893950182073574],
                            [2.240066980639349, 48.89468166930425],
                            [2.240252396861969, 48.894835133173316],
                            [2.240321975794533, 48.89497358506309],
                            [2.240324139541801, 48.8950230916839],
                            [2.240318726207366, 48.89509729713089],
                            [2.240307206451638, 48.89519430774331],
                            [2.240136594340738, 48.896273962603594],
                            [2.240079173771374, 48.896664526224924],
                        ],
                    },
                },
                767: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.83433942379566, 2.2740502622028296],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 446.679718551,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.271241500937831,
                            48.833365343840185,
                            2.276712090531075,
                            48.834750010355144,
                        ),
                        "coordinates": [
                            [2.276712090531075, 48.833365343840185],
                            [2.276567355033138, 48.833422941514804],
                            [2.276350040571193, 48.83349801280861],
                            [2.276212046229431, 48.833545721711744],
                            [2.276077066080099, 48.833604251119],
                            [2.27598779767453, 48.83365287433989],
                            [2.275832789195283, 48.83375759026091],
                            [2.275586090117633, 48.83392385895518],
                            [2.275386331954293, 48.83405828667107],
                            [2.275158548144472, 48.83418611905798],
                            [2.274889822755882, 48.834302994825414],
                            [2.274661590733933, 48.83438513519567],
                            [2.274454149631713, 48.834440902912256],
                            [2.273585524255225, 48.83462489369209],
                            [2.273196365304441, 48.834692490303894],
                            [2.27300490543493, 48.834713724817455],
                            [2.272768736973572, 48.83472701281981],
                            [2.272551267760715, 48.834734970157854],
                            [2.272215546787288, 48.83473945373925],
                            [2.271827028581843, 48.83474421574629],
                            [2.271241500937831, 48.834750010355144],
                        ],
                    },
                },
                768: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93476526666103, 2.324146393929253],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 390.497174091,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32149519817071,
                            48.93460856766366,
                            2.326793312266221,
                            48.93497582668586,
                        ),
                        "coordinates": [
                            [2.32149519817071, 48.93460856766366],
                            [2.321898755590141, 48.93463150653894],
                            [2.322321245272388, 48.93465331997726],
                            [2.322772724280024, 48.93467800079941],
                            [2.323377942842823, 48.93471139876611],
                            [2.323811005146459, 48.93473597079644],
                            [2.3240849139641, 48.93475179209192],
                            [2.324695577867892, 48.93478307379373],
                            [2.325145856412024, 48.93481701776602],
                            [2.325708695825687, 48.934860159108005],
                            [2.326230265400371, 48.93491091749302],
                            [2.326793312266221, 48.93497582668586],
                        ],
                    },
                },
                769: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.91239592003089, 2.2317575515347308],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 485.066263941,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.229571613274198,
                            48.91080258974541,
                            2.233988601425483,
                            48.91404768156708,
                        ),
                        "coordinates": [
                            [2.233988601425483, 48.91080258974541],
                            [2.233581858476612, 48.91109111021132],
                            [2.232410415090217, 48.91191958199613],
                            [2.230417453557094, 48.913339234128024],
                            [2.230287241217624, 48.91344284516438],
                            [2.229963747965308, 48.913713213450656],
                            [2.229571613274198, 48.91404768156708],
                        ],
                    },
                },
                770: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93368053035783, 2.3101118496587327],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 446.061579731,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307089653527023,
                            48.93344984077206,
                            2.313132640491603,
                            48.933932029779314,
                        ),
                        "coordinates": [
                            [2.307089653527023, 48.93344984077206],
                            [2.308029358706468, 48.93350357111898],
                            [2.308571972028544, 48.93354477346668],
                            [2.309001816736196, 48.93359293662458],
                            [2.310978798060116, 48.93375088822732],
                            [2.312574801919959, 48.933879974707466],
                            [2.313132640491603, 48.933932029779314],
                        ],
                    },
                },
                771: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.8985434787872, 2.36634422369441],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 395.033517228,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.363651382181137,
                            48.89849110155687,
                            2.369036949316923,
                            48.89860117217836,
                        ),
                        "coordinates": [
                            [2.369036949316923, 48.89860117217836],
                            [2.368621315236188, 48.89859112979621],
                            [2.36815807031003, 48.89857869352628],
                            [2.364044801641717, 48.898497674399266],
                            [2.363651382181137, 48.89849110155687],
                        ],
                    },
                },
                772: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.11517623165698, 2.5197203171049836],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 3599.69716977,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.506143689252232,
                            49.0995869391937,
                            2.526463637892827,
                            49.12678094198271,
                        ),
                        "coordinates": [
                            [2.506143689252232, 49.12678094198271],
                            [2.506887269943709, 49.12629547418165],
                            [2.508340625409566, 49.12532564128292],
                            [2.509634446989854, 49.124470951804845],
                            [2.511214322296226, 49.12342760786834],
                            [2.512465000584569, 49.122599600305705],
                            [2.513930812480357, 49.12162634632489],
                            [2.515670038799358, 49.12049109172255],
                            [2.517100498349076, 49.11959946301517],
                            [2.517941025838817, 49.119088903520534],
                            [2.520143645099111, 49.11774584787595],
                            [2.520780156790105, 49.1173522399332],
                            [2.52132264408256, 49.11702064411832],
                            [2.521684242075068, 49.11678450879804],
                            [2.522089138284026, 49.11649595770762],
                            [2.522378323654706, 49.11628372954367],
                            [2.522580736919733, 49.11613112653699],
                            [2.52276864883617, 49.11597854476354],
                            [2.522949320549317, 49.11582835439004],
                            [2.523176949593234, 49.115635259646076],
                            [2.523375652520484, 49.115461246002],
                            [2.523603242564199, 49.11525863307339],
                            [2.523816324006448, 49.115053664100394],
                            [2.524022162121535, 49.114851085581996],
                            [2.524209940831935, 49.11466519122262],
                            [2.524412089379553, 49.11444596367849],
                            [2.524621421038634, 49.11421006750092],
                            [2.52483071475988, 49.11396465448349],
                            [2.52502911450683, 49.11371449923568],
                            [2.525259881365917, 49.1133976694584],
                            [2.5253715972193, 49.11322855340959],
                            [2.52553010370472, 49.11297370549167],
                            [2.525659722755146, 49.1127474559007],
                            [2.525828909298395, 49.112442623428734],
                            [2.525958244250419, 49.11214261381345],
                            [2.526065939293247, 49.11187119258258],
                            [2.52613764378801, 49.11166645209505],
                            [2.526234344817988, 49.11136411774319],
                            [2.526309355078754, 49.11107609454382],
                            [2.526373399017927, 49.11076429571217],
                            [2.526440941102093, 49.11017668404954],
                            [2.526461537942227, 49.1098768537888],
                            [2.526463637892827, 49.10947950185519],
                            [2.526440497787389, 49.10911550228004],
                            [2.526406074523773, 49.10864445161508],
                            [2.526296737503929, 49.10753824191231],
                            [2.526184610458316, 49.10638838262464],
                            [2.526007358679905, 49.10457800199242],
                            [2.525852517039498, 49.10293889586863],
                            [2.525716722902096, 49.101540070052955],
                            [2.525531713992054, 49.0995869391937],
                        ],
                    },
                },
                773: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T11",
                        "rer": 0,
                        "extcode": "800:T11",
                        "geo_point_2d": [48.95859931022009, 2.3786383683018917],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01999",
                        "navette": 0,
                        "idrefliga": "A02225",
                        "shape_leng": 1986.48159188,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.365842107661724,
                            48.95492900449691,
                            2.390955086162519,
                            48.96016288691666,
                        ),
                        "coordinates": [
                            [2.390955086162519, 48.95492900449691],
                            [2.390146363134674, 48.95511166962726],
                            [2.390124699834392, 48.95511710071828],
                            [2.390093089344261, 48.95512551263386],
                            [2.390052177506772, 48.95513679174698],
                            [2.390002610172692, 48.95515082352994],
                            [2.389945033190964, 48.955167493454205],
                            [2.389880092409523, 48.95518668699069],
                            [2.389808432299384, 48.95520829050264],
                            [2.389730700062306, 48.955232190367376],
                            [2.389647540200875, 48.95525827025149],
                            [2.389559598541703, 48.9552864174263],
                            [2.389467520933358, 48.955316517365986],
                            [2.389371953214953, 48.955348456445435],
                            [2.389273539893852, 48.95538211833665],
                            [2.389172929533057, 48.955417390331284],
                            [2.389070765246779, 48.955454158795945],
                            [2.388967692914039, 48.95549230741566],
                            [2.388868634141028, 48.95553006903565],
                            [2.388769963573675, 48.95556871383318],
                            [2.388672339725113, 48.955607864776965],
                            [2.388576419747471, 48.95564714483103],
                            [2.388482866238801, 48.95568617878771],
                            [2.388392334995225, 48.95572458960811],
                            [2.388305485914066, 48.955762000276046],
                            [2.388222980251295, 48.955798034683234],
                            [2.388145473804829, 48.95583231669493],
                            [2.388073627847911, 48.95586446930616],
                            [2.388008102290867, 48.9558941155059],
                            [2.387949552938854, 48.95592087916205],
                            [2.387898642425173, 48.95594438417732],
                            [2.387856026566331, 48.955964253520285],
                            [2.387822368005058, 48.95598011019359],
                            [2.387798322533611, 48.95599157896223],
                            [2.386941278511445, 48.95639948550269],
                            [2.385045339482162, 48.95735749155884],
                            [2.383554691822718, 48.95814095746315],
                            [2.382859735899469, 48.958473460291124],
                            [2.382202029441812, 48.95871097823078],
                            [2.381417971316556, 48.958938918290194],
                            [2.380797587126076, 48.959075500577825],
                            [2.380032644422419, 48.95921430709747],
                            [2.379177409753562, 48.959349666530414],
                            [2.378779270759728, 48.959407087254654],
                            [2.378367724235961, 48.95945253989039],
                            [2.377960870708116, 48.95948314613104],
                            [2.377102249089167, 48.959523300507094],
                            [2.375972473746779, 48.95957690906042],
                            [2.372539900217033, 48.95995158279298],
                            [2.371463946042102, 48.96003517190025],
                            [2.369530217273084, 48.960087476936],
                            [2.365842107661724, 48.96016288691666],
                        ],
                    },
                },
                774: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T11",
                        "rer": 0,
                        "extcode": "800:T11",
                        "geo_point_2d": [48.93650004327459, 2.4170696558304643],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01999",
                        "navette": 0,
                        "idrefliga": "A02225",
                        "shape_leng": 1771.37118918,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.41147348701014,
                            48.93020617892931,
                            2.423464552379919,
                            48.94363000666017,
                        ),
                        "coordinates": [
                            [2.423464552379919, 48.93020617892931],
                            [2.422556282871514, 48.931136829433584],
                            [2.422020741650734, 48.9315589632826],
                            [2.421448187038244, 48.931898828466615],
                            [2.419252611451424, 48.933023162662664],
                            [2.418685399886802, 48.93336660949523],
                            [2.418013544803232, 48.93386301332707],
                            [2.417438021220705, 48.93446338341526],
                            [2.417085501243685, 48.93498274801824],
                            [2.415847302187557, 48.93766776370495],
                            [2.414817373145691, 48.93964711300736],
                            [2.414070901483805, 48.94098541491317],
                            [2.413630857198859, 48.94157214952884],
                            [2.41313177100425, 48.942108627666514],
                            [2.41251865960112, 48.94266595826349],
                            [2.41147348701014, 48.94363000666017],
                        ],
                    },
                },
                775: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.95782917967823, 2.342094513233926],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 338.469648641,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.341727785380489,
                            48.9566718460312,
                            2.34310923572538,
                            48.959318144169146,
                        ),
                        "coordinates": [
                            [2.34310923572538, 48.9566718460312],
                            [2.342854981003604, 48.9568206838871],
                            [2.342021230129807, 48.95732350174329],
                            [2.342004207380675, 48.95733598190994],
                            [2.341988620207863, 48.95734778560842],
                            [2.341974363960235, 48.957358981508776],
                            [2.341961331289834, 48.95736963556819],
                            [2.341949418933388, 48.95737981466559],
                            [2.341938520873551, 48.95738958746321],
                            [2.341928531127232, 48.95739901992551],
                            [2.341919343699691, 48.957408178916225],
                            [2.341910853961237, 48.95741713130641],
                            [2.341902955905666, 48.95742594485891],
                            [2.341895543537625, 48.9574346864372],
                            [2.341888512215868, 48.95744342381155],
                            [2.341881757321906, 48.957452222953634],
                            [2.341875170129355, 48.95746115071198],
                            [2.341868648727355, 48.95747027487161],
                            [2.341862084378132, 48.95747966318019],
                            [2.34185186558136, 48.95749510599136],
                            [2.341842699259053, 48.95751036303421],
                            [2.341834525968358, 48.95752538362366],
                            [2.341827283546634, 48.957540116160324],
                            [2.341820912585046, 48.957554507261435],
                            [2.341815352263851, 48.95756850713347],
                            [2.341810540442943, 48.957582062378656],
                            [2.341806419033233, 48.95759512321835],
                            [2.341802924529146, 48.95760763624718],
                            [2.341799997487295, 48.95761955077994],
                            [2.341797577121472, 48.95763081432532],
                            [2.341795603988126, 48.95764137619808],
                            [2.341794015935482, 48.95765118389945],
                            [2.34179275216561, 48.95766018583741],
                            [2.341791751869334, 48.957668331319134],
                            [2.341790955636972, 48.95767556696166],
                            [2.34173672849128, 48.95853420285839],
                            [2.341727785380489, 48.958669775075855],
                            [2.341735417682894, 48.958780455710254],
                            [2.341766969565322, 48.95885676723059],
                            [2.342053801387074, 48.959318144169146],
                        ],
                    },
                },
                776: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T11",
                        "rer": 0,
                        "extcode": "800:T11",
                        "geo_point_2d": [48.96034670584997, 2.35462757454456],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01999",
                        "navette": 0,
                        "idrefliga": "A02225",
                        "shape_leng": 1647.69788814,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.343414543882292,
                            48.96003376394423,
                            2.365842107661724,
                            48.96064592922915,
                        ),
                        "coordinates": [
                            [2.365842107661724, 48.96016288691666],
                            [2.365152234397057, 48.96017713457],
                            [2.363979464718209, 48.9601985191772],
                            [2.362656624878208, 48.96022956491416],
                            [2.359149100845658, 48.96044404297449],
                            [2.355974125639671, 48.96064592922915],
                            [2.354839563206529, 48.96064458927774],
                            [2.353474414823587, 48.960589650246256],
                            [2.350485235425912, 48.96037839262421],
                            [2.346568050397516, 48.96012060741652],
                            [2.343414543882292, 48.96003376394423],
                        ],
                    },
                },
                777: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.1612641882742, 2.4723459696047416],
                        "indice_lig": "D",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 5972.03303925,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.459520081112193,
                            49.13828637527201,
                            2.490178985421196,
                            49.1873335365493,
                        ),
                        "coordinates": [
                            [2.459520081112193, 49.1873335365493],
                            [2.461836468528622, 49.1801828036466],
                            [2.467035849576074, 49.16706500976759],
                            [2.469862503286604, 49.16035541205852],
                            [2.470996521965048, 49.15817425749942],
                            [2.472832002408762, 49.15601757063088],
                            [2.47890791783622, 49.150525112054396],
                            [2.48286309441142, 49.14666464133141],
                            [2.485386608474283, 49.143733606577776],
                            [2.488861887593484, 49.13978485710428],
                            [2.490178985421196, 49.13828637527201],
                        ],
                    },
                },
                778: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.04104047317543, 2.4900424224678406],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2498.23681611,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.478033365115083,
                            49.033182769031264,
                            2.501758065846462,
                            49.049325600885666,
                        ),
                        "coordinates": [
                            [2.501758065846462, 49.049325600885666],
                            [2.499468515941002, 49.047639242234766],
                            [2.498165910202896, 49.04667982477075],
                            [2.494537561781734, 49.043948620000975],
                            [2.492890514043921, 49.0427374052095],
                            [2.492306454832931, 49.04230991613465],
                            [2.491983598212982, 49.042074797289295],
                            [2.491555584413875, 49.041775577332004],
                            [2.490191988374697, 49.04088991134044],
                            [2.485895009227335, 49.03816646514511],
                            [2.483313414919215, 49.036528040503256],
                            [2.48072112443948, 49.03488481347117],
                            [2.478033365115083, 49.033182769031264],
                        ],
                    },
                },
                779: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.918559045836986, 2.189066380171806],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 678.061753092,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.185353376302864,
                            48.91674629011933,
                            2.192783100891459,
                            48.920379373924355,
                        ),
                        "coordinates": [
                            [2.185353376302864, 48.920379373924355],
                            [2.186145208575256, 48.9200021067702],
                            [2.186767090397931, 48.919707886644076],
                            [2.188218351335855, 48.9189764806864],
                            [2.191073467000742, 48.917556762960395],
                            [2.192783100891459, 48.91674629011933],
                        ],
                    },
                },
                780: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.046150180136536, 2.0981522761291633],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 446.377365123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.095195067225969,
                            49.04564873988319,
                            2.101108482966614,
                            49.04664576264113,
                        ),
                        "coordinates": [
                            [2.101108482966614, 49.04564873988319],
                            [2.099538274275683, 49.04593526764531],
                            [2.096377570034755, 49.04643086426444],
                            [2.095195067225969, 49.04664576264113],
                        ],
                    },
                },
                781: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.045431012009466, 2.1031051862686283],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 295.647988421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.101108482966614,
                            49.045311648350264,
                            2.105110703444507,
                            49.04564873988319,
                        ),
                        "coordinates": [
                            [2.105110703444507, 49.045311648350264],
                            [2.104628215681291, 49.04532047996179],
                            [2.104374559147197, 49.04533000897707],
                            [2.104086670840201, 49.04534147623432],
                            [2.103441731027953, 49.045386363089136],
                            [2.10270505892091, 49.04544511964608],
                            [2.102295453480011, 49.045478428084046],
                            [2.101824629861494, 49.0455337048508],
                            [2.101108482966614, 49.04564873988319],
                        ],
                    },
                },
                782: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.882311770777534, 2.3991846007773066],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 810.798149363,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.396751288803897,
                            48.87947036907198,
                            2.401221761278451,
                            48.885016789193514,
                        ),
                        "coordinates": [
                            [2.401221761278451, 48.87947036907198],
                            [2.401026746180397, 48.87971447031913],
                            [2.400814502488197, 48.87997515041987],
                            [2.400477879269675, 48.88038463866222],
                            [2.400253888267231, 48.880662390994985],
                            [2.400218686004642, 48.8807117082178],
                            [2.40017912175685, 48.880763858038684],
                            [2.400155452978393, 48.880814184511436],
                            [2.400138998332189, 48.88086454712416],
                            [2.40012833856728, 48.88091303489299],
                            [2.400127823315973, 48.880957766637906],
                            [2.400134324933624, 48.881019665718796],
                            [2.400143867909581, 48.881068254707024],
                            [2.400174890477141, 48.88113122812543],
                            [2.400200382616618, 48.88117323479766],
                            [2.400247300999013, 48.88123438395212],
                            [2.400335804771336, 48.88131858518375],
                            [2.400585476827601, 48.881568251977015],
                            [2.400613843728868, 48.88161122442224],
                            [2.400646453527912, 48.881661832696494],
                            [2.400670383245433, 48.88171430048184],
                            [2.400689982509947, 48.881766747481535],
                            [2.400702367513648, 48.88181915746382],
                            [2.400710467211753, 48.88186773914355],
                            [2.400711429263386, 48.88190962288383],
                            [2.400707797954063, 48.88197432651461],
                            [2.400698515371334, 48.882028531898314],
                            [2.400680497785096, 48.88208935665971],
                            [2.400662775903536, 48.88212448375482],
                            [2.40064204694408, 48.88217006574585],
                            [2.400600962724345, 48.88222887113726],
                            [2.400565836423481, 48.882271525670156],
                            [2.400530742932034, 48.88231132499589],
                            [2.400488444592208, 48.882350136745785],
                            [2.400411271687925, 48.882409712833656],
                            [2.400338549710938, 48.88245884121192],
                            [2.400255734830412, 48.8825069683985],
                            [2.400164284713447, 48.882553147491286],
                            [2.400088840174404, 48.88258798527763],
                            [2.399984446028951, 48.88263029252546],
                            [2.399901840296107, 48.8826603359712],
                            [2.399787409282607, 48.882696882019786],
                            [2.39971937617944, 48.88271462547229],
                            [2.399636901835308, 48.8827332470583],
                            [2.399564572344656, 48.88274811351947],
                            [2.399469143187475, 48.88276381466048],
                            [2.399356386144491, 48.88278038118114],
                            [2.39901396110198, 48.882814830974574],
                            [2.398723572755701, 48.88284192654626],
                            [2.398386863748851, 48.88288116248613],
                            [2.398263994053962, 48.88289862864983],
                            [2.398120776418467, 48.882928366218025],
                            [2.398019453629302, 48.882954506525074],
                            [2.39789776215483, 48.88299482200643],
                            [2.397820904489655, 48.88302679589523],
                            [2.397748397969909, 48.88305688864889],
                            [2.397694674316547, 48.88308517197859],
                            [2.397626419822034, 48.88312194825137],
                            [2.397569710330571, 48.8831587825765],
                            [2.397511523735129, 48.88319846479911],
                            [2.397440163456399, 48.883254261355184],
                            [2.397365773226125, 48.883322415533904],
                            [2.39731019755461, 48.88338590514541],
                            [2.397269218764842, 48.883435192323766],
                            [2.39721045877319, 48.8835243640709],
                            [2.397186818922283, 48.88357183463953],
                            [2.397157196415435, 48.883637358707794],
                            [2.397103680395594, 48.88377224340269],
                            [2.397082848494181, 48.883826390280056],
                            [2.396889238788797, 48.88434413938648],
                            [2.396845701462653, 48.88448954318752],
                            [2.396809258685827, 48.8846454526306],
                            [2.396785550057359, 48.88478436871638],
                            [2.396751288803897, 48.885016789193514],
                        ],
                    },
                },
                783: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.83752944780615, 2.407997625467399],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 515.30219429,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.406657147135102,
                            48.8355222083493,
                            2.408866513853417,
                            48.839839993228985,
                        ),
                        "coordinates": [
                            [2.406657147135102, 48.8355222083493],
                            [2.406762986552121, 48.835602823424296],
                            [2.406943236775721, 48.83575957960477],
                            [2.407391082434134, 48.8361585918683],
                            [2.407522172951762, 48.83628000498941],
                            [2.40767540745567, 48.83643543537401],
                            [2.407736774011866, 48.83650712613804],
                            [2.407785416115642, 48.83658827271766],
                            [2.407836553094708, 48.836687873045435],
                            [2.407869063497726, 48.83676120519883],
                            [2.40793984486925, 48.83695608489635],
                            [2.408031166205846, 48.83724684460603],
                            [2.408178406159755, 48.83769255213402],
                            [2.408365487555025, 48.83828063453528],
                            [2.408577002642193, 48.838939630276236],
                            [2.408713653285395, 48.83936624731438],
                            [2.40877223696773, 48.8395486932446],
                            [2.408866513853417, 48.839839993228985],
                        ],
                    },
                },
                784: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.83699752458114, 2.2746171971042783],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 555.566371433,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.271174403433847,
                            48.836122980192656,
                            2.278119178310992,
                            48.83807589055981,
                        ),
                        "coordinates": [
                            [2.271174403433847, 48.83807589055981],
                            [2.271471421873426, 48.83795806607422],
                            [2.271854194428046, 48.83781849528561],
                            [2.27265571510813, 48.837532352200384],
                            [2.272907832099508, 48.837448207872725],
                            [2.274056255354431, 48.83708565535805],
                            [2.274634944143773, 48.83692140388902],
                            [2.275056030623676, 48.83681731604956],
                            [2.275549470136647, 48.836702797817885],
                            [2.276768560757034, 48.83642085257669],
                            [2.277057752761983, 48.836357074153646],
                            [2.278119178310992, 48.836122980192656],
                        ],
                    },
                },
                785: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.820784227403415, 2.3670392217814755],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 499.93847583,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.364015464906326,
                            48.81976126758558,
                            2.370053603529677,
                            48.821829558069034,
                        ),
                        "coordinates": [
                            [2.364015464906326, 48.81976126758558],
                            [2.364670560653662, 48.8199768291984],
                            [2.365135003808477, 48.82015895693301],
                            [2.366009838275289, 48.82044974680701],
                            [2.369008553961367, 48.82141856364925],
                            [2.369147332969275, 48.82147497816834],
                            [2.369367683311084, 48.82158036755864],
                            [2.369473046490057, 48.821628752986754],
                            [2.36959786773494, 48.82167724180059],
                            [2.369742666241439, 48.821727619241905],
                            [2.370053603529677, 48.821829558069034],
                        ],
                    },
                },
                786: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.84180652559532, 2.409498881436827],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 446.839015732,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.408866850400784,
                            48.8398410732243,
                            2.41013203807822,
                            48.84377178668507,
                        ),
                        "coordinates": [
                            [2.408866850400784, 48.8398410732243],
                            [2.408961463532976, 48.84013345304594],
                            [2.408990940465171, 48.84022482609911],
                            [2.409072692607223, 48.840504017837006],
                            [2.409116067986305, 48.84061902358804],
                            [2.409201591222205, 48.840881891512055],
                            [2.409757792032256, 48.842608387234954],
                            [2.409885244920176, 48.84300521252215],
                            [2.410037719462863, 48.843484968283505],
                            [2.41013203807822, 48.84377178668507],
                        ],
                    },
                },
                787: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.94651577152034, 2.35721975761406],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 378.469775041,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.357006356470642,
                            48.94481893267206,
                            2.35746152627313,
                            48.94820812758011,
                        ),
                        "coordinates": [
                            [2.35746152627313, 48.94820812758011],
                            [2.357440431038929, 48.94804431582343],
                            [2.357391873195714, 48.94764718274553],
                            [2.357341965120256, 48.9473594904494],
                            [2.357310355882964, 48.94722798172479],
                            [2.357271888065291, 48.94706693184905],
                            [2.35725193248556, 48.94692787137822],
                            [2.357183974764757, 48.94634694839582],
                            [2.357148893235475, 48.94602888024295],
                            [2.357074291183238, 48.94540128542991],
                            [2.357025892930138, 48.944991777990765],
                            [2.357006356470642, 48.94481893267206],
                        ],
                    },
                },
                788: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.82804481674768, 2.303744235787404],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 447.079817363,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.300851826132675,
                            48.82741485955381,
                            2.306635926501743,
                            48.82867193954727,
                        ),
                        "coordinates": [
                            [2.300851826132675, 48.82867193954727],
                            [2.301160011950779, 48.828605297189036],
                            [2.301546445814918, 48.82852301936385],
                            [2.303078160948289, 48.828190480788116],
                            [2.303793017906206, 48.82803045114209],
                            [2.304690378343459, 48.827833087550246],
                            [2.3053409321726, 48.82770461172973],
                            [2.305695054613472, 48.82762923701785],
                            [2.306256549549628, 48.827498516834844],
                            [2.306635926501743, 48.82741485955381],
                        ],
                    },
                },
                789: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93351326070264, 2.2982593199339814],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 343.184767406,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.295922020386378,
                            48.933393832020336,
                            2.300593399375418,
                            48.933568568710506,
                        ),
                        "coordinates": [
                            [2.300593399375418, 48.933393832020336],
                            [2.300174722028336, 48.933428981999114],
                            [2.299487756744538, 48.93348778423118],
                            [2.29918841845792, 48.933510780054114],
                            [2.298581640260254, 48.933514844657026],
                            [2.297906819030016, 48.9335299277196],
                            [2.296963200597572, 48.93355785605126],
                            [2.296382380165145, 48.933560009605],
                            [2.295922020386378, 48.933568568710506],
                        ],
                    },
                },
                790: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.820929690651475, 2.3359603464061807],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 405.813854664,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.333339832857646,
                            48.82035003419019,
                            2.338580749640995,
                            48.82150891739615,
                        ),
                        "coordinates": [
                            [2.333339832857646, 48.82150891739615],
                            [2.333670105995028, 48.82143555739824],
                            [2.333961408350485, 48.82137040213487],
                            [2.334611172328499, 48.8212274356708],
                            [2.337657070239516, 48.82055480374672],
                            [2.338094169196779, 48.82046098487686],
                            [2.338580749640995, 48.82035003419019],
                        ],
                    },
                },
                791: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.940535838703596, 2.3565393794273333],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 354.402593261,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356321867421057,
                            48.93895015783626,
                            2.356729741525478,
                            48.942125455106826,
                        ),
                        "coordinates": [
                            [2.356729741525478, 48.942125455106826],
                            [2.356709502661764, 48.9419511774418],
                            [2.356684618298954, 48.941743564554635],
                            [2.356431051851529, 48.93958365310374],
                            [2.356321867421057, 48.93895015783626],
                        ],
                    },
                },
                792: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89774133170234, 2.333928810734728],
                        "indice_lig": "3",
                        "idf": 0,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 601.252348423,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.329830334493886,
                            48.89767181948476,
                            2.338026740232628,
                            48.897832385089565,
                        ),
                        "coordinates": [
                            [2.338026740232628, 48.897832385089565],
                            [2.336524789599086, 48.89777924624911],
                            [2.334020039764945, 48.89773223798941],
                            [2.332514080507254, 48.897725642741904],
                            [2.329830334493886, 48.89767181948476],
                        ],
                    },
                },
                793: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89758974790774, 2.3267792709460204],
                        "indice_lig": "3",
                        "idf": 0,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 447.761901433,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32372791300899,
                            48.89751671682976,
                            2.329830334493886,
                            48.89767181948476,
                        ),
                        "coordinates": [
                            [2.329830334493886, 48.89767181948476],
                            [2.328183136308087, 48.89761406956224],
                            [2.326167325552567, 48.89757938470483],
                            [2.32372791300899, 48.89751671682976],
                        ],
                    },
                },
                794: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.12445410755038, 2.2868201684168663],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 2289.26535467,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.280515369819846,
                            49.114061951542226,
                            2.289505921794906,
                            49.132577702391806,
                        ),
                        "coordinates": [
                            [2.287915343526005, 49.114061951542226],
                            [2.28830659168989, 49.11662558755965],
                            [2.288357021538845, 49.11694681759301],
                            [2.288436428022629, 49.11729423362733],
                            [2.288530398751394, 49.11757503319891],
                            [2.288631616968672, 49.1178582150244],
                            [2.288750936667034, 49.11816757774532],
                            [2.289022194121215, 49.118795832827736],
                            [2.289166845941157, 49.119152791886634],
                            [2.289315067602379, 49.11956923508511],
                            [2.28940535844051, 49.11991665447931],
                            [2.289470277591376, 49.120261683187564],
                            [2.289502586187276, 49.12059242252884],
                            [2.289505921794906, 49.12089459871056],
                            [2.289491108991441, 49.12122055938044],
                            [2.289450948405008, 49.12151795854032],
                            [2.289396264519452, 49.12183676557945],
                            [2.289309002235829, 49.12210559329852],
                            [2.289185413794657, 49.12245054436564],
                            [2.289025560035484, 49.122807376904],
                            [2.288778564160312, 49.12330217279451],
                            [2.286573635496457, 49.12762684137346],
                            [2.285966938726975, 49.1288186157871],
                            [2.285828883434149, 49.12908979748605],
                            [2.285658151143287, 49.12940379196838],
                            [2.285491087357516, 49.12967496006374],
                            [2.285309545760705, 49.129919949243515],
                            [2.285095374180886, 49.13016254407357],
                            [2.284892118396909, 49.130364695057075],
                            [2.284616297801082, 49.13061201968683],
                            [2.284264309722811, 49.13088310223222],
                            [2.28395226881371, 49.13108995957257],
                            [2.283578579262125, 49.13130154707487],
                            [2.283226685066815, 49.131475073809455],
                            [2.28270431532732, 49.13170086459664],
                            [2.282171075949369, 49.13191475127873],
                            [2.280538684486732, 49.132568276914796],
                            [2.280515369819846, 49.132577702391806],
                        ],
                    },
                },
                795: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98352840272177, 1.7323652453972609],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2339.87486742,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.716985230225326,
                            48.98197836893915,
                            1.747786182906161,
                            48.98505986509816,
                        ),
                        "coordinates": [
                            [1.716985230225326, 48.98294677854624],
                            [1.717603813449699, 48.98276171412389],
                            [1.718137148382026, 48.98262346421197],
                            [1.718650457288927, 48.98249548247999],
                            [1.719433362534453, 48.98233077283618],
                            [1.719889836779225, 48.982252335013236],
                            [1.720360649706443, 48.98218348964009],
                            [1.7208336224081, 48.982121381692764],
                            [1.721650294106043, 48.98204214067667],
                            [1.722206559977197, 48.982003070959436],
                            [1.722832243256125, 48.98198025759216],
                            [1.723367292837499, 48.98197836893915],
                            [1.723952830556004, 48.98198626643678],
                            [1.724581510966729, 48.982013425771505],
                            [1.725152178371905, 48.982054549784955],
                            [1.725686498344667, 48.98211213308127],
                            [1.726173704524123, 48.982178979556664],
                            [1.726646307084847, 48.98225764095034],
                            [1.727259536453248, 48.98236560627509],
                            [1.729463412792157, 48.98276755041199],
                            [1.729986375405204, 48.982867881476785],
                            [1.730444267978145, 48.98296786604116],
                            [1.730966941804259, 48.983091985148995],
                            [1.73139204442747, 48.98321320671891],
                            [1.731929143247268, 48.983377550132],
                            [1.732331542729272, 48.98350816643865],
                            [1.733684328160941, 48.98396858368231],
                            [1.734408156824341, 48.9842008202285],
                            [1.73486477049055, 48.98433349713143],
                            [1.735305293981077, 48.98445180939565],
                            [1.735808110097762, 48.98457580103273],
                            [1.736267900242778, 48.98467101468146],
                            [1.736771133672103, 48.98476109737522],
                            [1.737260941888888, 48.98484040114616],
                            [1.738048753009511, 48.98494089302297],
                            [1.738775919150704, 48.98501161734152],
                            [1.739513627118635, 48.98505594926107],
                            [1.740308955801521, 48.98505986509816],
                            [1.740985081039136, 48.985053870449875],
                            [1.741777342671697, 48.985010407297985],
                            [1.742425081476358, 48.984943289714394],
                            [1.742953237977467, 48.98486920222355],
                            [1.743912892897122, 48.98473379587805],
                            [1.745868513597715, 48.984448868780746],
                            [1.747212049926789, 48.984255932912646],
                            [1.747786182906161, 48.98417275530591],
                        ],
                    },
                },
                796: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.055184979623895, 3.2940548593086194],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 7567.09294312,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.280297683892131,
                            48.02668663232931,
                            3.309004545822311,
                            48.0851844944416,
                        ),
                        "coordinates": [
                            [3.286256499458407, 48.0851844944416],
                            [3.287016299061232, 48.08304028408149],
                            [3.286446538752083, 48.079881935388784],
                            [3.284309345628479, 48.074770524806326],
                            [3.281931916237612, 48.070430518674456],
                            [3.280858900005268, 48.06761834868354],
                            [3.280297683892131, 48.06488736637587],
                            [3.280638710043828, 48.06266175055593],
                            [3.282001383843315, 48.06051303513901],
                            [3.28438237434218, 48.05827023028991],
                            [3.28867401848842, 48.05592571209786],
                            [3.300418806704018, 48.04992674808714],
                            [3.305091431613689, 48.04757832216632],
                            [3.306720732607794, 48.04611092703306],
                            [3.308083495664925, 48.04404737983395],
                            [3.308924783190965, 48.04138989806118],
                            [3.309004545822311, 48.03890998693456],
                            [3.307795030311733, 48.03567182074027],
                            [3.305685405217034, 48.03201396697032],
                            [3.302564536511451, 48.02668663232931],
                        ],
                    },
                },
                797: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.05114397270041, 2.7550182741165643],
                        "indice_lig": "R",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 10400.0703506,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.738670736945426,
                            48.007031701468264,
                            2.77230261766097,
                            48.09650277877714,
                        ),
                        "coordinates": [
                            [2.77230261766097, 48.09650277877714],
                            [2.769392020873821, 48.08751832323362],
                            [2.764882396188975, 48.073321753389095],
                            [2.760541633358244, 48.057163913688484],
                            [2.756089071351188, 48.04921602486933],
                            [2.750724356237062, 48.04127134372375],
                            [2.742033736695781, 48.02843722440753],
                            [2.739256682501753, 48.02379102808862],
                            [2.738670736945426, 48.019014425275365],
                            [2.740088761308753, 48.013617997936905],
                            [2.743038312684583, 48.007031701468264],
                        ],
                    },
                },
                798: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98049002134593, 1.7965241944453054],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1888.44445122,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.783973407729849,
                            48.9792514910568,
                            1.808907828712391,
                            48.98297976320563,
                        ),
                        "coordinates": [
                            [1.783973407729849, 48.979292248544446],
                            [1.784113406024897, 48.97928641196018],
                            [1.784684753516562, 48.979267754802265],
                            [1.785230693880385, 48.97925849278836],
                            [1.786246531847681, 48.9792514910568],
                            [1.787215225355044, 48.9792585299782],
                            [1.788415067419059, 48.97928332307666],
                            [1.789614595412037, 48.97933665726022],
                            [1.790770542598254, 48.97940880362781],
                            [1.791633681749685, 48.97948192403707],
                            [1.792330677892193, 48.979542350676304],
                            [1.793186382252216, 48.979634458772374],
                            [1.794070876534528, 48.979738593537874],
                            [1.794872162055996, 48.979849466189954],
                            [1.795575957804679, 48.97995035417782],
                            [1.796398700827595, 48.98008273246472],
                            [1.797080607015184, 48.980202542984564],
                            [1.797729985849793, 48.98032219624302],
                            [1.798606497125247, 48.980497639672166],
                            [1.799616295722199, 48.980716531137524],
                            [1.801375839773103, 48.98113641677692],
                            [1.804361145571652, 48.98186892776987],
                            [1.808907828712391, 48.98297976320563],
                        ],
                    },
                },
                799: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [49.172320180311495, 2.8157959846365297],
                        "indice_lig": "K",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 7248.48251592,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.79445455010732,
                            49.14288419832467,
                            2.838108478036551,
                            49.20087707910112,
                        ),
                        "coordinates": [
                            [2.79445455010732, 49.14288419832467],
                            [2.802800121956027, 49.15070810043967],
                            [2.815235703365665, 49.17192867407871],
                            [2.824344157673586, 49.18728512797439],
                            [2.826825157962253, 49.19079937819332],
                            [2.829674821226445, 49.19401262586999],
                            [2.833701241275337, 49.197556556515536],
                            [2.838108478036551, 49.20087707910112],
                        ],
                    },
                },
                800: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.800711270491334, 2.634891262577311],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2539.14660211,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.619395781719303,
                            48.795654821412064,
                            2.65038766844115,
                            48.80577037511879,
                        ),
                        "coordinates": [
                            [2.619395781719303, 48.80577037511879],
                            [2.62033659854746, 48.80546362845502],
                            [2.621418866793547, 48.80511830671614],
                            [2.624032578818235, 48.80424805111126],
                            [2.62658189777989, 48.80342286165644],
                            [2.627735511136074, 48.8030467235935],
                            [2.62950461280818, 48.80246845608912],
                            [2.631356544562773, 48.80186117094648],
                            [2.633205707528341, 48.80125386191333],
                            [2.635982862887326, 48.80035812165081],
                            [2.638420196546505, 48.79956123480164],
                            [2.640854733538161, 48.798765202380544],
                            [2.643290547448431, 48.79796821457687],
                            [2.647533065612068, 48.79659072762],
                            [2.648570874623787, 48.796248865871185],
                            [2.64934378727576, 48.79599405234788],
                            [2.65038766844115, 48.795654821412064],
                        ],
                    },
                },
                801: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.8400266581225, 2.2853232388343945],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 452.217286709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.282700027239131,
                            48.838960939372015,
                            2.287945766487379,
                            48.84109405724891,
                        ),
                        "coordinates": [
                            [2.287945766487379, 48.84109405724891],
                            [2.286579015400138, 48.840536528159014],
                            [2.28642215649715, 48.840472540384276],
                            [2.282700027239131, 48.838960939372015],
                        ],
                    },
                },
                802: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.467862035062616, 2.7665218453153955],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 5873.52915957,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.751153658380149,
                            48.442882064226566,
                            2.773485606663736,
                            48.487222875528246,
                        ),
                        "coordinates": [
                            [2.760926733738456, 48.442882064226566],
                            [2.761595951004158, 48.44354694021371],
                            [2.763422457189777, 48.445359056860475],
                            [2.764926650505398, 48.446868994569265],
                            [2.765680142918008, 48.44761329316563],
                            [2.765951009215691, 48.447896288729545],
                            [2.766124752982382, 48.448074727769395],
                            [2.766225533085432, 48.448198865003135],
                            [2.766321623876522, 48.448339422882505],
                            [2.766421774736739, 48.44850614724888],
                            [2.766586591072239, 48.44881037152612],
                            [2.766743584332989, 48.44914789796946],
                            [2.766882983986937, 48.44948279412558],
                            [2.766986886946515, 48.44977645864304],
                            [2.767074105482878, 48.450016230276155],
                            [2.767324460026053, 48.450835406492644],
                            [2.767426846737313, 48.45113944996402],
                            [2.767532538329151, 48.45145330840755],
                            [2.767681640379815, 48.45180042278222],
                            [2.767831749205445, 48.452135609759615],
                            [2.767888189285304, 48.452241370777884],
                            [2.768350304169477, 48.45301401374466],
                            [2.768503899000985, 48.45326792043091],
                            [2.768920876041274, 48.4539650575954],
                            [2.769207590781253, 48.45444866594502],
                            [2.769811043678867, 48.45545874875412],
                            [2.77007976253259, 48.45592406519053],
                            [2.77035913428027, 48.45637982223105],
                            [2.770825994270108, 48.45712407983803],
                            [2.771222131880606, 48.4577255822222],
                            [2.77136382249737, 48.457977245511394],
                            [2.771491266504765, 48.458236101546795],
                            [2.771574140953394, 48.458429639862544],
                            [2.771817774610239, 48.45908426846817],
                            [2.771916567490021, 48.459406724335636],
                            [2.771994377541466, 48.45973789308037],
                            [2.772193108546506, 48.460735674391266],
                            [2.772316576384184, 48.46137534151357],
                            [2.772440480960773, 48.46197391068492],
                            [2.772585800884284, 48.46267028235211],
                            [2.772694172546813, 48.4631599649219],
                            [2.772807204354267, 48.46371887295381],
                            [2.772887787100706, 48.46412233250483],
                            [2.773365257537985, 48.46646937497422],
                            [2.773418655732841, 48.46683511706058],
                            [2.773447698267541, 48.46708505414123],
                            [2.773465728805673, 48.46744738915953],
                            [2.773485606663736, 48.467866370244394],
                            [2.773457057579393, 48.468469888228924],
                            [2.773404735362116, 48.46887853676099],
                            [2.773335706074937, 48.46928688966345],
                            [2.773170868595014, 48.46996202604711],
                            [2.773008668838968, 48.47055521547116],
                            [2.772648855063921, 48.471788595626215],
                            [2.772465603035616, 48.472305024023306],
                            [2.772268010049928, 48.47278005296128],
                            [2.772072691561673, 48.47318377514302],
                            [2.771789646262083, 48.47366003513115],
                            [2.771485763848649, 48.47410375294116],
                            [2.77120549910066, 48.474535071882094],
                            [2.770600178812847, 48.475400720924135],
                            [2.77031561305327, 48.47580648005272],
                            [2.770044435919698, 48.476196900727025],
                            [2.769630305275653, 48.47679199934125],
                            [2.769312517881354, 48.477268026437116],
                            [2.768677604746096, 48.478141838809755],
                            [2.768141037009027, 48.478815635470184],
                            [2.767868040105863, 48.47915569828132],
                            [2.767290401176827, 48.47975161386681],
                            [2.766793892302045, 48.480234404195315],
                            [2.766255387394773, 48.480687845353465],
                            [2.765757730570017, 48.48110688068657],
                            [2.765401072575688, 48.481382650833126],
                            [2.764881310400018, 48.481773643711556],
                            [2.764325483713099, 48.48214569697125],
                            [2.763522391228304, 48.482666701966124],
                            [2.763006955411796, 48.48297619225833],
                            [2.762367833682136, 48.48332728889813],
                            [2.761665846489327, 48.483689200513965],
                            [2.760831671652031, 48.48408015459614],
                            [2.759719510474557, 48.48461252023684],
                            [2.75928104563875, 48.484821156227184],
                            [2.758739169459785, 48.48507538313257],
                            [2.758289899490584, 48.48527691715416],
                            [2.757797697238829, 48.48548098876748],
                            [2.757415982506981, 48.485629924957514],
                            [2.756930593312749, 48.48579351918423],
                            [2.756402294189915, 48.485964157295335],
                            [2.755964682047495, 48.48610374057985],
                            [2.75552761458263, 48.48622699012184],
                            [2.755095442948047, 48.486335655639394],
                            [2.754631016848214, 48.48643967936091],
                            [2.754213016978645, 48.48653163466971],
                            [2.75273398453552, 48.48686304015041],
                            [2.751883734060254, 48.48705650403138],
                            [2.751153658380149, 48.487222875528246],
                        ],
                    },
                },
                803: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.49626023449947, 2.673189432649022],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 6014.82244004,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.662762979853312,
                            48.4755230723766,
                            2.692033259866399,
                            48.52299439391623,
                        ),
                        "coordinates": [
                            [2.692033259866399, 48.4755230723766],
                            [2.691686618251609, 48.47573547002441],
                            [2.691082585997087, 48.476085628404626],
                            [2.690201672341864, 48.47659646343196],
                            [2.689179331329361, 48.47719316237408],
                            [2.688308042660941, 48.477694655809366],
                            [2.687341920267955, 48.47825100163571],
                            [2.686797727956086, 48.47857012448603],
                            [2.685800639284007, 48.4791442682248],
                            [2.684678641092634, 48.4797879591731],
                            [2.684017587024792, 48.48016549439286],
                            [2.683138720729849, 48.48066586280016],
                            [2.681825301379014, 48.48142987195499],
                            [2.680747342325166, 48.482046323434545],
                            [2.679865594292645, 48.482560045525055],
                            [2.678729156609944, 48.48322687067516],
                            [2.678211687771568, 48.48351349737593],
                            [2.677683525694789, 48.48381993816555],
                            [2.676902051155626, 48.48427371684216],
                            [2.676315311077137, 48.48466750341887],
                            [2.675869257828674, 48.4849710434032],
                            [2.675310433482517, 48.48538056771836],
                            [2.674688974199491, 48.48591079287395],
                            [2.674152618102982, 48.486385278011646],
                            [2.673688668469069, 48.486850622469895],
                            [2.673270343616544, 48.48731582958682],
                            [2.672542708741492, 48.48816523927329],
                            [2.672142267013732, 48.48867760912956],
                            [2.671837831290883, 48.489065293583025],
                            [2.670936229207066, 48.490348645122864],
                            [2.670598898136044, 48.49087305679068],
                            [2.670374309885933, 48.49123183263913],
                            [2.670284607947011, 48.491373280588135],
                            [2.670137386763549, 48.4916129181202],
                            [2.669985510166678, 48.49188844484194],
                            [2.669839626069873, 48.49215476071982],
                            [2.669685661113397, 48.492417531945335],
                            [2.66954513113252, 48.49267758660376],
                            [2.669217898751352, 48.493315225069395],
                            [2.669086771982049, 48.49360061375874],
                            [2.668951348319225, 48.49392390767301],
                            [2.66884171002255, 48.49420831050155],
                            [2.668743055740724, 48.49449867668083],
                            [2.668625864950517, 48.49482772073163],
                            [2.668431507923496, 48.49551172865773],
                            [2.668275153579723, 48.49621450967455],
                            [2.66819901872877, 48.496568142078864],
                            [2.668089155594461, 48.49734542666724],
                            [2.668054065400957, 48.497983396007264],
                            [2.668035848462255, 48.4984912417543],
                            [2.668023119565936, 48.49922597641024],
                            [2.66801225872781, 48.500447206650136],
                            [2.66800747022895, 48.500949909040024],
                            [2.667997729069282, 48.50131773676442],
                            [2.667992267625602, 48.50151469131494],
                            [2.667985995651498, 48.50173084369807],
                            [2.667972568379602, 48.502422105057335],
                            [2.667962569523811, 48.50288726809226],
                            [2.66794603577719, 48.503727913515704],
                            [2.667923053262378, 48.506182971152654],
                            [2.667893896852581, 48.5068889781593],
                            [2.667862013054771, 48.50723461494378],
                            [2.667826882823972, 48.50760049241765],
                            [2.667777829706965, 48.50795773883156],
                            [2.667697297700236, 48.508468660149894],
                            [2.667506590539158, 48.50950876627907],
                            [2.667391866202985, 48.51017006054065],
                            [2.667318807013511, 48.510583036065846],
                            [2.667240863100024, 48.51107606050739],
                            [2.667120095556507, 48.511847981112325],
                            [2.666974816933652, 48.51269298176516],
                            [2.666627393525305, 48.51471177511217],
                            [2.666402152575688, 48.51599713041929],
                            [2.666169971066119, 48.51717556295379],
                            [2.666034064152957, 48.51774699210963],
                            [2.665883184139579, 48.51822091304845],
                            [2.665777699602716, 48.518518633338644],
                            [2.665647269707232, 48.518835459780725],
                            [2.665460053427252, 48.519230967710705],
                            [2.665237033935429, 48.51962895890787],
                            [2.665120094388878, 48.51981964392905],
                            [2.665003188616977, 48.52001508501247],
                            [2.66489333261209, 48.52019385132316],
                            [2.664708827309792, 48.52045848827051],
                            [2.664489345627315, 48.52077632477222],
                            [2.664286752785638, 48.521052984124765],
                            [2.663991620118767, 48.52146210352899],
                            [2.663562202076866, 48.52203797222404],
                            [2.662762979853312, 48.52299439391623],
                        ],
                    },
                },
                804: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.68897770552408, 2.518668897394993],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 2938.60368335,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.506078153203696,
                            48.681016616342724,
                            2.533130656571037,
                            48.69973243390383,
                        ),
                        "coordinates": [
                            [2.533130656571037, 48.681016616342724],
                            [2.533083199969267, 48.681036908862126],
                            [2.532420245237413, 48.68130501241577],
                            [2.531858424403045, 48.681525827311454],
                            [2.531122229286065, 48.68181260863568],
                            [2.530166395190735, 48.68216971084296],
                            [2.528636439410602, 48.68275970284952],
                            [2.527384140172082, 48.68325092711469],
                            [2.525814500754922, 48.68386873852389],
                            [2.523791239115818, 48.684675135001115],
                            [2.523209316117805, 48.68491878306068],
                            [2.522627803766856, 48.68516714672711],
                            [2.522191252125509, 48.685373793459576],
                            [2.521766940500577, 48.6855858134296],
                            [2.521402301317052, 48.68577525356521],
                            [2.520762555585214, 48.6861279063839],
                            [2.520261087236943, 48.68641378661939],
                            [2.519931057683086, 48.68662008435654],
                            [2.519620171125085, 48.68682218937744],
                            [2.519292327448007, 48.68705023251167],
                            [2.518727460664905, 48.68746030672398],
                            [2.518210210107044, 48.687894582783834],
                            [2.51777291551441, 48.688281967524496],
                            [2.517136591601049, 48.688849148509895],
                            [2.516363556401142, 48.68954408354144],
                            [2.515953333460746, 48.68991343226858],
                            [2.514893183474851, 48.69085663669972],
                            [2.514105095249711, 48.69154131564824],
                            [2.513505313585758, 48.69209080553229],
                            [2.513079321689099, 48.69247661522168],
                            [2.512688850727272, 48.69282947523966],
                            [2.512481714053253, 48.69302493737972],
                            [2.512251587380239, 48.69325011164466],
                            [2.511942940635518, 48.693550943881],
                            [2.511427253655409, 48.694078710836905],
                            [2.510991505145755, 48.69455059822122],
                            [2.510715444432601, 48.69485137801083],
                            [2.510463726849502, 48.69512244423393],
                            [2.509782952423262, 48.69584379944969],
                            [2.509643544375335, 48.69599059291947],
                            [2.50936473457913, 48.69628687684477],
                            [2.508931620430535, 48.69674616261593],
                            [2.508348323378641, 48.69738372928118],
                            [2.508257641925479, 48.69748098686163],
                            [2.507689269499808, 48.69803704997495],
                            [2.507471029928957, 48.69825734323042],
                            [2.507270728216306, 48.69847796559789],
                            [2.506974287412474, 48.698791356624],
                            [2.506750944552601, 48.69902909851392],
                            [2.506562788768913, 48.69922811883625],
                            [2.506385470274386, 48.69941813059212],
                            [2.506078153203696, 48.69973243390383],
                        ],
                    },
                },
                805: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.532107762372455, 2.6399020333534953],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 2554.04400073,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.625522155066302,
                            48.52724332146015,
                            2.654990282141887,
                            48.538775256627815,
                        ),
                        "coordinates": [
                            [2.654990282141887, 48.52724332146015],
                            [2.654417667755585, 48.527373220137065],
                            [2.653539149006601, 48.527567222324514],
                            [2.652441044420506, 48.5277977343036],
                            [2.651811198282233, 48.527929944006594],
                            [2.650964790072547, 48.528107648819606],
                            [2.649877643332884, 48.528326480112945],
                            [2.648970394125592, 48.5285196253129],
                            [2.648041592983785, 48.52873170790309],
                            [2.646964303886952, 48.52901612918054],
                            [2.646087244964201, 48.52927841262732],
                            [2.645104865128238, 48.52958985389654],
                            [2.644227958615014, 48.5298787821565],
                            [2.64308156242943, 48.530282957076125],
                            [2.642288253494157, 48.53060392470094],
                            [2.641480867215042, 48.530967751740775],
                            [2.640805811554372, 48.53129790876197],
                            [2.640173563304269, 48.5315993950506],
                            [2.639544829852352, 48.531891350354464],
                            [2.638498231610322, 48.53239617430495],
                            [2.638027283354891, 48.532624691505994],
                            [2.636290729471906, 48.53340715551677],
                            [2.635863317546536, 48.53358832560296],
                            [2.635274563263848, 48.533830618538126],
                            [2.634908946248339, 48.53397373548194],
                            [2.633888629708109, 48.53437365345555],
                            [2.632919252629083, 48.534741809195076],
                            [2.63187330765147, 48.53513902812013],
                            [2.631071995193906, 48.53546834053523],
                            [2.630307385170337, 48.535822459476606],
                            [2.629675126113145, 48.53615652577562],
                            [2.629127210173015, 48.536467967457895],
                            [2.628483252127347, 48.536853701990076],
                            [2.626960072940523, 48.537820721361946],
                            [2.625522155066302, 48.538775256627815],
                        ],
                    },
                },
                806: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.965297910739366, 2.962762494670167],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2477.7645205,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.950060382752808,
                            48.960226490735955,
                            2.973519215077535,
                            48.97436062282584,
                        ),
                        "coordinates": [
                            [2.950060382752808, 48.960226490735955],
                            [2.95175079330588, 48.96024949464454],
                            [2.952303744520137, 48.96025722986969],
                            [2.952895823771479, 48.960273317432076],
                            [2.95341641533515, 48.96029407102819],
                            [2.953986050652563, 48.96033597142898],
                            [2.954660068251468, 48.96040300449745],
                            [2.955184527751131, 48.960472982317285],
                            [2.955673298267127, 48.96054957561234],
                            [2.956250326817945, 48.96066209391428],
                            [2.956736222952542, 48.96076867939837],
                            [2.957320185970004, 48.96091541721596],
                            [2.957904423092041, 48.961083567542964],
                            [2.958426875862008, 48.961252049689094],
                            [2.958965915173825, 48.96144613731513],
                            [2.959413659733209, 48.961621445278276],
                            [2.959858400296315, 48.961816040907166],
                            [2.960329456026285, 48.962034048822304],
                            [2.960830294689846, 48.96229257955372],
                            [2.961308508071661, 48.962561940193304],
                            [2.961682124014346, 48.96278903927934],
                            [2.962062570625729, 48.963041797134],
                            [2.96242356225512, 48.963298943976326],
                            [2.962706102234541, 48.96352439611816],
                            [2.963061110207489, 48.96382226260639],
                            [2.963495554418657, 48.96422890710962],
                            [2.963890760994318, 48.96461863341497],
                            [2.965317276522482, 48.96605845029489],
                            [2.968368402964463, 48.96914894686642],
                            [2.969478976229396, 48.970279941310054],
                            [2.970366764019293, 48.97117657603807],
                            [2.971294691949179, 48.972113709668555],
                            [2.973117102488859, 48.97395169499413],
                            [2.973519215077535, 48.97436062282584],
                        ],
                    },
                },
                807: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.58032014674072, 2.589409838485273],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 3494.85205435,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.58394771106125,
                            48.564949495670916,
                            2.594551816007613,
                            48.595563837991776,
                        ),
                        "coordinates": [
                            [2.594551816007613, 48.564949495670916],
                            [2.594295504436848, 48.56545677875951],
                            [2.59394493728639, 48.566297471138796],
                            [2.593513140386829, 48.567378656710105],
                            [2.592647916108226, 48.569933613348155],
                            [2.592298847202012, 48.571078849405694],
                            [2.591903749787656, 48.57234077373574],
                            [2.591473493827524, 48.57374315570742],
                            [2.591127969309865, 48.574890759355135],
                            [2.590837866272776, 48.5758674762185],
                            [2.590598102195244, 48.57666508302081],
                            [2.590238337562021, 48.57784126690704],
                            [2.589807856422505, 48.57921747191162],
                            [2.589310338910697, 48.58081509872764],
                            [2.588812824486161, 48.58241986298694],
                            [2.588347481668348, 48.584010276998],
                            [2.587987516220817, 48.58516742138348],
                            [2.587511457618529, 48.58677689070458],
                            [2.586973779293195, 48.588501098135],
                            [2.586601945524944, 48.58968840234978],
                            [2.586134388752506, 48.59086322685132],
                            [2.585694396053536, 48.59181591901776],
                            [2.585149965885586, 48.592927460295556],
                            [2.584091329784307, 48.59523255348737],
                            [2.58394771106125, 48.595563837991776],
                        ],
                    },
                },
                808: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.01487848028882, 3.3875320932671755],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 6335.86256003,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.364927128865269,
                            48.99193822029961,
                            3.409597359882764,
                            49.03794894167955,
                        ),
                        "coordinates": [
                            [3.364927128865269, 48.99193822029961],
                            [3.376317693222663, 48.99738781894549],
                            [3.378482696931921, 48.99877354886844],
                            [3.380253713090378, 49.000765159603226],
                            [3.386921406219843, 49.013018368259],
                            [3.393165441347809, 49.02433817117766],
                            [3.39676218429671, 49.030729736325505],
                            [3.398750089574201, 49.03325446896857],
                            [3.400408470804616, 49.03464450308404],
                            [3.402775009832036, 49.03582715495288],
                            [3.406365802680644, 49.037132182957755],
                            [3.409597359882764, 49.03794894167955],
                        ],
                    },
                },
                809: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9785290016097, 3.344327922757435],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 4249.34948913,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.32188681725306,
                            48.969278782071456,
                            3.364927128865269,
                            48.99193822029961,
                        ),
                        "coordinates": [
                            [3.32188681725306, 48.969278782071456],
                            [3.32799486415054, 48.96997246850015],
                            [3.333615172961879, 48.97087541659164],
                            [3.335976076474291, 48.971449692278775],
                            [3.338888718286613, 48.972494992789954],
                            [3.346001312709376, 48.977046514612006],
                            [3.34827305145462, 48.97876648225163],
                            [3.349847019582927, 48.98116183833388],
                            [3.351324951423921, 48.983825722928195],
                            [3.352886892290022, 48.985618823749384],
                            [3.355670361408304, 48.98746795176199],
                            [3.364927128865269, 48.99193822029961],
                        ],
                    },
                },
                810: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.86157429691315, 2.338801581903395],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 379.331434302,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.336496460942477,
                            48.8608062912721,
                            2.341108591634067,
                            48.86234803084025,
                        ),
                        "coordinates": [
                            [2.341108591634067, 48.8608062912721],
                            [2.341050102589076, 48.86082521978887],
                            [2.340512343610978, 48.86099924485785],
                            [2.336496460942477, 48.86234803084025],
                        ],
                    },
                },
                811: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96071631750698, 2.259755151442724],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2298.94251917,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.255032689365674,
                            48.95101678180594,
                            2.264112769834031,
                            48.97051992210463,
                        ),
                        "coordinates": [
                            [2.263924959788352, 48.97051992210463],
                            [2.263992109928939, 48.97019280444279],
                            [2.264046731490777, 48.969913028985125],
                            [2.264079603745008, 48.969677496087265],
                            [2.264112769834031, 48.96908259899572],
                            [2.264102445871056, 48.96873045095783],
                            [2.264081190379899, 48.968437778931545],
                            [2.264056288828641, 48.9681688979576],
                            [2.264013355979051, 48.96787383197799],
                            [2.263952363043426, 48.96757161918285],
                            [2.26385890318257, 48.96723131360182],
                            [2.26374736648998, 48.966898134173015],
                            [2.263624976124514, 48.9665744660007],
                            [2.263488111905425, 48.96626268607745],
                            [2.263369218964826, 48.966017537966174],
                            [2.263210646843699, 48.9657271572229],
                            [2.263019582070232, 48.96541534203537],
                            [2.262857334875192, 48.96516778559439],
                            [2.262565269472823, 48.96473693713095],
                            [2.258830194746513, 48.95921914955461],
                            [2.257085585989827, 48.95660067595872],
                            [2.256155656117332, 48.95522238777198],
                            [2.255964649660679, 48.95492721550783],
                            [2.255788085807808, 48.95463919094129],
                            [2.255629586658888, 48.95435117925937],
                            [2.255488421137162, 48.95405098894533],
                            [2.255348090121299, 48.953703506775305],
                            [2.25521508387373, 48.953296545494695],
                            [2.25514686990983, 48.95303476987765],
                            [2.255089619571894, 48.952699241134],
                            [2.255050345752057, 48.95241607313774],
                            [2.255032689365674, 48.95216860868762],
                            [2.255040465136331, 48.951835507961334],
                            [2.25505160172218, 48.95165468557088],
                            [2.25508371139436, 48.95101678180594],
                        ],
                    },
                },
                812: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.78640256771013, 2.6730783577754096],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 4320.77534872,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.65038766844115,
                            48.7707789170597,
                            2.690252782195758,
                            48.795654821412064,
                        ),
                        "coordinates": [
                            [2.65038766844115, 48.795654821412064],
                            [2.653738082681988, 48.79456375969959],
                            [2.654293578544201, 48.794374264997444],
                            [2.655001273111905, 48.79414657249452],
                            [2.658862788945834, 48.79288483318345],
                            [2.66130748957195, 48.79207754218481],
                            [2.664499211726753, 48.79104593321487],
                            [2.666678938297153, 48.79033011518671],
                            [2.66885860370027, 48.78961425604855],
                            [2.671039561150659, 48.78889745204991],
                            [2.673504313525253, 48.78809433686021],
                            [2.675968967318145, 48.78728847025629],
                            [2.678434915405753, 48.786484345712665],
                            [2.679329631706581, 48.78617500629736],
                            [2.67981579165295, 48.78598582565908],
                            [2.680244371035857, 48.78581074330536],
                            [2.680636457320475, 48.78563510048336],
                            [2.681036778289391, 48.7854373615558],
                            [2.681452903633455, 48.78522885817877],
                            [2.681987531079078, 48.78491838524668],
                            [2.682455316941921, 48.784623086557026],
                            [2.682716109257094, 48.784450545926546],
                            [2.683063902704594, 48.784209585365055],
                            [2.683291287444024, 48.784031735674226],
                            [2.683610598937456, 48.78376637584698],
                            [2.683786439475538, 48.78361296259848],
                            [2.68398524881878, 48.78343609805765],
                            [2.68420824317259, 48.78321509402277],
                            [2.684478486418863, 48.78293998847224],
                            [2.684633707729437, 48.78275785956092],
                            [2.684821297129882, 48.782534265014235],
                            [2.685072111464724, 48.78220615978139],
                            [2.68538060446695, 48.7817591718489],
                            [2.685609637853775, 48.781376197417686],
                            [2.685838907521479, 48.78094301828567],
                            [2.686183085204097, 48.780154190155315],
                            [2.686498103258331, 48.779430693919146],
                            [2.686821822981746, 48.778684598663126],
                            [2.68800829622975, 48.775976801836975],
                            [2.688231903163656, 48.775464419760496],
                            [2.688709847845154, 48.77436222134508],
                            [2.689292442230653, 48.77305466097908],
                            [2.689696578735758, 48.77205903973373],
                            [2.689989370966271, 48.77137533830717],
                            [2.690252782195758, 48.7707789170597],
                        ],
                    },
                },
                813: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.88295715568775, 2.3196820795515647],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1516.1561858,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313732451520271,
                            48.87683695396951,
                            2.324738046836634,
                            48.88822016276462,
                        ),
                        "coordinates": [
                            [2.324738046836634, 48.87683695396951],
                            [2.32420142057937, 48.87748880417361],
                            [2.323956605544434, 48.877847241123426],
                            [2.32373720863479, 48.878224548844315],
                            [2.32352415360155, 48.87863539844985],
                            [2.323339714766086, 48.87900013217418],
                            [2.323107564883391, 48.87948434675638],
                            [2.322872780798152, 48.87990183133246],
                            [2.322699857158072, 48.880154733598346],
                            [2.322475211042448, 48.88042595099708],
                            [2.322188319175849, 48.88072928059579],
                            [2.321847299445921, 48.88108256843456],
                            [2.321165706465782, 48.88174482790253],
                            [2.320547906039082, 48.88237470681367],
                            [2.319826119003644, 48.88310506035692],
                            [2.319162051301495, 48.883785452158705],
                            [2.318772266168705, 48.88418512040464],
                            [2.317981852446237, 48.884977315949094],
                            [2.317371900145514, 48.88554825533218],
                            [2.316909910839129, 48.88598121765758],
                            [2.316419050997167, 48.88641655115975],
                            [2.316011197598551, 48.88677813862067],
                            [2.315596526577928, 48.88708453333479],
                            [2.314979371694457, 48.88749604387476],
                            [2.314105991626147, 48.8880026761262],
                            [2.313732451520271, 48.88822016276462],
                        ],
                    },
                },
                814: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.853906410128914, 2.36522376860386],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 708.264711694,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.360956490023828,
                            48.852479422836296,
                            2.369320584925386,
                            48.85523625280237,
                        ),
                        "coordinates": [
                            [2.369320584925386, 48.852479422836296],
                            [2.369282543945361, 48.85252461805575],
                            [2.36925937064433, 48.85254802567055],
                            [2.369236028178525, 48.852568293647224],
                            [2.369212075838694, 48.852585802786784],
                            [2.369187273036883, 48.85260072629506],
                            [2.369162217059622, 48.85261247104969],
                            [2.369133672664284, 48.85262249223347],
                            [2.369101381150728, 48.85263088291189],
                            [2.369064833937473, 48.85263777620247],
                            [2.368984766628364, 48.852647001333224],
                            [2.368864346467385, 48.852654501754365],
                            [2.368817131191295, 48.85265744180188],
                            [2.368748869102989, 48.85266370092754],
                            [2.368682044120558, 48.85267451382544],
                            [2.368653675078195, 48.852681524786775],
                            [2.368628169979566, 48.85268971911294],
                            [2.368581545612303, 48.852710583589165],
                            [2.368538698109018, 48.85273781651064],
                            [2.36849917569544, 48.852771697893424],
                            [2.368462188006935, 48.85281289538511],
                            [2.368433721687968, 48.85285187327287],
                            [2.368404934254453, 48.85289800111011],
                            [2.368321032349271, 48.8530543072663],
                            [2.368289964045675, 48.85310790653959],
                            [2.368257569508601, 48.85315578341542],
                            [2.368224577298573, 48.853195736528086],
                            [2.36818973157716, 48.85322928274961],
                            [2.368152429981962, 48.85325698369137],
                            [2.368112173370187, 48.853279205449994],
                            [2.36806863935478, 48.8532961234926],
                            [2.366886753859458, 48.853447410804655],
                            [2.366276767025489, 48.85356079622263],
                            [2.364361613859286, 48.85409047483843],
                            [2.362826689750927, 48.854618409471584],
                            [2.362065855707397, 48.85490521406514],
                            [2.361563289363017, 48.855075472685584],
                            [2.360956490023828, 48.85523625280237],
                        ],
                    },
                },
                815: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.95072830819521, 2.1369854267991397],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1556.82134848,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.129363096573621,
                            48.945795934518046,
                            2.144558756800802,
                            48.95558242610153,
                        ),
                        "coordinates": [
                            [2.129363096573621, 48.95558242610153],
                            [2.129364252725261, 48.95558180229322],
                            [2.130186393825507, 48.95510504093087],
                            [2.130918026939952, 48.954668561787386],
                            [2.1323489735282, 48.95373842337728],
                            [2.134018912585963, 48.9526611748752],
                            [2.134996935419867, 48.95202999852488],
                            [2.13705434703725, 48.95069641978865],
                            [2.139423112433903, 48.94916585477055],
                            [2.141654189842415, 48.94770400653005],
                            [2.14260315743467, 48.94706319950211],
                            [2.143302133117028, 48.94660517253894],
                            [2.144558756800802, 48.945795934518046],
                        ],
                    },
                },
                816: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.92879071327043, 2.1710667342244236],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2834.83343407,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.157086496469818,
                            48.920379373924355,
                            2.185353376302864,
                            48.93773606341459,
                        ),
                        "coordinates": [
                            [2.157086496469818, 48.93773606341459],
                            [2.159197405123777, 48.93641370175961],
                            [2.161018108093818, 48.93526729322632],
                            [2.163222511688236, 48.93384305627839],
                            [2.165271328905886, 48.93246851051073],
                            [2.167844735351957, 48.93077825372754],
                            [2.168677232891343, 48.93021081769022],
                            [2.169625501214284, 48.929574546127455],
                            [2.172737711964865, 48.92756137399833],
                            [2.175144080165984, 48.926003956090945],
                            [2.177159517778266, 48.924700530967506],
                            [2.177716684610704, 48.92435392458564],
                            [2.178190624459705, 48.924061924895064],
                            [2.178769411868191, 48.9237248614286],
                            [2.179221561827801, 48.923468515339664],
                            [2.179691766691154, 48.92320981530839],
                            [2.180295726453799, 48.92289895093932],
                            [2.181319146329174, 48.92238403128845],
                            [2.182027886422397, 48.922042369149914],
                            [2.183726181297828, 48.92118856022069],
                            [2.184525333215453, 48.92078752097505],
                            [2.185353376302864, 48.920379373924355],
                        ],
                    },
                },
                817: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.043392756550006, 2.103670178900755],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 764.663069972,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.101108482966614,
                            49.03998130935,
                            2.104731441997329,
                            49.04564873988319,
                        ),
                        "coordinates": [
                            [2.10385269644926, 49.03998130935],
                            [2.103894189299988, 49.04009281176542],
                            [2.104617380681375, 49.042108982759835],
                            [2.104712051825991, 49.042455076590976],
                            [2.104731441997329, 49.04269636039878],
                            [2.104715623143703, 49.04286065821373],
                            [2.104663251189402, 49.04323555124596],
                            [2.104510836788841, 49.04364891068721],
                            [2.104470811492738, 49.04372436904673],
                            [2.104425213185352, 49.043821398638705],
                            [2.104288923849149, 49.04400457451242],
                            [2.103932572712254, 49.04443910203954],
                            [2.103419400678432, 49.0448144563268],
                            [2.103049885721393, 49.04501560498302],
                            [2.102701012760657, 49.045180900076154],
                            [2.102311313653998, 49.04531919116353],
                            [2.101607349709782, 49.04551964999514],
                            [2.101108482966614, 49.04564873988319],
                        ],
                    },
                },
                818: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.891686890332686, 2.4962094717582097],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2467.88253877,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.479793329961401,
                            48.88907659470566,
                            2.512566821462173,
                            48.89401251501928,
                        ),
                        "coordinates": [
                            [2.479793329961401, 48.89401251501928],
                            [2.481197722405834, 48.893804725496125],
                            [2.482784825989295, 48.89358618952957],
                            [2.486294326270926, 48.89306533586322],
                            [2.489865193721433, 48.892576412576965],
                            [2.49315463000745, 48.8921163153306],
                            [2.496267288843588, 48.89168611101783],
                            [2.499755003990543, 48.891207702729695],
                            [2.501755019254608, 48.89093049383821],
                            [2.506235894697583, 48.89031483248706],
                            [2.50687858796131, 48.89022644904722],
                            [2.50855849299117, 48.88998777777983],
                            [2.508957648940871, 48.88992236626066],
                            [2.509392246574917, 48.88985137720946],
                            [2.509862766838769, 48.889763963817956],
                            [2.510292260577928, 48.88967870192147],
                            [2.510730698786668, 48.88958666904331],
                            [2.511151789939301, 48.889487047296036],
                            [2.511647841755376, 48.88936256437549],
                            [2.512112092573541, 48.88922480279171],
                            [2.512566821462173, 48.88907659470566],
                        ],
                    },
                },
                819: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.95906967168272, 2.327166879022447],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 237.990985476,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32609015753849,
                            48.958269604608034,
                            2.32824501026232,
                            48.95987163649979,
                        ),
                        "coordinates": [
                            [2.32824501026232, 48.958269604608034],
                            [2.327390056245584, 48.958902276974186],
                            [2.32609015753849, 48.95987163649979],
                        ],
                    },
                },
                820: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.868850757136194, 2.310506257201992],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 493.318115576,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.30747079344783,
                            48.86790534489709,
                            2.313545549946741,
                            48.86980822019896,
                        ),
                        "coordinates": [
                            [2.313545549946741, 48.86790534489709],
                            [2.309935388700378, 48.869026528172164],
                            [2.308607493526256, 48.86943888165911],
                            [2.30747079344783, 48.86980822019896],
                        ],
                    },
                },
                821: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.14258121193363, 1.9410021448726438],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 4610.5275496,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.936404406282517,
                            49.12345185404933,
                            1.949332680280041,
                            49.16267058077503,
                        ),
                        "coordinates": [
                            [1.949332680280041, 49.12345185404933],
                            [1.949185475917967, 49.12378430761103],
                            [1.949104582604222, 49.12396569001574],
                            [1.94906001725428, 49.12405726641162],
                            [1.949008475131125, 49.12416500562504],
                            [1.948961127224009, 49.12426196888726],
                            [1.948899668364135, 49.12441104182411],
                            [1.948677644142843, 49.12494086837261],
                            [1.948354212597838, 49.125645712108835],
                            [1.947911904182227, 49.126655008666965],
                            [1.947649598670639, 49.12725124352399],
                            [1.947221212344662, 49.12822910966549],
                            [1.947170995731967, 49.12834134977251],
                            [1.946874172548261, 49.12896804154083],
                            [1.946639048125813, 49.12939342870717],
                            [1.946366049974775, 49.12980084821339],
                            [1.946088942919607, 49.13018479864618],
                            [1.945918705255562, 49.13039734908229],
                            [1.945698842510051, 49.13064660097523],
                            [1.945567556038215, 49.130785541848205],
                            [1.945383795623346, 49.130974664694975],
                            [1.945060650715532, 49.13128651195902],
                            [1.944233272120679, 49.132105629669866],
                            [1.943425187274626, 49.13290772130572],
                            [1.942731826031594, 49.13358430159307],
                            [1.942683466858274, 49.133633596070055],
                            [1.941559174675724, 49.13472505688229],
                            [1.940799244166007, 49.135493123162135],
                            [1.940462892353715, 49.13590653194088],
                            [1.939991773709939, 49.13654396173729],
                            [1.939794055794995, 49.13686703029378],
                            [1.939675695066615, 49.13708294663929],
                            [1.93950206860149, 49.137450876604255],
                            [1.939303422180774, 49.13790029980681],
                            [1.939171986740406, 49.13828101745344],
                            [1.939067200120823, 49.138692180723424],
                            [1.938971188976278, 49.13921163345045],
                            [1.938952480858631, 49.139322180491234],
                            [1.938907469990834, 49.139975803965385],
                            [1.938902856777726, 49.140378667417416],
                            [1.938882412396459, 49.14138579397961],
                            [1.938871946518622, 49.141834500165665],
                            [1.938873077029986, 49.142374973166376],
                            [1.938859597047989, 49.14302780627577],
                            [1.938847749566484, 49.14381823618507],
                            [1.938834485755011, 49.14444409105921],
                            [1.938827702825857, 49.14545666062833],
                            [1.938826732247982, 49.14557716147961],
                            [1.93882548648793, 49.145731834112986],
                            [1.938824943604575, 49.14579927771332],
                            [1.938818433317541, 49.14609691821341],
                            [1.93881922500777, 49.14616886393916],
                            [1.93881191282284, 49.14656632148197],
                            [1.938807807931568, 49.14724616512458],
                            [1.938834359853648, 49.14769410080937],
                            [1.938896987940069, 49.1480882036881],
                            [1.93898727952948, 49.14845182705083],
                            [1.939157369190831, 49.14895061918455],
                            [1.939222793991834, 49.149110044650826],
                            [1.939279729943177, 49.14924780658754],
                            [1.939480091837816, 49.14973321365721],
                            [1.939726476201954, 49.15029252129591],
                            [1.939901089203664, 49.15074186729888],
                            [1.940015729817905, 49.151147840178965],
                            [1.940038032842936, 49.15127291784952],
                            [1.9400786826006, 49.151503274961016],
                            [1.940106121473767, 49.15184239919653],
                            [1.940090758375393, 49.15221914541746],
                            [1.940038833771533, 49.152568400853],
                            [1.940006303902632, 49.152708090427254],
                            [1.939941667231574, 49.15293449354225],
                            [1.939897976356676, 49.153066786359105],
                            [1.939816421080084, 49.153260465964536],
                            [1.93969488393565, 49.15354152148326],
                            [1.939603111357302, 49.15370127590263],
                            [1.939304644659973, 49.15416067566739],
                            [1.939045589120717, 49.154492513571384],
                            [1.938764549520273, 49.1547919936153],
                            [1.938528400879658, 49.15504018217532],
                            [1.938217300127178, 49.15536374377609],
                            [1.937752709808606, 49.155847741863944],
                            [1.937322992368784, 49.156343873220585],
                            [1.936916294485169, 49.15701380522366],
                            [1.936758771024738, 49.157363352595596],
                            [1.936655536489487, 49.15765551197302],
                            [1.936572553495464, 49.1579080242288],
                            [1.936484650957162, 49.158275543933904],
                            [1.936432627481818, 49.15869027532295],
                            [1.936424846505528, 49.15880445730658],
                            [1.936420353412215, 49.158851204604794],
                            [1.936411682941337, 49.1589060306748],
                            [1.936404406282517, 49.15929629397013],
                            [1.936499035833846, 49.15997108596125],
                            [1.936542310067271, 49.160214941894736],
                            [1.936678172214937, 49.16087818725432],
                            [1.936690105717014, 49.16092858799794],
                            [1.936700645806429, 49.16098168285089],
                            [1.936716525157527, 49.16105278163155],
                            [1.936745649107598, 49.16118148045347],
                            [1.936770523474651, 49.161327250603144],
                            [1.936840510387389, 49.16165932932405],
                            [1.936908906882405, 49.16235741100266],
                            [1.936911337535203, 49.16239608835169],
                            [1.936916370461952, 49.16245186157214],
                            [1.936928635785827, 49.16267058077503],
                        ],
                    },
                },
                822: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [49.04206464125564, 2.117764141952975],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2336.0222247,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.105110703444507,
                            49.033987636271455,
                            2.128263873923673,
                            49.04558799326531,
                        ),
                        "coordinates": [
                            [2.128263873923673, 49.033987636271455],
                            [2.128129194074634, 49.034113715787555],
                            [2.127001222509834, 49.03514131753568],
                            [2.126554371205225, 49.03555093473141],
                            [2.126148450092699, 49.035907090451964],
                            [2.125911377526481, 49.03612793351793],
                            [2.12554623049908, 49.036468101551904],
                            [2.12521636011758, 49.036808334727496],
                            [2.125137259772239, 49.03689919806773],
                            [2.124921739789295, 49.03715576938806],
                            [2.124701970925326, 49.03741818034744],
                            [2.124508532850205, 49.037707907023204],
                            [2.12440497701337, 49.03785768139787],
                            [2.124326846051249, 49.037970682918875],
                            [2.124059183968403, 49.03838472483637],
                            [2.123776786101228, 49.038804811006315],
                            [2.123509210313695, 49.03921103870588],
                            [2.123276559854186, 49.03955502910891],
                            [2.123100396882108, 49.03980470005338],
                            [2.122898114370557, 49.04008399728096],
                            [2.12250205708275, 49.04057156555514],
                            [2.121908172963902, 49.041253005346746],
                            [2.121542675220651, 49.041629116409815],
                            [2.121276213118279, 49.04187861479338],
                            [2.120950794296375, 49.042158576515476],
                            [2.120635065769966, 49.042411577662996],
                            [2.12029610305886, 49.04265913833664],
                            [2.119932502105776, 49.04290935003786],
                            [2.11951273202694, 49.04317743811158],
                            [2.119077985287255, 49.04342841147821],
                            [2.118628222981144, 49.043671260106215],
                            [2.118168981940748, 49.04389070806361],
                            [2.117752285473035, 49.04407876024903],
                            [2.117253422064275, 49.04428553856905],
                            [2.116779262196315, 49.044473477956316],
                            [2.11632440698335, 49.04462638000719],
                            [2.115877800296, 49.04476940466895],
                            [2.115450420487825, 49.04489537797772],
                            [2.115038154341169, 49.045006091655345],
                            [2.114254838940086, 49.04518712632793],
                            [2.113839944694883, 49.0452726509574],
                            [2.113425656976553, 49.045347331347266],
                            [2.11300892676945, 49.045412217757935],
                            [2.112633856150531, 49.04546364254553],
                            [2.112022053058747, 49.04552899151093],
                            [2.11138984248111, 49.04556911615135],
                            [2.110894539819698, 49.04558612667887],
                            [2.110754998510663, 49.04558675096887],
                            [2.110445627189619, 49.04558799326531],
                            [2.110005283062125, 49.045570484125804],
                            [2.109539658597023, 49.04554626751525],
                            [2.109099345927297, 49.04552209925562],
                            [2.108193440028024, 49.04546705174223],
                            [2.107233059674136, 49.04539401994291],
                            [2.106582403517276, 49.045354551360596],
                            [2.105934758426439, 49.04532512796745],
                            [2.105610917541017, 49.04531443254045],
                            [2.105221049327595, 49.04530962796638],
                            [2.105110703444507, 49.045311648350264],
                        ],
                    },
                },
                823: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.912292461169045, 2.2596551973101593],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3160.84864113,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.239684117127617,
                            48.908565915509755,
                            2.279278948726629,
                            48.91401670786369,
                        ),
                        "coordinates": [
                            [2.239684117127617, 48.90963293312601],
                            [2.239788042200377, 48.90966790803246],
                            [2.241995925431958, 48.91035114100607],
                            [2.242951956154106, 48.91063745113761],
                            [2.244203785933159, 48.91103819851468],
                            [2.247133195820976, 48.91198988774084],
                            [2.24786918081334, 48.912223636908],
                            [2.248457268204739, 48.912402542415116],
                            [2.24904847188424, 48.912568016147056],
                            [2.251081180060197, 48.91312499149592],
                            [2.251763555789819, 48.91329392273688],
                            [2.252251419758943, 48.91341039674463],
                            [2.252771067623638, 48.91351737418004],
                            [2.253198357374484, 48.91359382465759],
                            [2.253694965326188, 48.91366651913946],
                            [2.254194490360345, 48.91372208158493],
                            [2.255086280297262, 48.91380175877012],
                            [2.256129412795597, 48.9138929135812],
                            [2.256804402811331, 48.91393859365573],
                            [2.257483014712011, 48.9139771356279],
                            [2.258237459247105, 48.91400382810579],
                            [2.258912507761698, 48.91401380738276],
                            [2.259685039270891, 48.91401670786369],
                            [2.260414272768297, 48.91400530048436],
                            [2.261154356673425, 48.913979619633295],
                            [2.262009984389932, 48.913937352252105],
                            [2.263067825180868, 48.91385714155414],
                            [2.263930726664052, 48.913776796819725],
                            [2.2649633538998, 48.91365372319466],
                            [2.265537425637974, 48.91357749210933],
                            [2.266515946729223, 48.913418680027654],
                            [2.267259784266638, 48.91328351289951],
                            [2.268090299584195, 48.91311508175604],
                            [2.268881116173234, 48.912937102787836],
                            [2.269661112848016, 48.912744837192434],
                            [2.270224469729805, 48.91258574914724],
                            [2.270950337336166, 48.912372027717794],
                            [2.271835124939057, 48.912089392196414],
                            [2.272420190338338, 48.911880340279616],
                            [2.273055852773434, 48.91161896918386],
                            [2.2736626589117, 48.91133854222718],
                            [2.274511446864157, 48.91094879676207],
                            [2.276371524613339, 48.910083712992474],
                            [2.277386407905229, 48.90961789327552],
                            [2.278022091681943, 48.90929225223706],
                            [2.278614480260324, 48.9089451708651],
                            [2.279278948726629, 48.908565915509755],
                        ],
                    },
                },
                824: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98022007333439, 2.0552128182098466],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1604.1909791,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.049083121493801,
                            48.97482086455293,
                            2.05978806303153,
                            48.98705700117252,
                        ),
                        "coordinates": [
                            [2.049083121493801, 48.97482086455293],
                            [2.049084494313324, 48.97482161645026],
                            [2.051445168138702, 48.97616093298332],
                            [2.051840650117065, 48.976403186488994],
                            [2.052398093672699, 48.97676718752143],
                            [2.052931631366626, 48.97714112029085],
                            [2.053467184058789, 48.97754360791849],
                            [2.053851353709436, 48.977871482222646],
                            [2.054190180684881, 48.978164981295464],
                            [2.054563394845749, 48.978514240687765],
                            [2.05491283932303, 48.97884916395295],
                            [2.055240430275703, 48.97921401207399],
                            [2.055608982067314, 48.979623215937586],
                            [2.055854620192034, 48.97990791479121],
                            [2.056091415739849, 48.98022257141917],
                            [2.056358189770312, 48.9806058267493],
                            [2.056562458671274, 48.9809204016805],
                            [2.056773091890544, 48.981260689900104],
                            [2.057228238550051, 48.98208839091795],
                            [2.058011225649485, 48.98363355133636],
                            [2.058502577100653, 48.98458839360021],
                            [2.05978806303153, 48.98705700117252],
                        ],
                    },
                },
                825: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.78038186975661, 2.0258616290799933],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 3145.01228687,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.006566869057667,
                            48.77480280977951,
                            2.044621987173176,
                            48.787390238280715,
                        ),
                        "coordinates": [
                            [2.006566869057667, 48.77480280977951],
                            [2.009207627400197, 48.77551998221428],
                            [2.012150762593544, 48.77632073131186],
                            [2.013135320830001, 48.776604296916304],
                            [2.013800047485958, 48.776801289944],
                            [2.014321057356297, 48.776955044031524],
                            [2.014838545728923, 48.777096890365996],
                            [2.015273377671665, 48.77721708596506],
                            [2.015790903839563, 48.77735416849987],
                            [2.016340756002657, 48.777503236601405],
                            [2.016991261209501, 48.777676377637114],
                            [2.017799895689103, 48.7778927864028],
                            [2.018586969518075, 48.77810436950985],
                            [2.021627507027376, 48.778921801016935],
                            [2.022874635557149, 48.779260733614514],
                            [2.02367252431761, 48.77947707071204],
                            [2.025383362444883, 48.77993621619956],
                            [2.026896514915116, 48.78034721175265],
                            [2.028894962887152, 48.78088322525144],
                            [2.029732462123214, 48.78110676527361],
                            [2.03116305426704, 48.78148892845829],
                            [2.032309533113018, 48.7818227289014],
                            [2.032880911060994, 48.78200032632209],
                            [2.03345940904871, 48.782192215908246],
                            [2.034469285971461, 48.7825525525616],
                            [2.035018876698637, 48.78276339320652],
                            [2.03554684069051, 48.782978932581834],
                            [2.036074765672647, 48.783201606342466],
                            [2.036588280324179, 48.783426619685514],
                            [2.037187879655413, 48.78370658173795],
                            [2.037826906024246, 48.784017576032426],
                            [2.039083350065184, 48.78464425604487],
                            [2.040031099034028, 48.78511546056952],
                            [2.040684464390339, 48.78544313177748],
                            [2.042483131752127, 48.78633291093265],
                            [2.044621987173176, 48.787390238280715],
                        ],
                    },
                },
                826: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.79377959655812, 2.05797549772682],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2386.69156187,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.04462198987871,
                            48.7873902392018,
                            2.071847005929401,
                            48.79870763528835,
                        ),
                        "coordinates": [
                            [2.04462198987871, 48.7873902392018],
                            [2.044851105628235, 48.78750349640637],
                            [2.046741304126305, 48.78844003846329],
                            [2.047258327554183, 48.78869832312603],
                            [2.048565214852195, 48.78936071667585],
                            [2.049383771745726, 48.78978630894997],
                            [2.051178973182095, 48.79070687265457],
                            [2.052959877315797, 48.79162023425542],
                            [2.054245460494912, 48.792256337309674],
                            [2.058741619891684, 48.794489710908344],
                            [2.061679413663929, 48.79595062396591],
                            [2.062070911434097, 48.79614191596519],
                            [2.062516342039329, 48.79634999307187],
                            [2.062907965074912, 48.79651986861153],
                            [2.063242176986505, 48.796651535583436],
                            [2.063705846985577, 48.79681920285661],
                            [2.064173185834679, 48.79697497863914],
                            [2.064637031043277, 48.797111711223465],
                            [2.066485347074011, 48.79761321151646],
                            [2.067965653930496, 48.797961639157485],
                            [2.069370074197862, 48.79828149046026],
                            [2.069903062061266, 48.79839604889063],
                            [2.070856322002004, 48.79857633553913],
                            [2.071332370669918, 48.79864848827117],
                            [2.071695582347995, 48.79869339867155],
                            [2.071847005929401, 48.79870763528835],
                        ],
                    },
                },
                827: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.23832663027716, 2.4434644187831958],
                        "indice_lig": "H",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 6764.76743301,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.417369391049351,
                            49.21385632476746,
                            2.468914115351039,
                            49.26394414450533,
                        ),
                        "coordinates": [
                            [2.417369391049351, 49.21385632476746],
                            [2.423768295033752, 49.21710297449618],
                            [2.426015745894975, 49.218571759838966],
                            [2.430514530664024, 49.22334732339265],
                            [2.44364447306937, 49.23889870640681],
                            [2.450962253011323, 49.24710198287682],
                            [2.458843796152947, 49.25518165120713],
                            [2.468914115351039, 49.26394414450533],
                        ],
                    },
                },
                828: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.04534072858193, 2.106172270618482],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 155.514119079,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.105110703444507,
                            49.04530962796638,
                            2.107233059674136,
                            49.04539401994291,
                        ),
                        "coordinates": [
                            [2.107233059674136, 49.04539401994291],
                            [2.106582403517276, 49.045354551360596],
                            [2.105934758426439, 49.04532512796745],
                            [2.105610917541017, 49.04531443254045],
                            [2.105221049327595, 49.04530962796638],
                            [2.105110703444507, 49.045311648350264],
                        ],
                    },
                },
                829: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.00896242279198, 1.9414519203399303],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 3356.83036109,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.919237111731365,
                            49.00670027774167,
                            1.963551770278395,
                            49.01014136865553,
                        ),
                        "coordinates": [
                            [1.919237111731365, 49.00670027774167],
                            [1.919962154609168, 49.00679272531784],
                            [1.921295728366337, 49.0069141644876],
                            [1.921917281266103, 49.00697828333089],
                            [1.922560355579283, 49.007063890677166],
                            [1.923297187488737, 49.0071831440945],
                            [1.924117049575658, 49.007321728962125],
                            [1.924846556663963, 49.007452842342346],
                            [1.925464049616322, 49.00757165350609],
                            [1.925994742073372, 49.007690148787006],
                            [1.926637184087518, 49.007854250715305],
                            [1.927214624944173, 49.008006220539585],
                            [1.927976094109237, 49.00821118913309],
                            [1.929596489074198, 49.00864763260691],
                            [1.930989538629571, 49.009023764111305],
                            [1.931574217397635, 49.00917811424799],
                            [1.932126587596815, 49.00930379648014],
                            [1.932754990057206, 49.009420226009],
                            [1.933340223667563, 49.009507948589494],
                            [1.93392203816692, 49.00957186287439],
                            [1.934395579228628, 49.009606839349885],
                            [1.934923451820828, 49.00963248768522],
                            [1.935849102513868, 49.00966904677881],
                            [1.937736598157521, 49.00973988652296],
                            [1.942788014531863, 49.009931083201096],
                            [1.945622882241175, 49.01004074089918],
                            [1.948128713562733, 49.010137316349436],
                            [1.948869672389161, 49.01014136865553],
                            [1.94950346371552, 49.010129952542655],
                            [1.950256828674234, 49.01009109804834],
                            [1.950640084387352, 49.01006383987754],
                            [1.951055767526005, 49.01002349259428],
                            [1.951439393410282, 49.00997730812208],
                            [1.951758150693537, 49.009935441674244],
                            [1.952171557073107, 49.009873412573974],
                            [1.952438995344456, 49.009825900306545],
                            [1.953108952031279, 49.00972107752833],
                            [1.954506871415831, 49.009492575522245],
                            [1.95577800368968, 49.009287431617906],
                            [1.957223007196716, 49.00904715853953],
                            [1.957567380590215, 49.008986308791485],
                            [1.957937978828172, 49.00890973085301],
                            [1.958356459105238, 49.008814750951345],
                            [1.958719285382097, 49.00872594319529],
                            [1.959020045817519, 49.00864861304148],
                            [1.959781349263777, 49.00841794487313],
                            [1.960484851548508, 49.00817756363266],
                            [1.961173862662032, 49.00793951235834],
                            [1.963512748838912, 49.00714055851738],
                            [1.963551770278395, 49.00712724722575],
                        ],
                    },
                },
                830: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.99521691364474, 1.985369609018619],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 4276.19533509,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.963551770278395,
                            48.98107191008835,
                            2.00593089306856,
                            49.00712724722575,
                        ),
                        "coordinates": [
                            [1.963551770278395, 49.00712724722575],
                            [1.966504229714531, 49.00612001225277],
                            [1.969169283586467, 49.00520778971877],
                            [1.969883718400177, 49.00494359496062],
                            [1.970641916885702, 49.004629566626136],
                            [1.971509280064331, 49.00422308748815],
                            [1.972351546127064, 49.00378559057962],
                            [1.97309599138091, 49.003369190331846],
                            [1.976516420966801, 49.00147957052218],
                            [1.979187413352886, 48.999984667403446],
                            [1.980383619065264, 48.999297233533895],
                            [1.980934788738326, 48.99897793357045],
                            [1.981285774062346, 48.99874632270073],
                            [1.981726285418852, 48.998435041776936],
                            [1.983292072527056, 48.997320636859996],
                            [1.986599920129499, 48.994985233047736],
                            [1.992072386069761, 48.99111444955427],
                            [1.993652914913131, 48.98999709405227],
                            [1.99458126773623, 48.989290151775776],
                            [1.995384130320824, 48.98872312763308],
                            [1.997313715319048, 48.98729411462418],
                            [1.999210479069605, 48.98589067001332],
                            [2.000143506587969, 48.985208163013866],
                            [2.000780028771487, 48.9847446304471],
                            [2.001446790197096, 48.9842983147471],
                            [2.002376770537794, 48.98373712781365],
                            [2.00351809931744, 48.98303093273212],
                            [2.004326521660503, 48.98247651381918],
                            [2.004890556772752, 48.982039676661145],
                            [2.005264894718132, 48.98174096209572],
                            [2.005683193481696, 48.98135433740403],
                            [2.00593089306856, 48.98107191008835],
                        ],
                    },
                },
                831: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.55684371677862, 2.148664039097329],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 3686.51940304,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.125707269059876,
                            48.551091975575105,
                            2.170976266414434,
                            48.56459702646747,
                        ),
                        "coordinates": [
                            [2.125707269059876, 48.551091975575105],
                            [2.126789913795467, 48.55132510271452],
                            [2.12896546467409, 48.5517954504796],
                            [2.131890509438409, 48.55242367232928],
                            [2.133658068003907, 48.55280301427043],
                            [2.135675392558938, 48.553233219469504],
                            [2.137650577218092, 48.55366140857071],
                            [2.14007951322794, 48.554183618925485],
                            [2.14171138019304, 48.55453119651698],
                            [2.142518544348514, 48.554704129145016],
                            [2.143333213733597, 48.55488373138448],
                            [2.144142858458884, 48.55506664914837],
                            [2.144958776230192, 48.55527166383912],
                            [2.145734380099473, 48.555482386378145],
                            [2.148862060813467, 48.556378656182126],
                            [2.149779004613058, 48.55662830760487],
                            [2.151408493271612, 48.557082358878276],
                            [2.153609071392398, 48.55770050523466],
                            [2.154839717419387, 48.558045579947716],
                            [2.157526642226454, 48.55879933518742],
                            [2.158085579555874, 48.55896010557366],
                            [2.158521679477913, 48.55909236685552],
                            [2.158957702515967, 48.55924627754289],
                            [2.159361065521268, 48.55941345968396],
                            [2.15977692797825, 48.55959398341209],
                            [2.161891270731794, 48.56053827358643],
                            [2.163294200748161, 48.56116332681434],
                            [2.165406154639093, 48.56211087853001],
                            [2.16592727645762, 48.56234150458849],
                            [2.169692978201667, 48.564022611808895],
                            [2.170976266414434, 48.56459702646747],
                        ],
                    },
                },
                832: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.987580197609205, 1.827066751252897],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2859.41441828,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.808907828712391,
                            48.98297976320563,
                            1.845134443502388,
                            48.992241629671234,
                        ),
                        "coordinates": [
                            [1.808907828712391, 48.98297976320563],
                            [1.814186700328448, 48.98426983899382],
                            [1.817093127672203, 48.984975485028244],
                            [1.830703012666158, 48.98830102949521],
                            [1.833822661788837, 48.9890619165253],
                            [1.834522231246966, 48.98924344293764],
                            [1.835091823233133, 48.98940774141917],
                            [1.835632348833083, 48.98958618445617],
                            [1.836215878498463, 48.98980288592875],
                            [1.836878424452741, 48.99007227475576],
                            [1.838523288626669, 48.99081468162012],
                            [1.839149631768785, 48.99109103808666],
                            [1.839617786325658, 48.99127866461101],
                            [1.840046481930515, 48.99143518747165],
                            [1.840489814688565, 48.99157511592291],
                            [1.840890015633595, 48.99168868284594],
                            [1.841431067858026, 48.99181951369095],
                            [1.841986697410191, 48.991938507597496],
                            [1.8425461638335, 48.99203610276609],
                            [1.843163547288799, 48.99212680478414],
                            [1.843683670107396, 48.99218139359167],
                            [1.844265424092584, 48.99221959223536],
                            [1.844963045003878, 48.992241629671234],
                            [1.845134443502388, 48.99224128128681],
                        ],
                    },
                },
                833: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.594448918646535, 1.629531322781602],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 6378.60219136,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.592457915304339,
                            48.58527871010612,
                            1.66971881148154,
                            48.596612809761496,
                        ),
                        "coordinates": [
                            [1.66971881148154, 48.596612809761496],
                            [1.664198319810269, 48.594542915477234],
                            [1.660447674751515, 48.59368877062189],
                            [1.653424466314514, 48.59372991001287],
                            [1.644505364755206, 48.59484050410136],
                            [1.637342623084048, 48.59587804397521],
                            [1.629937012457074, 48.59633131372066],
                            [1.61526879007175, 48.595989504779595],
                            [1.607252946713564, 48.59527279468085],
                            [1.602624234159465, 48.59449427867406],
                            [1.598634901619174, 48.592887848613124],
                            [1.595910781419093, 48.59054084389476],
                            [1.592457915304339, 48.58527871010612],
                        ],
                    },
                },
                834: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.3587161628151, 1.7009673511785828],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 22436.26679,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.621498624336312,
                            48.274632389218624,
                            1.779583709723208,
                            48.4452537046015,
                        ),
                        "coordinates": [
                            [1.779583709723208, 48.4452537046015],
                            [1.768995760656805, 48.43364412036157],
                            [1.755296596779767, 48.41844232042788],
                            [1.74151180170861, 48.40304604219221],
                            [1.732094930838047, 48.393378158543854],
                            [1.724488636728099, 48.385514651321984],
                            [1.712870493381974, 48.37538438515128],
                            [1.69956173467922, 48.362358022918535],
                            [1.688660408633678, 48.349664519598605],
                            [1.667684774478871, 48.32116946906912],
                            [1.654360385498008, 48.301768510814384],
                            [1.643524245119653, 48.288451232676536],
                            [1.636946736535745, 48.28242621097359],
                            [1.62855267565382, 48.27818475280662],
                            [1.621498624336312, 48.274632389218624],
                        ],
                    },
                },
                835: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.53471116759861, 2.002341357247183],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 973.286577058,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.995901990362833,
                            48.533732833977226,
                            2.008771813873437,
                            48.535620622584574,
                        ),
                        "coordinates": [
                            [1.995901990362833, 48.535620622584574],
                            [1.996149655407846, 48.53560324126843],
                            [1.996587037059659, 48.535559348810345],
                            [1.997030099120749, 48.53550456125951],
                            [1.999272807572155, 48.535186543819215],
                            [2.000910309415123, 48.53494032899217],
                            [2.0024632183799, 48.534695091273704],
                            [2.004712286620207, 48.53435707456925],
                            [2.006203528914461, 48.534126773590195],
                            [2.00703818318476, 48.53399786252292],
                            [2.008771813873437, 48.533732833977226],
                        ],
                    },
                },
                836: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.33320608699662, 3.101404074310204],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4861.57235986,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.071746453743138,
                            48.324052274414186,
                            3.131139534626574,
                            48.342613680163964,
                        ),
                        "coordinates": [
                            [3.071746453743138, 48.342613680163964],
                            [3.115567152603026, 48.328640816904304],
                            [3.131139534626574, 48.324052274414186],
                        ],
                    },
                },
                837: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.525515739412654, 1.5747411120645025],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 4274.46213397,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.557776370603914,
                            48.510447392863114,
                            1.589985279870708,
                            48.54218361116044,
                        ),
                        "coordinates": [
                            [1.589985279870708, 48.54218361116044],
                            [1.583732264286488, 48.53322781722326],
                            [1.572988505325944, 48.52317349734392],
                            [1.557776370603914, 48.510447392863114],
                        ],
                    },
                },
                838: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.56354715720726, 1.5925539712816026],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 4816.91675146,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.589985279870708,
                            48.54218361116044,
                            1.593413292689264,
                            48.58527871010612,
                        ),
                        "coordinates": [
                            [1.592457915304339, 48.58527871010612],
                            [1.592339852974729, 48.577706607446785],
                            [1.592992125789578, 48.56756203616545],
                            [1.593413292689264, 48.55608496382611],
                            [1.593099187967317, 48.55192354668608],
                            [1.589985279870708, 48.54218361116044],
                        ],
                    },
                },
                839: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.49751296476139, 2.6861985369150476],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 3017.03064454,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.678973982691401,
                            48.487076395248074,
                            2.69503731516767,
                            48.510265175268025,
                        ),
                        "coordinates": [
                            [2.69503731516767, 48.487076395248074],
                            [2.694245575197542, 48.487281572807596],
                            [2.693509532376374, 48.48749953727407],
                            [2.692867053870831, 48.4877118107041],
                            [2.692250465805759, 48.48793334259983],
                            [2.69158537619751, 48.48819261790166],
                            [2.690815269927012, 48.48852415773336],
                            [2.690522171756, 48.4886589831965],
                            [2.6900940554476, 48.4888578019078],
                            [2.689685481029043, 48.48907263631791],
                            [2.689297445758597, 48.48929686183042],
                            [2.688813966004562, 48.48960771190611],
                            [2.688355025342478, 48.48994636097858],
                            [2.687876290443878, 48.49035701010034],
                            [2.687522550803856, 48.490714384858826],
                            [2.687167445395255, 48.491137966707285],
                            [2.686875371613728, 48.491546235827855],
                            [2.686597845502224, 48.492047403255086],
                            [2.68643375205892, 48.49243247404081],
                            [2.686310821426463, 48.49284651427812],
                            [2.686186525672235, 48.49345300102005],
                            [2.686164067422796, 48.49372464797546],
                            [2.686173832219567, 48.494736288854114],
                            [2.686202135695622, 48.49607790229893],
                            [2.686236255323618, 48.497089467982434],
                            [2.686244244936598, 48.49784662348441],
                            [2.686282949245358, 48.499127055042585],
                            [2.686252432699991, 48.49979530194838],
                            [2.686157087701774, 48.50028659447774],
                            [2.686078125886153, 48.50060517747804],
                            [2.685816428867547, 48.501302913932896],
                            [2.685676440760374, 48.50160280062751],
                            [2.685496057224245, 48.50193158769325],
                            [2.685214692563314, 48.502333525747275],
                            [2.684955889151448, 48.502672444905656],
                            [2.684319767270796, 48.50343337706348],
                            [2.683529459310763, 48.504404306722705],
                            [2.683309378298592, 48.50467116206516],
                            [2.683097332682365, 48.50492630225843],
                            [2.682706756457446, 48.50539151659371],
                            [2.68146138858131, 48.506908773942925],
                            [2.681281486538678, 48.50711795093848],
                            [2.680970187146986, 48.50750558088728],
                            [2.680588914414678, 48.50795187415301],
                            [2.680175580334432, 48.50846031271878],
                            [2.679845527274557, 48.50887857128996],
                            [2.679604470085139, 48.50921099848539],
                            [2.679454774943514, 48.50941935062202],
                            [2.679257236993564, 48.50973015661758],
                            [2.679039404519952, 48.51013458460954],
                            [2.678973982691401, 48.510265175268025],
                        ],
                    },
                },
                840: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89475153867198, 2.355271109975443],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 3147.39469752,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352273798625216,
                            48.880922006671476,
                            2.35776859674016,
                            48.90875602475913,
                        ),
                        "coordinates": [
                            [2.356328543670162, 48.880922006671476],
                            [2.356628054656908, 48.88155417154206],
                            [2.356799333165851, 48.881982196383895],
                            [2.356994235882585, 48.88246469507391],
                            [2.357153723092858, 48.882900503241956],
                            [2.357301391124828, 48.88328961735871],
                            [2.357460898560597, 48.88376044832461],
                            [2.357638214045052, 48.88448421689481],
                            [2.357732877413799, 48.885091258325765],
                            [2.35776859674016, 48.88584618505727],
                            [2.35771581244326, 48.886426164530604],
                            [2.357672776648871, 48.88704955877387],
                            [2.357622547948076, 48.88773481642559],
                            [2.357514564652608, 48.88836298218558],
                            [2.357406615422702, 48.88907680292586],
                            [2.35732021320441, 48.88955268597487],
                            [2.357212161668813, 48.89002857305947],
                            [2.35702476399322, 48.890604406366215],
                            [2.356866168146696, 48.89102319759584],
                            [2.356671515411152, 48.89151813463572],
                            [2.356188407767444, 48.89257940363092],
                            [2.355726862337239, 48.893459837040616],
                            [2.355279785936971, 48.894483026670464],
                            [2.354955332043211, 48.89535391720402],
                            [2.354760668682024, 48.89592023004912],
                            [2.354573252941464, 48.89658647405615],
                            [2.354400303679799, 48.89735264752717],
                            [2.354321102683396, 48.89790466678896],
                            [2.354243027550289, 48.89844847923835],
                            [2.354148424680226, 48.89948338357097],
                            [2.353906105047874, 48.90043998621057],
                            [2.353278831413479, 48.90253866092549],
                            [2.352860729356008, 48.90428515788201],
                            [2.352396188268603, 48.90767816593894],
                            [2.352342196388262, 48.90815880031198],
                            [2.352273798625216, 48.90875602475913],
                        ],
                    },
                },
                841: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.05114397270041, 2.7550182741165643],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 10400.0703506,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.738670736945426,
                            48.007031701468264,
                            2.77230261766097,
                            48.09650277877714,
                        ),
                        "coordinates": [
                            [2.77230261766097, 48.09650277877714],
                            [2.769392020873821, 48.08751832323362],
                            [2.764882396188975, 48.073321753389095],
                            [2.760541633358244, 48.057163913688484],
                            [2.756089071351188, 48.04921602486933],
                            [2.750724356237062, 48.04127134372375],
                            [2.742033736695781, 48.02843722440753],
                            [2.739256682501753, 48.02379102808862],
                            [2.738670736945426, 48.019014425275365],
                            [2.740088761308753, 48.013617997936905],
                            [2.743038312684583, 48.007031701468264],
                        ],
                    },
                },
                842: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [49.21788212247294, 2.861952038330218],
                        "indice_lig": "K",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 5032.92100367,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.838108478036551,
                            49.20087707910112,
                            2.887366704975861,
                            49.23101806016452,
                        ),
                        "coordinates": [
                            [2.838108478036551, 49.20087707910112],
                            [2.844183521054062, 49.20540513205603],
                            [2.856747697064284, 49.21449898355462],
                            [2.869207547703421, 49.22369286039603],
                            [2.873402401867243, 49.226808969590174],
                            [2.875137133045359, 49.228084527008036],
                            [2.876469927580216, 49.228888680908966],
                            [2.877721599922062, 49.229457255755875],
                            [2.878842915672854, 49.22986869761287],
                            [2.880541550898866, 49.230362764675235],
                            [2.881630604801776, 49.230606456143505],
                            [2.882910408116714, 49.23082534800725],
                            [2.883833112929981, 49.23091153752207],
                            [2.884680712875338, 49.230973338334756],
                            [2.885803093887545, 49.230942296144725],
                            [2.887366704975861, 49.23101806016452],
                        ],
                    },
                },
                843: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.52548204661493, 2.659085047135647],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 757.135303279,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.654990282141887,
                            48.52299439391623,
                            2.662762979853312,
                            48.52724332146015,
                        ),
                        "coordinates": [
                            [2.662762979853312, 48.52299439391623],
                            [2.662367729584691, 48.5234163855458],
                            [2.66187938625594, 48.52388810259803],
                            [2.661552206633087, 48.5241616612084],
                            [2.661067551298998, 48.524529262119025],
                            [2.660754469951943, 48.52473303483431],
                            [2.660391868384008, 48.52497507379692],
                            [2.659807924496361, 48.52532295561293],
                            [2.659168178246081, 48.525648157075636],
                            [2.658010948626033, 48.526186144151836],
                            [2.65724369114478, 48.52652408139624],
                            [2.65690973922152, 48.526656115732926],
                            [2.656347964922313, 48.52686151098016],
                            [2.655904859934028, 48.52701113843918],
                            [2.655425094624118, 48.527144679624996],
                            [2.654990282141887, 48.52724332146015],
                        ],
                    },
                },
                844: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.936653769775475, 2.3451285029196813],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 493.357983985,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344611081014025,
                            48.93445554506131,
                            2.345604378196291,
                            48.93884268321627,
                        ),
                        "coordinates": [
                            [2.345604378196291, 48.93445554506131],
                            [2.34552682729569, 48.934759881220835],
                            [2.345435526614926, 48.935194669214006],
                            [2.345360667089803, 48.93555115323384],
                            [2.345304141024547, 48.93586840064392],
                            [2.345187141814928, 48.936525023869564],
                            [2.345094819779337, 48.93693648596403],
                            [2.344825212527904, 48.938001662135036],
                            [2.344718752966593, 48.93841979525869],
                            [2.344611081014025, 48.93884268321627],
                        ],
                    },
                },
                845: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.85924902223169, 2.3777335200959504],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 591.669847741,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37473343128132,
                            48.85745372268132,
                            2.38071878585627,
                            48.86101925991959,
                        ),
                        "coordinates": [
                            [2.37473343128132, 48.86101925991959],
                            [2.376740325336328, 48.85985761763788],
                            [2.380467183465338, 48.85760575823935],
                            [2.38071878585627, 48.85745372268132],
                        ],
                    },
                },
                846: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.14834953804842, 2.279785751042292],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 318.514756128,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.277823190629399,
                            49.14771950559884,
                            2.281752268322335,
                            49.148967156548686,
                        ),
                        "coordinates": [
                            [2.281752268322335, 49.148967156548686],
                            [2.281180812366807, 49.148787927193325],
                            [2.280938254210719, 49.14871047223341],
                            [2.280925920623213, 49.14870686865076],
                            [2.280799843988752, 49.148668138829606],
                            [2.280666916298323, 49.148626707466526],
                            [2.280554542531452, 49.148593379302895],
                            [2.279717238875601, 49.14833487591467],
                            [2.278248235215121, 49.14786022134636],
                            [2.277823190629399, 49.14771950559884],
                        ],
                    },
                },
                847: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.84318509326101, 1.8979550294451668],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 4973.64175446,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.875595590302068,
                            48.833512070590515,
                            1.924597779359982,
                            48.85999873043875,
                        ),
                        "coordinates": [
                            [1.924597779359982, 48.833512070590515],
                            [1.923194770327423, 48.8336678299516],
                            [1.921190318523971, 48.83390708528862],
                            [1.919700159752708, 48.834056324325296],
                            [1.918703550013512, 48.83415429582055],
                            [1.918185450073443, 48.83420815147946],
                            [1.917712271985488, 48.834265767155195],
                            [1.917507723534034, 48.83429109570287],
                            [1.916580250283213, 48.834427971826806],
                            [1.916093254192245, 48.834508012591954],
                            [1.915059071771255, 48.834697540693014],
                            [1.915049521137181, 48.83469930417211],
                            [1.914713855049627, 48.83476461050825],
                            [1.914315351291881, 48.83485036595376],
                            [1.913440379459775, 48.83505845562745],
                            [1.912948925994493, 48.835180733139666],
                            [1.911243513250594, 48.83564291391187],
                            [1.909382363398708, 48.83615214829706],
                            [1.908593099039535, 48.836368615725696],
                            [1.908239433593845, 48.8364653103759],
                            [1.905403226666929, 48.83724060099547],
                            [1.903368563528334, 48.83779314686094],
                            [1.901077081489615, 48.83842021676756],
                            [1.900507667949804, 48.838570020222555],
                            [1.899849395057337, 48.838754554302625],
                            [1.899424382767335, 48.83888295765245],
                            [1.898988664991143, 48.8390327328708],
                            [1.898475025416582, 48.839224402691016],
                            [1.897922117497722, 48.83947558396048],
                            [1.89771008414774, 48.83957369003812],
                            [1.897510309452956, 48.83967184306835],
                            [1.897118414863756, 48.83987661390771],
                            [1.896757918099072, 48.84007925449823],
                            [1.896431717214061, 48.840287064583684],
                            [1.896093818571919, 48.84052253545949],
                            [1.895686448907955, 48.840845898593436],
                            [1.895347895741671, 48.84115441227406],
                            [1.895101504160527, 48.84139779201599],
                            [1.894912771304306, 48.84160697994902],
                            [1.894711777059476, 48.84184091695893],
                            [1.894557405271386, 48.84204086002167],
                            [1.894442983050777, 48.84219149797927],
                            [1.894396140582562, 48.84224977023602],
                            [1.894280249967738, 48.842412092310454],
                            [1.894013749691345, 48.84281034383009],
                            [1.893179296491143, 48.84410208169784],
                            [1.893082647696013, 48.844244693385534],
                            [1.892883691705741, 48.844553275997995],
                            [1.892044938542822, 48.84586207608825],
                            [1.891800371538073, 48.84624152289608],
                            [1.891740954455565, 48.84633391831386],
                            [1.891543457631963, 48.84662991364212],
                            [1.891394259084974, 48.84685775130098],
                            [1.891184808608388, 48.84711862714696],
                            [1.891023723334837, 48.84730415165089],
                            [1.890697694876669, 48.84764910447068],
                            [1.890406339439276, 48.847925846869245],
                            [1.890255270340923, 48.84805745138342],
                            [1.889989035800739, 48.84826774298703],
                            [1.889526792071094, 48.84860586474786],
                            [1.889307542327516, 48.84874259681445],
                            [1.888833611713345, 48.849015920432066],
                            [1.887846656114627, 48.84951384686808],
                            [1.887030992758062, 48.84990362639705],
                            [1.885802010045025, 48.85048961067134],
                            [1.885644623273448, 48.850564529509974],
                            [1.885461206267309, 48.85065463242783],
                            [1.885001384395286, 48.850870442147766],
                            [1.884916533163449, 48.850910574747054],
                            [1.884114573593193, 48.8512868979541],
                            [1.883673850115235, 48.85149918048404],
                            [1.881774175736952, 48.85239990788418],
                            [1.881063508312302, 48.85277207649475],
                            [1.880789511388133, 48.85293015725882],
                            [1.880234267344406, 48.85329305004022],
                            [1.879948925488302, 48.85349874558174],
                            [1.879722433519892, 48.853676797527775],
                            [1.879519196843302, 48.85384505094054],
                            [1.879295227771028, 48.85404469541246],
                            [1.878900482159473, 48.854438800756014],
                            [1.878790236769664, 48.85457145382602],
                            [1.878616856789359, 48.85475241439242],
                            [1.878347920560391, 48.85509846201705],
                            [1.878054268363712, 48.85546419290713],
                            [1.877712091996414, 48.855918757935974],
                            [1.877197799589176, 48.856563279856786],
                            [1.876762902132102, 48.857168549597745],
                            [1.876691011294865, 48.857278872891605],
                            [1.876429417057593, 48.85771217619204],
                            [1.876237738290118, 48.8581007961128],
                            [1.876127566257983, 48.858371038954516],
                            [1.875992168270031, 48.85871582076509],
                            [1.875891533074525, 48.85898610157833],
                            [1.875595590302068, 48.85999873043875],
                        ],
                    },
                },
                848: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.731641449478616, 2.8140072233964633],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 8463.68633386,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.758824548674894,
                            48.72925514765488,
                            2.868955830083688,
                            48.73948720730179,
                        ),
                        "coordinates": [
                            [2.868955830083688, 48.73493929649145],
                            [2.868197302691268, 48.73443743566381],
                            [2.867784049931228, 48.734185762817404],
                            [2.866931699093922, 48.7336798348921],
                            [2.866467032818083, 48.73341700564049],
                            [2.865770411682557, 48.73301256464791],
                            [2.865331488334355, 48.732773592596764],
                            [2.86491451820529, 48.73255340203805],
                            [2.86431192483627, 48.732263026884524],
                            [2.863926781786748, 48.732094843778995],
                            [2.863386419585624, 48.731888839287954],
                            [2.862669776306663, 48.73162493175473],
                            [2.86215283697806, 48.731453297434555],
                            [2.861474749666426, 48.73122936145288],
                            [2.860657897438782, 48.73098581865698],
                            [2.859842602125489, 48.730760247887204],
                            [2.858843548631731, 48.730511233945165],
                            [2.857846193296063, 48.730293678992105],
                            [2.857365006652782, 48.7302015077727],
                            [2.856702068323538, 48.730079483267176],
                            [2.855970820063126, 48.729958719090966],
                            [2.855183935923024, 48.729847196453115],
                            [2.854529198100088, 48.729762945540735],
                            [2.853897747940544, 48.729695671859105],
                            [2.853191557574606, 48.72963053169702],
                            [2.851881546394702, 48.72954024452118],
                            [2.851291327253678, 48.72951593585632],
                            [2.850289313424991, 48.729500676539644],
                            [2.848813059860551, 48.72950283259856],
                            [2.846650069532342, 48.729480169015424],
                            [2.844587862873845, 48.72947590076476],
                            [2.842957897144348, 48.72946787432002],
                            [2.841327933278764, 48.72945982471901],
                            [2.839697978038175, 48.72945265049482],
                            [2.838617228953117, 48.72944752988711],
                            [2.834801274197068, 48.72942652366336],
                            [2.833001362189048, 48.729415500497375],
                            [2.830217251370838, 48.729402427376],
                            [2.828952918301787, 48.729389916391014],
                            [2.827182940742363, 48.72938137035884],
                            [2.825198167301746, 48.729371021240574],
                            [2.823526070189561, 48.72936289797087],
                            [2.821852623183643, 48.729355654981276],
                            [2.820181885325143, 48.72934747609726],
                            [2.817659276193586, 48.72932879597313],
                            [2.81551622452184, 48.72931324282554],
                            [2.813880798114946, 48.72930122664587],
                            [2.812278021432503, 48.72929174790525],
                            [2.810675252952337, 48.72928314617924],
                            [2.809569988010802, 48.729276580494016],
                            [2.808710867407425, 48.729271525386054],
                            [2.808055626852463, 48.72926779049362],
                            [2.807275329761981, 48.72926577941091],
                            [2.806365818784903, 48.72925514765488],
                            [2.805297012574751, 48.72925817231656],
                            [2.804237432553437, 48.729294486642445],
                            [2.803577238118977, 48.72934306104721],
                            [2.802987912688529, 48.72941112509641],
                            [2.802299632290224, 48.72950926731548],
                            [2.801450153482003, 48.72966831636383],
                            [2.80012998990253, 48.729945453500264],
                            [2.799212966382549, 48.73014415858717],
                            [2.797993361492169, 48.730412596199635],
                            [2.796399209198989, 48.73075267688845],
                            [2.794159153000896, 48.73123988865306],
                            [2.79205090839847, 48.7316928130709],
                            [2.790899024014458, 48.731942017693825],
                            [2.789743033765943, 48.73218942937371],
                            [2.787939899744581, 48.732583280723404],
                            [2.785063439617828, 48.73320345654553],
                            [2.784081106842361, 48.733417752737886],
                            [2.782359249856981, 48.73378871327212],
                            [2.780638726774271, 48.73415964325189],
                            [2.779508098275174, 48.73440397197068],
                            [2.778300732026962, 48.734657943050266],
                            [2.775614065430515, 48.73524387055144],
                            [2.774174435725202, 48.73555270072453],
                            [2.772639595576318, 48.735884793566306],
                            [2.770620297800346, 48.7363097723162],
                            [2.768704250597731, 48.73672982799424],
                            [2.767106809819226, 48.73706111298733],
                            [2.766364602908161, 48.73722159331134],
                            [2.765857296023076, 48.73732993730883],
                            [2.765444426882826, 48.73742428718611],
                            [2.764999324593582, 48.73753541291024],
                            [2.764618862154339, 48.73764378179794],
                            [2.764187165104781, 48.737767558755415],
                            [2.763438587470111, 48.73801000557641],
                            [2.762579183285676, 48.738293368524225],
                            [2.760393815718868, 48.73898169495798],
                            [2.758824548674894, 48.73948720730179],
                        ],
                    },
                },
                849: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80738791345056, 2.973101704150685],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3429.44115718,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.953730383101934,
                            48.80417686931555,
                            2.993109893419177,
                            48.81077532178037,
                        ),
                        "coordinates": [
                            [2.993109893419177, 48.80865396493307],
                            [2.990709606822247, 48.80940829284611],
                            [2.990089916073384, 48.809602498275076],
                            [2.989480847436489, 48.80978838952263],
                            [2.988864473045204, 48.809968624489386],
                            [2.988245197662251, 48.810114631786256],
                            [2.987891785180404, 48.81018679249689],
                            [2.987520887540429, 48.8102373648395],
                            [2.987134761606885, 48.81028226034113],
                            [2.986725759013785, 48.81031045907051],
                            [2.986282833452384, 48.81032480779425],
                            [2.985882470611465, 48.81031517942641],
                            [2.985567661028314, 48.81029920161439],
                            [2.985251696674947, 48.81026970637737],
                            [2.984839242971863, 48.810212568924996],
                            [2.984445712495797, 48.81015364008926],
                            [2.983948100423079, 48.81005212669939],
                            [2.9834130139531, 48.8099052576863],
                            [2.982975192781956, 48.80975783445286],
                            [2.982569558244773, 48.80958996827341],
                            [2.98214746043456, 48.80939256149227],
                            [2.981732746472705, 48.80915865652677],
                            [2.981419358713379, 48.808970161919746],
                            [2.980968173304679, 48.80861278717678],
                            [2.980576216825366, 48.80826907973069],
                            [2.980243498359322, 48.807957883569],
                            [2.979807976707063, 48.80754935559512],
                            [2.979513852367254, 48.80730040845847],
                            [2.979128223652701, 48.80700753241476],
                            [2.978627149519647, 48.806701028033835],
                            [2.978246420167149, 48.80650805630155],
                            [2.977949275618639, 48.80637172165721],
                            [2.977540134121476, 48.80620984049273],
                            [2.977210881022343, 48.806097477614834],
                            [2.976784224105451, 48.80597376298629],
                            [2.976310834413202, 48.80585744741021],
                            [2.975826671705476, 48.805743569536304],
                            [2.974898575063514, 48.80555078891234],
                            [2.973406135639297, 48.80521019887229],
                            [2.972597936154589, 48.805036644479415],
                            [2.971795708153195, 48.80486081691203],
                            [2.971177521615658, 48.80471782280691],
                            [2.97073312389193, 48.80461322058398],
                            [2.970252799946781, 48.80451595465856],
                            [2.969653402942331, 48.80440269023666],
                            [2.969180558675533, 48.80432679254418],
                            [2.968675390323818, 48.80425821072068],
                            [2.968238960155719, 48.80421304017145],
                            [2.967870145847296, 48.804188532897285],
                            [2.967521092309976, 48.80417812197487],
                            [2.967035392795515, 48.80417686931555],
                            [2.966628273824733, 48.804200143389494],
                            [2.966092484607458, 48.80424394268387],
                            [2.96553520449233, 48.804320388350625],
                            [2.964881026457769, 48.80443859637909],
                            [2.964375535558804, 48.80455789927259],
                            [2.96383358011103, 48.80472307806971],
                            [2.963288209296099, 48.80491910506867],
                            [2.962753187627467, 48.80513787764479],
                            [2.96221627516754, 48.80542320627935],
                            [2.961768272268781, 48.80568940898927],
                            [2.961463861820348, 48.80589497100491],
                            [2.960975800883497, 48.80627715196083],
                            [2.9600237910985, 48.80712051363151],
                            [2.959656097805605, 48.80743997880412],
                            [2.959138959974744, 48.807875035101695],
                            [2.958687671282343, 48.808280720692466],
                            [2.958352074980656, 48.80855504117014],
                            [2.957948871790213, 48.808867499395575],
                            [2.957483738092628, 48.80918084252058],
                            [2.957087460944171, 48.809419053560035],
                            [2.956658508288335, 48.809664112603315],
                            [2.956234993310772, 48.80987775025719],
                            [2.95570950477239, 48.81010428231028],
                            [2.955219071460242, 48.810301442212925],
                            [2.954702600852694, 48.81047620428591],
                            [2.954203500236609, 48.81064508445913],
                            [2.953730383101934, 48.81077532178037],
                        ],
                    },
                },
                850: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.1131808382978, 3.066219739939638],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 5184.71959853,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.057990651830578,
                            49.09188299627486,
                            3.075626562947475,
                            49.13547414375095,
                        ),
                        "coordinates": [
                            [3.075626562947475, 49.13547414375095],
                            [3.075229177092534, 49.13190698075701],
                            [3.074997143799277, 49.13004330645605],
                            [3.074880647023124, 49.129400150628506],
                            [3.074796957967831, 49.12893484720719],
                            [3.074690527752866, 49.12850656150359],
                            [3.074296624005067, 49.12708818517078],
                            [3.074212240827551, 49.12685131034866],
                            [3.074006491847284, 49.12623970998088],
                            [3.07383913453677, 49.12581500497667],
                            [3.073689679786, 49.12541727398567],
                            [3.073383919928233, 49.12469289303281],
                            [3.073212495371251, 49.12431538425196],
                            [3.072943941492871, 49.12373980592],
                            [3.072148843658405, 49.122266385691184],
                            [3.071721662778833, 49.12155057470113],
                            [3.071222571206968, 49.12078935761827],
                            [3.071003987075186, 49.120463407544555],
                            [3.070896118711915, 49.12030402067948],
                            [3.07016330651083, 49.119302380178446],
                            [3.067868341767203, 49.116335817344265],
                            [3.067689644712098, 49.11611033080519],
                            [3.066311206965854, 49.11433307627346],
                            [3.064332290773528, 49.11177361927007],
                            [3.062157512880818, 49.10898468349302],
                            [3.060935266785134, 49.10740019075615],
                            [3.060078533206293, 49.1063045379949],
                            [3.05977653731974, 49.105908351704336],
                            [3.059576345916269, 49.105612841486064],
                            [3.059189236953362, 49.10499431934409],
                            [3.058920692941152, 49.1045180156823],
                            [3.058682210216297, 49.10397483406948],
                            [3.058476461338707, 49.103434809652406],
                            [3.058327783238762, 49.102981036714304],
                            [3.058247193039191, 49.102673408270064],
                            [3.058174780306424, 49.10239764300285],
                            [3.058120632498592, 49.10215966663203],
                            [3.058059303621754, 49.10180482502257],
                            [3.057990651830578, 49.10104174296728],
                            [3.058000798243712, 49.100562978293475],
                            [3.058027201540221, 49.09993821346115],
                            [3.058106338331776, 49.099276469995374],
                            [3.058153399582697, 49.099024667705116],
                            [3.058243661281336, 49.09860436702784],
                            [3.058443706778534, 49.09788523342769],
                            [3.058597054600228, 49.09744288194165],
                            [3.058790516908031, 49.09696863312417],
                            [3.058945315833268, 49.09662620902377],
                            [3.059071015311288, 49.09637557735779],
                            [3.059465263713218, 49.095664468464236],
                            [3.05986614788201, 49.095071394540284],
                            [3.060092331018913, 49.094755168188364],
                            [3.060336291436921, 49.09444049506401],
                            [3.060907230864604, 49.09376565264417],
                            [3.06131428920744, 49.09333169078106],
                            [3.062690406987056, 49.09188299627486],
                        ],
                    },
                },
                851: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.01063462363853, 3.019372072552726],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3201.06899827,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.007953055749719,
                            48.99841539320162,
                            3.031758445836778,
                            49.021757268637266,
                        ),
                        "coordinates": [
                            [3.031758445836778, 49.021757268637266],
                            [3.031192632609206, 49.021451637047775],
                            [3.02937804733439, 49.020469780313704],
                            [3.027564913344277, 49.01948878511261],
                            [3.02728111042359, 49.0193358148912],
                            [3.02663359523629, 49.0189862859137],
                            [3.025066047911244, 49.01814143261744],
                            [3.024772607323102, 49.01798163076165],
                            [3.024320414073001, 49.01772946360061],
                            [3.024030862086733, 49.017554935796205],
                            [3.023536827606953, 49.01722695089455],
                            [3.023100171713156, 49.016895023382475],
                            [3.022899041594082, 49.01672867265889],
                            [3.022629808841753, 49.01648710658191],
                            [3.022483522244274, 49.01634640667193],
                            [3.022301120954777, 49.01615761930662],
                            [3.022153265296338, 49.01599741225286],
                            [3.021938391680297, 49.01574671934196],
                            [3.021770680404929, 49.015521200120375],
                            [3.02163132744376, 49.015332153801204],
                            [3.021463228469008, 49.01507832136779],
                            [3.02126742711388, 49.01477192065155],
                            [3.02080333898293, 49.01403455861575],
                            [3.020706914916997, 49.01388314989977],
                            [3.020231597272865, 49.013123370146694],
                            [3.01915639215236, 49.011399439643824],
                            [3.018881948950972, 49.01095968816022],
                            [3.018517641772965, 49.01037359352136],
                            [3.018200391891305, 49.00987006775914],
                            [3.017175887840634, 49.00823491279709],
                            [3.016194869955983, 49.006675932294584],
                            [3.015947465032778, 49.00627810431446],
                            [3.015769944192662, 49.00599227676004],
                            [3.015307289719046, 49.005247689988494],
                            [3.01432916091712, 49.003691374475046],
                            [3.014059725863468, 49.00326489472907],
                            [3.013773452435715, 49.002835817453686],
                            [3.013461663756977, 49.00242487544922],
                            [3.01312957451806, 49.00202844149354],
                            [3.01297470197025, 49.00185554213996],
                            [3.01256631797443, 49.00142489465815],
                            [3.012451480966465, 49.001316591611705],
                            [3.012254967627573, 49.00113878768798],
                            [3.0119200580077, 49.00083499668754],
                            [3.011495428768955, 49.00049014226873],
                            [3.011226927479065, 49.000291851492186],
                            [3.010930269025352, 49.00007040730094],
                            [3.01050480379268, 48.99978573999148],
                            [3.010286490798526, 48.99963947221157],
                            [3.010005726162612, 48.99946956561279],
                            [3.00974543992512, 48.999316193900626],
                            [3.009459731780556, 48.99915464446193],
                            [3.009072232651956, 48.99895371517964],
                            [3.008726609738067, 48.99877816606785],
                            [3.007953055749719, 48.99841539320162],
                        ],
                    },
                },
                852: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.8111628812768, 3.061798363457108],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2985.59158757,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.042938266046296,
                            48.80850206349516,
                            3.080343011929784,
                            48.81379848212747,
                        ),
                        "coordinates": [
                            [3.080343011929784, 48.80850206349516],
                            [3.077337778782705, 48.80999479199734],
                            [3.076203956715552, 48.81054704631031],
                            [3.075637423893467, 48.81079534474709],
                            [3.074624970621095, 48.811206866164355],
                            [3.074109584200572, 48.811415209083286],
                            [3.073608284995546, 48.81160257434704],
                            [3.073257314184835, 48.811717256529384],
                            [3.072842308029973, 48.81182965276151],
                            [3.072397161657425, 48.81192965196878],
                            [3.072056771736029, 48.811985988283766],
                            [3.07154987570324, 48.81204763426375],
                            [3.071150429905094, 48.81207876106522],
                            [3.07064266552498, 48.812093925838596],
                            [3.070174614624569, 48.81209325355607],
                            [3.069730800639253, 48.81206885645771],
                            [3.06922741406098, 48.81201542050371],
                            [3.068768605683843, 48.811948501513655],
                            [3.068281031903928, 48.81184910701382],
                            [3.067869039132653, 48.81174758022826],
                            [3.067258228455184, 48.81158362811228],
                            [3.066055549972939, 48.811255417993024],
                            [3.064562672837766, 48.81084766964273],
                            [3.063570161269064, 48.810576107919594],
                            [3.063190249204707, 48.81048077320204],
                            [3.062731238120739, 48.81037820479021],
                            [3.062299734494043, 48.810293716266784],
                            [3.061734649862922, 48.81019928447444],
                            [3.061337177726046, 48.810142780910866],
                            [3.060850704234703, 48.810087987868364],
                            [3.060318775992009, 48.81004214102092],
                            [3.059727520435087, 48.810004282581815],
                            [3.059162589014512, 48.809990013659],
                            [3.058539993926606, 48.80999022031065],
                            [3.05795603690172, 48.81001192664627],
                            [3.057420476558753, 48.81005655942325],
                            [3.056979738827774, 48.8100945127738],
                            [3.056536570203853, 48.81014407546588],
                            [3.056114288123208, 48.810204396527894],
                            [3.055736420541823, 48.810271429791825],
                            [3.055361687483528, 48.8103457371135],
                            [3.054923853522874, 48.810442370048946],
                            [3.054450694137266, 48.810562084202886],
                            [3.053470575770452, 48.8108306791563],
                            [3.052621725555496, 48.81107612898464],
                            [3.051925008576484, 48.811273284102455],
                            [3.05109163126128, 48.81150829539009],
                            [3.050282368077969, 48.81173650053079],
                            [3.049613514773414, 48.811926650424],
                            [3.048899124828313, 48.81212859854744],
                            [3.04806640062477, 48.81236457758318],
                            [3.047031617794968, 48.81265700927636],
                            [3.045692455870439, 48.81302268428452],
                            [3.04425523172087, 48.813428793955524],
                            [3.042938266046296, 48.81379848212747],
                        ],
                    },
                },
                853: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.87217992809245, 2.8679179775721435],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3142.65038893,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.854315926463895,
                            48.8632902390859,
                            2.883201728539714,
                            48.88268104666967,
                        ),
                        "coordinates": [
                            [2.854315926463895, 48.88268104666967],
                            [2.856644668363824, 48.879458828545886],
                            [2.856802549398204, 48.879233090773596],
                            [2.856967915321395, 48.878981746810574],
                            [2.857125472733312, 48.878725324765526],
                            [2.857300441789926, 48.87840404647633],
                            [2.857541207895059, 48.87794949901487],
                            [2.858091106318945, 48.87690712689522],
                            [2.858261485896771, 48.876642122518],
                            [2.858447525942609, 48.87639238679099],
                            [2.858654364811935, 48.87615448946868],
                            [2.858856356248211, 48.87594729824542],
                            [2.859117480361318, 48.875710857049796],
                            [2.859409754393366, 48.87548790905373],
                            [2.859725372881151, 48.87527337729556],
                            [2.860046392311225, 48.87508098203457],
                            [2.860390773514688, 48.87489870605718],
                            [2.860768874931072, 48.87472820604863],
                            [2.861201273422776, 48.874560866805496],
                            [2.861543767572944, 48.87444507736772],
                            [2.861876136110965, 48.874349792066305],
                            [2.862254946805611, 48.87424747273815],
                            [2.864206011614499, 48.87375264082796],
                            [2.867131344306717, 48.87301971093815],
                            [2.867510153847908, 48.87291907816883],
                            [2.867925082625485, 48.872813162839556],
                            [2.86826776444696, 48.872717809901225],
                            [2.868641236798737, 48.872601856018726],
                            [2.868957877339857, 48.87248787119745],
                            [2.869274366675177, 48.87236024823657],
                            [2.869696145252711, 48.87217076407481],
                            [2.870081668388279, 48.87197462912744],
                            [2.87041811238854, 48.87178042726096],
                            [2.870726073705668, 48.871581242958904],
                            [2.871018454882052, 48.87137531150639],
                            [2.871274675236126, 48.87117125415404],
                            [2.871479563927353, 48.870999825651765],
                            [2.871730337336006, 48.870770220090506],
                            [2.872022029269046, 48.87050121664161],
                            [2.873173454380311, 48.86944231164542],
                            [2.874693250766208, 48.86804412933708],
                            [2.874962026773236, 48.86780932015138],
                            [2.875215647262726, 48.8676069687116],
                            [2.875436174813149, 48.8674508033667],
                            [2.875728662957316, 48.86725849608329],
                            [2.875993129543531, 48.86710382587176],
                            [2.876314198417295, 48.86692672442582],
                            [2.8767303650063, 48.86670314641096],
                            [2.880709417232306, 48.864561911953444],
                            [2.88200910774739, 48.86385849111414],
                            [2.882355912784986, 48.86367613555402],
                            [2.882646253346079, 48.863528144039876],
                            [2.882916183764921, 48.86340411480701],
                            [2.883201728539714, 48.8632902390859],
                        ],
                    },
                },
                854: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.98106315549728, 2.0768962508253357],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 2305.58842662,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.073769886475506,
                            48.970665048322616,
                            2.07803798220009,
                            48.99101254867934,
                        ),
                        "coordinates": [
                            [2.073769886475506, 48.99101254867934],
                            [2.073779661264222, 48.99096171188935],
                            [2.073879411496579, 48.99055983125146],
                            [2.074019020488473, 48.99014138587337],
                            [2.0741983857691, 48.98972541061173],
                            [2.074432381748382, 48.989233421812195],
                            [2.074808983748562, 48.988437201885674],
                            [2.076362176250532, 48.985269071863705],
                            [2.076742329616248, 48.984472853600245],
                            [2.076939740037784, 48.984054535501954],
                            [2.077115342777914, 48.983657581467504],
                            [2.07729858464019, 48.98318212852255],
                            [2.077412377923963, 48.98285165677231],
                            [2.077537304439022, 48.98246648461567],
                            [2.077658884537246, 48.98202895926283],
                            [2.077754922611568, 48.98163658249293],
                            [2.077843965823255, 48.981198983651325],
                            [2.077899965343129, 48.98085886246776],
                            [2.077963815271243, 48.98039979261784],
                            [2.07800954927886, 48.97994781801503],
                            [2.07803798220009, 48.979348284876586],
                            [2.078028030755505, 48.97848455869799],
                            [2.078002901077792, 48.97775879810884],
                            [2.077873249960118, 48.974206130751305],
                            [2.077731764565598, 48.970665048322616],
                        ],
                    },
                },
                855: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9018782236084, 2.8068273689403016],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 616.487330738,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.804079706711413,
                            48.89979105744454,
                            2.810248219362661,
                            48.90307291600507,
                        ),
                        "coordinates": [
                            [2.810248219362661, 48.90307291600507],
                            [2.80700011758749, 48.90218589628686],
                            [2.806685256018316, 48.90209439511844],
                            [2.806337598314561, 48.90196971756673],
                            [2.805949929325692, 48.901811891212596],
                            [2.80563807401666, 48.901656130886366],
                            [2.805340409447035, 48.90147413990198],
                            [2.805076227268223, 48.90127516834251],
                            [2.804841725161372, 48.90108520412572],
                            [2.804625020575563, 48.900862778988035],
                            [2.804452413589881, 48.900655512765645],
                            [2.804318561411674, 48.90044468005146],
                            [2.804197253894176, 48.900192882600365],
                            [2.804128216979653, 48.90000053427984],
                            [2.804079706711413, 48.89979105744454],
                        ],
                    },
                },
                856: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.848614140305266, 2.3499894022314236],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 481.626619969,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.348054291858487,
                            48.846656851242656,
                            2.351623255016012,
                            48.850127322904584,
                        ),
                        "coordinates": [
                            [2.351623255016012, 48.846656851242656],
                            [2.351518372646667, 48.8467659443561],
                            [2.35146969506008, 48.84682541413321],
                            [2.351199743531648, 48.84717358979796],
                            [2.349311715993315, 48.84960855678914],
                            [2.349302354925577, 48.84962037109677],
                            [2.349244828292, 48.84968373629803],
                            [2.34917816410915, 48.84974307660665],
                            [2.349103008660787, 48.84979781813686],
                            [2.349020085317445, 48.849847435087916],
                            [2.348930191834036, 48.84989144793149],
                            [2.348834194752249, 48.84992943507336],
                            [2.348733018555706, 48.8499610282985],
                            [2.348692092074515, 48.84997161488691],
                            [2.348054291858487, 48.850127322904584],
                        ],
                    },
                },
                857: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.87215890573533, 2.3494715466878078],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2383.56014927,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345430546578709,
                            48.861822272798115,
                            2.357115334947971,
                            48.88076895833307,
                        ),
                        "coordinates": [
                            [2.347012687238757, 48.861822272798115],
                            [2.346139950534157, 48.86386291966857],
                            [2.345636988821748, 48.86531838987238],
                            [2.345557722441634, 48.86568232681121],
                            [2.345522355293041, 48.865997287939436],
                            [2.345482191727732, 48.86627516707191],
                            [2.345453618065505, 48.86658002326778],
                            [2.345441380929341, 48.866759879030795],
                            [2.345437319872033, 48.866928043946544],
                            [2.345430546578709, 48.86717264717367],
                            [2.345437983713143, 48.867400407823276],
                            [2.345444249176205, 48.867599802139644],
                            [2.345459272257531, 48.867767065829796],
                            [2.345478390228793, 48.8679694010646],
                            [2.34550295806468, 48.86815105240558],
                            [2.345535809422007, 48.868338646891864],
                            [2.345582320764311, 48.86849683109246],
                            [2.345653412169549, 48.868684934039884],
                            [2.345736183005508, 48.86887944650945],
                            [2.345823453089305, 48.86903771212665],
                            [2.345989418474129, 48.869313639539946],
                            [2.346169802910834, 48.8696123196003],
                            [2.346423420956653, 48.869966612439036],
                            [2.346563867742066, 48.87016623878365],
                            [2.34683112753148, 48.87054211184874],
                            [2.346978707051198, 48.870755475257596],
                            [2.347148845854515, 48.870995316639934],
                            [2.347291782533406, 48.87119926333222],
                            [2.347413389762284, 48.8713756852506],
                            [2.347525209254973, 48.87153664437751],
                            [2.347620664123193, 48.8716733246529],
                            [2.347812940357576, 48.871949383184464],
                            [2.347889305541526, 48.87205908782341],
                            [2.347988853327868, 48.872200263339515],
                            [2.347991580985481, 48.87220475960292],
                            [2.348117039735388, 48.87238460199915],
                            [2.348223677774877, 48.87253583271807],
                            [2.348327049504371, 48.87268403904699],
                            [2.348438874629225, 48.872844997129704],
                            [2.348565700165098, 48.873023939841445],
                            [2.348793443130341, 48.87334855400916],
                            [2.348914816201521, 48.87352030156975],
                            [2.349120741423353, 48.873807148208115],
                            [2.349242116960456, 48.873977996929256],
                            [2.34937304071208, 48.87416503150311],
                            [2.349493054517679, 48.87433587969868],
                            [2.349629434954679, 48.874534603476704],
                            [2.349892649886407, 48.87490417492728],
                            [2.350011172639738, 48.87505591606561],
                            [2.350147675855348, 48.875222488499574],
                            [2.350300411336523, 48.87538164119075],
                            [2.350391782008514, 48.87547875183336],
                            [2.350496784902015, 48.87557496148159],
                            [2.350659063038761, 48.87572422147292],
                            [2.350900428930991, 48.87591663572261],
                            [2.351025884203083, 48.87601194310479],
                            [2.351115884397448, 48.876075780178056],
                            [2.351241336677679, 48.87615759816922],
                            [2.351519512826296, 48.87633381927517],
                            [2.351627237619566, 48.87640214970282],
                            [2.351722691737228, 48.87646148947573],
                            [2.351914961644672, 48.87657926872294],
                            [2.352019960308049, 48.876644001966824],
                            [2.352115414232821, 48.8767024420729],
                            [2.352268140687587, 48.87679594589649],
                            [2.353010576106873, 48.877242747218865],
                            [2.353466110615679, 48.877536326382575],
                            [2.354125305776175, 48.87800155410312],
                            [2.354773056677193, 48.87850528865128],
                            [2.355374585563331, 48.878979859670146],
                            [2.356321622424064, 48.87975798181816],
                            [2.356458336773375, 48.87988471140258],
                            [2.356680756385788, 48.880127307226694],
                            [2.356875876646691, 48.880369270286586],
                            [2.357066538030486, 48.88067080499799],
                            [2.357115334947971, 48.88076895833307],
                        ],
                    },
                },
                858: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.91331566771093, 2.3182610987949297],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1812.63218865,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313835382457718,
                            48.9056549540281,
                            2.322400403166692,
                            48.92087280435657,
                        ),
                        "coordinates": [
                            [2.322400403166692, 48.9056549540281],
                            [2.322343016394903, 48.90593448954394],
                            [2.322321163367262, 48.90602351577318],
                            [2.322170935282105, 48.90659094009398],
                            [2.321997513371347, 48.90715476491949],
                            [2.321796827133725, 48.90764034846976],
                            [2.321728563122154, 48.90781120180266],
                            [2.321556521307095, 48.90813313361577],
                            [2.321330207791256, 48.90849833197662],
                            [2.321124362874009, 48.90881475654188],
                            [2.320629817828479, 48.90946752188185],
                            [2.32032954704596, 48.90985776609357],
                            [2.319924176440652, 48.91038198561147],
                            [2.319649816930623, 48.910773131270716],
                            [2.319528325280212, 48.910965558119436],
                            [2.319283957033095, 48.91140706628604],
                            [2.319120000188026, 48.91170536711489],
                            [2.318942970870801, 48.91211458694541],
                            [2.318588852132442, 48.91307578575448],
                            [2.318484080193902, 48.913306565552205],
                            [2.318422652102822, 48.91346121270532],
                            [2.318357623693711, 48.91359444478965],
                            [2.318252869329116, 48.913770499719135],
                            [2.317815825746098, 48.914389057347904],
                            [2.317255971307212, 48.9151598709375],
                            [2.316649141155665, 48.91599491534771],
                            [2.31648659391065, 48.91621854476956],
                            [2.315905032023427, 48.916998864982666],
                            [2.315649614227107, 48.9173796010488],
                            [2.315411178041731, 48.91775549361236],
                            [2.315288340981974, 48.91795533477694],
                            [2.31510882904646, 48.918283126780764],
                            [2.314389064917821, 48.91974791118154],
                            [2.313911022100327, 48.92071723734009],
                            [2.313835382457718, 48.92087280435657],
                        ],
                    },
                },
                859: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.742372967526805, 2.29696124963346],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2658.6298568,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.281050094857402,
                            48.736934177101105,
                            2.312711013515798,
                            48.747941901886946,
                        ),
                        "coordinates": [
                            [2.281050094857402, 48.736934177101105],
                            [2.281649451204855, 48.73708723570982],
                            [2.282179988699193, 48.737229321493196],
                            [2.282715905060216, 48.73736076879698],
                            [2.28346081322031, 48.73755968148079],
                            [2.28402909496622, 48.73771125523257],
                            [2.284358003944237, 48.73781302524864],
                            [2.284654278956173, 48.73792107484667],
                            [2.284907058945396, 48.738018311686574],
                            [2.285234579335344, 48.738152452980955],
                            [2.285793129839512, 48.73838651607704],
                            [2.286662910560374, 48.73874121723714],
                            [2.287618993349294, 48.73913942065063],
                            [2.288441910765133, 48.73948119063661],
                            [2.289417744531419, 48.73987458505421],
                            [2.290606959593062, 48.74037507043785],
                            [2.290952185464527, 48.74051010131528],
                            [2.291393925343595, 48.74066945042673],
                            [2.291777456021941, 48.74079103458878],
                            [2.292338621659828, 48.74096568480165],
                            [2.293081974937282, 48.74118454072133],
                            [2.293736004545056, 48.741369098253784],
                            [2.295511505203764, 48.741870524410345],
                            [2.297202400269014, 48.74233887743137],
                            [2.300400244584853, 48.74318740057063],
                            [2.301246714029321, 48.74344721845134],
                            [2.302263413507445, 48.74375938173845],
                            [2.302933781349519, 48.7439711063506],
                            [2.303303545232317, 48.74409981029637],
                            [2.303797013418046, 48.74428070792639],
                            [2.304335176901581, 48.74448769775749],
                            [2.304745197893997, 48.74467102201594],
                            [2.304981031273856, 48.744791829642836],
                            [2.305547870507395, 48.74508334955477],
                            [2.306037219836903, 48.7453568609457],
                            [2.306682871457191, 48.74576170539381],
                            [2.307403275670077, 48.746247498851424],
                            [2.308134578430528, 48.746719802528396],
                            [2.308449949484962, 48.746909627458685],
                            [2.308724546587425, 48.74706347071359],
                            [2.309017596454245, 48.74720002578425],
                            [2.309251525322473, 48.74729439605155],
                            [2.309557930520907, 48.74741258935359],
                            [2.309762132361388, 48.7474767165459],
                            [2.310015491351156, 48.74756048434858],
                            [2.310271728727082, 48.74763037994978],
                            [2.310543117409528, 48.74769384872567],
                            [2.310818322496114, 48.74775190717779],
                            [2.311142616636978, 48.747811629750544],
                            [2.31142748001463, 48.747856358817074],
                            [2.311790727320648, 48.747898337007165],
                            [2.312197969687264, 48.74792673771592],
                            [2.312529148392644, 48.74793905512518],
                            [2.312711013515798, 48.747941901886946],
                        ],
                    },
                },
                860: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.82194275596548, 2.3842004486949167],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2081.76727457,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.376695892125261,
                            48.813989052009454,
                            2.391686971662538,
                            48.82987504460341,
                        ),
                        "coordinates": [
                            [2.391686971662538, 48.813989052009454],
                            [2.391644736066674, 48.81403367489162],
                            [2.391256089487555, 48.814445486936805],
                            [2.390734284057633, 48.81499536125855],
                            [2.390298842776883, 48.81545953803256],
                            [2.389615060350911, 48.816173659556846],
                            [2.388902483060373, 48.81693537502156],
                            [2.387675212460237, 48.818242186449375],
                            [2.386429870754618, 48.81955851019719],
                            [2.384853298547533, 48.821222344253066],
                            [2.383431420318824, 48.822726677377766],
                            [2.382729474191612, 48.823497868782205],
                            [2.382412726451002, 48.82388344932435],
                            [2.38204555869107, 48.82430711771084],
                            [2.381713885426457, 48.82464175224206],
                            [2.381462328800976, 48.824904562472305],
                            [2.381174280815445, 48.82516640174247],
                            [2.38100145262221, 48.825325884515536],
                            [2.380241787770921, 48.826111359755714],
                            [2.379957379772388, 48.826432677685865],
                            [2.379118555179876, 48.82740138296538],
                            [2.378513688223332, 48.82806544209967],
                            [2.376695892125261, 48.82987504460341],
                        ],
                    },
                },
                861: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.81787032423113, 2.4178621537907707],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 1006.33706735,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.413737517516731,
                            48.814803007000464,
                            2.422376142845623,
                            48.82159576732173,
                        ),
                        "coordinates": [
                            [2.422376142845623, 48.814803007000464],
                            [2.421067977076466, 48.81523974790579],
                            [2.420832869221672, 48.815320028187344],
                            [2.420597762014679, 48.815400307108156],
                            [2.420381046994354, 48.81549028278448],
                            [2.420220928957431, 48.815558400626045],
                            [2.420067529519512, 48.815629366791974],
                            [2.419849647707164, 48.8157389755548],
                            [2.419657944879164, 48.81585547610576],
                            [2.41948890653203, 48.81596562435418],
                            [2.419328623339417, 48.81609419905796],
                            [2.419175343599234, 48.816238898323974],
                            [2.419064760427647, 48.81635706724039],
                            [2.418941997854795, 48.81649598305599],
                            [2.418816271325988, 48.81663635210845],
                            [2.418758740308558, 48.81669889485958],
                            [2.418705536641495, 48.81675806796601],
                            [2.417030950318258, 48.81860357083674],
                            [2.41593644556262, 48.81965553109013],
                            [2.41483245148485, 48.82076413698176],
                            [2.413737517516731, 48.82159576732173],
                        ],
                    },
                },
                862: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.8816800661722, 2.2912170288033753],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1300.40567099,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.284431219916768,
                            48.87790843816007,
                            2.29803330457685,
                            48.8854042809258,
                        ),
                        "coordinates": [
                            [2.284431219916768, 48.87790843816007],
                            [2.284637913298522, 48.87806762103028],
                            [2.28512705878747, 48.87837359725023],
                            [2.288183582753859, 48.880032301006736],
                            [2.28927924077639, 48.880625383994165],
                            [2.289461851970203, 48.88072527907499],
                            [2.28985569655129, 48.88093856992243],
                            [2.290573895455465, 48.88132554987828],
                            [2.291211696658164, 48.88167022841889],
                            [2.291861773542192, 48.88202120301819],
                            [2.293625319392737, 48.88299489788621],
                            [2.295172239169192, 48.88383539405694],
                            [2.296742382001151, 48.884687567547985],
                            [2.297362300724286, 48.885028422180405],
                            [2.297937730828242, 48.885352544004384],
                            [2.29803330457685, 48.8854042809258],
                        ],
                    },
                },
                863: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.79620666123304, 2.1495320290864575],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 1102.10440123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.142141851963426,
                            48.795715917344765,
                            2.15683568548617,
                            48.797310081377546,
                        ),
                        "coordinates": [
                            [2.142141851963426, 48.795715917344765],
                            [2.142706607881934, 48.79574745613372],
                            [2.143856757254184, 48.79579486437915],
                            [2.147234244824272, 48.795959949065534],
                            [2.148995074205409, 48.79602948652837],
                            [2.150017745902113, 48.796064478878215],
                            [2.150442631394686, 48.79608658921006],
                            [2.150781082583517, 48.79610855609176],
                            [2.151285101512348, 48.7961569644232],
                            [2.151641490132594, 48.796197992654015],
                            [2.152030230622056, 48.79625572855427],
                            [2.152480159919246, 48.796323079295],
                            [2.152976821918897, 48.79641429648562],
                            [2.154495584415558, 48.796699879271635],
                            [2.155085753590148, 48.7968293061806],
                            [2.155636272857649, 48.79696818445126],
                            [2.155923219353944, 48.797048173958764],
                            [2.15683568548617, 48.797310081377546],
                        ],
                    },
                },
                864: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84758078099591, 2.266693751160531],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 377.860796719,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.264218775687729,
                            48.847150054810506,
                            2.26913587274288,
                            48.84793480789206,
                        ),
                        "coordinates": [
                            [2.264218775687729, 48.84793480789206],
                            [2.264487791752322, 48.8479095682552],
                            [2.264793999647843, 48.847872098538694],
                            [2.265098029681218, 48.847827560027916],
                            [2.265150903024347, 48.84781905571141],
                            [2.266008188932392, 48.84762588821207],
                            [2.266470600566861, 48.84751673234948],
                            [2.266796430405863, 48.84748206692934],
                            [2.267280705897958, 48.84747655008249],
                            [2.267733354047905, 48.84749907332624],
                            [2.267816938819927, 48.84750175506047],
                            [2.267948212229081, 48.847500019459154],
                            [2.268078805166548, 48.84749104054676],
                            [2.268207798259172, 48.847474879255266],
                            [2.268334293155357, 48.847451652409816],
                            [2.26845739768979, 48.84742152184523],
                            [2.268576250398807, 48.84738469545496],
                            [2.268690016308189, 48.84734143615876],
                            [2.268696245147245, 48.847338819301996],
                            [2.26913587274288, 48.847150054810506],
                        ],
                    },
                },
                865: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.8360950499327, 2.4046850439652596],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 452.342195758,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.402333164555186,
                            48.8347851580814,
                            2.406280328778553,
                            48.83711700698871,
                        ),
                        "coordinates": [
                            [2.405383210626771, 48.8347851580814],
                            [2.406123460289508, 48.835237534670014],
                            [2.406149436361219, 48.83525464812118],
                            [2.406195075206364, 48.83529235567804],
                            [2.406231689765138, 48.83533413210694],
                            [2.406258463684416, 48.835379045220286],
                            [2.406274796675007, 48.83542609105325],
                            [2.406280328778553, 48.83547421646748],
                            [2.406274930496894, 48.83552234878056],
                            [2.406258728463678, 48.83556941477997],
                            [2.406232079338666, 48.83561436037969],
                            [2.406195580371164, 48.83565618035183],
                            [2.406150047319025, 48.83569394340024],
                            [2.406096496586366, 48.835726805562864],
                            [2.406036127279206, 48.835754030809234],
                            [2.406029379211099, 48.835756559585484],
                            [2.402333164555186, 48.83711700698871],
                        ],
                    },
                },
                866: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.8549943562229, 2.2885902008619197],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 562.948769348,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.286419448213008,
                            48.853033488503854,
                            2.290391553460649,
                            48.857293413870465,
                        ),
                        "coordinates": [
                            [2.290391553460649, 48.857293413870465],
                            [2.290233969629259, 48.857116916754364],
                            [2.290008021717807, 48.85681736577427],
                            [2.289933189343854, 48.8566878397138],
                            [2.289829784316117, 48.856507942791616],
                            [2.289555002595611, 48.85597545777357],
                            [2.289344119514535, 48.85560756696089],
                            [2.289137257007656, 48.85531431749175],
                            [2.289004555406866, 48.855147078499826],
                            [2.288856018681601, 48.85496090005867],
                            [2.288707462235874, 48.85479840769266],
                            [2.288512776337732, 48.85461220893282],
                            [2.288389863687753, 48.85451724497622],
                            [2.286419448213008, 48.853033488503854],
                        ],
                    },
                },
                867: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.00596191886903, 2.0882839213425717],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3008.10735935,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.085506679860896,
                            48.995462534556246,
                            2.094643974392771,
                            49.01834916361145,
                        ),
                        "coordinates": [
                            [2.094643974392771, 48.99574683395328],
                            [2.094115793261617, 48.995631206683015],
                            [2.093749494578502, 48.995566662210194],
                            [2.093352059656961, 48.995501574705614],
                            [2.092896647311002, 48.995462534556246],
                            [2.092455498486702, 48.99546397305766],
                            [2.091996081612054, 48.99550344011252],
                            [2.091605246115984, 48.9955668459734],
                            [2.091210619108013, 48.995665930766954],
                            [2.090790492348363, 48.995803031724805],
                            [2.090431784401015, 48.99594978007585],
                            [2.090109150295021, 48.99611325923673],
                            [2.089844381610968, 48.99627448493622],
                            [2.089575805183725, 48.99647376950273],
                            [2.089375987873591, 48.99666130569426],
                            [2.089172342072614, 48.99689166331516],
                            [2.089019243828573, 48.997136404045776],
                            [2.088858511452071, 48.997462026615274],
                            [2.088774556142994, 48.99766941850957],
                            [2.088653983776406, 48.99819439395835],
                            [2.088283466587654, 48.999851410536195],
                            [2.088171523848284, 49.00037005180863],
                            [2.088059416498945, 49.000921067583164],
                            [2.087829779056399, 49.00203004764123],
                            [2.087759262258183, 49.00238917605548],
                            [2.08762642643255, 49.00291576456261],
                            [2.087564108166994, 49.003200564597314],
                            [2.087124533193176, 49.00526165541821],
                            [2.08701554469947, 49.00573174133361],
                            [2.086676559529283, 49.007354201266836],
                            [2.086561849354139, 49.007872835421814],
                            [2.086375748551401, 49.008722248144664],
                            [2.086279170620937, 49.009168080012586],
                            [2.08625538646241, 49.00927594164314],
                            [2.085806100710601, 49.0113433012357],
                            [2.085579489851317, 49.012358091396464],
                            [2.085532733313348, 49.01268172920538],
                            [2.085506679860896, 49.01296674442584],
                            [2.085524365549785, 49.013253652989704],
                            [2.085552513396006, 49.01336432689372],
                            [2.085565883876988, 49.01342370825528],
                            [2.085678753985918, 49.01381244534922],
                            [2.085820813494618, 49.01410682136232],
                            [2.085952412419675, 49.01430764943292],
                            [2.086194093017157, 49.01462478800239],
                            [2.086488001898017, 49.01491583604665],
                            [2.087009451542514, 49.01534862891433],
                            [2.087201471451877, 49.015498328538634],
                            [2.087371888939506, 49.015594023785575],
                            [2.088199244624964, 49.01609942066983],
                            [2.08859712910706, 49.016367370471684],
                            [2.089009926742526, 49.016661429272084],
                            [2.089481020740325, 49.01705543400022],
                            [2.090052730601043, 49.01756386144909],
                            [2.090557643614887, 49.018034373000205],
                            [2.090906063354292, 49.01834916361145],
                        ],
                    },
                },
                868: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.73196009027211, 2.4248197089895176],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 1754.50043697,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.419565024387933,
                            48.72553530486119,
                            2.427126860952247,
                            48.739830699436546,
                        ),
                        "coordinates": [
                            [2.419565024387933, 48.72553530486119],
                            [2.42003172895545, 48.72589892183461],
                            [2.420570675383841, 48.726306793251375],
                            [2.421331455392465, 48.726870072253654],
                            [2.42165810394813, 48.727118926280724],
                            [2.422378111958649, 48.72767143652627],
                            [2.423094134970894, 48.728268909547715],
                            [2.423543450453407, 48.72869572077309],
                            [2.423975071980242, 48.729105457791086],
                            [2.424222937797265, 48.729371450553074],
                            [2.424745974393252, 48.729966364269885],
                            [2.425311453210206, 48.73072401020537],
                            [2.42537005883369, 48.73081029453371],
                            [2.425693134899638, 48.73131633147364],
                            [2.425939981850506, 48.73176127746846],
                            [2.426016358219715, 48.73190060428871],
                            [2.426251045007963, 48.7323842272299],
                            [2.426312462463028, 48.73251996864988],
                            [2.42653234146575, 48.7330809408986],
                            [2.426689331252346, 48.733510144360565],
                            [2.426786567061396, 48.73383882492036],
                            [2.426925135884896, 48.73453655030067],
                            [2.427072200943807, 48.735419517897796],
                            [2.427115335419036, 48.73596534166231],
                            [2.427126860952247, 48.73632324280238],
                            [2.427114010831894, 48.736734219712574],
                            [2.427086168320174, 48.73712452646617],
                            [2.427038046539816, 48.737577797219416],
                            [2.426977526343041, 48.737942949625996],
                            [2.426856101230651, 48.73846012758495],
                            [2.426733176144821, 48.73890176769799],
                            [2.426485694615085, 48.739637567483975],
                            [2.426399820474823, 48.739830699436546],
                        ],
                    },
                },
                869: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.06437754303691, 2.7220831911567926],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 7811.02953548,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.69945308646072,
                            49.0325740895669,
                            2.744686207442424,
                            49.09612080982236,
                        ),
                        "coordinates": [
                            [2.69945308646072, 49.0325740895669],
                            [2.702669368485551, 49.036670656360904],
                            [2.706585976117261, 49.04164284464314],
                            [2.708844273363393, 49.044514561038376],
                            [2.709286516408457, 49.04508417167599],
                            [2.709666734898624, 49.045587358115355],
                            [2.709984893314095, 49.04601936706036],
                            [2.710387330557418, 49.04658672404211],
                            [2.710848516921564, 49.04726333563445],
                            [2.711438023799308, 49.04815367139899],
                            [2.717769982404683, 49.05769307714154],
                            [2.720572353378316, 49.06191423599426],
                            [2.729486360189672, 49.07533795999044],
                            [2.730366204722761, 49.076666725604724],
                            [2.73251030364449, 49.079888602399606],
                            [2.733541801844478, 49.081415682033104],
                            [2.73465314394954, 49.08308904425939],
                            [2.736808270580688, 49.08633153197838],
                            [2.737246216276035, 49.08698558167945],
                            [2.737613618590033, 49.087549948913704],
                            [2.738590973827442, 49.08902300880758],
                            [2.739213361885679, 49.08997241603058],
                            [2.740146888119386, 49.091370975192994],
                            [2.740470225531092, 49.09183619253856],
                            [2.740864852063662, 49.09233446870444],
                            [2.741266576396518, 49.092769427718295],
                            [2.74162309771016, 49.09313301523283],
                            [2.744686207442424, 49.09612080982236],
                        ],
                    },
                },
                870: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.74638396186467, 2.422303450937929],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 1574.8577434,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.418113047325797,
                            48.739830699436546,
                            2.426399820474823,
                            48.75288655674139,
                        ),
                        "coordinates": [
                            [2.426399820474823, 48.739830699436546],
                            [2.426225698495076, 48.74022229971281],
                            [2.425884234238307, 48.74087274164829],
                            [2.425800210283278, 48.74102658370741],
                            [2.42533649689724, 48.741750860369116],
                            [2.424837441032456, 48.742489550721984],
                            [2.424658408258681, 48.742742384591885],
                            [2.424049480877902, 48.74364392478024],
                            [2.423513832793183, 48.74447346464863],
                            [2.423211442085479, 48.744953906391345],
                            [2.42294702566572, 48.7453794629365],
                            [2.422442529908542, 48.74615951408769],
                            [2.422161801042074, 48.74659587273325],
                            [2.420869300454085, 48.748607609694574],
                            [2.420646855145592, 48.74894769907054],
                            [2.420140972652831, 48.74975381966134],
                            [2.419362382815036, 48.7509540180889],
                            [2.418988003244222, 48.751535219516676],
                            [2.418516375847919, 48.75226363932598],
                            [2.418113047325797, 48.75288655674139],
                        ],
                    },
                },
                871: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.82949284193254, 1.9771930768514645],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 2719.75448517,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.960026560248269,
                            48.82365326874927,
                            1.992864535155556,
                            48.83095952864679,
                        ),
                        "coordinates": [
                            [1.960026560248269, 48.83095952864679],
                            [1.960935037637888, 48.8309379250036],
                            [1.962093061398932, 48.83091025970915],
                            [1.963721094929362, 48.83087243058366],
                            [1.963757878332537, 48.830871652009066],
                            [1.966582072810431, 48.83080531245419],
                            [1.969404903416691, 48.83073800049453],
                            [1.971730451228169, 48.8306843159905],
                            [1.974054625266235, 48.83063147843705],
                            [1.97455188070673, 48.8306204691827],
                            [1.976381517728135, 48.83057860283449],
                            [1.977309278389815, 48.830557249532816],
                            [1.97944692409613, 48.83049112489424],
                            [1.980105181229709, 48.83044192528568],
                            [1.980684545473023, 48.83037718861256],
                            [1.981573604029977, 48.83024326924754],
                            [1.981914547415635, 48.83018497848945],
                            [1.982507918347994, 48.83006541945888],
                            [1.982889947928216, 48.82997577732718],
                            [1.983445473163384, 48.82983171815846],
                            [1.984110075155704, 48.82963692860319],
                            [1.985080954442035, 48.829293702141804],
                            [1.985893753053863, 48.828959872761175],
                            [1.986162995461228, 48.82883030457826],
                            [1.986708414721469, 48.828553201710655],
                            [1.987065343057734, 48.828350158970814],
                            [1.987578284775649, 48.82804147726763],
                            [1.987929990763962, 48.82780514161545],
                            [1.988274960049601, 48.82755799357086],
                            [1.988536414014613, 48.8273717411227],
                            [1.988870612356766, 48.82710567358642],
                            [1.989320163455206, 48.826704164316794],
                            [1.991813433196942, 48.82443294496405],
                            [1.991988781901201, 48.82428599279434],
                            [1.992248912743041, 48.824089835255215],
                            [1.992864535155556, 48.82365326874927],
                        ],
                    },
                },
                872: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.98249787034772, 2.26469614788774],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1183.05987226,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25747415725031,
                            48.980646100425986,
                            2.272084772747633,
                            48.98500470125915,
                        ),
                        "coordinates": [
                            [2.272084772747633, 48.980646100425986],
                            [2.271950869618948, 48.98065591704335],
                            [2.271823795701041, 48.98066663645357],
                            [2.271758211804184, 48.98067109521663],
                            [2.271662563736779, 48.98067913480196],
                            [2.271161102964788, 48.98072021476257],
                            [2.270614515042522, 48.98079094371412],
                            [2.270471029382747, 48.98081424142235],
                            [2.270322078497261, 48.98083843554761],
                            [2.269851993930268, 48.98091190326584],
                            [2.26954526509951, 48.98096437982222],
                            [2.269004726617549, 48.98105798659492],
                            [2.268027562605059, 48.981275029387575],
                            [2.267747367056282, 48.98135669483977],
                            [2.266934115114945, 48.98159361082247],
                            [2.266826128905727, 48.98163041570474],
                            [2.266060654556562, 48.981888936410705],
                            [2.26429179731313, 48.98251102926852],
                            [2.263314407492389, 48.982847635066406],
                            [2.261622025452842, 48.983449052471265],
                            [2.261108001244041, 48.9836411590941],
                            [2.260894732323527, 48.983721952743366],
                            [2.258429804144584, 48.984645647981104],
                            [2.257613609603145, 48.984951740311374],
                            [2.25747415725031, 48.98500470125915],
                        ],
                    },
                },
                873: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.93321924525004, 2.5215044099627923],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2052.71609895,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.508038741924935,
                            48.93186318839768,
                            2.534714974742524,
                            48.93628018565177,
                        ),
                        "coordinates": [
                            [2.508038741924935, 48.9322501569209],
                            [2.508894596512746, 48.93223792259556],
                            [2.509646496422219, 48.932201203928194],
                            [2.510485530429816, 48.93213149761696],
                            [2.511224846103302, 48.932061939035634],
                            [2.511930979106314, 48.93200884859771],
                            [2.51262472371931, 48.93197767383939],
                            [2.515844297567993, 48.93186318839768],
                            [2.516895498306539, 48.93187248982931],
                            [2.517668438667157, 48.931912334059334],
                            [2.518603555712695, 48.931990239213626],
                            [2.519301866079423, 48.93207125218204],
                            [2.519975337870622, 48.9321769384203],
                            [2.520661328123656, 48.93229628685087],
                            [2.521289201626911, 48.93242941260758],
                            [2.521946257786894, 48.93258712612503],
                            [2.522724024590236, 48.93280212396912],
                            [2.525327835753683, 48.933553406834356],
                            [2.528796948978665, 48.93455776646745],
                            [2.53207915600295, 48.93553045504139],
                            [2.532896322318356, 48.93577175173164],
                            [2.533630327330832, 48.93598701443105],
                            [2.534107583631052, 48.93611943664953],
                            [2.534714974742524, 48.93628018565177],
                        ],
                    },
                },
                874: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84678033732759, 2.2701086645710498],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 163.849094749,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.26913587274288,
                            48.84657540472636,
                            2.271115349613071,
                            48.847150054810506,
                        ),
                        "coordinates": [
                            [2.26913587274288, 48.847150054810506],
                            [2.270275634698988, 48.84666065949085],
                            [2.270285308837443, 48.846656929463016],
                            [2.270376561560882, 48.84662651809887],
                            [2.270472326053471, 48.84660291810516],
                            [2.270571442837939, 48.84658641199825],
                            [2.270672712649166, 48.84657720470963],
                            [2.270774900784081, 48.84657540472636],
                            [2.270876768286297, 48.846581035073484],
                            [2.270977077495319, 48.846594026153305],
                            [2.27107461510639, 48.846614223080586],
                            [2.271115349613071, 48.846625048719645],
                        ],
                    },
                },
                875: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.8168767144128, 2.2353499494160367],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 932.904086543,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.229808003729513,
                            48.81488431421452,
                            2.240919294866535,
                            48.818947800937735,
                        ),
                        "coordinates": [
                            [2.229808003729513, 48.818947800937735],
                            [2.229857218778483, 48.81892887000757],
                            [2.230953446759334, 48.81851112931037],
                            [2.232067676451515, 48.81809101450884],
                            [2.233459526133406, 48.8175712087063],
                            [2.236571238318494, 48.816415248560084],
                            [2.238590346168604, 48.815665134263284],
                            [2.239592639617607, 48.81530671268915],
                            [2.240299259538093, 48.81506700072195],
                            [2.240919294866535, 48.81488431421452],
                        ],
                    },
                },
                876: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.833921904133994, 2.403440496238061],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 341.756458955,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.401448054218978,
                            48.83316292950388,
                            2.405383210626771,
                            48.8347851580814,
                        ),
                        "coordinates": [
                            [2.401448054218978, 48.83316292950388],
                            [2.402450655477677, 48.83353872945894],
                            [2.404399887771404, 48.83426642104576],
                            [2.404497263274304, 48.83430164294866],
                            [2.404641162943785, 48.83436059674831],
                            [2.404778913282287, 48.834425638144445],
                            [2.404909923538385, 48.83449648631435],
                            [2.404995298491396, 48.8345480947677],
                            [2.405383210626771, 48.8347851580814],
                        ],
                    },
                },
                877: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.817893599066835, 1.734002721117619],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 4912.05823832,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.703218425476859,
                            48.810402464358575,
                            1.765056756557643,
                            48.82657842806816,
                        ),
                        "coordinates": [
                            [1.703218425476859, 48.82657842806816],
                            [1.703834706081143, 48.82646491843838],
                            [1.704440868864696, 48.826353168721774],
                            [1.705059332238571, 48.826237886526634],
                            [1.705386982651539, 48.82617764765288],
                            [1.705975387351061, 48.82606938935608],
                            [1.706640251963787, 48.82594626129542],
                            [1.7068696017519, 48.82590436112266],
                            [1.707990364636365, 48.82570280394646],
                            [1.708435472943173, 48.8256162256746],
                            [1.708836863898313, 48.82554019578124],
                            [1.709611040257465, 48.825387975302824],
                            [1.710195613521477, 48.82525809031064],
                            [1.710804866956573, 48.825114847945656],
                            [1.711348633248916, 48.82498023683586],
                            [1.712008744744395, 48.824799497119244],
                            [1.712223352927734, 48.824737720647825],
                            [1.712816613266964, 48.82456560288375],
                            [1.713334762327082, 48.82440925836364],
                            [1.713593239341642, 48.82432433778815],
                            [1.713657530608635, 48.82430220636175],
                            [1.713760098814089, 48.82426859299619],
                            [1.713947476039934, 48.82420576497837],
                            [1.714273009634636, 48.82409512880752],
                            [1.714821504639136, 48.82390746813572],
                            [1.715179820401797, 48.82378891484546],
                            [1.716881164567938, 48.823221719061586],
                            [1.71780841570151, 48.82291199699557],
                            [1.720304265419156, 48.822079267838525],
                            [1.721752435411251, 48.82160146069737],
                            [1.724410791146531, 48.82072185532163],
                            [1.725454163075655, 48.820374924638415],
                            [1.72645474936757, 48.82003775341909],
                            [1.72848322513523, 48.819349724692636],
                            [1.730612228450318, 48.818641615831204],
                            [1.732366338047564, 48.818073571818424],
                            [1.734643164394577, 48.81729422681533],
                            [1.735079370350868, 48.81714544641768],
                            [1.736558681682944, 48.816658623749824],
                            [1.737761912325528, 48.81625306855582],
                            [1.738329338511924, 48.81606179818051],
                            [1.738490705957064, 48.816005089491334],
                            [1.738671179311696, 48.81594488264169],
                            [1.739734851702543, 48.81559163425183],
                            [1.740027429514338, 48.81549424200263],
                            [1.740255687190121, 48.81542349177832],
                            [1.740618018259811, 48.81530038328331],
                            [1.741312646775495, 48.81506030140504],
                            [1.742156178047613, 48.81477962323151],
                            [1.742314739589809, 48.814729189653775],
                            [1.743851501127592, 48.814208398571],
                            [1.744212454851976, 48.81408527195248],
                            [1.74450643005247, 48.81398337892803],
                            [1.745094854012801, 48.81378116166545],
                            [1.745879825709287, 48.81355234643284],
                            [1.746817159311929, 48.813298395575416],
                            [1.747076583180959, 48.81323858451115],
                            [1.74821493818605, 48.81299425430823],
                            [1.748713261864647, 48.812896306543024],
                            [1.749087106460449, 48.81283258510359],
                            [1.750412987050746, 48.812632569203565],
                            [1.751530464204398, 48.81246657956357],
                            [1.752381300567321, 48.812337807300985],
                            [1.753630824029237, 48.81214455770408],
                            [1.754761671860952, 48.81196867441502],
                            [1.75503449631644, 48.81192600100822],
                            [1.755771042534285, 48.811817341766975],
                            [1.757926093173865, 48.811500054108166],
                            [1.759934009884037, 48.811187377382815],
                            [1.762259726740296, 48.81082500715827],
                            [1.765056756557643, 48.810402464358575],
                        ],
                    },
                },
                878: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80097656474467, 2.213117185082394],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 4528.45180755,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.183684109854236,
                            48.79863737633212,
                            2.240883069335648,
                            48.80749262578012,
                        ),
                        "coordinates": [
                            [2.240883069335648, 48.80749262578012],
                            [2.240320698555044, 48.80678704468132],
                            [2.240092906273693, 48.806476005367635],
                            [2.240019625386438, 48.80635454104201],
                            [2.239886626967051, 48.80613680349458],
                            [2.239776685821098, 48.805964947942485],
                            [2.239635523373623, 48.80574630367408],
                            [2.239475288795493, 48.80553483740985],
                            [2.239316375513287, 48.805344055684714],
                            [2.239165577561272, 48.80518115741641],
                            [2.238963136330118, 48.80497235194884],
                            [2.238806893375868, 48.804810347579185],
                            [2.238675089807507, 48.80468253749114],
                            [2.23849974967032, 48.8045403004669],
                            [2.238313548339405, 48.80438366553852],
                            [2.238164035122339, 48.80426213404542],
                            [2.23799142403651, 48.804118100397694],
                            [2.237822890045549, 48.803978567012834],
                            [2.23754290363341, 48.803749007977665],
                            [2.2370792599209, 48.80345633861449],
                            [2.236720210267189, 48.80328156382477],
                            [2.236395165437536, 48.80312210617549],
                            [2.236003414869444, 48.80296348853488],
                            [2.235756780566318, 48.802882050936],
                            [2.235475524950392, 48.80280744542746],
                            [2.234780171058944, 48.80266294036302],
                            [2.234577313608959, 48.80262807118488],
                            [2.234337887985154, 48.80258700436088],
                            [2.234184110037434, 48.80256078727876],
                            [2.233841167130502, 48.802504723245505],
                            [2.233470997363747, 48.80244863292458],
                            [2.233045012124602, 48.80239338943316],
                            [2.232184834546844, 48.80230267617639],
                            [2.231556020635476, 48.80224364372678],
                            [2.229507587568691, 48.80206727398585],
                            [2.228318002250498, 48.801966327795014],
                            [2.226061347344496, 48.80177261143904],
                            [2.225526447716622, 48.80172712647114],
                            [2.221341207704024, 48.80136864808362],
                            [2.221232323540725, 48.801359545429825],
                            [2.220701513104539, 48.80131584087513],
                            [2.219299646113744, 48.80119479994797],
                            [2.216840269347992, 48.8009836057611],
                            [2.215771866196214, 48.80089254808984],
                            [2.215615350988152, 48.80087889245937],
                            [2.215520079607423, 48.80087069777654],
                            [2.215400310985341, 48.800859778896296],
                            [2.215254681130944, 48.80084793280485],
                            [2.214142732503124, 48.80075321712257],
                            [2.211356795959032, 48.80049928606813],
                            [2.209187360082731, 48.800318821108746],
                            [2.206556566559994, 48.80010001865402],
                            [2.205972706863281, 48.8000507885488],
                            [2.204611729014256, 48.79993770816375],
                            [2.201183452879624, 48.79965220591762],
                            [2.201105880523553, 48.79964491937094],
                            [2.199857881853771, 48.7995418082242],
                            [2.197843688212044, 48.79937390150759],
                            [2.196850985230035, 48.79928385223194],
                            [2.196006498943287, 48.79919628660919],
                            [2.193981630377544, 48.798962651219036],
                            [2.192857634189156, 48.798828143432225],
                            [2.192533761469411, 48.79879266222908],
                            [2.191766539847763, 48.79870648698661],
                            [2.191145688653347, 48.79865960080871],
                            [2.190534555150434, 48.79863903382209],
                            [2.189945145674272, 48.79863737633212],
                            [2.189107891694344, 48.798669566969984],
                            [2.188658597093236, 48.798698659372846],
                            [2.188256027429874, 48.79873715782228],
                            [2.187936245774292, 48.798784899484275],
                            [2.187655694525374, 48.79884010315162],
                            [2.187308949882079, 48.79891901797551],
                            [2.186336973295001, 48.7991402951749],
                            [2.185480920864058, 48.79932757326997],
                            [2.185267063569635, 48.79937405179657],
                            [2.183684109854236, 48.79972882534396],
                        ],
                    },
                },
                879: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98935751527942, 2.2458746664321008],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 1954.61314817,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.234276393996537,
                            48.98500470125915,
                            2.25747415725031,
                            48.99371348038584,
                        ),
                        "coordinates": [
                            [2.25747415725031, 48.98500470125915],
                            [2.256667529466798, 48.98530179983275],
                            [2.256537648249651, 48.98534937040701],
                            [2.256406397970248, 48.98539873895597],
                            [2.256324367152076, 48.98542925655962],
                            [2.25483957933873, 48.98598395673322],
                            [2.254752076836709, 48.98601716760732],
                            [2.254065722420399, 48.98627566499257],
                            [2.252697094129654, 48.986791752504],
                            [2.252152919385233, 48.98699548761377],
                            [2.250853987138239, 48.98748372667994],
                            [2.25052446527544, 48.98760757845762],
                            [2.250302957914854, 48.987691044437135],
                            [2.250069147044349, 48.987778097556905],
                            [2.248828968929537, 48.98824477512492],
                            [2.248735984251072, 48.98828247410205],
                            [2.248689496718009, 48.98829862493679],
                            [2.248644373466953, 48.988315676355626],
                            [2.248578741899453, 48.988339906642],
                            [2.248519944991161, 48.988362343427454],
                            [2.248182205336202, 48.9884897792397],
                            [2.247942915503344, 48.98857952129495],
                            [2.244431417603644, 48.98989778089434],
                            [2.244312450985003, 48.98994174964649],
                            [2.244241341042742, 48.98996956972559],
                            [2.244168866746831, 48.98999648911002],
                            [2.244036222252495, 48.9900476409717],
                            [2.243727181301108, 48.99016159795455],
                            [2.243554620207485, 48.99022882178484],
                            [2.242902227019158, 48.99047741455814],
                            [2.24162140823175, 48.990954603971424],
                            [2.239750755235367, 48.99166921656483],
                            [2.237898175127222, 48.99236001975328],
                            [2.23664981377814, 48.99283004478473],
                            [2.235958195596444, 48.99308036887799],
                            [2.234276393996537, 48.99371348038584],
                        ],
                    },
                },
                880: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.795632177901794, 2.4295745833280105],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 1530.4152893,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.426482408484048,
                            48.78891489668918,
                            2.432070116592686,
                            48.80204938032392,
                        ),
                        "coordinates": [
                            [2.432070116592686, 48.78891489668918],
                            [2.431857313997105, 48.78943027009336],
                            [2.431660120323357, 48.78988012947137],
                            [2.431473668068494, 48.79029904713331],
                            [2.431254965732261, 48.79080364752911],
                            [2.430659790727081, 48.792179395721874],
                            [2.430340868570299, 48.79301956358032],
                            [2.430229929071471, 48.79339083026073],
                            [2.430147798354993, 48.793762074000824],
                            [2.430119416877252, 48.79399051350288],
                            [2.43008415009924, 48.79438789111289],
                            [2.430038158688936, 48.7948281059252],
                            [2.429989295476793, 48.79565853383082],
                            [2.429953915578894, 48.795996428041754],
                            [2.429925447488488, 48.796179659568146],
                            [2.429889830398333, 48.796391450447665],
                            [2.429832615912633, 48.79661039544663],
                            [2.429771764490148, 48.796810309873905],
                            [2.429667843333378, 48.79708877668779],
                            [2.429578178412195, 48.79728871353238],
                            [2.429447291688545, 48.797544786007194],
                            [2.429140611158748, 48.79805672309048],
                            [2.429014369083738, 48.79824567307316],
                            [2.42886635520273, 48.79844003572659],
                            [2.42835571706259, 48.799082529760724],
                            [2.428039017466682, 48.79949099821307],
                            [2.427620398081034, 48.800078146945296],
                            [2.4272970635476, 48.80053047876123],
                            [2.427156963907712, 48.800732833785176],
                            [2.426884050436453, 48.80118750326808],
                            [2.426744087931962, 48.80146837501133],
                            [2.42650013095641, 48.80200629831029],
                            [2.426482408484048, 48.80204938032392],
                        ],
                    },
                },
                881: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.843560965046294, 2.2468333232592097],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 1218.84503642,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.238887327153073,
                            48.84200534728956,
                            2.254756719786218,
                            48.845227500732506,
                        ),
                        "coordinates": [
                            [2.238887327153073, 48.84200534728956],
                            [2.240212887969732, 48.84227126909347],
                            [2.245756591865973, 48.843299552511695],
                            [2.246693585185178, 48.84346968906736],
                            [2.249515594193968, 48.84407580675903],
                            [2.254756719786218, 48.845227500732506],
                        ],
                    },
                },
                882: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84813093405408, 2.296876280958804],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 341.483698466,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.295420478027581,
                            48.84701958188098,
                            2.298301401728378,
                            48.84935055362092,
                        ),
                        "coordinates": [
                            [2.298301401728378, 48.84935055362092],
                            [2.297916591840311, 48.84906456347491],
                            [2.297214693589996, 48.84854287185959],
                            [2.296820873142968, 48.8481211407298],
                            [2.296210711979744, 48.847413729806256],
                            [2.296183667062807, 48.84737867538298],
                            [2.296126629050682, 48.847316997795865],
                            [2.296060567136754, 48.84725937537788],
                            [2.295986144061761, 48.847206379513324],
                            [2.295904094005731, 48.84715853793809],
                            [2.295815234972688, 48.8471163258194],
                            [2.295720449751358, 48.847080162946554],
                            [2.295620677825113, 48.84705040738823],
                            [2.29551691533681, 48.847027358191234],
                            [2.295420478027581, 48.84701958188098],
                        ],
                    },
                },
                883: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.85005919668223, 2.323847911359897],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 466.531931212,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.321257862893747,
                            48.84881637336959,
                            2.326488473969165,
                            48.851192349321856,
                        ),
                        "coordinates": [
                            [2.326488473969165, 48.851192349321856],
                            [2.326056269563519, 48.85101194614864],
                            [2.324194754821362, 48.85025743024269],
                            [2.32332556665854, 48.84987271370687],
                            [2.322202261141149, 48.84930908423716],
                            [2.321257862893747, 48.84881637336959],
                        ],
                    },
                },
                884: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84518907825709, 2.2640344169880593],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 354.551036821,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.261623492404885,
                            48.84513983133517,
                            2.266441541719401,
                            48.84524756545478,
                        ),
                        "coordinates": [
                            [2.266441541719401, 48.845204703581174],
                            [2.266292053153175, 48.84517785536296],
                            [2.266140071601101, 48.84515803552183],
                            [2.265986346477628, 48.845145339483295],
                            [2.265872564116859, 48.84514128846771],
                            [2.265831649437521, 48.84513983133517],
                            [2.265703257870185, 48.84514073506456],
                            [2.261893641759714, 48.84524119484093],
                            [2.261623492404885, 48.84524756545478],
                        ],
                    },
                },
                885: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.798210947640875, 2.0691567761066767],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 412.815831932,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.066485347074011,
                            48.79761321151646,
                            2.071847005929401,
                            48.79870763528835,
                        ),
                        "coordinates": [
                            [2.066485347074011, 48.79761321151646],
                            [2.067965653930496, 48.797961639157485],
                            [2.069370074197862, 48.79828149046026],
                            [2.069903062061266, 48.79839604889063],
                            [2.070856322002004, 48.79857633553913],
                            [2.071332370669918, 48.79864848827117],
                            [2.071695582347995, 48.79869339867155],
                            [2.071847005929401, 48.79870763528835],
                        ],
                    },
                },
                886: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.851610050796126, 2.3419601507407273],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 361.537845663,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.339646335932881,
                            48.851050282314304,
                            2.344273345421351,
                            48.852167261116506,
                        ),
                        "coordinates": [
                            [2.344273345421351, 48.851050282314304],
                            [2.343225270805059, 48.85130609722682],
                            [2.34134322872245, 48.85175882831748],
                            [2.339646335932881, 48.852167261116506],
                        ],
                    },
                },
                887: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.95981676573135, 2.2954343956420593],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1782.32127973,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.285930718208942,
                            48.95339646167632,
                            2.302347871689533,
                            48.96358968487314,
                        ),
                        "coordinates": [
                            [2.30234042019572, 48.95339646167632],
                            [2.302347871689533, 48.953587394392805],
                            [2.302335399445179, 48.95384997875558],
                            [2.302325714332493, 48.9540316291705],
                            [2.302311941596061, 48.954199790015444],
                            [2.302309173530747, 48.954253745730234],
                            [2.302300896093228, 48.95437514561916],
                            [2.302295357408279, 48.95448395628861],
                            [2.302285703186266, 48.95462064301265],
                            [2.302210146365722, 48.955268997834544],
                            [2.30214986257661, 48.95555674848297],
                            [2.302060886266997, 48.95586427341901],
                            [2.301955563060278, 48.95611424032951],
                            [2.301873510143942, 48.95628327934421],
                            [2.301691666802028, 48.9565979707393],
                            [2.301571368460207, 48.956778687720664],
                            [2.301452455235365, 48.956929730308644],
                            [2.301341746444026, 48.95706638543275],
                            [2.301112151930768, 48.95731181696755],
                            [2.300709041023123, 48.957671401572156],
                            [2.300346958340289, 48.957942867907676],
                            [2.299999922192097, 48.95817477112097],
                            [2.299070848881404, 48.958773386723855],
                            [2.298872729195725, 48.958910011304766],
                            [2.298722435736681, 48.95900438509954],
                            [2.298660951962535, 48.95904483266034],
                            [2.298144475413129, 48.95938548540862],
                            [2.297925868499213, 48.95951760450818],
                            [2.297554240696941, 48.95973330444529],
                            [2.297179891122347, 48.959932814757366],
                            [2.29689708699247, 48.96007210413513],
                            [2.296641611901363, 48.960190719728224],
                            [2.296405023996748, 48.960297733488574],
                            [2.29612657882905, 48.96040546510364],
                            [2.295805020759344, 48.96052593735619],
                            [2.295476327784761, 48.96063364843375],
                            [2.295125254956447, 48.96074503187028],
                            [2.294588394798257, 48.9609174961694],
                            [2.294000996068092, 48.96109353727476],
                            [2.291081678522152, 48.961997081668244],
                            [2.290912280567436, 48.96204917211165],
                            [2.29027567125032, 48.96224585692243],
                            [2.288450512538769, 48.96281164555615],
                            [2.28684117432929, 48.96330375839909],
                            [2.286281035766312, 48.963479770849645],
                            [2.285930718208942, 48.96358968487314],
                        ],
                    },
                },
                888: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.92382711606271, 1.8487648060113193],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3519.95865451,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.840517029657971,
                            48.90930537596191,
                            1.857227537127738,
                            48.93871923993318,
                        ),
                        "coordinates": [
                            [1.857227537127738, 48.90930537596191],
                            [1.85712590272219, 48.909369046854245],
                            [1.85668920623179, 48.909663979077486],
                            [1.856080562334649, 48.91010387250079],
                            [1.855989780959639, 48.910179930569456],
                            [1.855574419826138, 48.91052440999987],
                            [1.854890208454059, 48.91115732671301],
                            [1.854654618896742, 48.91139284731552],
                            [1.854229330699102, 48.911914440705125],
                            [1.854175415154536, 48.911987055496375],
                            [1.854122872676552, 48.91205877772853],
                            [1.853805844305684, 48.91253046641334],
                            [1.853564225273821, 48.912963803606274],
                            [1.852976383229974, 48.91420234121349],
                            [1.852659938186628, 48.914891659073845],
                            [1.851639212054924, 48.91713826298202],
                            [1.851475887887029, 48.917514373625785],
                            [1.851186216023402, 48.91825236258693],
                            [1.851095210133959, 48.91848848979546],
                            [1.85050944912226, 48.92019825475057],
                            [1.850145968335598, 48.92122370192491],
                            [1.84973038610369, 48.92241169689954],
                            [1.849555646142469, 48.922835419344175],
                            [1.849395184583136, 48.923194452515276],
                            [1.849265634167208, 48.92346278934344],
                            [1.848826266950478, 48.92442855424574],
                            [1.848730081984784, 48.92463408197598],
                            [1.848580958646926, 48.9249490971864],
                            [1.848031239394895, 48.926169787773915],
                            [1.847749581685022, 48.926776506215475],
                            [1.846935319722306, 48.92852304580808],
                            [1.846737199683602, 48.928960152566184],
                            [1.846546565795222, 48.92932984404897],
                            [1.846497928722657, 48.92941776649678],
                            [1.84572410347682, 48.930793062547586],
                            [1.845358708894, 48.9314425809393],
                            [1.844392800073066, 48.93318665212398],
                            [1.844292769664877, 48.93336338192229],
                            [1.844124797161808, 48.93364683560616],
                            [1.843933386162074, 48.93395356841005],
                            [1.843771422144674, 48.934181290739275],
                            [1.843624632911881, 48.93439289173311],
                            [1.843455948970307, 48.93460979246324],
                            [1.84254768227431, 48.935761462634346],
                            [1.842365151401569, 48.935997187156964],
                            [1.841980894235166, 48.93647664738376],
                            [1.841407236850366, 48.93719449765197],
                            [1.841103793768826, 48.9376446274236],
                            [1.840958005240096, 48.9378904024925],
                            [1.840835492569125, 48.93812908264213],
                            [1.840530895345835, 48.938693417019884],
                            [1.840517029657971, 48.93871923993318],
                        ],
                    },
                },
                889: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.99930148736807, 2.673087968220827],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2180.09646847,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.665059869307301,
                            48.99139140287414,
                            2.680252455973217,
                            49.00811401774285,
                        ),
                        "coordinates": [
                            [2.665059869307301, 48.99139140287414],
                            [2.665250943504244, 48.991521782150706],
                            [2.667302748636683, 48.992921768796684],
                            [2.668040132067271, 48.993428821290266],
                            [2.668403439326552, 48.99368712007222],
                            [2.66872323432271, 48.99392650846737],
                            [2.668974077786951, 48.994128026860345],
                            [2.669268596979791, 48.99437224647582],
                            [2.669537809215702, 48.99461653768957],
                            [2.669770771349431, 48.994846657580645],
                            [2.669981959891061, 48.99506494547527],
                            [2.670175039331194, 48.995278527047006],
                            [2.670590626357085, 48.99577936151701],
                            [2.671571813317128, 48.99703755953977],
                            [2.677923145482296, 49.005146714207676],
                            [2.680252455973217, 49.00811401774285],
                        ],
                    },
                },
                890: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.943752368671746, 2.3410429454336867],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 1189.2801389,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.336418315320437,
                            48.93884268321627,
                            2.344611081014025,
                            48.94783369425153,
                        ),
                        "coordinates": [
                            [2.344611081014025, 48.93884268321627],
                            [2.34445438759634, 48.93922909944737],
                            [2.344318818865329, 48.93960593663021],
                            [2.344199675596359, 48.93993191450605],
                            [2.344073302064426, 48.9402222023237],
                            [2.343784447655979, 48.94091698912217],
                            [2.343567793834791, 48.94139287038358],
                            [2.343405297819504, 48.94170933256215],
                            [2.343188624089768, 48.94207814333833],
                            [2.342953884887095, 48.942411264627516],
                            [2.34271552642032, 48.94273486821583],
                            [2.342329083715866, 48.94316316970892],
                            [2.341888451584169, 48.943608127361564],
                            [2.341577835338476, 48.94387938653777],
                            [2.341296109545675, 48.94411733240661],
                            [2.340952975273245, 48.94439334912475],
                            [2.340382279712963, 48.944795478745384],
                            [2.339327549259685, 48.94551882780223],
                            [2.338760437553038, 48.945901914348276],
                            [2.338247501223794, 48.94624692676937],
                            [2.33785015168668, 48.94653007376765],
                            [2.337387774586994, 48.94689173748575],
                            [2.337044601839636, 48.94719629528594],
                            [2.336668912202581, 48.947557956116526],
                            [2.336418315320437, 48.94783369425153],
                        ],
                    },
                },
                891: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.83576402699245, 2.2505174658817313],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 1086.8694362,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.243840593741985,
                            48.83370884911258,
                            2.257122229832621,
                            48.83796121443631,
                        ),
                        "coordinates": [
                            [2.243840593741985, 48.83370884911258],
                            [2.244528518154731, 48.83392011581616],
                            [2.246703252750269, 48.83458795401501],
                            [2.253634437107219, 48.83672121960498],
                            [2.256523832599368, 48.83760513097819],
                            [2.256598003345001, 48.83762965477499],
                            [2.256703041881682, 48.837671181479834],
                            [2.256802017267713, 48.83771875649558],
                            [2.256894135229277, 48.83777199626477],
                            [2.256978652516787, 48.837830473478846],
                            [2.257044752469555, 48.83788530708654],
                            [2.257054887828879, 48.837893715346716],
                            [2.257122229832621, 48.83796121443631],
                        ],
                    },
                },
                892: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.84399877202113, 2.2608885954536295],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 267.081880779,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.260032902225193,
                            48.84293869496324,
                            2.261745124963672,
                            48.845058172313735,
                        ),
                        "coordinates": [
                            [2.260032902225193, 48.84293869496324],
                            [2.261434160982968, 48.84467495706587],
                            [2.261745124963672, 48.845058172313735],
                        ],
                    },
                },
                893: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.86381070003097, 2.2902186228705275],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 616.453878011,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.286243169328236,
                            48.86305068923498,
                            2.29416201539428,
                            48.8647940649002,
                        ),
                        "coordinates": [
                            [2.286243169328236, 48.863065020217924],
                            [2.286452797189907, 48.86305422793424],
                            [2.286662990836629, 48.86305068923498],
                            [2.286873179099509, 48.863054412404836],
                            [2.287016167715549, 48.86306189977771],
                            [2.287166876865423, 48.86307378223337],
                            [2.287291230144058, 48.86308358652862],
                            [2.28749794783657, 48.86310895602549],
                            [2.287702369890653, 48.86314142987291],
                            [2.287903936033242, 48.86318091661129],
                            [2.28810209301024, 48.86322730953737],
                            [2.288150736911247, 48.86323989302775],
                            [2.293169292528034, 48.86456291427242],
                            [2.29358018843245, 48.86467122442978],
                            [2.293743736696991, 48.86471183662677],
                            [2.293951308948943, 48.86475641994006],
                            [2.29416201539428, 48.8647940649002],
                        ],
                    },
                },
                894: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.84187349648306, 2.3930911443954828],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 712.048725802,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.390075111457481,
                            48.839445428379506,
                            2.396182886452633,
                            48.84440867207195,
                        ),
                        "coordinates": [
                            [2.396182886452633, 48.839445428379506],
                            [2.395952926588724, 48.839567198337505],
                            [2.395808889362026, 48.83964923370333],
                            [2.395632734529534, 48.83975929259695],
                            [2.39546429229586, 48.839874494074024],
                            [2.395303907402738, 48.83999460067825],
                            [2.395169447445132, 48.84010436328871],
                            [2.394713866798677, 48.840491247292675],
                            [2.393692515951678, 48.84135856036905],
                            [2.391399436484194, 48.84329208974053],
                            [2.390075111457481, 48.84440867207195],
                        ],
                    },
                },
                895: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.87086513854975, 2.3468328531630798],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 558.980299709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.343154773075233,
                            48.870164201799824,
                            2.350497971851879,
                            48.87149773935003,
                        ),
                        "coordinates": [
                            [2.350497971851879, 48.870164201799824],
                            [2.34886485986124, 48.87051251804543],
                            [2.347975366047469, 48.870697494284876],
                            [2.346645561090464, 48.87092338792206],
                            [2.34524170993027, 48.871135598315604],
                            [2.344395064966588, 48.87128251993561],
                            [2.343154773075233, 48.87149773935003],
                        ],
                    },
                },
                896: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.854040690997955, 2.2690771833436343],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 361.538427242,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.268176749423331,
                            48.852504091512166,
                            2.270109138941893,
                            48.855485050404425,
                        ),
                        "coordinates": [
                            [2.268176749423331, 48.852504091512166],
                            [2.269325400377701, 48.85456058905599],
                            [2.269558362658405, 48.85486172702288],
                            [2.269835312185028, 48.855175155512825],
                            [2.270109138941893, 48.855485050404425],
                        ],
                    },
                },
                897: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.96848959985272, 1.760976031613833],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 7554.73964061,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.715210986447546,
                            48.96309520715419,
                            1.809094508773784,
                            48.983654507541004,
                        ),
                        "coordinates": [
                            [1.809094508773784, 48.96334411275807],
                            [1.80751423281709, 48.96325064241118],
                            [1.805456304559444, 48.96316890655146],
                            [1.803191036621014, 48.963110230415914],
                            [1.801692782735805, 48.96309520715419],
                            [1.79934146825186, 48.963108244055825],
                            [1.792204806172105, 48.96326539029052],
                            [1.782026620456471, 48.96345915675499],
                            [1.776948362263403, 48.96355337477295],
                            [1.775099652863674, 48.963590948124676],
                            [1.773613949196232, 48.96363360909356],
                            [1.772211191739051, 48.963690935560294],
                            [1.769672844099819, 48.96382589443027],
                            [1.767235389594588, 48.963985097537076],
                            [1.765629489902814, 48.96410795388584],
                            [1.764417700490392, 48.964211345998606],
                            [1.763343221870768, 48.96431541627785],
                            [1.762174483775721, 48.964445174002414],
                            [1.760611090710833, 48.964639556318616],
                            [1.759315143228286, 48.96483050902828],
                            [1.758261546780888, 48.96500126089294],
                            [1.757320044285388, 48.9651654299684],
                            [1.755712131011992, 48.96545469591098],
                            [1.754762826784092, 48.965666393247496],
                            [1.752479520296583, 48.9662258061199],
                            [1.751747233380135, 48.96641955140475],
                            [1.750789935183282, 48.96669304138924],
                            [1.749948321962167, 48.96696235705018],
                            [1.749258897543363, 48.96719675619359],
                            [1.74843494005744, 48.96749946352447],
                            [1.747472689567889, 48.96788235148487],
                            [1.746223205312962, 48.968408892905884],
                            [1.744414288685574, 48.969172843744644],
                            [1.743081221101059, 48.969732229617016],
                            [1.742260283059671, 48.97007773759341],
                            [1.740999302518121, 48.9706493696809],
                            [1.740257613960113, 48.97101431042357],
                            [1.739671949524783, 48.9713277163682],
                            [1.739136988581911, 48.97163186407823],
                            [1.738569093653484, 48.97196915082827],
                            [1.737986331490821, 48.97233966732065],
                            [1.737406942404305, 48.97272923479087],
                            [1.736714214009256, 48.97322527819537],
                            [1.736155971960294, 48.97365777816402],
                            [1.735447806546557, 48.9742322545396],
                            [1.735060972266274, 48.97453716214809],
                            [1.734546623902395, 48.97492467822281],
                            [1.7341272785774, 48.975227033636926],
                            [1.733569628129071, 48.97560717877947],
                            [1.732666373100019, 48.97616871062862],
                            [1.731923671988704, 48.97660497542186],
                            [1.730103599862883, 48.977647032933106],
                            [1.728862982753179, 48.97829954063289],
                            [1.728113742786351, 48.978673882942175],
                            [1.727503048619697, 48.97895140103639],
                            [1.72683809647815, 48.979231005763666],
                            [1.726086328698559, 48.979514904576845],
                            [1.725298437784954, 48.979796223139395],
                            [1.72402769662093, 48.98024389026234],
                            [1.723319687472679, 48.98049469202141],
                            [1.72246249361554, 48.98082320878138],
                            [1.720264259571234, 48.98172269510186],
                            [1.71949191677146, 48.98201047192969],
                            [1.718462645660327, 48.98237410203644],
                            [1.717594407918111, 48.982703772839415],
                            [1.716985230225326, 48.98294677854624],
                            [1.715210986447546, 48.983654507541004],
                        ],
                    },
                },
                898: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.73196009027211, 2.4248197089895176],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1754.50043697,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.419565024387933,
                            48.72553530486119,
                            2.427126860952247,
                            48.739830699436546,
                        ),
                        "coordinates": [
                            [2.419565024387933, 48.72553530486119],
                            [2.42003172895545, 48.72589892183461],
                            [2.420570675383841, 48.726306793251375],
                            [2.421331455392465, 48.726870072253654],
                            [2.42165810394813, 48.727118926280724],
                            [2.422378111958649, 48.72767143652627],
                            [2.423094134970894, 48.728268909547715],
                            [2.423543450453407, 48.72869572077309],
                            [2.423975071980242, 48.729105457791086],
                            [2.424222937797265, 48.729371450553074],
                            [2.424745974393252, 48.729966364269885],
                            [2.425311453210206, 48.73072401020537],
                            [2.42537005883369, 48.73081029453371],
                            [2.425693134899638, 48.73131633147364],
                            [2.425939981850506, 48.73176127746846],
                            [2.426016358219715, 48.73190060428871],
                            [2.426251045007963, 48.7323842272299],
                            [2.426312462463028, 48.73251996864988],
                            [2.42653234146575, 48.7330809408986],
                            [2.426689331252346, 48.733510144360565],
                            [2.426786567061396, 48.73383882492036],
                            [2.426925135884896, 48.73453655030067],
                            [2.427072200943807, 48.735419517897796],
                            [2.427115335419036, 48.73596534166231],
                            [2.427126860952247, 48.73632324280238],
                            [2.427114010831894, 48.736734219712574],
                            [2.427086168320174, 48.73712452646617],
                            [2.427038046539816, 48.737577797219416],
                            [2.426977526343041, 48.737942949625996],
                            [2.426856101230651, 48.73846012758495],
                            [2.426733176144821, 48.73890176769799],
                            [2.426485694615085, 48.739637567483975],
                            [2.426399820474823, 48.739830699436546],
                        ],
                    },
                },
                899: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.798210947640875, 2.0691567761066767],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 412.815831932,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.066485347074011,
                            48.79761321151646,
                            2.071847005929401,
                            48.79870763528835,
                        ),
                        "coordinates": [
                            [2.066485347074011, 48.79761321151646],
                            [2.067965653930496, 48.797961639157485],
                            [2.069370074197862, 48.79828149046026],
                            [2.069903062061266, 48.79839604889063],
                            [2.070856322002004, 48.79857633553913],
                            [2.071332370669918, 48.79864848827117],
                            [2.071695582347995, 48.79869339867155],
                            [2.071847005929401, 48.79870763528835],
                        ],
                    },
                },
                900: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.87858153985711, 2.4114505027412605],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 789.151114085,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.406480156998486,
                            48.87717481930547,
                            2.416479643681515,
                            48.87976125309793,
                        ),
                        "coordinates": [
                            [2.406480156998486, 48.87717481930547],
                            [2.406528497611208, 48.87718842300151],
                            [2.407438929664649, 48.8774722880944],
                            [2.409930462523421, 48.87824907380458],
                            [2.411207485813837, 48.87860710844014],
                            [2.412159991767255, 48.87884802387255],
                            [2.413363668528157, 48.87911636998595],
                            [2.414483584395984, 48.8793433514737],
                            [2.41538216511015, 48.87952137147636],
                            [2.416479643681515, 48.87976125309793],
                        ],
                    },
                },
                901: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.853048546085056, 2.336757726724945],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 465.600444752,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.333776138218468,
                            48.85230076310175,
                            2.339727782955844,
                            48.85372074517208,
                        ),
                        "coordinates": [
                            [2.333776138218468, 48.853718934000206],
                            [2.333896462286003, 48.85372074517208],
                            [2.33401653940035, 48.85371532762985],
                            [2.334135371315595, 48.85370272708255],
                            [2.334251975393904, 48.85368304778792],
                            [2.33432064068788, 48.85366786467495],
                            [2.334649399429998, 48.85358849942936],
                            [2.335031714654845, 48.8534962041096],
                            [2.336292839746393, 48.85318077638929],
                            [2.337398697204311, 48.85287279738427],
                            [2.33869599079677, 48.8525584295741],
                            [2.339165251123934, 48.85244124331418],
                            [2.339727782955844, 48.85230076310175],
                        ],
                    },
                },
                902: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.84926763770581, 2.329032568006554],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 625.679199947,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.326792785027681,
                            48.84687823885142,
                            2.331256291381555,
                            48.851672244720596,
                        ),
                        "coordinates": [
                            [2.326792785027681, 48.84687823885142],
                            [2.327329552106665, 48.84742907602668],
                            [2.327403488369505, 48.847504948988636],
                            [2.327901799353064, 48.84803969690239],
                            [2.328003664590446, 48.8481500324326],
                            [2.330855699413341, 48.85123899165447],
                            [2.331256291381555, 48.851672244720596],
                        ],
                    },
                },
                903: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.86329790986506, 2.347115216847768],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 309.175541968,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345673828222722,
                            48.8623162786956,
                            2.348880653940287,
                            48.86380743868794,
                        ),
                        "coordinates": [
                            [2.345673828222722, 48.8623162786956],
                            [2.345988850416349, 48.86287033545783],
                            [2.346028004479487, 48.862930779564635],
                            [2.346080798864675, 48.86299472289839],
                            [2.346142976790579, 48.86305487906093],
                            [2.346213928281358, 48.863110651137276],
                            [2.346292941935626, 48.863161485725904],
                            [2.34637923485528, 48.86320687759983],
                            [2.346471948500343, 48.8632463741813],
                            [2.346570163569714, 48.86327958461723],
                            [2.346664865330057, 48.863304373199426],
                            [2.348880653940287, 48.86380743868794],
                        ],
                    },
                },
                904: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.89567181224325, 2.3463066332774734],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 440.303370018,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344847748752398,
                            48.89394138802911,
                            2.347765501718976,
                            48.89740222289809,
                        ),
                        "coordinates": [
                            [2.347765501718976, 48.89394138802911],
                            [2.347368496150066, 48.89441232095493],
                            [2.344847748752398, 48.89740222289809],
                        ],
                    },
                },
                905: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.792776165880106, 2.0554436206259865],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 1973.87595046,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.044621987173176,
                            48.787390238280715,
                            2.066485347074011,
                            48.79761321151646,
                        ),
                        "coordinates": [
                            [2.044621987173176, 48.787390238280715],
                            [2.044851105628235, 48.78750349640637],
                            [2.046741304126305, 48.78844003846329],
                            [2.047258327554183, 48.78869832312603],
                            [2.048565214852195, 48.78936071667585],
                            [2.049383771745726, 48.78978630894997],
                            [2.051178973182095, 48.79070687265457],
                            [2.052959877315797, 48.79162023425542],
                            [2.054245460494912, 48.792256337309674],
                            [2.058741619891684, 48.794489710908344],
                            [2.061679413663929, 48.79595062396591],
                            [2.062070911434097, 48.79614191596519],
                            [2.062516342039329, 48.79634999307187],
                            [2.062907965074912, 48.79651986861153],
                            [2.063242176986505, 48.796651535583436],
                            [2.063705846985577, 48.79681920285661],
                            [2.064173185834679, 48.79697497863914],
                            [2.064637031043277, 48.797111711223465],
                            [2.066485347074011, 48.79761321151646],
                        ],
                    },
                },
                906: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.77564123890962, 2.3106283288792704],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1096.02902421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.309890081968055,
                            48.77072199352213,
                            2.312307716888594,
                            48.78031379639698,
                        ),
                        "coordinates": [
                            [2.310205453235823, 48.77072199352213],
                            [2.310234840392793, 48.77095662406682],
                            [2.310255164535159, 48.77111400201783],
                            [2.310276732764815, 48.771488104945355],
                            [2.310269653248328, 48.77200878316555],
                            [2.31018087087919, 48.77266523206927],
                            [2.309999423516448, 48.77359054280913],
                            [2.309937984100235, 48.773989806224435],
                            [2.309890081968055, 48.774512272990385],
                            [2.30989799528152, 48.77497719952673],
                            [2.309923694337317, 48.775259577970814],
                            [2.309931809110679, 48.77534950749734],
                            [2.309937222041714, 48.77540346529411],
                            [2.309942639292121, 48.7754511280722],
                            [2.30996244800209, 48.77556645279218],
                            [2.309986516563828, 48.775652929823785],
                            [2.310047209996318, 48.77581715644492],
                            [2.310103720313004, 48.775949082280896],
                            [2.310157283218017, 48.776072576085134],
                            [2.310435110513839, 48.776622901324146],
                            [2.310718658178116, 48.77714373970285],
                            [2.311312704398269, 48.778235591904306],
                            [2.312183629100422, 48.7800675091415],
                            [2.312307716888594, 48.78031379639698],
                        ],
                    },
                },
                907: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.732707983110366, 1.9055149546534647],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 3310.55653413,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.890004563697985,
                            48.72191596105865,
                            1.921036600039739,
                            48.74348398592533,
                        ),
                        "coordinates": [
                            [1.890004563697985, 48.72191596105865],
                            [1.890034431822112, 48.721936895367286],
                            [1.890266086137454, 48.72209856823183],
                            [1.891620949749069, 48.7230355335236],
                            [1.891785688193822, 48.7231566818875],
                            [1.892501621874721, 48.72365408454952],
                            [1.895511355051447, 48.725750332141075],
                            [1.896271931016806, 48.726280257723445],
                            [1.89783355362877, 48.72738071825863],
                            [1.898844173125484, 48.72807885787199],
                            [1.899652182529723, 48.72863322465181],
                            [1.900023645844506, 48.728901737789634],
                            [1.901184246010784, 48.729711044894486],
                            [1.902651551611075, 48.73074003762751],
                            [1.904708292188821, 48.73215344622749],
                            [1.905902813171118, 48.73298801416836],
                            [1.907447505811745, 48.73405140925048],
                            [1.908213712840531, 48.734588471514456],
                            [1.908504326461507, 48.73478381104041],
                            [1.90872465011916, 48.73493212253206],
                            [1.90884495574657, 48.73501261159476],
                            [1.910870763410868, 48.73642758928511],
                            [1.912002200183204, 48.73721797359011],
                            [1.914187243962756, 48.738732242570805],
                            [1.91661919159956, 48.74041869378139],
                            [1.91779942111266, 48.74124154398555],
                            [1.919580594358542, 48.742480594453625],
                            [1.921036600039739, 48.74348398592533],
                        ],
                    },
                },
                908: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.820684400843895, 2.222425201633709],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 1149.81956414,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.21485979543755,
                            48.818947800937735,
                            2.229808003729513,
                            48.821353445618726,
                        ),
                        "coordinates": [
                            [2.21485979543755, 48.82121703789382],
                            [2.215385136870361, 48.82125565245838],
                            [2.216548842138161, 48.82131636844021],
                            [2.217518042257242, 48.82134831766572],
                            [2.217871150812068, 48.821353445618726],
                            [2.218361203741479, 48.821349196707054],
                            [2.218865693458763, 48.82133544357092],
                            [2.219986456226751, 48.82127235524613],
                            [2.220627968190282, 48.8212159056292],
                            [2.22115416995627, 48.82116171543497],
                            [2.221683989790666, 48.82110038820959],
                            [2.222451736509177, 48.820989332514486],
                            [2.223050090805913, 48.820894756311176],
                            [2.223677321435976, 48.820776413758495],
                            [2.224268528603829, 48.820653273404055],
                            [2.224960685761454, 48.820501675635285],
                            [2.225656469550867, 48.82033818128925],
                            [2.226287392891662, 48.82017462028862],
                            [2.226846242163563, 48.820013364582856],
                            [2.227372684543435, 48.81984017957013],
                            [2.227798163343908, 48.81970020601756],
                            [2.22874653871935, 48.819356103927056],
                            [2.229808003729513, 48.818947800937735],
                        ],
                    },
                },
                909: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.857313373561595, 2.347922430109488],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1026.0841958,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.346034983092227,
                            48.85333579557522,
                            2.348937051546064,
                            48.861822272798115,
                        ),
                        "coordinates": [
                            [2.346034983092227, 48.85333579557522],
                            [2.346491073780257, 48.85361546663164],
                            [2.346729697820193, 48.85377739070193],
                            [2.346933758470224, 48.85393691861212],
                            [2.347258930249784, 48.85420838480803],
                            [2.347641626783052, 48.854618004844916],
                            [2.347902546885543, 48.8549681629014],
                            [2.348081160959828, 48.855244794075396],
                            [2.348328621261669, 48.855636935852246],
                            [2.348538577448332, 48.85600741424442],
                            [2.348705203191695, 48.85633584993295],
                            [2.348849466113054, 48.8567164590795],
                            [2.348937051546064, 48.857207573089134],
                            [2.348934849043051, 48.857578854498826],
                            [2.348838199210787, 48.85804963503795],
                            [2.34869891028162, 48.85843017989895],
                            [2.348388280850902, 48.859017660999875],
                            [2.348387994662607, 48.85901820264864],
                            [2.347970423861637, 48.85971563273594],
                            [2.347663212781215, 48.86030109116217],
                            [2.347012687238757, 48.861822272798115],
                        ],
                    },
                },
                910: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.58032014674072, 2.589409838485273],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 3494.85205435,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.58394771106125,
                            48.564949495670916,
                            2.594551816007613,
                            48.595563837991776,
                        ),
                        "coordinates": [
                            [2.594551816007613, 48.564949495670916],
                            [2.594295504436848, 48.56545677875951],
                            [2.59394493728639, 48.566297471138796],
                            [2.593513140386829, 48.567378656710105],
                            [2.592647916108226, 48.569933613348155],
                            [2.592298847202012, 48.571078849405694],
                            [2.591903749787656, 48.57234077373574],
                            [2.591473493827524, 48.57374315570742],
                            [2.591127969309865, 48.574890759355135],
                            [2.590837866272776, 48.5758674762185],
                            [2.590598102195244, 48.57666508302081],
                            [2.590238337562021, 48.57784126690704],
                            [2.589807856422505, 48.57921747191162],
                            [2.589310338910697, 48.58081509872764],
                            [2.588812824486161, 48.58241986298694],
                            [2.588347481668348, 48.584010276998],
                            [2.587987516220817, 48.58516742138348],
                            [2.587511457618529, 48.58677689070458],
                            [2.586973779293195, 48.588501098135],
                            [2.586601945524944, 48.58968840234978],
                            [2.586134388752506, 48.59086322685132],
                            [2.585694396053536, 48.59181591901776],
                            [2.585149965885586, 48.592927460295556],
                            [2.584091329784307, 48.59523255348737],
                            [2.58394771106125, 48.595563837991776],
                        ],
                    },
                },
                911: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.81305069694782, 2.2994035021320878],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 609.661984132,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.297077796972985,
                            48.810746486780936,
                            2.301678555482428,
                            48.81530753120022,
                        ),
                        "coordinates": [
                            [2.301678555482428, 48.810746486780936],
                            [2.301502485801944, 48.8109555761508],
                            [2.301329349396387, 48.8111607942989],
                            [2.301087168864895, 48.81143055997529],
                            [2.3008612309052, 48.81166737103],
                            [2.300256980325456, 48.81224181853263],
                            [2.299378279785043, 48.813071260112125],
                            [2.298850922504267, 48.813584956903185],
                            [2.297077796972985, 48.81530753120022],
                        ],
                    },
                },
                912: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.83408660982188, 2.3654899053950813],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 432.087468508,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362856399519012,
                            48.833216719709846,
                            2.368126330413209,
                            48.83494772325454,
                        ),
                        "coordinates": [
                            [2.362856399519012, 48.833216719709846],
                            [2.363795145335177, 48.83353488327561],
                            [2.367677310669225, 48.83480115478208],
                            [2.368126330413209, 48.83494772325454],
                        ],
                    },
                },
                913: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.83201597568027, 2.3403236461215573],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 507.833092609,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.3371351933439,
                            48.831129548026645,
                            2.343511657749776,
                            48.832900815660246,
                        ),
                        "coordinates": [
                            [2.3371351933439, 48.832900815660246],
                            [2.340772017517918, 48.83189228124353],
                            [2.343511657749776, 48.831129548026645],
                        ],
                    },
                },
                914: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.832881021568205, 2.316100304475476],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 373.381022995,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.314122323459022,
                            48.83182565048562,
                            2.31807828549193,
                            48.83393639265079,
                        ),
                        "coordinates": [
                            [2.314122323459022, 48.83182565048562],
                            [2.31807828549193, 48.83393639265079],
                        ],
                    },
                },
                915: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.65419193483319, 2.4255090258130707],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1894.84526276,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.415206841330065,
                            48.64848911258698,
                            2.435330530181305,
                            48.65897542383006,
                        ),
                        "coordinates": [
                            [2.435330530181305, 48.64848911258698],
                            [2.434296243897668, 48.64918528844229],
                            [2.43311571079601, 48.64998574790938],
                            [2.432759230507603, 48.650222558126515],
                            [2.432051696015392, 48.65070066716915],
                            [2.430904982158173, 48.651480392220385],
                            [2.430243467010812, 48.65190989115007],
                            [2.429491060639191, 48.65236913587792],
                            [2.428981284897285, 48.65266451200408],
                            [2.428158240075537, 48.6531031231548],
                            [2.427121519147219, 48.653615223622566],
                            [2.425676169904779, 48.65432913780677],
                            [2.425310494960331, 48.654510042456174],
                            [2.425040329385829, 48.654648286423125],
                            [2.424689415437661, 48.65482886726796],
                            [2.424269996616088, 48.65504188232397],
                            [2.423770452659503, 48.65529136651131],
                            [2.423042598391984, 48.655654865404905],
                            [2.422605292419735, 48.65587696014729],
                            [2.422122668933979, 48.656115211667434],
                            [2.421564840088738, 48.65639058206119],
                            [2.420900233357033, 48.65672225703363],
                            [2.420268648386038, 48.65701538064415],
                            [2.419654967449961, 48.65728231542664],
                            [2.419113038888149, 48.65750636763567],
                            [2.418528018221294, 48.657737584842245],
                            [2.417777767240734, 48.65801743408316],
                            [2.415882706373182, 48.65872450417001],
                            [2.415206841330065, 48.65897542383006],
                        ],
                    },
                },
                916: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.779976401869696, 2.3051281825780436],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1174.12551211,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.297647677794033,
                            48.77909642616331,
                            2.312307716888594,
                            48.78135672132315,
                        ),
                        "coordinates": [
                            [2.297647677794033, 48.78135672132315],
                            [2.297970249908121, 48.78126510563911],
                            [2.298153252369795, 48.7812176914121],
                            [2.298370388333813, 48.78116991881549],
                            [2.298520097852168, 48.78113669648342],
                            [2.300108342120451, 48.78081168219063],
                            [2.302166087972306, 48.78039056110041],
                            [2.303275247301547, 48.78015527990871],
                            [2.304357171303353, 48.77993436893597],
                            [2.307341606180701, 48.77931737003838],
                            [2.307970317632498, 48.779204221293085],
                            [2.308332123939044, 48.779154223957704],
                            [2.308731054169251, 48.77911756192676],
                            [2.309122427128992, 48.77909834043633],
                            [2.309501992130245, 48.77909642616331],
                            [2.309858879140204, 48.77911146771583],
                            [2.310196791176348, 48.77914318357079],
                            [2.310513907202771, 48.779191399683086],
                            [2.310809161338291, 48.7792559499702],
                            [2.311077357961176, 48.77933517218979],
                            [2.311323064973002, 48.77942985015943],
                            [2.311545857307733, 48.779539819669104],
                            [2.311745440278066, 48.77966493343925],
                            [2.311921529270236, 48.77980499926581],
                            [2.312074019381796, 48.779959919506375],
                            [2.312202778949053, 48.78012955857533],
                            [2.312307716888594, 48.78031379639698],
                        ],
                    },
                },
                917: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.92412995666955, 2.5181281615099786],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 570.867740833,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.516443536539131,
                            48.92192614328582,
                            2.519131192691025,
                            48.92664020200147,
                        ),
                        "coordinates": [
                            [2.516443536539131, 48.92192614328582],
                            [2.516766210463665, 48.92229443749416],
                            [2.517676172017214, 48.92331136788641],
                            [2.51801696871195, 48.92369390472829],
                            [2.518212797237365, 48.92392677191939],
                            [2.518408698341315, 48.92417867413253],
                            [2.5185611461492, 48.92439733118271],
                            [2.518666503519407, 48.92457323672881],
                            [2.518775563575706, 48.924775308133725],
                            [2.518859265510304, 48.9249536273755],
                            [2.518932126790011, 48.92512958555806],
                            [2.518994171423509, 48.92531031589814],
                            [2.519049110965598, 48.92552199159604],
                            [2.519093235067227, 48.92573844306737],
                            [2.519115598990031, 48.925928754992164],
                            [2.519126964734161, 48.92607387795849],
                            [2.519131192691025, 48.926242806791215],
                            [2.51912830844822, 48.92644029697725],
                            [2.519103763829303, 48.92664020200147],
                        ],
                    },
                },
                918: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T4",
                        "rer": 0,
                        "extcode": "800:T4",
                        "geo_point_2d": [48.91216121149285, 2.5162816138494803],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01843",
                        "navette": 0,
                        "idrefliga": "A01761",
                        "shape_leng": 897.644777692,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.515061446192154,
                            48.90816541612633,
                            2.517124705097184,
                            48.91609650409271,
                        ),
                        "coordinates": [
                            [2.517025495287702, 48.90816541612633],
                            [2.517065657480323, 48.90829145874116],
                            [2.517105940580933, 48.90845081081528],
                            [2.517124705097184, 48.90864826737879],
                            [2.51708788209864, 48.90944303173658],
                            [2.517052723879799, 48.90970243715876],
                            [2.517006689028221, 48.909947583514786],
                            [2.516924769497434, 48.910252268533824],
                            [2.516828427347871, 48.91056173794047],
                            [2.516482437511175, 48.91171151002912],
                            [2.516211310533822, 48.91260419238934],
                            [2.515232905284331, 48.91558705360621],
                            [2.515061446192154, 48.91609650409271],
                        ],
                    },
                },
                919: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.05366743728424, 3.054256200529882],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 8665.08815973,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.031758445836778,
                            49.021757268637266,
                            3.066608008896255,
                            49.09188299627486,
                        ),
                        "coordinates": [
                            [3.062690406987056, 49.09188299627486],
                            [3.063603799028829, 49.09090972643143],
                            [3.06401175034329, 49.09049474502763],
                            [3.064512840295526, 49.089965078264925],
                            [3.064818071954384, 49.08962184771553],
                            [3.065072167646034, 49.08931043162812],
                            [3.065343024050841, 49.08896786369541],
                            [3.065561717639361, 49.08862775382952],
                            [3.065786904794956, 49.08824822941065],
                            [3.065960220269138, 49.08792163658805],
                            [3.06610425032391, 49.08758329984063],
                            [3.066241121741434, 49.087234317494435],
                            [3.066376886490948, 49.0868103887377],
                            [3.066528983863308, 49.086118194065776],
                            [3.066595698486269, 49.085483173083496],
                            [3.066608008896255, 49.08505140202872],
                            [3.066589544421756, 49.084820396383535],
                            [3.066576047468108, 49.084647813343786],
                            [3.066540973716021, 49.08435090791982],
                            [3.06649933257993, 49.084106328183026],
                            [3.066417474223486, 49.0837137666325],
                            [3.066326751064308, 49.08340787153626],
                            [3.066212744546021, 49.08307047818137],
                            [3.066065411238063, 49.0827083129937],
                            [3.065892725596543, 49.082346308855904],
                            [3.065673740638557, 49.081939626630074],
                            [3.064772929867041, 49.0802751194925],
                            [3.064100250001276, 49.07908310687664],
                            [3.063340227621834, 49.07770857121048],
                            [3.062975190825979, 49.07705653107882],
                            [3.061982853550437, 49.075257292152514],
                            [3.061300911363224, 49.07399561745078],
                            [3.060772889152478, 49.072896394351446],
                            [3.060648129961923, 49.07259972606884],
                            [3.060526933433462, 49.072263401013245],
                            [3.060411994059985, 49.07185771830223],
                            [3.060279341939041, 49.07134459510583],
                            [3.060201548833917, 49.07098793324647],
                            [3.060120109256934, 49.070445459180974],
                            [3.060038134958052, 49.06986634500941],
                            [3.059899625029979, 49.068868481168934],
                            [3.059764278397069, 49.067847714343614],
                            [3.059626212275811, 49.066827863038675],
                            [3.059490981750694, 49.06581428969889],
                            [3.059214639108601, 49.063851928742125],
                            [3.059172689706847, 49.063603083421384],
                            [3.059142605889707, 49.063417114972076],
                            [3.059029872805711, 49.06278553883761],
                            [3.058875583398004, 49.062092308175956],
                            [3.058714962790737, 49.061494376282276],
                            [3.058628482537339, 49.061157435309944],
                            [3.058578747857831, 49.06097453117885],
                            [3.058388284497723, 49.06032780957576],
                            [3.05819201453893, 49.05972942662851],
                            [3.057991400015168, 49.05917060597082],
                            [3.057853808443352, 49.05878215707284],
                            [3.057704001456914, 49.05841500026176],
                            [3.057559409442629, 49.058057803243045],
                            [3.057399348554642, 49.057682382102826],
                            [3.05725005718897, 49.05735019933928],
                            [3.057095672318054, 49.05701638134754],
                            [3.056852541946258, 49.056504902681944],
                            [3.056531869635117, 49.055888975390275],
                            [3.055799367103623, 49.05448613391184],
                            [3.055280727099677, 49.05349834902036],
                            [3.054824660415702, 49.0526300933167],
                            [3.054336886101066, 49.051654590788225],
                            [3.054085081782075, 49.05108420307554],
                            [3.053989165167662, 49.05082397585257],
                            [3.053871226190851, 49.05048839627956],
                            [3.0538025641416, 49.05028198378415],
                            [3.053637568879302, 49.049751025874585],
                            [3.053554276557624, 49.04942342100333],
                            [3.053468161808265, 49.049075847784884],
                            [3.053396830783833, 49.0486890824147],
                            [3.053323164305656, 49.04826758961478],
                            [3.053268272974603, 49.04786953120066],
                            [3.053230420829081, 49.04752998337677],
                            [3.053204879119348, 49.047165374841136],
                            [3.053184616245502, 49.04671916758694],
                            [3.053105494706221, 49.045126076978086],
                            [3.053027759038395, 49.04353387614017],
                            [3.052950001689018, 49.041939878094226],
                            [3.052930358540742, 49.04152721528851],
                            [3.052869540165152, 49.04034769417151],
                            [3.05285750466842, 49.03998804410725],
                            [3.052845962298888, 49.03966256388611],
                            [3.052785165826623, 49.03846019542045],
                            [3.052755299341463, 49.037795804192484],
                            [3.052685936301546, 49.036676947766104],
                            [3.052652123122738, 49.036440642542054],
                            [3.052596602427684, 49.03610453607607],
                            [3.052502388528324, 49.03572036949981],
                            [3.052388178775563, 49.03535464895046],
                            [3.052293358039071, 49.035103734102066],
                            [3.052151551787678, 49.034756507612705],
                            [3.051942782816169, 49.03433307886755],
                            [3.051706347588776, 49.0339231499985],
                            [3.051540610180645, 49.033672676548456],
                            [3.051333676896308, 49.03337582307692],
                            [3.051065283892919, 49.03303271574216],
                            [3.050604383585108, 49.03251425200638],
                            [3.050221637233089, 49.03214520539636],
                            [3.049982940529118, 49.03192849690118],
                            [3.049762407252088, 49.03174165544732],
                            [3.049404764134454, 49.03146292939244],
                            [3.04893965075725, 49.03112543368331],
                            [3.048424662548047, 49.030787793438016],
                            [3.0478633768862, 49.03046392763128],
                            [3.045707394664824, 49.02929338799202],
                            [3.044142640104384, 49.02844860198017],
                            [3.043310925032412, 49.028001889375766],
                            [3.041803189878661, 49.027186506581536],
                            [3.04029550481004, 49.02637110332115],
                            [3.038787856848813, 49.02555478131903],
                            [3.038612847795833, 49.025460526317325],
                            [3.036592682139192, 49.02437032516736],
                            [3.034098586842194, 49.02302307274451],
                            [3.033778900558709, 49.02284965239199],
                            [3.033008643589508, 49.02243255778861],
                            [3.031758445836778, 49.021757268637266],
                        ],
                    },
                },
                920: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.76202702315821, 2.8891947127560473],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 6789.11276818,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.868955830083688,
                            48.73493929649145,
                            2.907866786241034,
                            48.78949667687371,
                        ),
                        "coordinates": [
                            [2.907387270372533, 48.78949667687371],
                            [2.907672278124837, 48.78857671836464],
                            [2.90774467243484, 48.788243613896185],
                            [2.907788550683037, 48.787916047231555],
                            [2.907814390355671, 48.787642940890585],
                            [2.907858952362596, 48.78717197069109],
                            [2.907866786241034, 48.78687855133041],
                            [2.907837649454092, 48.78661990569762],
                            [2.90777130445866, 48.78605637458288],
                            [2.907653744742842, 48.785536266942074],
                            [2.907491199073863, 48.78500919081661],
                            [2.907362568962345, 48.7846706045163],
                            [2.907163062247064, 48.78428239813506],
                            [2.906961524018084, 48.78391469196295],
                            [2.906796109871589, 48.78362649801079],
                            [2.906535279261195, 48.78329450669294],
                            [2.906198622914274, 48.782891503082645],
                            [2.905217087029088, 48.781905372237745],
                            [2.904238320683652, 48.78092011786055],
                            [2.903258222537577, 48.77993396401712],
                            [2.903064209036372, 48.77974517559402],
                            [2.902087011441527, 48.77877068744661],
                            [2.901059173085188, 48.77776676562529],
                            [2.900229060352602, 48.7769174363788],
                            [2.899104680375913, 48.77579166909271],
                            [2.898412183864179, 48.77507384495052],
                            [2.897693764563782, 48.77434805074234],
                            [2.897238381291322, 48.773901540323834],
                            [2.896877931853254, 48.77354808870332],
                            [2.895910666136787, 48.77258788938728],
                            [2.895353430141775, 48.77203395547823],
                            [2.894724667435965, 48.77140932391289],
                            [2.893732573600871, 48.7704114581142],
                            [2.893420241071258, 48.77009822880923],
                            [2.892915297693068, 48.769592590248884],
                            [2.892499481767197, 48.76914856682951],
                            [2.892145240574735, 48.768735716352914],
                            [2.891924142652818, 48.76842833370249],
                            [2.891553053963667, 48.76784559590744],
                            [2.89102230376021, 48.7669731604868],
                            [2.890682823899723, 48.766417245497955],
                            [2.890163206537758, 48.76556453635456],
                            [2.889833447988031, 48.765024758735535],
                            [2.889649177179815, 48.76472348832138],
                            [2.889300016273418, 48.764150530187564],
                            [2.888730391989809, 48.76320003384317],
                            [2.888314867743198, 48.762528470507114],
                            [2.887870034134938, 48.76178870169665],
                            [2.887439084538023, 48.76107314482548],
                            [2.887052565173101, 48.760438308503495],
                            [2.886695144025573, 48.759850993635666],
                            [2.886449995452512, 48.75945288737531],
                            [2.886064920778273, 48.75882343751583],
                            [2.885786307295673, 48.75834995036194],
                            [2.885308481863254, 48.757571660438785],
                            [2.885002304938059, 48.757064131804306],
                            [2.884632385771341, 48.75644899196209],
                            [2.884247495922932, 48.755832125464536],
                            [2.883766869645194, 48.75504215246377],
                            [2.883455274074854, 48.754533746420165],
                            [2.882992609559591, 48.75376706528362],
                            [2.882656028252816, 48.75321111387641],
                            [2.881024564387434, 48.75052372459487],
                            [2.880433240123644, 48.74954991123406],
                            [2.879792014317041, 48.74848730200429],
                            [2.879153556386817, 48.747426475554796],
                            [2.878513745435965, 48.74636385258965],
                            [2.877858868157162, 48.74528870887593],
                            [2.877204017843514, 48.74421356057026],
                            [2.876550557150757, 48.74313840278631],
                            [2.876324888405327, 48.74276626318562],
                            [2.875569790068015, 48.74155031159599],
                            [2.875145825594815, 48.740862636944534],
                            [2.874990819182418, 48.74061066671271],
                            [2.874768339670694, 48.74027987814688],
                            [2.874582794233398, 48.74000318268982],
                            [2.874250517146026, 48.73954310092453],
                            [2.873842935757708, 48.73906749822995],
                            [2.873517980601827, 48.73868862821459],
                            [2.872943552196497, 48.738121180315865],
                            [2.872481936260866, 48.73769878278018],
                            [2.871930303787981, 48.73720326941313],
                            [2.871022361279409, 48.73646651389438],
                            [2.870270076725789, 48.735916974866626],
                            [2.869692909211364, 48.735468231922106],
                            [2.868955830083688, 48.73493929649145],
                        ],
                    },
                },
                921: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80659675454427, 2.926148663533012],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 5114.77794539,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.906161397416222,
                            48.78949667687371,
                            2.953730383101934,
                            48.813619747962505,
                        ),
                        "coordinates": [
                            [2.953730383101934, 48.81077532178037],
                            [2.953329211502365, 48.81087793726541],
                            [2.952789100876691, 48.8109998660778],
                            [2.952324895610694, 48.811078507869055],
                            [2.951854017070723, 48.811147814330866],
                            [2.951134958747968, 48.81123811218608],
                            [2.95046067222862, 48.81132537814673],
                            [2.947656093543874, 48.811687566673115],
                            [2.946816530371679, 48.811803417376616],
                            [2.946083033892751, 48.81193038023987],
                            [2.945431494854362, 48.81204659363544],
                            [2.944607032364517, 48.812214664030705],
                            [2.943441809812445, 48.812466379048445],
                            [2.939602450196421, 48.81329431293807],
                            [2.939011335808973, 48.81339456086146],
                            [2.938611363484698, 48.81344999751361],
                            [2.938140520447207, 48.81350871839909],
                            [2.937572957442571, 48.81355704977085],
                            [2.937042075280546, 48.813597393501475],
                            [2.936448304364605, 48.813616795038996],
                            [2.93588630545274, 48.813619747962505],
                            [2.935324105164708, 48.81360604386553],
                            [2.934808596099368, 48.813580195208004],
                            [2.934159799589404, 48.81354476750924],
                            [2.933568659139823, 48.813503208649074],
                            [2.932980950953201, 48.813434338047145],
                            [2.932569371105819, 48.81337073351317],
                            [2.932121129536421, 48.81329682800951],
                            [2.931669677002505, 48.813208264876295],
                            [2.931153569433, 48.81309134838635],
                            [2.93063038464191, 48.81295381949701],
                            [2.929978271724415, 48.81275834916493],
                            [2.929432082661814, 48.81257559445242],
                            [2.928811872222717, 48.81232113420862],
                            [2.928019212768972, 48.81196192678717],
                            [2.927584841926005, 48.811745245852975],
                            [2.927164166842634, 48.81151186247822],
                            [2.926685206783411, 48.81122405228713],
                            [2.92634251858611, 48.81099845987687],
                            [2.9256642643071, 48.81052353423742],
                            [2.925300071307058, 48.81023853707957],
                            [2.924939817954663, 48.80994092680508],
                            [2.923592052916786, 48.808803057183],
                            [2.922736550761754, 48.80807092654039],
                            [2.921069715830944, 48.8066769264118],
                            [2.920660616016986, 48.80636390621538],
                            [2.920067475727485, 48.80593887378623],
                            [2.919624356893845, 48.80565156412965],
                            [2.918827852885868, 48.80518169993301],
                            [2.917996240911639, 48.804735391940746],
                            [2.917063121751383, 48.804240104709315],
                            [2.915817875932205, 48.80355939534779],
                            [2.914634404566135, 48.80293768714485],
                            [2.913450961583915, 48.80231422211566],
                            [2.912102067667015, 48.80158343167483],
                            [2.911372307606685, 48.80115017377197],
                            [2.910578352990439, 48.80063696892352],
                            [2.90977821719795, 48.80008892681216],
                            [2.909333548296815, 48.799775505424456],
                            [2.909064360102315, 48.79956911741686],
                            [2.908585670802458, 48.79915928469009],
                            [2.908092969009444, 48.798670189515406],
                            [2.907814541634286, 48.79836941887951],
                            [2.907625554744399, 48.79813618818794],
                            [2.907417861804971, 48.79784621138876],
                            [2.907276445483669, 48.79762209330325],
                            [2.907126327468852, 48.79735125501844],
                            [2.906807827098722, 48.79675930847902],
                            [2.906632133484097, 48.79639417028809],
                            [2.906469209773402, 48.79596537710317],
                            [2.906311180527012, 48.795348984970815],
                            [2.906226777756416, 48.79492202704146],
                            [2.906179382374182, 48.79453667318341],
                            [2.906161397416222, 48.79427326736863],
                            [2.90617093462054, 48.793818259358204],
                            [2.906224503946948, 48.79330090616567],
                            [2.906317326397706, 48.79276344833569],
                            [2.906430964025943, 48.79232455258264],
                            [2.906526129566338, 48.79200879778995],
                            [2.907387270372533, 48.78949667687371],
                        ],
                    },
                },
                922: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.89908760496979, 2.3544152080487066],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4150.59167367,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350389537889768,
                            48.88076895833307,
                            2.357987231679084,
                            48.91756717658463,
                        ),
                        "coordinates": [
                            [2.357115334947971, 48.88076895833307],
                            [2.357224397262525, 48.880988328674505],
                            [2.357445256042034, 48.88147424717533],
                            [2.357621439110227, 48.881871422258904],
                            [2.35774914983309, 48.882202947538026],
                            [2.357832083614176, 48.88244802807216],
                            [2.357892965018944, 48.88266961754862],
                            [2.357929690564065, 48.882926256465836],
                            [2.357949099642765, 48.883182353683466],
                            [2.357987231679084, 48.88377480212628],
                            [2.35797711174668, 48.88415874398148],
                            [2.35776859674016, 48.88584618505727],
                            [2.35771581244326, 48.886426164530604],
                            [2.357672776648871, 48.88704955877387],
                            [2.357622547948076, 48.88773481642559],
                            [2.357514564652608, 48.88836298218558],
                            [2.357406615422702, 48.88907680292586],
                            [2.35732021320441, 48.88955268597487],
                            [2.357212161668813, 48.89002857305947],
                            [2.35702476399322, 48.890604406366215],
                            [2.356866168146696, 48.89102319759584],
                            [2.356671515411152, 48.89151813463572],
                            [2.356188407767444, 48.89257940363092],
                            [2.355726862337239, 48.893459837040616],
                            [2.355279785936971, 48.894483026670464],
                            [2.354955332043211, 48.89535391720402],
                            [2.354760668682024, 48.89592023004912],
                            [2.354573252941464, 48.89658647405615],
                            [2.354400303679799, 48.89735264752717],
                            [2.354321102683396, 48.89790466678896],
                            [2.354243027550289, 48.89844847923835],
                            [2.354148424680226, 48.89948338357097],
                            [2.353906105047874, 48.90043998621057],
                            [2.353278831413479, 48.90253866092549],
                            [2.352860729356008, 48.90428515788201],
                            [2.352396188268603, 48.90767816593894],
                            [2.352342196388262, 48.90815880031198],
                            [2.352273798625216, 48.90875602475913],
                            [2.35215133701112, 48.909622122033454],
                            [2.352064855283502, 48.910114657431315],
                            [2.351524032040559, 48.912265654778864],
                            [2.351167059230403, 48.91366713435516],
                            [2.350983170912253, 48.914445201971155],
                            [2.350802520014954, 48.91553295868042],
                            [2.350627204005268, 48.91657322295872],
                            [2.350565910713105, 48.916863510991256],
                            [2.350443305575427, 48.91738222188803],
                            [2.350389537889768, 48.91756717658463],
                        ],
                    },
                },
                923: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.85457374160598, 2.3550251403984452],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 1271.58750872,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347944311105259,
                            48.85123760888376,
                            2.36198522500636,
                            48.85770881968848,
                        ),
                        "coordinates": [
                            [2.36198522500636, 48.85123760888376],
                            [2.361174342995155, 48.85191028471704],
                            [2.360985248127231, 48.85209064051416],
                            [2.360923132071242, 48.85214634750456],
                            [2.360833901927574, 48.85221678133918],
                            [2.360679138468474, 48.852329365730135],
                            [2.360517959039052, 48.852442323929566],
                            [2.36037982000026, 48.852533202728004],
                            [2.360250735216829, 48.85261119526902],
                            [2.360128314393031, 48.85267763603299],
                            [2.360011423121908, 48.85273413061581],
                            [2.359890042569244, 48.85278673114828],
                            [2.358791192635678, 48.853187842772584],
                            [2.356034185592047, 48.85419176087476],
                            [2.354892065609004, 48.8546248148369],
                            [2.353758970776246, 48.855073682112206],
                            [2.351305928574801, 48.85604087162298],
                            [2.349053058914019, 48.85690276208983],
                            [2.348970348029527, 48.856948646700076],
                            [2.348663920498496, 48.85710872028555],
                            [2.34858918447032, 48.85715136900102],
                            [2.348539885010515, 48.85718366162392],
                            [2.348459916183919, 48.85724616552021],
                            [2.348362977042973, 48.857328069480964],
                            [2.348064288666177, 48.85759671729587],
                            [2.347944311105259, 48.85770881968848],
                        ],
                    },
                },
                924: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.80048491400792, 2.177568699750391],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 920.733640239,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.171389812756379,
                            48.79972882534396,
                            2.183684109854236,
                            48.800720766349464,
                        ),
                        "coordinates": [
                            [2.183684109854236, 48.79972882534396],
                            [2.181549600534488, 48.800207172114476],
                            [2.181037401196676, 48.80032158054706],
                            [2.180435311758618, 48.80045025127266],
                            [2.180044832620709, 48.8005272873863],
                            [2.179621038661392, 48.80059951195484],
                            [2.179189058512375, 48.800664361173034],
                            [2.178993254809456, 48.80068650189317],
                            [2.178819450514283, 48.800695034197034],
                            [2.178649252405362, 48.800693040898544],
                            [2.178130973726579, 48.80066321899656],
                            [2.177821314060172, 48.80063423733164],
                            [2.177472022349711, 48.80060995499961],
                            [2.177065087651669, 48.80059035108217],
                            [2.176654529377904, 48.80057787835856],
                            [2.175919822294987, 48.800562566282714],
                            [2.174282238330508, 48.80061633996727],
                            [2.173064633662477, 48.800682384781815],
                            [2.172336889530995, 48.8007152310616],
                            [2.171903089010338, 48.800720766349464],
                            [2.171400515562385, 48.80071880338744],
                            [2.171389812756379, 48.80071846386355],
                        ],
                    },
                },
                925: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.98075859926737, 2.2709659827582835],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 166.303618961,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.269851993930268,
                            48.980646100425986,
                            2.272084772747633,
                            48.98091190326584,
                        ),
                        "coordinates": [
                            [2.272084772747633, 48.980646100425986],
                            [2.271950869618948, 48.98065591704335],
                            [2.271823795701041, 48.98066663645357],
                            [2.271758211804184, 48.98067109521663],
                            [2.271662563736779, 48.98067913480196],
                            [2.271161102964788, 48.98072021476257],
                            [2.270614515042522, 48.98079094371412],
                            [2.270471029382747, 48.98081424142235],
                            [2.270322078497261, 48.98083843554761],
                            [2.269851993930268, 48.98091190326584],
                        ],
                    },
                },
                926: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.8467719713281, 2.290710111604889],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 693.513797098,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.285999222059007,
                            48.84653463673119,
                            2.295420478027581,
                            48.84701958188098,
                        ),
                        "coordinates": [
                            [2.295420478027581, 48.84701958188098],
                            [2.294293146389938, 48.8469562378928],
                            [2.29323988708562, 48.84689704513644],
                            [2.291229083730106, 48.846792458179316],
                            [2.286839116323963, 48.846581165537295],
                            [2.286567175413732, 48.84656807097152],
                            [2.285999222059007, 48.84653463673119],
                        ],
                    },
                },
                927: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.86969139412682, 2.35255025368495],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 318.81128192,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350497971851879,
                            48.8692241707531,
                            2.354603790708304,
                            48.870164201799824,
                        ),
                        "coordinates": [
                            [2.354603790708304, 48.8692241707531],
                            [2.354280879075376, 48.86929400766136],
                            [2.353796758672038, 48.869403441993924],
                            [2.350497971851879, 48.870164201799824],
                        ],
                    },
                },
                928: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.41555112110927, 2.7713153104568433],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 5730.51860268,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.751904834473551,
                            48.406805624897885,
                            2.79923356025455,
                            48.430970724114694,
                        ),
                        "coordinates": [
                            [2.79923356025455, 48.406805624897885],
                            [2.799072492906067, 48.40708697156878],
                            [2.79867484562515, 48.40761286402814],
                            [2.798431659214008, 48.4078989229961],
                            [2.798287116450325, 48.408043394528924],
                            [2.798137253492672, 48.40819687949061],
                            [2.797428905141483, 48.40886701740094],
                            [2.796223663116023, 48.40999959196637],
                            [2.795602259098052, 48.41058213654204],
                            [2.794394248880042, 48.411716501013245],
                            [2.792989344490695, 48.413017519939785],
                            [2.792508077041744, 48.41340350555173],
                            [2.792083532475449, 48.413698801684504],
                            [2.791700363849092, 48.41394111986955],
                            [2.791264472289154, 48.41417031611049],
                            [2.790916980824161, 48.414339912425184],
                            [2.790504738964452, 48.41452171142746],
                            [2.789988234889679, 48.414714125671104],
                            [2.789553436335253, 48.414851485254054],
                            [2.78913269431545, 48.414962617216],
                            [2.788718989456961, 48.41506182090557],
                            [2.788276586648537, 48.41514924313738],
                            [2.787891640093051, 48.41520927484739],
                            [2.787442756301341, 48.41526950742816],
                            [2.787102628943957, 48.41530143702232],
                            [2.786662741038076, 48.41533411829984],
                            [2.786239845930466, 48.41534713244729],
                            [2.785718428320555, 48.41534830403235],
                            [2.785310332659736, 48.41533283696512],
                            [2.784900453779014, 48.41529876401361],
                            [2.784417705797117, 48.41524681874924],
                            [2.783975791828507, 48.41519243945447],
                            [2.781479724907929, 48.41487161365356],
                            [2.780932255378192, 48.414800006122256],
                            [2.780506362729724, 48.41473505722359],
                            [2.780166288752163, 48.414674528436755],
                            [2.779797765675095, 48.41459648176391],
                            [2.779352438290774, 48.41449391044911],
                            [2.778919848045636, 48.41437247743765],
                            [2.777892352368236, 48.414050882575296],
                            [2.77721044207148, 48.413850941857305],
                            [2.776744728220558, 48.413726651481504],
                            [2.776350725382032, 48.4136282525323],
                            [2.775990587114377, 48.41353595291372],
                            [2.775222585317681, 48.41336883111024],
                            [2.774054780287646, 48.413105141733226],
                            [2.773269595664325, 48.412933048855884],
                            [2.772905573758838, 48.41285711601474],
                            [2.772157385073164, 48.41272090546711],
                            [2.771241037602005, 48.412573503524136],
                            [2.770618452584293, 48.412490238973184],
                            [2.770081806667879, 48.412425675186284],
                            [2.76930237073166, 48.412345985175094],
                            [2.768440120336602, 48.41227967631133],
                            [2.767338987243908, 48.41222057589135],
                            [2.766949791223278, 48.412205476681784],
                            [2.766613137286354, 48.41219904702445],
                            [2.76629052390608, 48.41219449287268],
                            [2.765834375634037, 48.412201673006074],
                            [2.765330229632203, 48.412210604325495],
                            [2.764922979962904, 48.41222451535868],
                            [2.76422040581056, 48.412265281421995],
                            [2.763794600922663, 48.412303893154764],
                            [2.763218796509414, 48.412368763672575],
                            [2.762530556658693, 48.412478139967725],
                            [2.762080942559337, 48.41256072707248],
                            [2.761563585455199, 48.41266260079373],
                            [2.761025064611816, 48.41279786175095],
                            [2.760019291365712, 48.413044317066976],
                            [2.759316684503863, 48.413218252636085],
                            [2.75862116154522, 48.4133850191897],
                            [2.757907944041439, 48.41357326081361],
                            [2.757319588842031, 48.41373486294929],
                            [2.75686695812904, 48.413886439381145],
                            [2.756443036192114, 48.41405218412817],
                            [2.755980057235826, 48.41424900297609],
                            [2.7555635335856, 48.414445647640306],
                            [2.755111666236446, 48.41469000665039],
                            [2.754778565483647, 48.4148907027214],
                            [2.754375810847667, 48.415168187623465],
                            [2.753973317024598, 48.41547739438108],
                            [2.753635476242541, 48.41576414098161],
                            [2.753334812445446, 48.41606029419747],
                            [2.753032587932407, 48.416394506816665],
                            [2.752751908809898, 48.41678047651531],
                            [2.752566460182669, 48.417078285526564],
                            [2.752327070808497, 48.41752012677244],
                            [2.752191706872143, 48.41786324178563],
                            [2.752056944407048, 48.41827931967993],
                            [2.751951298410519, 48.41875873795634],
                            [2.751925880318116, 48.419142690717436],
                            [2.751904834473551, 48.419479041111146],
                            [2.75191738516436, 48.419843820510486],
                            [2.751958425425438, 48.420195805155785],
                            [2.752017847993785, 48.420465239209776],
                            [2.752088325580623, 48.42070205512957],
                            [2.752198281326492, 48.42095947088061],
                            [2.752436040299621, 48.42146935240028],
                            [2.752978932208324, 48.422565004232254],
                            [2.753246619894984, 48.42323339388371],
                            [2.753364247099733, 48.4236231651128],
                            [2.753428314419767, 48.42387672048399],
                            [2.753454226622768, 48.42412724473554],
                            [2.75346149750553, 48.424428594539805],
                            [2.75344964985324, 48.424723670878976],
                            [2.753427714493442, 48.424952163899405],
                            [2.753363595127807, 48.42526646670219],
                            [2.753197117427577, 48.42588252422285],
                            [2.752886797416735, 48.426971796630504],
                            [2.752813453933754, 48.427324201984256],
                            [2.752764049441432, 48.427689208955876],
                            [2.752725438313367, 48.42820645125176],
                            [2.75271534722732, 48.42871407168776],
                            [2.752733172716005, 48.42913910687007],
                            [2.752790051215376, 48.42967503258873],
                            [2.752895173213066, 48.43013171436322],
                            [2.752931766124795, 48.43027571304698],
                            [2.752977505842713, 48.43044615241056],
                            [2.753126847026339, 48.4308565643828],
                            [2.753177568842823, 48.430970724114694],
                        ],
                    },
                },
                929: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.3817678729322, 2.916855356028169],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 3199.11206586,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.89720177783042,
                            48.378795760781145,
                            2.936180968314843,
                            48.38468131279181,
                        ),
                        "coordinates": [
                            [2.936180968314843, 48.37999957527981],
                            [2.934908556263945, 48.379945094509075],
                            [2.934343402316594, 48.379929026804426],
                            [2.933842607430669, 48.37991261717875],
                            [2.933459832304337, 48.379897964936035],
                            [2.933157302729277, 48.37989332873406],
                            [2.932801772400575, 48.37989332923899],
                            [2.93242317332602, 48.37991248760334],
                            [2.932130556722254, 48.37993920900663],
                            [2.931816363911015, 48.37996784078308],
                            [2.931475343709777, 48.380011002165496],
                            [2.931094127435304, 48.380079553223744],
                            [2.930753457159952, 48.38015238580757],
                            [2.930507066845852, 48.38021015008532],
                            [2.930194983432587, 48.380300100632155],
                            [2.929715062684075, 48.38046988255187],
                            [2.929434323656812, 48.38058825958691],
                            [2.929204632763628, 48.38068568513686],
                            [2.928933018224873, 48.38081025617642],
                            [2.928742953438621, 48.3809147184292],
                            [2.928539247592428, 48.381040783223526],
                            [2.928328928634067, 48.381178572711065],
                            [2.928024858464159, 48.38137980032377],
                            [2.927668765441012, 48.38163435595594],
                            [2.927108123670214, 48.382059040917014],
                            [2.926566179767029, 48.38246743799783],
                            [2.926227487066166, 48.382734476547334],
                            [2.925909485554005, 48.3829915370427],
                            [2.925637750952431, 48.38318899265284],
                            [2.925414180158933, 48.38334932773829],
                            [2.92524529691606, 48.38346162197285],
                            [2.925099641314644, 48.38354336785668],
                            [2.924907807347333, 48.383651556280014],
                            [2.924705270747713, 48.383762181997376],
                            [2.924532683984613, 48.38384807734107],
                            [2.924397436514429, 48.38391036365294],
                            [2.924180741558208, 48.38400429320013],
                            [2.923977196053016, 48.38408860788371],
                            [2.923761866950689, 48.384166358723384],
                            [2.923512300819755, 48.38424614823105],
                            [2.923288373686647, 48.38431359860544],
                            [2.922951933961305, 48.38440527022479],
                            [2.922534453300523, 48.38449376339217],
                            [2.922158610434262, 48.38456405507815],
                            [2.921832421999865, 48.38460890860832],
                            [2.921611496116461, 48.38463574838564],
                            [2.921354286696245, 48.3846585178601],
                            [2.921099994891111, 48.38466840001788],
                            [2.920868220456624, 48.38467692466362],
                            [2.920699223899258, 48.38468131279181],
                            [2.920363051268959, 48.384680351499355],
                            [2.920028102554904, 48.38466859131676],
                            [2.91972815803245, 48.384648556221045],
                            [2.91943887893585, 48.38461677429952],
                            [2.919160347576653, 48.38458044036269],
                            [2.918847900699907, 48.38452989292958],
                            [2.918543449407775, 48.384470310259694],
                            [2.918199632145059, 48.38439204404506],
                            [2.917601013362818, 48.384227858525406],
                            [2.91460179522727, 48.38333856956497],
                            [2.913402941151773, 48.38298228759372],
                            [2.912252856898915, 48.3826392340088],
                            [2.911478017965539, 48.3824084683481],
                            [2.910349661136737, 48.38207427864092],
                            [2.90822976955379, 48.38144384091659],
                            [2.906347054415935, 48.380891304257396],
                            [2.904515728287218, 48.380342974026526],
                            [2.904028119760863, 48.3802067139952],
                            [2.903482404342524, 48.38006521621463],
                            [2.902885087702344, 48.37991727784598],
                            [2.902313083661703, 48.379782984696476],
                            [2.901508007465895, 48.37961615019661],
                            [2.899424697247027, 48.37921917323933],
                            [2.897377939078802, 48.37882826848556],
                            [2.89720177783042, 48.378795760781145],
                        ],
                    },
                },
                930: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.378933796069596, 2.869080995539171],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4449.42887632,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.842037388815223,
                            48.3761682673058,
                            2.89720177783042,
                            48.38677098743939,
                        ),
                        "coordinates": [
                            [2.89720177783042, 48.378795760781145],
                            [2.896808464150924, 48.37872317951363],
                            [2.895639687658116, 48.37850054973934],
                            [2.894571115865848, 48.37830529105546],
                            [2.893578169186761, 48.37811234791602],
                            [2.892981467176332, 48.37798489145734],
                            [2.89244256301096, 48.377863485287264],
                            [2.8919041416398, 48.37772850096775],
                            [2.891068893646203, 48.37751227981643],
                            [2.890001920226928, 48.377213555220024],
                            [2.888797735035791, 48.37683365742108],
                            [2.888329206536057, 48.37669835702407],
                            [2.887818580375002, 48.37654715989875],
                            [2.887383867015373, 48.376442598239244],
                            [2.886997652809127, 48.376351071676034],
                            [2.886589345654188, 48.37628636100634],
                            [2.886188371497628, 48.376238289216815],
                            [2.885859085772801, 48.37620654141172],
                            [2.885538922258274, 48.376186766320494],
                            [2.884786031423821, 48.3761682673058],
                            [2.883226695837259, 48.37618717385729],
                            [2.881731571873894, 48.37623036041627],
                            [2.880367253481564, 48.37626210744904],
                            [2.878842429865258, 48.37630539852298],
                            [2.877583363129011, 48.37633456160693],
                            [2.876421665460311, 48.37636393163492],
                            [2.87528851703477, 48.37638839098344],
                            [2.874037357953064, 48.37641101734882],
                            [2.873215386859092, 48.37643972326668],
                            [2.872779305231565, 48.376454806032044],
                            [2.872375676808823, 48.376495123927846],
                            [2.871979860689369, 48.376548518511726],
                            [2.870719442483533, 48.376755448397276],
                            [2.869366534734984, 48.37696191568133],
                            [2.868488425371061, 48.37709943923884],
                            [2.867778046882965, 48.37720758549761],
                            [2.867163495805184, 48.37729601772687],
                            [2.866602919070646, 48.3773867738123],
                            [2.866077453908983, 48.37747916114854],
                            [2.865591073074123, 48.37756596749361],
                            [2.865123551383109, 48.37764908572968],
                            [2.864608193861114, 48.3777554491332],
                            [2.864099952770061, 48.37786698889568],
                            [2.863284224689854, 48.37806468067677],
                            [2.863001247975378, 48.37813199348046],
                            [2.862792612933853, 48.37818871881505],
                            [2.862094024119183, 48.37837901300959],
                            [2.861787142284975, 48.37846719278623],
                            [2.861431959308621, 48.37857722604059],
                            [2.860889853245013, 48.3787586928607],
                            [2.857547790288095, 48.379889638425695],
                            [2.854287494424182, 48.38100031892755],
                            [2.849483847615191, 48.38261336466326],
                            [2.848885050020713, 48.38282979143653],
                            [2.84818378651001, 48.38311708626159],
                            [2.84750735106731, 48.3834107452318],
                            [2.847101493865976, 48.3836049226816],
                            [2.846633021671185, 48.38384192856431],
                            [2.846169642172232, 48.384092001528636],
                            [2.845723941072985, 48.384350322262804],
                            [2.844873247542179, 48.38486672485294],
                            [2.843765717606249, 48.38561987909138],
                            [2.843153460059032, 48.38602537529961],
                            [2.842636480875915, 48.38636592596165],
                            [2.842037388815223, 48.38677098743939],
                        ],
                    },
                },
                931: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.64878906112415, 2.559649723799478],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4702.9854373,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.547548045814366,
                            48.62837555172384,
                            2.56958354823646,
                            48.66790196104987,
                        ),
                        "coordinates": [
                            [2.56958354823646, 48.62837555172384],
                            [2.569406439175108, 48.62889890137802],
                            [2.56913342267403, 48.62962039695549],
                            [2.568629048530896, 48.63081638115946],
                            [2.568266513822785, 48.631590401960274],
                            [2.567391618190399, 48.63334812704903],
                            [2.566950589204467, 48.634234132914834],
                            [2.566449473902916, 48.6353272596119],
                            [2.565994695460244, 48.63635366933025],
                            [2.56568511442547, 48.637066496834905],
                            [2.565340977921392, 48.637766824389495],
                            [2.564894971173897, 48.63874253154561],
                            [2.564635729043129, 48.63931858668684],
                            [2.564051150823877, 48.6406129906347],
                            [2.563723760738216, 48.64135086234981],
                            [2.56330872968431, 48.642282506963454],
                            [2.563018228015947, 48.64294067665082],
                            [2.562630848528986, 48.64381206177847],
                            [2.562312511904095, 48.644500385980066],
                            [2.561942507202297, 48.64535552551547],
                            [2.561587925483845, 48.64620923051155],
                            [2.561053363199314, 48.64732311202191],
                            [2.55973832591891, 48.650149252410294],
                            [2.55962275481229, 48.650405771799306],
                            [2.559009989226959, 48.651776564824345],
                            [2.558813759673332, 48.65220859982774],
                            [2.558609478770262, 48.65266223198352],
                            [2.558406499926798, 48.653104171436375],
                            [2.558151110818841, 48.653664916390206],
                            [2.557979153435526, 48.654064528093244],
                            [2.557813708441414, 48.65440297737949],
                            [2.557525663005992, 48.654948496784925],
                            [2.557179414908994, 48.655531897920326],
                            [2.556766882555606, 48.656168482914076],
                            [2.556536225230001, 48.65649716443471],
                            [2.556108453040318, 48.65706723109287],
                            [2.555622429634984, 48.657666184527585],
                            [2.555091932232451, 48.658340760760815],
                            [2.554545342900555, 48.659063925760314],
                            [2.554210584935686, 48.65949531875231],
                            [2.553481552192786, 48.66041127221636],
                            [2.553119710579877, 48.66086249832071],
                            [2.552562120158716, 48.66156589038121],
                            [2.552000468691985, 48.662275583110564],
                            [2.551502236174676, 48.662899721998],
                            [2.551272712301752, 48.66319151972034],
                            [2.550593088637024, 48.66399975558181],
                            [2.550260789836023, 48.664407245867245],
                            [2.549846390610607, 48.66493623613217],
                            [2.549421184863024, 48.66546048499634],
                            [2.548967377971035, 48.666018096460355],
                            [2.548387495128188, 48.6667635390484],
                            [2.548050814835807, 48.667245184400095],
                            [2.547730847990273, 48.66766933678332],
                            [2.547548045814366, 48.66790196104987],
                        ],
                    },
                },
                932: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.7063564569781, 2.4731877714913058],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 1679.0416788,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.462282244689792,
                            48.70563117036449,
                            2.484245146583624,
                            48.70823782858165,
                        ),
                        "coordinates": [
                            [2.484245146583624, 48.70661094689584],
                            [2.483999090311285, 48.706578257972986],
                            [2.48299836448982, 48.70643143780319],
                            [2.482413004274576, 48.7063340427909],
                            [2.481458498299263, 48.7061728730927],
                            [2.480704140633706, 48.70604107453491],
                            [2.48011354949652, 48.70594646880368],
                            [2.479517385293175, 48.705865980715004],
                            [2.478807926423619, 48.70578953251095],
                            [2.478110095024648, 48.705730431143486],
                            [2.477258683545632, 48.70567275667939],
                            [2.476822478805115, 48.705649914143045],
                            [2.476243636639174, 48.70563623900458],
                            [2.475977319575276, 48.70563117036449],
                            [2.475494992029789, 48.70563445835077],
                            [2.474875455476397, 48.70564420577465],
                            [2.474666234679159, 48.705650755584216],
                            [2.474510000606064, 48.70565634035054],
                            [2.474245076312613, 48.70566385562254],
                            [2.473408270082582, 48.70571792284229],
                            [2.472821455820152, 48.70576988616582],
                            [2.472192567143237, 48.705838983167816],
                            [2.471522957362155, 48.70592341216338],
                            [2.471028580198388, 48.705994141285274],
                            [2.470418799794077, 48.706097377111234],
                            [2.469476054655626, 48.70628194199456],
                            [2.468648054671239, 48.70647714204885],
                            [2.468087275787389, 48.706618079066395],
                            [2.466859775096365, 48.70691715067424],
                            [2.4655133330434, 48.70724299521899],
                            [2.464567693276872, 48.707482698255745],
                            [2.46392409849711, 48.70765877891531],
                            [2.463453002050065, 48.70781128272832],
                            [2.462804681259587, 48.708024074480846],
                            [2.462437563629043, 48.7081712211007],
                            [2.462282244689792, 48.70823782858165],
                        ],
                    },
                },
                933: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.8483131066409, 2.3716258379955346],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 966.126399941,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.369320584925386,
                            48.84573523381857,
                            2.37496291887346,
                            48.852479422836296,
                        ),
                        "coordinates": [
                            [2.37496291887346, 48.84602764938302],
                            [2.37391759472424, 48.84588836271746],
                            [2.372943607100269, 48.84575264250914],
                            [2.372876837388829, 48.8457407627555],
                            [2.372803984741051, 48.84573523381857],
                            [2.372730706386764, 48.84573711151685],
                            [2.372658719778807, 48.84574634999475],
                            [2.372589714463698, 48.84576273147693],
                            [2.372525308385546, 48.84578587413283],
                            [2.372467004265676, 48.845815233646114],
                            [2.372416177091923, 48.84585012383308],
                            [2.372374015432794, 48.84588972442815],
                            [2.372341507453807, 48.845933110688144],
                            [2.372324270000712, 48.84596670750242],
                            [2.371800913786207, 48.847155731530286],
                            [2.369983249986304, 48.851282692656504],
                            [2.369414919184414, 48.85235466264552],
                            [2.369320584925386, 48.852479422836296],
                        ],
                    },
                },
                934: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.84776084172973, 2.3910030580025134],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 705.610549931,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.386341707704105,
                            48.84730378704746,
                            2.395554512170688,
                            48.84815602646337,
                        ),
                        "coordinates": [
                            [2.395554512170688, 48.84757936747707],
                            [2.395440566622602, 48.847604638299494],
                            [2.395330639313232, 48.84763674013361],
                            [2.395225669566975, 48.84767539803906],
                            [2.395126549641074, 48.847720283778216],
                            [2.395034130198364, 48.84777101404462],
                            [2.394949195728426, 48.847827154834796],
                            [2.394872474003225, 48.84788822869028],
                            [2.394856389242105, 48.847902617946374],
                            [2.3948367177576, 48.84791994883321],
                            [2.394769721540761, 48.84797079848751],
                            [2.394694656772568, 48.848016474666736],
                            [2.394612431997462, 48.848056423454516],
                            [2.394524048987605, 48.848090160657705],
                            [2.394430579524625, 48.848117276186336],
                            [2.394333155777101, 48.848137441200485],
                            [2.394232962091269, 48.8481504107674],
                            [2.394131215880861, 48.84815602646337],
                            [2.394029151210597, 48.84815422168707],
                            [2.39395094438265, 48.848147763906326],
                            [2.391015907838114, 48.84782122592169],
                            [2.386808445777995, 48.84735451689955],
                            [2.386341707704105, 48.84730378704746],
                        ],
                    },
                },
                935: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.88539039787926, 2.3496624761416935],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 439.641299771,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.3496242520065,
                            48.88343618805934,
                            2.349774443646268,
                            48.88737490965435,
                        ),
                        "coordinates": [
                            [2.349774443646268, 48.88343618805934],
                            [2.349695143684662, 48.88357327563426],
                            [2.349636148269586, 48.88373446574697],
                            [2.349628519261735, 48.883770888511805],
                            [2.3496242520065, 48.88385608667173],
                            [2.349661938769813, 48.885644890279714],
                            [2.349683339032798, 48.88679669403324],
                            [2.349694082213971, 48.88737490965435],
                        ],
                    },
                },
                936: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.856358151060356, 2.3562672737775183],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 731.924541378,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351577562994996,
                            48.85523625280237,
                            2.360956490023828,
                            48.85747798252934,
                        ),
                        "coordinates": [
                            [2.360956490023828, 48.85523625280237],
                            [2.360612348312373, 48.855319216946434],
                            [2.356113446598156, 48.856395714591066],
                            [2.351577562994996, 48.85747798252934],
                        ],
                    },
                },
                937: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.84676339634037, 2.4148106331649286],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 691.183372377,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.41014036933673,
                            48.84635698889295,
                            2.41947990037451,
                            48.84715847940882,
                        ),
                        "coordinates": [
                            [2.41947990037451, 48.84635698889295],
                            [2.417284208072775, 48.84655790097273],
                            [2.410778871873719, 48.847103396169075],
                            [2.41014036933673, 48.84715847940882],
                        ],
                    },
                },
                938: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.912292461169045, 2.2596551973101593],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 3160.84864113,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.239684117127617,
                            48.908565915509755,
                            2.279278948726629,
                            48.91401670786369,
                        ),
                        "coordinates": [
                            [2.239684117127617, 48.90963293312601],
                            [2.239788042200377, 48.90966790803246],
                            [2.241995925431958, 48.91035114100607],
                            [2.242951956154106, 48.91063745113761],
                            [2.244203785933159, 48.91103819851468],
                            [2.247133195820976, 48.91198988774084],
                            [2.24786918081334, 48.912223636908],
                            [2.248457268204739, 48.912402542415116],
                            [2.24904847188424, 48.912568016147056],
                            [2.251081180060197, 48.91312499149592],
                            [2.251763555789819, 48.91329392273688],
                            [2.252251419758943, 48.91341039674463],
                            [2.252771067623638, 48.91351737418004],
                            [2.253198357374484, 48.91359382465759],
                            [2.253694965326188, 48.91366651913946],
                            [2.254194490360345, 48.91372208158493],
                            [2.255086280297262, 48.91380175877012],
                            [2.256129412795597, 48.9138929135812],
                            [2.256804402811331, 48.91393859365573],
                            [2.257483014712011, 48.9139771356279],
                            [2.258237459247105, 48.91400382810579],
                            [2.258912507761698, 48.91401380738276],
                            [2.259685039270891, 48.91401670786369],
                            [2.260414272768297, 48.91400530048436],
                            [2.261154356673425, 48.913979619633295],
                            [2.262009984389932, 48.913937352252105],
                            [2.263067825180868, 48.91385714155414],
                            [2.263930726664052, 48.913776796819725],
                            [2.2649633538998, 48.91365372319466],
                            [2.265537425637974, 48.91357749210933],
                            [2.266515946729223, 48.913418680027654],
                            [2.267259784266638, 48.91328351289951],
                            [2.268090299584195, 48.91311508175604],
                            [2.268881116173234, 48.912937102787836],
                            [2.269661112848016, 48.912744837192434],
                            [2.270224469729805, 48.91258574914724],
                            [2.270950337336166, 48.912372027717794],
                            [2.271835124939057, 48.912089392196414],
                            [2.272420190338338, 48.911880340279616],
                            [2.273055852773434, 48.91161896918386],
                            [2.2736626589117, 48.91133854222718],
                            [2.274511446864157, 48.91094879676207],
                            [2.276371524613339, 48.910083712992474],
                            [2.277386407905229, 48.90961789327552],
                            [2.278022091681943, 48.90929225223706],
                            [2.278614480260324, 48.9089451708651],
                            [2.279278948726629, 48.908565915509755],
                        ],
                    },
                },
                939: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9712674260537, 2.038578397804256],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1732.17472117,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.027518775677185,
                            48.969987572193546,
                            2.049083121493801,
                            48.97482086455293,
                        ),
                        "coordinates": [
                            [2.027518775677185, 48.9703669339495],
                            [2.029697735715853, 48.97014792031068],
                            [2.030373941673409, 48.97008787285684],
                            [2.031039229438515, 48.97003968591812],
                            [2.031639332769309, 48.97001273643106],
                            [2.032196021539893, 48.96999280693307],
                            [2.032911640449786, 48.969987572193546],
                            [2.033457328587801, 48.96999377966578],
                            [2.033999358836002, 48.97000711357591],
                            [2.034530503128254, 48.97002755355511],
                            [2.035216893226258, 48.97007457236039],
                            [2.03578037484953, 48.970126024583394],
                            [2.036574972096633, 48.970209011235376],
                            [2.037271934473995, 48.97030125490967],
                            [2.037874905379498, 48.970398006789445],
                            [2.038542804221758, 48.97051633938152],
                            [2.039167293932286, 48.97064169376353],
                            [2.039809727171332, 48.97078850445559],
                            [2.040462908289185, 48.970951993196294],
                            [2.041307230331253, 48.97118497667782],
                            [2.041862781201672, 48.971357723212584],
                            [2.042483183086317, 48.97156632525577],
                            [2.043060203455286, 48.97177719392779],
                            [2.043669589789665, 48.97201669316724],
                            [2.044217597282537, 48.97224651653825],
                            [2.044794323339983, 48.97250971929899],
                            [2.045219540670145, 48.97272494466729],
                            [2.045716765166938, 48.9729879424503],
                            [2.046866063316261, 48.973614253996054],
                            [2.047906545527419, 48.97417623188714],
                            [2.049083121493801, 48.97482086455293],
                        ],
                    },
                },
                940: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.051930246401426, 2.1937179114595176],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1574.56425035,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.190262803121982,
                            49.04543025423756,
                            2.197087678318264,
                            49.058047811766336,
                        ),
                        "coordinates": [
                            [2.191244759191911, 49.058047811766336],
                            [2.190861645779191, 49.05745498788427],
                            [2.190548507695725, 49.05691952085123],
                            [2.190426094756453, 49.05667026589281],
                            [2.190320376514518, 49.05632840667057],
                            [2.190263903331224, 49.05599200549049],
                            [2.190262803121982, 49.05590117696955],
                            [2.190263384294123, 49.05570513614451],
                            [2.190286147146323, 49.05541110233548],
                            [2.190352253199126, 49.055143299819605],
                            [2.190476334369092, 49.054807972036606],
                            [2.190614746975041, 49.05452262832335],
                            [2.190767510816821, 49.05428013093477],
                            [2.190974640742354, 49.05401628817903],
                            [2.191239618929525, 49.05377631174804],
                            [2.191575177113631, 49.05351257614192],
                            [2.191838411525413, 49.05333125598555],
                            [2.192000148508365, 49.05323343873634],
                            [2.194354839966382, 49.05182093168787],
                            [2.194905705559385, 49.05139610171207],
                            [2.195268133108681, 49.05109544958792],
                            [2.195399875872445, 49.050956224249795],
                            [2.19560848076081, 49.05073076355253],
                            [2.195835107841015, 49.05042169181413],
                            [2.196012428182078, 49.050130545255556],
                            [2.196167887446513, 49.04982857941369],
                            [2.196558872161905, 49.0489346749638],
                            [2.196687457682791, 49.04858591982278],
                            [2.19678936158777, 49.04825740882277],
                            [2.196870196580013, 49.047732331233604],
                            [2.196987368693518, 49.04645010849869],
                            [2.197074722862676, 49.04555183964988],
                            [2.197087678318264, 49.04543025423756],
                        ],
                    },
                },
                941: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.973674330186945, 2.186111200792598],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1664.95730783,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.180012382147682,
                            48.968496267514055,
                            2.193442867808299,
                            48.98026352072714,
                        ),
                        "coordinates": [
                            [2.193442867808299, 48.968496267514055],
                            [2.19157186409578, 48.969381401203755],
                            [2.190978338607006, 48.96966378651482],
                            [2.1902435522939, 48.97004830082599],
                            [2.189573802459474, 48.97043527342087],
                            [2.189030671122052, 48.97077719678384],
                            [2.188541736648982, 48.97112156793707],
                            [2.188009246432196, 48.97152536561181],
                            [2.187208567566102, 48.97217150173453],
                            [2.184686399255714, 48.974347652006415],
                            [2.184037682844878, 48.97491307022139],
                            [2.183696960901743, 48.97522668737213],
                            [2.183432299089941, 48.97548806020267],
                            [2.183160316039686, 48.97577797485107],
                            [2.18292814199018, 48.97605128699664],
                            [2.182688659938041, 48.97634838219843],
                            [2.182507150741869, 48.97660034733762],
                            [2.182332830843454, 48.97686421893191],
                            [2.182100344733173, 48.97723508257516],
                            [2.181261152372282, 48.97858065112672],
                            [2.181108546755353, 48.97883265542286],
                            [2.180901519983585, 48.97914644528001],
                            [2.180727228100482, 48.979396037441305],
                            [2.180502184911612, 48.97969076845007],
                            [2.180284459880419, 48.97995695947532],
                            [2.180012382147682, 48.98026352072714],
                        ],
                    },
                },
                942: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.04011512442914, 2.2032496870682654],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1527.63946237,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.197087678318264,
                            49.0353113085212,
                            2.21024652105706,
                            49.04543025423756,
                        ),
                        "coordinates": [
                            [2.197087678318264, 49.04543025423756],
                            [2.197091584578418, 49.04539358810968],
                            [2.197128241811315, 49.04500784383413],
                            [2.197250225733227, 49.04444054996809],
                            [2.197407351607283, 49.04402347794081],
                            [2.197540752370864, 49.043771843022085],
                            [2.197630118776123, 49.04361277976131],
                            [2.197649355411089, 49.04358222808735],
                            [2.197793559990601, 49.04338006582437],
                            [2.197989858698796, 49.04313749985846],
                            [2.198293074597037, 49.04281682594025],
                            [2.198615340773231, 49.04253034582485],
                            [2.198944341208773, 49.04228074412014],
                            [2.199147147291959, 49.04215418994457],
                            [2.199440389363224, 49.041971988923954],
                            [2.200034945660414, 49.041654357020164],
                            [2.201032167398774, 49.04115104963407],
                            [2.201729355047593, 49.04079726823742],
                            [2.202422478287046, 49.04045395046211],
                            [2.204740031468318, 49.03929208260162],
                            [2.205789162215096, 49.038778900688854],
                            [2.20635074933096, 49.03848457933566],
                            [2.206852110795169, 49.03820367582338],
                            [2.207274061122938, 49.03795055781521],
                            [2.207675532602531, 49.03768122792333],
                            [2.208056494534667, 49.037407377732265],
                            [2.208585600289199, 49.03696822512475],
                            [2.208878982019251, 49.036706864228776],
                            [2.209258816733971, 49.03633408799743],
                            [2.21024652105706, 49.0353113085212],
                        ],
                    },
                },
                943: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.00630891359553, 1.9105019882715242],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1292.74038421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.901781979947734,
                            49.00576253682855,
                            1.919237111731365,
                            49.00670027774167,
                        ),
                        "coordinates": [
                            [1.901781979947734, 49.00576253682855],
                            [1.901790368381825, 49.00576423769356],
                            [1.902729160929524, 49.00594149584636],
                            [1.903689724174504, 49.00611169271597],
                            [1.904482276708446, 49.00624347054149],
                            [1.905071122249443, 49.00632183254277],
                            [1.905670966702997, 49.00638357875187],
                            [1.906216685650328, 49.00643084124695],
                            [1.906758955782845, 49.006459053606754],
                            [1.90735652766824, 49.006468617667586],
                            [1.907813070223567, 49.006471229968845],
                            [1.907968951258836, 49.00646551889662],
                            [1.908543235855356, 49.006446985609024],
                            [1.909184460914762, 49.00643319469682],
                            [1.909355365117211, 49.00642933689485],
                            [1.909875055716564, 49.006400702181246],
                            [1.910097972388945, 49.0063889434238],
                            [1.912091835759061, 49.00629114201759],
                            [1.912452856034925, 49.00627449575719],
                            [1.913312850695135, 49.00622294912462],
                            [1.913811458069127, 49.00619910650897],
                            [1.914310654289818, 49.006189054038025],
                            [1.914795242248773, 49.006195599436765],
                            [1.915366526181886, 49.00621436166403],
                            [1.915981031332432, 49.00625469322571],
                            [1.91657007856274, 49.006311583196954],
                            [1.917198748634746, 49.006387649694645],
                            [1.917812832804513, 49.00647793657892],
                            [1.918488239911505, 49.00658747973578],
                            [1.91917454426289, 49.00669229884557],
                            [1.919237111731365, 49.00670027774167],
                        ],
                    },
                },
                944: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.02956750650235, 2.2161423200398764],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1503.17482203,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.21024652105706,
                            49.02477854792459,
                            2.222727322175325,
                            49.0353113085212,
                        ),
                        "coordinates": [
                            [2.21024652105706, 49.0353113085212],
                            [2.211234958996772, 49.03428772109431],
                            [2.211934269416814, 49.033582554388474],
                            [2.212050828308599, 49.033461279179775],
                            [2.212334650991096, 49.03317831650688],
                            [2.213225941394156, 49.03225752362751],
                            [2.213538589551506, 49.031926927152576],
                            [2.213985600077804, 49.03145978343459],
                            [2.214118607509665, 49.03131963926773],
                            [2.214311899127952, 49.031135494912284],
                            [2.214701291296587, 49.030734833662926],
                            [2.215198981152886, 49.0302272718783],
                            [2.216408251732713, 49.02897316043149],
                            [2.217537890315237, 49.02782506743145],
                            [2.217861445474715, 49.027484578934526],
                            [2.218125983816123, 49.02723125711528],
                            [2.218428825015656, 49.02697167991636],
                            [2.218793227077343, 49.026701373666675],
                            [2.219173966359555, 49.02645986042647],
                            [2.219546440380735, 49.02624171788984],
                            [2.220100905316275, 49.02597340085845],
                            [2.221887363440193, 49.025156864773834],
                            [2.222727322175325, 49.02477854792459],
                        ],
                    },
                },
                945: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.0061833642051, 2.2514035041850473],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2513.46718163,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.242479108496568,
                            48.99609884257494,
                            2.259655619057618,
                            49.015584975459475,
                        ),
                        "coordinates": [
                            [2.242479108496568, 49.015584975459475],
                            [2.243891923138443, 49.01453029274929],
                            [2.244324528878944, 49.01421859449099],
                            [2.245137802949952, 49.01357896361903],
                            [2.245465000925462, 49.013333722204244],
                            [2.245951107650513, 49.012911449182134],
                            [2.246345489125486, 49.01255474932075],
                            [2.246694770052406, 49.01218811988461],
                            [2.246812588856645, 49.0120515230458],
                            [2.246976992433265, 49.01185740846296],
                            [2.247440086972719, 49.01129302540317],
                            [2.247818247749802, 49.010821200356936],
                            [2.248055304932615, 49.01052498448478],
                            [2.248261937282807, 49.01026579592635],
                            [2.248831076252792, 49.00955005446084],
                            [2.249102926643525, 49.00922191352898],
                            [2.249342175503082, 49.00891992099268],
                            [2.250233936549223, 49.00777137844844],
                            [2.250918944239741, 49.006946263171656],
                            [2.251419125522458, 49.006325630150876],
                            [2.252872474242901, 49.00452316574334],
                            [2.253923911874838, 49.00325118153558],
                            [2.255407261307396, 49.00139613999132],
                            [2.255753769687276, 49.00096383377891],
                            [2.256620708454428, 48.99987632037915],
                            [2.257083614594808, 48.99929211501987],
                            [2.258113442257416, 48.998010460210544],
                            [2.259025444872625, 48.99688069384329],
                            [2.259655619057618, 48.99609884257494],
                        ],
                    },
                },
                946: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.57128981382939, 2.181358047525474],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2135.7834798,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.170976266414434,
                            48.56459702646747,
                            2.192063068770897,
                            48.577508489431835,
                        ),
                        "coordinates": [
                            [2.170976266414434, 48.56459702646747],
                            [2.17172654415447, 48.564932847306856],
                            [2.17335369672128, 48.56565514387435],
                            [2.173646850060759, 48.56579047151535],
                            [2.174032706859375, 48.56597089998105],
                            [2.174418509952119, 48.56616798274798],
                            [2.174789190539962, 48.56638669348678],
                            [2.175132222885808, 48.56662035326221],
                            [2.175440110215418, 48.56685895995195],
                            [2.175747934074798, 48.5671175497863],
                            [2.176113277517944, 48.56743951034772],
                            [2.178403133233052, 48.569424682301666],
                            [2.180395316125702, 48.571156239567884],
                            [2.180788282429595, 48.571491547285916],
                            [2.18125389301595, 48.571871921797424],
                            [2.181738052320768, 48.57224322899794],
                            [2.182242973895478, 48.5725961029814],
                            [2.182776503358541, 48.57293326106523],
                            [2.183342731624164, 48.57324880897363],
                            [2.183903994797406, 48.57354935717823],
                            [2.184505461193709, 48.573836633991796],
                            [2.186713867521629, 48.5749165503998],
                            [2.187821077369343, 48.57544991426277],
                            [2.189555424622037, 48.57628826163466],
                            [2.191683312357492, 48.57732528310781],
                            [2.192063068770897, 48.577508489431835],
                        ],
                    },
                },
                947: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.046150180136536, 2.0981522761291633],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 446.377365123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.095195067225969,
                            49.04564873988319,
                            2.101108482966614,
                            49.04664576264113,
                        ),
                        "coordinates": [
                            [2.101108482966614, 49.04564873988319],
                            [2.099538274275683, 49.04593526764531],
                            [2.096377570034755, 49.04643086426444],
                            [2.095195067225969, 49.04664576264113],
                        ],
                    },
                },
                948: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.48720502968073, 2.7230846449776993],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4196.6630107,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.69503731516767,
                            48.48610095239564,
                            2.751153658380149,
                            48.488224297839004,
                        ),
                        "coordinates": [
                            [2.751153658380149, 48.487222875528246],
                            [2.750811983801073, 48.48730073616169],
                            [2.749747283783193, 48.487533035691584],
                            [2.749007710722303, 48.48769514221473],
                            [2.748296512086821, 48.487826211208805],
                            [2.747660218607561, 48.48792607216334],
                            [2.747206169495083, 48.48798958052788],
                            [2.746701972392033, 48.48804850919689],
                            [2.746001032679646, 48.48812242182931],
                            [2.745282022136315, 48.488174982641226],
                            [2.744698864033415, 48.48820801466586],
                            [2.744040093935752, 48.48822346817715],
                            [2.743478451420567, 48.488224297839004],
                            [2.742995182922323, 48.4882165142968],
                            [2.742379289406653, 48.48818541044871],
                            [2.741638105880442, 48.48815237119443],
                            [2.740939834349916, 48.48811441640423],
                            [2.740281014156473, 48.48808583309067],
                            [2.739650808096746, 48.488054764756065],
                            [2.739024124486071, 48.48801654355693],
                            [2.738443283681822, 48.487983302155456],
                            [2.737502262661784, 48.48793390176399],
                            [2.73662749746451, 48.48788779574794],
                            [2.735701100376435, 48.487835568048226],
                            [2.734784433431131, 48.48778882534265],
                            [2.734200781053006, 48.48775994427691],
                            [2.733223233991172, 48.487708644305776],
                            [2.732460532588034, 48.48766848249593],
                            [2.731258959189431, 48.48761318369091],
                            [2.730523547642252, 48.487591954794496],
                            [2.729007059343425, 48.487559358494124],
                            [2.72863773006876, 48.48755703909364],
                            [2.727783218926979, 48.48754663751616],
                            [2.726854329619693, 48.48753088784818],
                            [2.725987951369075, 48.487505316493404],
                            [2.725221606933592, 48.48745560083504],
                            [2.724397867333202, 48.48738942192397],
                            [2.723588445316262, 48.48732318874582],
                            [2.722761539498901, 48.487247179997816],
                            [2.721901608245138, 48.487190935282754],
                            [2.721145917116859, 48.48712925977201],
                            [2.720208641420853, 48.48704362176508],
                            [2.719709624572499, 48.4870277916152],
                            [2.719140726037449, 48.487021152763596],
                            [2.718593143733495, 48.48702606405739],
                            [2.718034838729163, 48.487057252769375],
                            [2.717019164707373, 48.48712951470483],
                            [2.716446189067496, 48.4871704990984],
                            [2.715863512492456, 48.48719940189754],
                            [2.715287098899902, 48.48720225435033],
                            [2.714742989406122, 48.48716983514569],
                            [2.714320275491372, 48.487121278650385],
                            [2.713975249029712, 48.48706814252182],
                            [2.713528248718653, 48.48698591630918],
                            [2.713112189980551, 48.48688936133404],
                            [2.712174337790873, 48.48665776471667],
                            [2.711595594454895, 48.486523603224626],
                            [2.711026947651539, 48.486408957944505],
                            [2.710584833637423, 48.48633183864669],
                            [2.710136953427396, 48.486266694491746],
                            [2.709520731988535, 48.48618544793254],
                            [2.709137507305188, 48.48615101865946],
                            [2.708686297795189, 48.48611919042639],
                            [2.708027626298147, 48.4861046962229],
                            [2.707308393057996, 48.48610095239564],
                            [2.706101938384312, 48.48612737351743],
                            [2.703870163645964, 48.4861625036262],
                            [2.703254730024604, 48.48617169015183],
                            [2.702732634690095, 48.486180571849836],
                            [2.701618107313714, 48.4861994543294],
                            [2.700701155161749, 48.486228481642726],
                            [2.700037237733369, 48.48626748266829],
                            [2.699390661628627, 48.48632561445008],
                            [2.69879488344611, 48.48638117001345],
                            [2.698076702743616, 48.48647710888577],
                            [2.697401010623497, 48.48658395145305],
                            [2.696725431993009, 48.48670744490158],
                            [2.696185722507929, 48.48681146913696],
                            [2.695556753246093, 48.48694670346259],
                            [2.69503731516767, 48.487076395248074],
                        ],
                    },
                },
                949: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.1380598109603, 2.2723418012754895],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 1901.06508262,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.267674786874433,
                            49.132577702391806,
                            2.280515369819846,
                            49.14528660789949,
                        ),
                        "coordinates": [
                            [2.280515369819846, 49.132577702391806],
                            [2.27565936485099, 49.13454062027236],
                            [2.274687083291566, 49.134932686664044],
                            [2.27412837303634, 49.13516079772366],
                            [2.273689365759236, 49.13535328260266],
                            [2.273341035287542, 49.13552678182589],
                            [2.272963638695093, 49.1357407114609],
                            [2.272607952052375, 49.13598796219108],
                            [2.272306675190137, 49.13622096790012],
                            [2.272001708776877, 49.13649917629721],
                            [2.271685798336763, 49.136824965649225],
                            [2.270029841963733, 49.13859185120883],
                            [2.268439142618548, 49.14028737212342],
                            [2.26817393733281, 49.140625077022],
                            [2.267981311096413, 49.140927135732966],
                            [2.267817627562239, 49.14127679768858],
                            [2.267737454764108, 49.14155513068775],
                            [2.267678932094973, 49.14190961473698],
                            [2.267674786874433, 49.14228078535519],
                            [2.267732310361471, 49.142640098585574],
                            [2.267837030870093, 49.14296374942959],
                            [2.267967214367085, 49.143235069968526],
                            [2.268159021828312, 49.14352784117683],
                            [2.268394369927039, 49.14380874219874],
                            [2.268687713633045, 49.14411584911734],
                            [2.268937644669891, 49.14434679097185],
                            [2.269270947505275, 49.14461109207766],
                            [2.269651444988593, 49.14484448919205],
                            [2.270039114589342, 49.14504174548885],
                            [2.270552769414137, 49.14528660789949],
                        ],
                    },
                },
                950: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.795632177901794, 2.4295745833280105],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 1530.4152893,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.426482408484048,
                            48.78891489668918,
                            2.432070116592686,
                            48.80204938032392,
                        ),
                        "coordinates": [
                            [2.432070116592686, 48.78891489668918],
                            [2.431857313997105, 48.78943027009336],
                            [2.431660120323357, 48.78988012947137],
                            [2.431473668068494, 48.79029904713331],
                            [2.431254965732261, 48.79080364752911],
                            [2.430659790727081, 48.792179395721874],
                            [2.430340868570299, 48.79301956358032],
                            [2.430229929071471, 48.79339083026073],
                            [2.430147798354993, 48.793762074000824],
                            [2.430119416877252, 48.79399051350288],
                            [2.43008415009924, 48.79438789111289],
                            [2.430038158688936, 48.7948281059252],
                            [2.429989295476793, 48.79565853383082],
                            [2.429953915578894, 48.795996428041754],
                            [2.429925447488488, 48.796179659568146],
                            [2.429889830398333, 48.796391450447665],
                            [2.429832615912633, 48.79661039544663],
                            [2.429771764490148, 48.796810309873905],
                            [2.429667843333378, 48.79708877668779],
                            [2.429578178412195, 48.79728871353238],
                            [2.429447291688545, 48.797544786007194],
                            [2.429140611158748, 48.79805672309048],
                            [2.429014369083738, 48.79824567307316],
                            [2.42886635520273, 48.79844003572659],
                            [2.42835571706259, 48.799082529760724],
                            [2.428039017466682, 48.79949099821307],
                            [2.427620398081034, 48.800078146945296],
                            [2.4272970635476, 48.80053047876123],
                            [2.427156963907712, 48.800732833785176],
                            [2.426884050436453, 48.80118750326808],
                            [2.426744087931962, 48.80146837501133],
                            [2.42650013095641, 48.80200629831029],
                            [2.426482408484048, 48.80204938032392],
                        ],
                    },
                },
                951: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.88706461018841, 2.8406314599336078],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2300.11453513,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.826405497304068,
                            48.88268104666967,
                            2.854315926463895,
                            48.890856796314026,
                        ),
                        "coordinates": [
                            [2.826405497304068, 48.890856796314026],
                            [2.828109627719599, 48.89029571120087],
                            [2.830181328085556, 48.88961683903838],
                            [2.833494897683794, 48.888530230373526],
                            [2.834278169975499, 48.88827282305988],
                            [2.83549693328756, 48.887878838038574],
                            [2.835922188710759, 48.88775253784432],
                            [2.836352664039321, 48.887631328789936],
                            [2.836901854393411, 48.88749084521827],
                            [2.837373754018282, 48.887376269049554],
                            [2.837791590553476, 48.887284088539914],
                            [2.838297206493627, 48.887181292921426],
                            [2.838906113147297, 48.887067812020085],
                            [2.839479036920323, 48.88697494475018],
                            [2.839928140712233, 48.88690818945581],
                            [2.841577533586265, 48.88667248367306],
                            [2.848838249628895, 48.8856309867704],
                            [2.849501514004537, 48.88552913943682],
                            [2.84992202081599, 48.8854488355575],
                            [2.850362975342174, 48.88534627651727],
                            [2.850739274743056, 48.88524059833006],
                            [2.851074214411359, 48.885135104930185],
                            [2.851445060419211, 48.88500217345081],
                            [2.851820787635331, 48.88484194231902],
                            [2.852072890676682, 48.884724885570705],
                            [2.85236850635528, 48.88456672009391],
                            [2.852620319932025, 48.8844223896437],
                            [2.852866734757018, 48.88425592114007],
                            [2.853100100416383, 48.88407757882474],
                            [2.853292250204567, 48.8839130590367],
                            [2.853517505261642, 48.88370065930428],
                            [2.853727019238246, 48.88346616654684],
                            [2.853933696515699, 48.88320782315563],
                            [2.854315926463895, 48.88268104666967],
                        ],
                    },
                },
                952: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.00397208253125, 3.3124842306198548],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 5956.71637881,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.297059231759595,
                            47.986192359878295,
                            3.33759167637693,
                            48.02668663232931,
                        ),
                        "coordinates": [
                            [3.302564536511451, 48.02668663232931],
                            [3.298188910257571, 48.019853351532504],
                            [3.297245087010692, 48.01712575993243],
                            [3.297059231759595, 48.014049723807474],
                            [3.297402425105371, 48.011995038133485],
                            [3.298374373611678, 48.00950752028471],
                            [3.302628573213903, 48.005452984280815],
                            [3.308426840382582, 48.00223981722276],
                            [3.318921528057901, 47.99821592550489],
                            [3.32321814340871, 47.99646843715336],
                            [3.326117032956252, 47.99490409762739],
                            [3.330521981549721, 47.99221498428188],
                            [3.33759167637693, 47.986192359878295],
                        ],
                    },
                },
                953: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [49.01487848028882, 3.3875320932671755],
                        "indice_lig": "P",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 6335.86256003,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.364927128865269,
                            48.99193822029961,
                            3.409597359882764,
                            49.03794894167955,
                        ),
                        "coordinates": [
                            [3.364927128865269, 48.99193822029961],
                            [3.376317693222663, 48.99738781894549],
                            [3.378482696931921, 48.99877354886844],
                            [3.380253713090378, 49.000765159603226],
                            [3.386921406219843, 49.013018368259],
                            [3.393165441347809, 49.02433817117766],
                            [3.39676218429671, 49.030729736325505],
                            [3.398750089574201, 49.03325446896857],
                            [3.400408470804616, 49.03464450308404],
                            [3.402775009832036, 49.03582715495288],
                            [3.406365802680644, 49.037132182957755],
                            [3.409597359882764, 49.03794894167955],
                        ],
                    },
                },
                954: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98075859926737, 2.2709659827582835],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 166.303618961,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.269851993930268,
                            48.980646100425986,
                            2.272084772747633,
                            48.98091190326584,
                        ),
                        "coordinates": [
                            [2.272084772747633, 48.980646100425986],
                            [2.271950869618948, 48.98065591704335],
                            [2.271823795701041, 48.98066663645357],
                            [2.271758211804184, 48.98067109521663],
                            [2.271662563736779, 48.98067913480196],
                            [2.271161102964788, 48.98072021476257],
                            [2.270614515042522, 48.98079094371412],
                            [2.270471029382747, 48.98081424142235],
                            [2.270322078497261, 48.98083843554761],
                            [2.269851993930268, 48.98091190326584],
                        ],
                    },
                },
                955: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.234656463580386, 1.5013975003500846],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 20374.5902831,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.38624502094351,
                            48.18643720958249,
                            1.621498624336312,
                            48.274632389218624,
                        ),
                        "coordinates": [
                            [1.621498624336312, 48.274632389218624],
                            [1.601725793965487, 48.26467647680493],
                            [1.589887469947284, 48.25998217812174],
                            [1.573572426389221, 48.25517094772278],
                            [1.545141466790635, 48.247708214975006],
                            [1.488309163146112, 48.23250486063014],
                            [1.462198913037642, 48.2254659692074],
                            [1.445907265737125, 48.22063632142484],
                            [1.426972921796003, 48.213560186448845],
                            [1.411995606785474, 48.20719731993754],
                            [1.403762504587323, 48.20285481350765],
                            [1.393044106576778, 48.194729194848286],
                            [1.389036552458326, 48.190249903186206],
                            [1.38624502094351, 48.18643720958249],
                        ],
                    },
                },
                956: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89834534905035, 2.321568134125083],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1671.51699482,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.315599220546768,
                            48.89416838621195,
                            2.324051867179437,
                            48.9056549540281,
                        ),
                        "coordinates": [
                            [2.315599220546768, 48.89416838621195],
                            [2.3162044042611, 48.8942882150201],
                            [2.316453371762191, 48.894342984278055],
                            [2.316770892021817, 48.89442155714364],
                            [2.3170811941327, 48.89450250807315],
                            [2.317214696296079, 48.89453822063951],
                            [2.317377062772124, 48.894583455053905],
                            [2.317647672528863, 48.89466677727455],
                            [2.318058720102041, 48.89480752097976],
                            [2.318459207455153, 48.89496098162603],
                            [2.318953233173107, 48.89515723387387],
                            [2.319328480557982, 48.8952881539551],
                            [2.319707521763037, 48.89540288229673],
                            [2.320035697914932, 48.89550001855271],
                            [2.320346575176216, 48.89558323403162],
                            [2.320706851523712, 48.895654770620645],
                            [2.321370812806657, 48.895745274616935],
                            [2.321614991242529, 48.89578132064631],
                            [2.321987277734828, 48.895855362146364],
                            [2.322182303559252, 48.8958940551107],
                            [2.322269587252762, 48.89591295102933],
                            [2.32242778596023, 48.89596153095794],
                            [2.322570978320146, 48.896018203321496],
                            [2.322671893970456, 48.89606497768878],
                            [2.322720986220413, 48.89609106227637],
                            [2.322738715386656, 48.89610005683397],
                            [2.322815082882335, 48.89613873504687],
                            [2.322881903693294, 48.89617471432631],
                            [2.322902359288628, 48.896185507629106],
                            [2.323046911643662, 48.89626376182044],
                            [2.323201008551196, 48.89635100992517],
                            [2.323495545356364, 48.89660284014326],
                            [2.323608718396747, 48.89672425553888],
                            [2.323768237930779, 48.89694729319441],
                            [2.323850033698968, 48.897097481174356],
                            [2.323896380127263, 48.89719910438095],
                            [2.323956357156106, 48.89733759930978],
                            [2.324029958516564, 48.89753185072025],
                            [2.324051867179437, 48.897792805161146],
                            [2.324016164001098, 48.89812896825027],
                            [2.323885062233823, 48.89873866214313],
                            [2.323856391184517, 48.898842975118654],
                            [2.323826349653045, 48.89897066893779],
                            [2.323799038128615, 48.89909116830721],
                            [2.323786749099442, 48.899144224403564],
                            [2.323702084095518, 48.899505724042804],
                            [2.323624244318794, 48.899847439274524],
                            [2.323560062636204, 48.900121711573405],
                            [2.323557330495518, 48.90013430098865],
                            [2.323540943250696, 48.90020803977016],
                            [2.323509535114344, 48.90033843168901],
                            [2.323482224230977, 48.9004517372017],
                            [2.323463103634747, 48.900540763308705],
                            [2.323442619655118, 48.90062889048006],
                            [2.323426231503564, 48.900701729891274],
                            [2.32339345543893, 48.9008438114234],
                            [2.323389358379954, 48.90086359485296],
                            [2.323386627887909, 48.900872587893716],
                            [2.323337457247732, 48.90111178940839],
                            [2.323297847430144, 48.901303330687696],
                            [2.323273261077127, 48.90142293138489],
                            [2.323211795668932, 48.901722383162216],
                            [2.323191308459891, 48.90181950335237],
                            [2.323146233274699, 48.902038921180136],
                            [2.322909926282011, 48.903182773225005],
                            [2.3228853385237, 48.90330507158649],
                            [2.322879872963146, 48.90333564620399],
                            [2.322576618681681, 48.90480143042753],
                            [2.322547930300097, 48.904943512757725],
                            [2.322506947213364, 48.905144945021966],
                            [2.322491922761533, 48.90521059092353],
                            [2.322459134923079, 48.90537695306019],
                            [2.322431814261328, 48.905501948866274],
                            [2.322400403166692, 48.9056549540281],
                        ],
                    },
                },
                957: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89048056005887, 2.306484293549573],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1651.83719007,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.29803330457685,
                            48.8854042809258,
                            2.315599220546768,
                            48.89416838621195,
                        ),
                        "coordinates": [
                            [2.29803330457685, 48.8854042809258],
                            [2.298278490321922, 48.88553700998297],
                            [2.298906871348438, 48.88585916014498],
                            [2.299499868875073, 48.886148678935285],
                            [2.300053263238162, 48.88642068160199],
                            [2.30046489801403, 48.88667170934397],
                            [2.300749769168129, 48.88684985547936],
                            [2.300974643437413, 48.88702708226512],
                            [2.301222672411993, 48.887244784124306],
                            [2.301435259014266, 48.88744718606856],
                            [2.301642390401899, 48.887653183671574],
                            [2.301771845610144, 48.88778541630017],
                            [2.301920375347839, 48.88794193488141],
                            [2.302006222792398, 48.888033687716785],
                            [2.302152025498302, 48.88819200401933],
                            [2.302191545922343, 48.88823068431048],
                            [2.302547201014362, 48.88861657975514],
                            [2.302833392748343, 48.88888554701571],
                            [2.303070541528806, 48.889087054457136],
                            [2.30340311755293, 48.889338049078965],
                            [2.303997437406768, 48.889732101675726],
                            [2.304166463946563, 48.88984635719162],
                            [2.304372305938201, 48.889970515700675],
                            [2.304586338694636, 48.890085682254366],
                            [2.304747208226468, 48.89016396405495],
                            [2.305946269516834, 48.89072521915211],
                            [2.307533920375972, 48.891474947649236],
                            [2.307772512865817, 48.89159011449711],
                            [2.30828378788212, 48.89183934154016],
                            [2.308815518190312, 48.892097563435854],
                            [2.31036847368245, 48.892857815797825],
                            [2.310843384229622, 48.893055150412785],
                            [2.31128651457019, 48.89322605440771],
                            [2.311762761774658, 48.89336415981205],
                            [2.31237612386189, 48.893521326783755],
                            [2.312827131249224, 48.8936284909725],
                            [2.313220417438781, 48.89371184914755],
                            [2.313537935800478, 48.89377377517818],
                            [2.315518841217685, 48.8941524701219],
                            [2.315599220546768, 48.89416838621195],
                        ],
                    },
                },
                958: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.8747439381964, 2.2797326247762855],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1034.47953057,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.275574526847743,
                            48.870974138193766,
                            2.284431219916768,
                            48.87790843816007,
                        ),
                        "coordinates": [
                            [2.275574526847743, 48.870974138193766],
                            [2.275774542519901, 48.87128179743647],
                            [2.275785427127885, 48.8712979903803],
                            [2.27598136738516, 48.87159575508543],
                            [2.276064373472024, 48.87171899994623],
                            [2.276087505707381, 48.87175408395329],
                            [2.276135130415138, 48.871826051673956],
                            [2.27621405722599, 48.87194209944553],
                            [2.276264400331111, 48.872021263018226],
                            [2.276453549682009, 48.8723028361081],
                            [2.276529753021967, 48.872417084646756],
                            [2.276581463810724, 48.87249355018142],
                            [2.276988446838697, 48.873017142076705],
                            [2.277529762025498, 48.87358473147246],
                            [2.27792077196972, 48.873945448132936],
                            [2.278265717019365, 48.874271393089536],
                            [2.278449590922048, 48.87441717006801],
                            [2.278929109238398, 48.87473215971842],
                            [2.279652588531028, 48.87511741361032],
                            [2.27984197783899, 48.875216428661886],
                            [2.280145840198249, 48.875357766026944],
                            [2.280517871638934, 48.87549823616644],
                            [2.28150809952964, 48.87583263263776],
                            [2.282279979614384, 48.87612858247744],
                            [2.282503436157638, 48.87625099055574],
                            [2.282767737421722, 48.8764264747647],
                            [2.282933932325939, 48.876551552591934],
                            [2.283082418220776, 48.876664031359894],
                            [2.28333167499062, 48.876887168374715],
                            [2.283507368452717, 48.877056314166545],
                            [2.283604056915825, 48.8771606750098],
                            [2.283638102946602, 48.87719666263622],
                            [2.283795558364668, 48.87734960150105],
                            [2.284028990935218, 48.87757633760556],
                            [2.284301425006699, 48.87780847578239],
                            [2.284431219916768, 48.87790843816007],
                        ],
                    },
                },
                959: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.86129307033593, 2.2757706498379027],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 775.493754385,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.274154629736559,
                            48.85804605538447,
                            2.278112559810519,
                            48.863978066607594,
                        ),
                        "coordinates": [
                            [2.274154629736559, 48.85804605538447],
                            [2.274217107763957, 48.858077046676584],
                            [2.274309884078307, 48.858113875040566],
                            [2.274344222888405, 48.85812543497071],
                            [2.274407028765989, 48.8581474822381],
                            [2.274494968897064, 48.858185232650506],
                            [2.274576444721372, 48.858228841795736],
                            [2.274650567428956, 48.858277831236705],
                            [2.274716522607881, 48.858331664530034],
                            [2.274773587886739, 48.85838975272833],
                            [2.274821139699761, 48.85845145801801],
                            [2.274858655862439, 48.85851610452639],
                            [2.274885725013902, 48.85858298557327],
                            [2.274896119567775, 48.85862076310269],
                            [2.275119282591025, 48.85959142566349],
                            [2.275129673779246, 48.859766429596],
                            [2.274959233394167, 48.860326338007276],
                            [2.275011965316607, 48.86057836735167],
                            [2.276165807864298, 48.862664988122454],
                            [2.276462263665336, 48.863169144403294],
                            [2.276913821146191, 48.863603230288646],
                            [2.276947842579061, 48.86363442304367],
                            [2.277024992697061, 48.86369582118853],
                            [2.277110400136415, 48.863752259760844],
                            [2.277203336846402, 48.86380325768965],
                            [2.277303010029727, 48.86384838207896],
                            [2.27740856764486, 48.86388724464411],
                            [2.277519110462201, 48.86391951707423],
                            [2.277633696303426, 48.863944920266185],
                            [2.277751345258756, 48.863963241444395],
                            [2.277871054855739, 48.86397432166173],
                            [2.277991802638051, 48.863978066607594],
                            [2.278112559810519, 48.86397444579114],
                        ],
                    },
                },
                960: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.94876873710224, 2.584765994787457],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2866.56229588,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.566448016963,
                            48.94418106597472,
                            2.603135305118449,
                            48.9531483875826,
                        ),
                        "coordinates": [
                            [2.566448016963, 48.94418106597472],
                            [2.566891948596433, 48.94430274383506],
                            [2.568060084076771, 48.944602570357915],
                            [2.569195661927715, 48.944888173339194],
                            [2.569817732203788, 48.94505108464606],
                            [2.570754486773528, 48.94530138872618],
                            [2.571557405897602, 48.94551150926684],
                            [2.573604556880427, 48.94605454643058],
                            [2.576045849572909, 48.94667048694143],
                            [2.578678916716112, 48.94733831537988],
                            [2.58119625510733, 48.94796588262504],
                            [2.58410432923042, 48.94869724276722],
                            [2.585019430124057, 48.948923681494264],
                            [2.586169571382587, 48.949192430824624],
                            [2.588419224238586, 48.94971334949363],
                            [2.591652740358425, 48.95046283702698],
                            [2.592202519073878, 48.950590098723566],
                            [2.59297655268225, 48.95076920162161],
                            [2.594032738515728, 48.951016666970744],
                            [2.59547956323488, 48.95135127815666],
                            [2.596702132176895, 48.95163165419941],
                            [2.601719329292711, 48.95281697296261],
                            [2.60283348429561, 48.95307849550037],
                            [2.603135305118449, 48.9531483875826],
                        ],
                    },
                },
                961: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.84988679045886, 2.266426758202463],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 615.924410568,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.264082030746222,
                            48.84789565020842,
                            2.268176749423331,
                            48.852504091512166,
                        ),
                        "coordinates": [
                            [2.264082030746222, 48.84789565020842],
                            [2.264130426738311, 48.84794309720084],
                            [2.264174875985738, 48.84798140391433],
                            [2.264261424886805, 48.84804386119327],
                            [2.264355894185705, 48.8481011022126],
                            [2.264457562341599, 48.84815269082238],
                            [2.264498167533411, 48.848170834253885],
                            [2.265870530257765, 48.84876223865912],
                            [2.265913006976611, 48.84878157664411],
                            [2.265995571346155, 48.848825786998944],
                            [2.266070681183415, 48.84887544939002],
                            [2.266137512849392, 48.848930021857186],
                            [2.26619533616355, 48.84898890545431],
                            [2.266243516964264, 48.849051455956214],
                            [2.266268045384424, 48.84909130708912],
                            [2.26760062614369, 48.85147255363127],
                            [2.268176749423331, 48.852504091512166],
                        ],
                    },
                },
                962: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.846479101287585, 2.262911172303661],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 359.135084713,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.261745124963672,
                            48.845058172313735,
                            2.264082030746222,
                            48.84789565020842,
                        ),
                        "coordinates": [
                            [2.261745124963672, 48.845058172313735],
                            [2.261893641759714, 48.84524119484093],
                            [2.262729100105323, 48.84625449310817],
                            [2.263482939051753, 48.847176685087106],
                            [2.264008151967574, 48.847819166858045],
                            [2.264082030746222, 48.84789565020842],
                        ],
                    },
                },
                963: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.83291000087737, 2.241239880036143],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 421.142873558,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.238639348575401,
                            48.832110560110216,
                            2.243840593741985,
                            48.83370884911258,
                        ),
                        "coordinates": [
                            [2.238639348575401, 48.832110560110216],
                            [2.239550121358392, 48.83239107972815],
                            [2.243840593741985, 48.83370884911258],
                        ],
                    },
                },
                964: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.87014011983252, 2.3292049841881264],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 444.698862395,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.326272274027749,
                            48.86963317302491,
                            2.332138599575903,
                            48.87064173324228,
                        ),
                        "coordinates": [
                            [2.332138599575903, 48.87064173324228],
                            [2.331143205595657, 48.87047609048401],
                            [2.326272274027749, 48.86963317302491],
                        ],
                    },
                },
                965: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.92597657591952, 2.347894984251233],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 1911.66686144,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345604378196291,
                            48.91756717658463,
                            2.350389537889768,
                            48.93445554506131,
                        ),
                        "coordinates": [
                            [2.350389537889768, 48.91756717658463],
                            [2.350342314076203, 48.91772961853044],
                            [2.350147572995856, 48.91853147990211],
                            [2.350032161666563, 48.9189835689119],
                            [2.349880647907257, 48.91944280003035],
                            [2.349725516327031, 48.9198877536472],
                            [2.34962876261022, 48.92012699342345],
                            [2.349377376763388, 48.92070151550807],
                            [2.349135603843973, 48.921220238976524],
                            [2.348994880841532, 48.921577155113006],
                            [2.348854186780369, 48.922060176981844],
                            [2.348768465522529, 48.92240132913136],
                            [2.348602377838885, 48.92310495920607],
                            [2.348377223838913, 48.92403258160752],
                            [2.348085590837943, 48.92511602811331],
                            [2.347753317643256, 48.92626277785316],
                            [2.347557632219622, 48.92690554426731],
                            [2.347432100906438, 48.92735109569436],
                            [2.34734718790273, 48.9276870841212],
                            [2.347243819834142, 48.92810828689276],
                            [2.347085068572845, 48.9287498309092],
                            [2.346824778539624, 48.929780925648814],
                            [2.346512776343114, 48.93097514614477],
                            [2.346221077323989, 48.93214258298946],
                            [2.345918274910239, 48.93328202093088],
                            [2.345604378196291, 48.93445554506131],
                        ],
                    },
                },
                966: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.79928332446579, 2.164063751824247],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1142.94869814,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.15683568548617,
                            48.797310081377546,
                            2.171389812756379,
                            48.80071846386355,
                        ),
                        "coordinates": [
                            [2.171389812756379, 48.80071846386355],
                            [2.170830357527754, 48.800700720559675],
                            [2.170326695902241, 48.80067533554842],
                            [2.169697168739786, 48.80062819510285],
                            [2.169202898781894, 48.8005843309325],
                            [2.168447606155488, 48.80048769712934],
                            [2.167687736234038, 48.80036640154266],
                            [2.167049172095505, 48.80023603764411],
                            [2.166345438479331, 48.80006859693602],
                            [2.165730297934967, 48.79991052985321],
                            [2.164692812178737, 48.79962773303816],
                            [2.164192683305267, 48.7994818365617],
                            [2.163649432820911, 48.79930969882626],
                            [2.163084630812713, 48.79912087097465],
                            [2.162850799732983, 48.799041995934324],
                            [2.161958736431169, 48.79873738058273],
                            [2.160494482932771, 48.79826508796951],
                            [2.160246219863137, 48.79819570134629],
                            [2.15992599538207, 48.79810716886839],
                            [2.15939704124788, 48.797973103336034],
                            [2.158322075302499, 48.79769604510322],
                            [2.157683680908086, 48.79753481665686],
                            [2.15683568548617, 48.797310081377546],
                        ],
                    },
                },
                967: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.79620666123304, 2.1495320290864575],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1102.10440123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.142141851963426,
                            48.795715917344765,
                            2.15683568548617,
                            48.797310081377546,
                        ),
                        "coordinates": [
                            [2.142141851963426, 48.795715917344765],
                            [2.142706607881934, 48.79574745613372],
                            [2.143856757254184, 48.79579486437915],
                            [2.147234244824272, 48.795959949065534],
                            [2.148995074205409, 48.79602948652837],
                            [2.150017745902113, 48.796064478878215],
                            [2.150442631394686, 48.79608658921006],
                            [2.150781082583517, 48.79610855609176],
                            [2.151285101512348, 48.7961569644232],
                            [2.151641490132594, 48.796197992654015],
                            [2.152030230622056, 48.79625572855427],
                            [2.152480159919246, 48.796323079295],
                            [2.152976821918897, 48.79641429648562],
                            [2.154495584415558, 48.796699879271635],
                            [2.155085753590148, 48.7968293061806],
                            [2.155636272857649, 48.79696818445126],
                            [2.155923219353944, 48.797048173958764],
                            [2.15683568548617, 48.797310081377546],
                        ],
                    },
                },
                968: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.85044691504327, 2.3925671967837854],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 617.203954613,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.389378127918613,
                            48.84894397285901,
                            2.395879435185689,
                            48.85231542739917,
                        ),
                        "coordinates": [
                            [2.389378127918613, 48.85231542739917],
                            [2.390248029137287, 48.85179664166849],
                            [2.394697609558224, 48.84914275848066],
                            [2.394754190033493, 48.84911671884675],
                            [2.39481449553381, 48.84909237532181],
                            [2.394878456230547, 48.84906975632655],
                            [2.394945984550421, 48.84904889288966],
                            [2.395017006641537, 48.849029808014926],
                            [2.395091373508978, 48.84901254141384],
                            [2.39516894846473, 48.84899712926267],
                            [2.395249549875246, 48.84898360571199],
                            [2.395333536581918, 48.84897193299768],
                            [2.395420124815692, 48.84896224655187],
                            [2.3955090157795, 48.84895457813544],
                            [2.395599828918848, 48.8489489590968],
                            [2.395692276433674, 48.848945413159875],
                            [2.395785677957483, 48.84894397285901],
                            [2.395879435185689, 48.848944645063824],
                        ],
                    },
                },
                969: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.85026365048288, 2.3984917976546765],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 507.304022231,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.395879435185689,
                            48.848944645063824,
                            2.401022270517142,
                            48.851812133001964,
                        ),
                        "coordinates": [
                            [2.395879435185689, 48.848944645063824],
                            [2.395972785027435, 48.84894742771957],
                            [2.396108623862366, 48.84895651069376],
                            [2.396249603236953, 48.84897274323189],
                            [2.396394444003146, 48.848995974065936],
                            [2.396541483954046, 48.84902594567642],
                            [2.396689319864514, 48.84906239466296],
                            [2.396835258170767, 48.84910468958688],
                            [2.396976907146054, 48.84915213938802],
                            [2.397111645548113, 48.84920386569471],
                            [2.400210639463515, 48.851481643290526],
                            [2.400298358022447, 48.85154145992896],
                            [2.400400222677859, 48.85160091300319],
                            [2.400509006870693, 48.85165476442435],
                            [2.400624004583223, 48.851702665286986],
                            [2.400744469855431, 48.851744302461405],
                            [2.400869623485108, 48.8517794085204],
                            [2.400998649024019, 48.85180775452512],
                            [2.401022270517142, 48.851812133001964],
                        ],
                    },
                },
                970: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.8597273896441, 2.4385436267979848],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 623.936647262,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.435555718419773,
                            48.85796559117888,
                            2.441310941253409,
                            48.861936914133,
                        ),
                        "coordinates": [
                            [2.435555718419773, 48.85796559117888],
                            [2.436293208006602, 48.85809790016153],
                            [2.436408474699518, 48.85812197888428],
                            [2.43645950083754, 48.85813587301006],
                            [2.436527009815294, 48.85815425510357],
                            [2.436640830450366, 48.85819322529908],
                            [2.43674907028107, 48.85823859222021],
                            [2.436850905729802, 48.85829001205394],
                            [2.436945562797558, 48.858347092658015],
                            [2.437032319711757, 48.85840940076746],
                            [2.437056979234383, 48.858429265431845],
                            [2.439277805719982, 48.860267519795556],
                            [2.439996395422241, 48.86083336621238],
                            [2.440867879267842, 48.86160615622119],
                            [2.441196173290902, 48.86185123876217],
                            [2.441310941253409, 48.861936914133],
                        ],
                    },
                },
                971: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.86494064238323, 2.297590422584121],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 508.378010508,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.29416201539428,
                            48.86476684497177,
                            2.300991003495585,
                            48.865048020150624,
                        ),
                        "coordinates": [
                            [2.29416201539428, 48.8647940649002],
                            [2.294375322859606, 48.86482467841332],
                            [2.2945906925196, 48.864848181745295],
                            [2.294807579836818, 48.86486451501827],
                            [2.294948212948008, 48.86487123342555],
                            [2.299726385461115, 48.865048020150624],
                            [2.299858342883838, 48.86504268559601],
                            [2.299990767568163, 48.86503016872666],
                            [2.300121204406921, 48.86501057120011],
                            [2.300248784624887, 48.864984023745],
                            [2.300264714794099, 48.86497973885113],
                            [2.300372663370413, 48.86495070310011],
                            [2.300492011527442, 48.864910832865256],
                            [2.300553260644607, 48.86488709186755],
                            [2.30062932249381, 48.864858116847564],
                            [2.300745760051936, 48.86482087613586],
                            [2.300866619008819, 48.86479037658171],
                            [2.300991003495585, 48.86476684497177],
                        ],
                    },
                },
                972: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.865967112666716, 2.3663905671065173],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 410.578903855,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.364234945635964,
                            48.86472762072593,
                            2.368496387112846,
                            48.867111639484264,
                        ),
                        "coordinates": [
                            [2.364234945635964, 48.867111639484264],
                            [2.365368582601575, 48.866598355328186],
                            [2.367543772490261, 48.86529998297932],
                            [2.368496387112846, 48.86472762072593],
                        ],
                    },
                },
                973: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.046150180136536, 2.0981522761291633],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 446.377365123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.095195067225969,
                            49.04564873988319,
                            2.101108482966614,
                            49.04664576264113,
                        ),
                        "coordinates": [
                            [2.101108482966614, 49.04564873988319],
                            [2.099538274275683, 49.04593526764531],
                            [2.096377570034755, 49.04643086426444],
                            [2.095195067225969, 49.04664576264113],
                        ],
                    },
                },
                974: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.85313452880966, 2.4083577939971192],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 345.162819209,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.406089161868773,
                            48.85272512017011,
                            2.410626429815428,
                            48.85354391700303,
                        ),
                        "coordinates": [
                            [2.406089161868773, 48.85272512017011],
                            [2.40682113854225, 48.8528572340281],
                            [2.410626429815428, 48.85354391700303],
                        ],
                    },
                },
                975: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.82045315566213, 2.4098158841455564],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 4770.25128044,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.390345965998709,
                            48.80204938032392,
                            2.426482408484048,
                            48.83631546891676,
                        ),
                        "coordinates": [
                            [2.426482408484048, 48.80204938032392],
                            [2.426213233389943, 48.80270366871429],
                            [2.426059067224202, 48.803103518578126],
                            [2.425865562558176, 48.803662814109195],
                            [2.425636975576803, 48.80424292499913],
                            [2.425500067919798, 48.804575763236556],
                            [2.425308930865491, 48.80503813993732],
                            [2.425131451195494, 48.805526583980225],
                            [2.424802040965552, 48.80632899240994],
                            [2.424661066987416, 48.806678919456175],
                            [2.424301888093021, 48.807594657790766],
                            [2.423945340007631, 48.808306202909264],
                            [2.4238066071551, 48.808545570792425],
                            [2.423630072802756, 48.80881009275069],
                            [2.423363810386366, 48.80915291901504],
                            [2.423071675265067, 48.809494865161774],
                            [2.422746842177166, 48.80982694379628],
                            [2.422361495815938, 48.81015720195034],
                            [2.422000423766193, 48.81045160176861],
                            [2.421588397441904, 48.810760360786645],
                            [2.420092448473936, 48.81182171041226],
                            [2.419617867358986, 48.812192557978705],
                            [2.419166456889185, 48.812581372445564],
                            [2.418674308593593, 48.81304215600817],
                            [2.418183542880156, 48.813520922732344],
                            [2.417734967710867, 48.81399336146604],
                            [2.417430592583147, 48.814349552081005],
                            [2.417261333276494, 48.81455065586815],
                            [2.417069037353589, 48.814788792325686],
                            [2.416913692091962, 48.8149964479154],
                            [2.416488893695249, 48.815597648120736],
                            [2.416210377872471, 48.815994422632],
                            [2.415946794225707, 48.81636510731462],
                            [2.415627652920495, 48.81683921532513],
                            [2.415503595505816, 48.817020435180275],
                            [2.415415890548352, 48.81714513857545],
                            [2.415322964685196, 48.81727594562042],
                            [2.415219942191224, 48.81742585543538],
                            [2.415157444171279, 48.817516725902586],
                            [2.415055535950904, 48.817658881174786],
                            [2.414972657548998, 48.81777854160697],
                            [2.414770182636784, 48.818052060328704],
                            [2.414647887813147, 48.818221207331455],
                            [2.414471216694762, 48.818451542308544],
                            [2.414260533010118, 48.818704381847574],
                            [2.414051194292975, 48.81894642965178],
                            [2.413811905866178, 48.819196590093426],
                            [2.413563072631133, 48.819441360909316],
                            [2.413301987130172, 48.81968883662897],
                            [2.413047690982288, 48.81992641596042],
                            [2.412797443495975, 48.820140611055436],
                            [2.412571657662627, 48.820322415163034],
                            [2.412408434024621, 48.82045201896428],
                            [2.412256093224649, 48.82057352229208],
                            [2.412062951465379, 48.82073192221927],
                            [2.411867079403589, 48.820885827704885],
                            [2.411616784560575, 48.821075739547794],
                            [2.411408651811768, 48.82122965227109],
                            [2.411192349967435, 48.821385368109524],
                            [2.410966520478706, 48.82154558654308],
                            [2.410733875941399, 48.821703110602364],
                            [2.410510741612263, 48.8218462398296],
                            [2.41029985096752, 48.821981268089914],
                            [2.41025903292298, 48.82200737347515],
                            [2.410216854174392, 48.82203347932984],
                            [2.410004588052336, 48.82216041400117],
                            [2.409652173980301, 48.822374667383436],
                            [2.409324239749755, 48.82256642227976],
                            [2.409031663100444, 48.82272488081891],
                            [2.408762210604572, 48.82286533778582],
                            [2.408490031842356, 48.82300489746526],
                            [2.40826410815419, 48.8231102547108],
                            [2.407759182536653, 48.82334977727461],
                            [2.407214732646087, 48.823572236719585],
                            [2.406283665804337, 48.82391902962454],
                            [2.405445158717418, 48.82423788137506],
                            [2.405170194371788, 48.82434416166671],
                            [2.404959205661507, 48.82442612226807],
                            [2.404618913210112, 48.82456751146986],
                            [2.404335797561936, 48.82469177985944],
                            [2.403960143470646, 48.8248718564924],
                            [2.40354230146633, 48.825078935613554],
                            [2.403144882580885, 48.825284202222214],
                            [2.402831854855952, 48.82545254881691],
                            [2.402535171598737, 48.82562448198626],
                            [2.402282053415619, 48.82578290055115],
                            [2.402033024959504, 48.82594671096045],
                            [2.401808498266836, 48.82609971603596],
                            [2.401569009892957, 48.82626981570265],
                            [2.401195832664583, 48.82655819275876],
                            [2.400834284691245, 48.82685386050075],
                            [2.400681893009959, 48.8269735496221],
                            [2.400393433755833, 48.82719853013525],
                            [2.40008456050687, 48.827437908965805],
                            [2.399740320857572, 48.827717774478614],
                            [2.399426035559518, 48.82799222677444],
                            [2.39920974592434, 48.82821176934364],
                            [2.399007073190293, 48.82843040410095],
                            [2.398865662351821, 48.8286256237548],
                            [2.398755540165808, 48.82879025107601],
                            [2.398610096929417, 48.8290304365512],
                            [2.398516340179615, 48.82921394000908],
                            [2.398428028740589, 48.82939474207146],
                            [2.398315283707336, 48.82964390175761],
                            [2.398171359476316, 48.83001538039786],
                            [2.398050486906158, 48.83030411238482],
                            [2.397982572837722, 48.83046062305791],
                            [2.397895604868111, 48.83062973322914],
                            [2.3977882157148, 48.83080784749022],
                            [2.397679433512619, 48.83096168157907],
                            [2.39758152642139, 48.83109752451698],
                            [2.39748769902434, 48.831228868591225],
                            [2.397406686186359, 48.83132460463281],
                            [2.397206507880598, 48.83153198292341],
                            [2.397008812813349, 48.831712034404575],
                            [2.396902670816615, 48.8317993206339],
                            [2.396687665879538, 48.83197749002836],
                            [2.396521636604763, 48.832105274481506],
                            [2.396312047021417, 48.83225826123725],
                            [2.396079307259286, 48.83241755489672],
                            [2.395794823378921, 48.83259306130089],
                            [2.395480393429601, 48.832788367203605],
                            [2.395118318527763, 48.83301337211617],
                            [2.394700414833012, 48.83325908818281],
                            [2.394240295775539, 48.83351921264995],
                            [2.393707998818727, 48.833800054192515],
                            [2.393257381108426, 48.83403858692467],
                            [2.392719658517632, 48.834349102510636],
                            [2.392361129475945, 48.83457498027207],
                            [2.39205402873903, 48.83479457005944],
                            [2.391799493674758, 48.834977246579015],
                            [2.391557244840326, 48.83518599466781],
                            [2.391221095491382, 48.83548291743034],
                            [2.390852317628658, 48.835843702378234],
                            [2.390569255563208, 48.83610912347908],
                            [2.390345965998709, 48.83631546891676],
                        ],
                    },
                },
                976: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.81473854538891, 2.249093345756752],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1983.69373123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.240883069335648,
                            48.80749262578012,
                            2.258759767033708,
                            48.81967448818826,
                        ),
                        "coordinates": [
                            [2.258759767033708, 48.81967448818826],
                            [2.258506352776809, 48.81957010317677],
                            [2.257893897515079, 48.81934396260658],
                            [2.257583586959452, 48.81923043900402],
                            [2.256594130534755, 48.81887543201725],
                            [2.256519273925318, 48.818849300662436],
                            [2.256136816724805, 48.818722233052924],
                            [2.255992534474839, 48.818680763821654],
                            [2.255652246683856, 48.818583400392406],
                            [2.255077804364769, 48.81844360293296],
                            [2.254879051828954, 48.81840209336958],
                            [2.253531883174579, 48.81813072459972],
                            [2.252545718540255, 48.817927280408895],
                            [2.251944238953642, 48.81779597063782],
                            [2.25164166513815, 48.81771389460787],
                            [2.251278000468443, 48.81761226471433],
                            [2.25094671016942, 48.81750494549433],
                            [2.250626258966474, 48.817380977153945],
                            [2.25039944963085, 48.81727849423599],
                            [2.250154672734464, 48.8171498247847],
                            [2.24990630200787, 48.817016392461504],
                            [2.249621957896679, 48.8168520006654],
                            [2.249348443604211, 48.816675720510254],
                            [2.248995841976396, 48.8164018264063],
                            [2.248733210482238, 48.81618748238978],
                            [2.248481417867572, 48.81595649242603],
                            [2.248258431002338, 48.81573742008663],
                            [2.248057023649177, 48.81553977796389],
                            [2.247877238868138, 48.81533977386025],
                            [2.247744229427276, 48.815175496319114],
                            [2.247589735663198, 48.814937440920666],
                            [2.247481984705417, 48.814751767959145],
                            [2.247374270913074, 48.81454706029154],
                            [2.247301184889382, 48.81438023178854],
                            [2.246993242965602, 48.81373970536708],
                            [2.246864387481381, 48.813462627047706],
                            [2.246753355226291, 48.81324269514836],
                            [2.246622855236019, 48.812999309169584],
                            [2.246326852250612, 48.81254224249612],
                            [2.246155698888792, 48.81231728722722],
                            [2.246018485062752, 48.81214811409195],
                            [2.245851335133564, 48.811969024947025],
                            [2.245688227582815, 48.81181332020108],
                            [2.245525125996986, 48.811654917048436],
                            [2.245232835999329, 48.81140918049756],
                            [2.245016712422211, 48.811242804130856],
                            [2.244708005097074, 48.81100858003137],
                            [2.244063511801291, 48.81052964281425],
                            [2.243227257418416, 48.80994083343499],
                            [2.242926769142224, 48.80972206221579],
                            [2.24267117380369, 48.80952401075466],
                            [2.242418308941523, 48.80932326341211],
                            [2.242198158636191, 48.80910365737626],
                            [2.241866636933593, 48.80874277190482],
                            [2.24170636582845, 48.8085394027854],
                            [2.241470040372006, 48.80823884723812],
                            [2.241178040929646, 48.80786270460133],
                            [2.240883069335648, 48.80749262578012],
                        ],
                    },
                },
                977: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.527211362206735, 2.2723040121192186],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 3105.06240268,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.254739702427517,
                            48.52040359106998,
                            2.290082513840396,
                            48.532890103244725,
                        ),
                        "coordinates": [
                            [2.290082513840396, 48.532890103244725],
                            [2.289734209201174, 48.53253649789415],
                            [2.289289225210587, 48.53209828136959],
                            [2.288938355857433, 48.531775772723115],
                            [2.288553233244141, 48.531451353204254],
                            [2.288148109787515, 48.53114588601439],
                            [2.287722985367884, 48.53086316280305],
                            [2.287369179467573, 48.53064114993548],
                            [2.286847002103546, 48.53034890042888],
                            [2.286370458634132, 48.53010786720578],
                            [2.285851089074588, 48.529874397727575],
                            [2.285343113467049, 48.52966747794502],
                            [2.284686717225082, 48.52943204412497],
                            [2.284138752105517, 48.5292535453459],
                            [2.283576495678448, 48.529095894444595],
                            [2.28301137245379, 48.52895340983816],
                            [2.282403419485687, 48.52881848697852],
                            [2.281815426567638, 48.52870822108015],
                            [2.281230268100794, 48.52861881241655],
                            [2.280568024784544, 48.52853505081832],
                            [2.279922878390861, 48.52847973934412],
                            [2.279246314363187, 48.528437680333774],
                            [2.27864394885956, 48.52842220226254],
                            [2.278027290449138, 48.52842188360666],
                            [2.277410618847667, 48.528432939927164],
                            [2.2765683769011, 48.52847231666823],
                            [2.275714707034037, 48.52851547264879],
                            [2.274858185217396, 48.52855672492686],
                            [2.274127312692539, 48.52856959727176],
                            [2.273513507684554, 48.528569255542905],
                            [2.272908294357497, 48.528548058069724],
                            [2.272325935166354, 48.528515492300926],
                            [2.27172933809518, 48.528456367237986],
                            [2.271132762818213, 48.52838017460659],
                            [2.270530500533806, 48.528288803635384],
                            [2.269956816596601, 48.528178485687526],
                            [2.269257576908441, 48.52802447552144],
                            [2.268575499776866, 48.527849613071275],
                            [2.267890604016973, 48.527651989839704],
                            [2.267245695746463, 48.527444905885865],
                            [2.266615089583204, 48.52722076181568],
                            [2.265981664349252, 48.526975752926795],
                            [2.265362551577256, 48.52670799508884],
                            [2.264766303036454, 48.526426975629136],
                            [2.264198633211657, 48.526128903303935],
                            [2.263642412954147, 48.52581566684544],
                            [2.263100501568763, 48.525481577883305],
                            [2.262561462899985, 48.52514179969478],
                            [2.261962566743837, 48.52474509311154],
                            [2.261395085444001, 48.52434650672226],
                            [2.261135580428958, 48.52416808749404],
                            [2.260773422943895, 48.52391564601215],
                            [2.259008330803085, 48.52267430971919],
                            [2.25840378914813, 48.522273786699685],
                            [2.2578676525067, 48.52194536711778],
                            [2.257305829094408, 48.52161882122433],
                            [2.25674968038453, 48.521318824222746],
                            [2.256467314338979, 48.521176406814156],
                            [2.256159265451747, 48.52103017824302],
                            [2.255631585081808, 48.52078518738958],
                            [2.254912773973982, 48.520471791151905],
                            [2.254739702427517, 48.52040359106998],
                        ],
                    },
                },
                978: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.50413554434974, 2.2048746491477043],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2766.7826763,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.194581700525426,
                            48.493644578496685,
                            2.21551781194949,
                            48.51424587530033,
                        ),
                        "coordinates": [
                            [2.21551781194949, 48.51424587530033],
                            [2.215405360368091, 48.51418258017618],
                            [2.214952259290799, 48.51389576226815],
                            [2.214561919548776, 48.51362228407414],
                            [2.214259948866942, 48.51339441062135],
                            [2.214017843237929, 48.51319504292397],
                            [2.213704581941054, 48.51291785309105],
                            [2.213428365211385, 48.5126653540132],
                            [2.212969969294566, 48.51222113463921],
                            [2.212491690469514, 48.51174276030041],
                            [2.211612000768824, 48.51087142028032],
                            [2.21108818153573, 48.51035506461171],
                            [2.210589994278624, 48.50986338703759],
                            [2.210254086764688, 48.5095292745408],
                            [2.209451332880974, 48.508733853717196],
                            [2.208279122134472, 48.507575259535955],
                            [2.20771212182366, 48.50701029465384],
                            [2.206917401264375, 48.50622965585639],
                            [2.206209283194002, 48.50551434077401],
                            [2.205546822287511, 48.504806660927215],
                            [2.205114253066435, 48.50436168153248],
                            [2.20416481223477, 48.503420042730916],
                            [2.203285973187758, 48.502552811701314],
                            [2.201560261566552, 48.50084870653122],
                            [2.201202854912382, 48.50049027095643],
                            [2.200503979430126, 48.4997931362266],
                            [2.199866557526376, 48.499167368842635],
                            [2.199488677185091, 48.49879221645242],
                            [2.199001520042713, 48.498315291153915],
                            [2.197373989353448, 48.49670225997784],
                            [2.196900534836992, 48.496237478178465],
                            [2.19630193559668, 48.49563601088248],
                            [2.195871836275718, 48.49518189782661],
                            [2.195516882203582, 48.4947915907083],
                            [2.195239327950306, 48.49447419373923],
                            [2.195057378088698, 48.494247935289636],
                            [2.194770816851011, 48.493889567467946],
                            [2.194581700525426, 48.493644578496685],
                        ],
                    },
                },
                979: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.73237049011738, 2.2681937050096677],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 959.30532643,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263073689251946,
                            48.72964839824706,
                            2.273483464396533,
                            48.734716586800225,
                        ),
                        "coordinates": [
                            [2.263073689251946, 48.72964839824706],
                            [2.263780803303505, 48.72997807971013],
                            [2.264330728328628, 48.7302282616453],
                            [2.264772813360702, 48.73044030344223],
                            [2.265275667283824, 48.7307172430537],
                            [2.265669558141648, 48.73094770426779],
                            [2.266063437781901, 48.731189854315865],
                            [2.266580415573251, 48.731526409288755],
                            [2.267092883857536, 48.731887427348006],
                            [2.267477224061654, 48.732155645835896],
                            [2.267713658471377, 48.732321335835614],
                            [2.267997593410009, 48.73252095186934],
                            [2.268239123627565, 48.732691174691105],
                            [2.268379013233885, 48.73278748174654],
                            [2.268584124577665, 48.7329072081117],
                            [2.268806902787484, 48.73303234103279],
                            [2.269002533673032, 48.73312688132901],
                            [2.269255248686636, 48.73323224674788],
                            [2.269491673615637, 48.73332051578235],
                            [2.269758006001752, 48.73340970126169],
                            [2.270145698147873, 48.73352865461254],
                            [2.270574346671643, 48.73365300545505],
                            [2.271186213048966, 48.73385117840906],
                            [2.271496334618988, 48.73398599406839],
                            [2.271683497278407, 48.73406639087547],
                            [2.271932139426364, 48.73417444558605],
                            [2.272145466301575, 48.734260898063596],
                            [2.272372394705531, 48.73434106221353],
                            [2.272748801728018, 48.73447346776019],
                            [2.273085810156915, 48.73458516686029],
                            [2.273483464396533, 48.734716586800225],
                        ],
                    },
                },
                980: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.846738030783534, 2.2752340385841583],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 402.711193437,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272763753316159,
                            48.84610560601282,
                            2.27771230631379,
                            48.84731369503087,
                        ),
                        "coordinates": [
                            [2.27771230631379, 48.84612369457793],
                            [2.277370572480526, 48.84610716729264],
                            [2.277332442617506, 48.84610567066436],
                            [2.277207702159871, 48.84610560601282],
                            [2.277083454820363, 48.84611292081969],
                            [2.27696070293469, 48.84612755549067],
                            [2.276840429139118, 48.84614939725365],
                            [2.276723608860166, 48.84617826404533],
                            [2.27661117731551, 48.84621392589619],
                            [2.276538193972036, 48.846241708511215],
                            [2.274168275622015, 48.84720817986025],
                            [2.274075420357931, 48.84724200645907],
                            [2.27397485936548, 48.84727042060346],
                            [2.273870459713758, 48.84729197618008],
                            [2.273763288801233, 48.84730645121942],
                            [2.273654451193809, 48.84731369503087],
                            [2.273545061283794, 48.84731363433284],
                            [2.273436241974509, 48.84730626964733],
                            [2.27332910831503, 48.847291676100035],
                            [2.273224763384682, 48.847270005193835],
                            [2.273145672180319, 48.8472482286076],
                            [2.272763753316159, 48.847131008196236],
                        ],
                    },
                },
                981: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.60289558454278, 2.300017632252716],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 906.589358564,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.297950577822679,
                            48.599059348508746,
                            2.302059691582639,
                            48.60674494894811,
                        ),
                        "coordinates": [
                            [2.302059691582639, 48.60674494894811],
                            [2.301456351484172, 48.60564591805656],
                            [2.301071583273852, 48.60487918759537],
                            [2.30073749090788, 48.604218587925644],
                            [2.300483377229273, 48.60372737741824],
                            [2.300194995583214, 48.60318495650788],
                            [2.299895189861859, 48.60263494538337],
                            [2.299609673323274, 48.602102005344875],
                            [2.299064336053399, 48.60110818765012],
                            [2.298593267081924, 48.6002281678049],
                            [2.298396264401124, 48.5998810876414],
                            [2.297950577822679, 48.599059348508746],
                        ],
                    },
                },
                982: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.87763949959616, 2.227261031922183],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1598.29199204,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.22102955043113,
                            48.87171419115656,
                            2.233691920150409,
                            48.883383813825255,
                        ),
                        "coordinates": [
                            [2.233691920150409, 48.883383813825255],
                            [2.233544230011552, 48.88322927169216],
                            [2.233341487922252, 48.883024053267555],
                            [2.233327878865389, 48.883011450880275],
                            [2.23329385487512, 48.88297994579525],
                            [2.233246223285348, 48.882935837411715],
                            [2.23275087133963, 48.882468662807234],
                            [2.231785919561585, 48.88162066227985],
                            [2.231768226200799, 48.88160535794083],
                            [2.231728756813296, 48.88157114906521],
                            [2.230456228372583, 48.88047285470365],
                            [2.230156866054467, 48.88019200108927],
                            [2.230091538082921, 48.880137084301346],
                            [2.229703643264529, 48.87981478033202],
                            [2.22873337339959, 48.87895235935132],
                            [2.227892372300882, 48.87822134763179],
                            [2.227869239054145, 48.87820064296801],
                            [2.227843383693998, 48.87817813643822],
                            [2.227739960062819, 48.87808900869021],
                            [2.227070441831837, 48.87750923356406],
                            [2.226885384622743, 48.87734448781184],
                            [2.226109802963735, 48.87664769922691],
                            [2.226085312598864, 48.87662519300606],
                            [2.225992791750209, 48.87654057145214],
                            [2.224139563150962, 48.87491736246457],
                            [2.224022550133282, 48.874814730179814],
                            [2.222731324025215, 48.87369654585657],
                            [2.222588500316376, 48.873556115585714],
                            [2.222018574399512, 48.87299709322498],
                            [2.221667761780453, 48.87260375663998],
                            [2.221386396977642, 48.87224645977171],
                            [2.221247785944357, 48.872056571819854],
                            [2.221159476252741, 48.87192698607902],
                            [2.221126874185613, 48.87187749303678],
                            [2.22102955043113, 48.87171419115656],
                        ],
                    },
                },
                983: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.02530767207706, 2.1407440104440876],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2590.05747503,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.128263873923673,
                            49.01913673984224,
                            2.154663485640923,
                            49.033987636271455,
                        ),
                        "coordinates": [
                            [2.154663485640923, 49.01913673984224],
                            [2.153012708040501, 49.01958148730108],
                            [2.1525802036884, 49.01969859749183],
                            [2.15187945004989, 49.01988361913078],
                            [2.150826891488006, 49.020175078735726],
                            [2.149978124031571, 49.020447077518284],
                            [2.149305915162764, 49.020671697973114],
                            [2.148826714662678, 49.02083817803502],
                            [2.148341998062405, 49.021016337694384],
                            [2.147705252554311, 49.02125989135247],
                            [2.147065696758275, 49.02152142255902],
                            [2.146498651858204, 49.021770480878665],
                            [2.14594799358884, 49.022024060222314],
                            [2.145346607428395, 49.02231082549486],
                            [2.144350588173181, 49.02280825434546],
                            [2.144093057933043, 49.02292652594874],
                            [2.143931358634076, 49.0230152822196],
                            [2.143650524185861, 49.02314790214863],
                            [2.143031225952273, 49.02346250313366],
                            [2.142701050689537, 49.023622914676324],
                            [2.142370881211854, 49.02378152687329],
                            [2.140962391049982, 49.0244841602294],
                            [2.139784055706185, 49.0250711659449],
                            [2.139636077743041, 49.02514465214651],
                            [2.139127744838577, 49.025396473601596],
                            [2.13819053882378, 49.02585977871451],
                            [2.137680805934782, 49.02611608728359],
                            [2.137340936435868, 49.026298048944646],
                            [2.137228556776113, 49.026359004402956],
                            [2.137055835991663, 49.026462120063606],
                            [2.136598001860149, 49.02673200308702],
                            [2.136292293463326, 49.02691851828956],
                            [2.135953572336817, 49.02715173687216],
                            [2.135933000988131, 49.02716608896057],
                            [2.13552704267224, 49.02745494442121],
                            [2.1353610539308, 49.02758234935377],
                            [2.13530891614649, 49.02762452376745],
                            [2.135145673271377, 49.027749236079515],
                            [2.134734036963733, 49.02808663965612],
                            [2.134330518977245, 49.02844383931215],
                            [2.133111242287299, 49.029505863609465],
                            [2.132522779267561, 49.03005920334172],
                            [2.131989640429896, 49.030574865619776],
                            [2.13162187645773, 49.03091147979036],
                            [2.131232357216787, 49.03125697622124],
                            [2.130733854692106, 49.03170399224864],
                            [2.13009097662359, 49.03227744575314],
                            [2.129407148815588, 49.03290435640467],
                            [2.129093756160098, 49.03321072338393],
                            [2.128263873923673, 49.033987636271455],
                        ],
                    },
                },
                984: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.84268278583512, 2.2142923298018635],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 879.10906998,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.209938360929272,
                            48.840517349814164,
                            2.217621080890435,
                            48.84610294864101,
                        ),
                        "coordinates": [
                            [2.217621080890435, 48.84610294864101],
                            [2.217443706978748, 48.845636937325274],
                            [2.217423398941245, 48.84558295986443],
                            [2.217397645592972, 48.84552717770745],
                            [2.217312265517721, 48.845336441099015],
                            [2.217190197201333, 48.8451042999668],
                            [2.217167121783925, 48.845068304405196],
                            [2.216990738966391, 48.84475966741812],
                            [2.216874011227362, 48.84457429409696],
                            [2.21660921328541, 48.84420711014718],
                            [2.21659292824429, 48.84418011488495],
                            [2.216575272870219, 48.84415671534174],
                            [2.216352616663704, 48.84383004288921],
                            [2.216174630285588, 48.84362481930477],
                            [2.215953051889635, 48.84341775109632],
                            [2.215920424297969, 48.843388040419285],
                            [2.215852453308995, 48.8433259183952],
                            [2.215765438986725, 48.84325028697513],
                            [2.215304436685793, 48.8428936831713],
                            [2.215195643880415, 48.84281083394447],
                            [2.21517932328762, 48.84279912581654],
                            [2.21476992311889, 48.842515416406734],
                            [2.2145223451432, 48.84235867732259],
                            [2.214315572488567, 48.842229858850146],
                            [2.214042094223859, 48.84207938634378],
                            [2.213608080542133, 48.84183701275158],
                            [2.213274713370565, 48.84166578998299],
                            [2.212931767902024, 48.8415116417676],
                            [2.212515301473346, 48.841339426628714],
                            [2.211964048644623, 48.841131092604876],
                            [2.211448117694085, 48.84096505994188],
                            [2.210910388399633, 48.840799900212666],
                            [2.210369963359886, 48.84062484324707],
                            [2.209938360929272, 48.840517349814164],
                        ],
                    },
                },
                985: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.957827373577715, 2.1115305062336804],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2796.71191986,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.093521901580612,
                            48.95540224453111,
                            2.129364252725261,
                            48.95942081579221,
                        ),
                        "coordinates": [
                            [2.093521901580612, 48.95540224453111],
                            [2.095275119180811, 48.955654064388554],
                            [2.096018815220241, 48.95577460055809],
                            [2.096618009515849, 48.95589244985157],
                            [2.097199058945369, 48.956026914310016],
                            [2.097718688332133, 48.95616124466473],
                            [2.098281520495417, 48.95632897650449],
                            [2.098880347475981, 48.956525331014426],
                            [2.099544077984347, 48.956750368259605],
                            [2.100608189393563, 48.95711899271907],
                            [2.101315248701186, 48.95735362746025],
                            [2.101924995466158, 48.95753809210881],
                            [2.102520396662549, 48.9577011077294],
                            [2.103123116157908, 48.957845103723315],
                            [2.10378009657946, 48.95797730778482],
                            [2.105895487496369, 48.958393226526475],
                            [2.106750946297849, 48.95858172935578],
                            [2.107656871894758, 48.9587976901254],
                            [2.10843651616127, 48.95897532140973],
                            [2.109136849052834, 48.959114719293304],
                            [2.109956464466103, 48.959244833795324],
                            [2.110639000414662, 48.959327083613374],
                            [2.111484219680787, 48.95939061488035],
                            [2.112322369032908, 48.95942081579221],
                            [2.113048645423283, 48.95941985921476],
                            [2.113803934326044, 48.95939516179983],
                            [2.114483473045252, 48.959341760471695],
                            [2.115260661327089, 48.95926713041187],
                            [2.1162728894209, 48.959152498848795],
                            [2.117111658406051, 48.95904228229965],
                            [2.118178295502507, 48.95887777293547],
                            [2.11932823883308, 48.95866582398323],
                            [2.120514540667297, 48.958412715591315],
                            [2.121747998698349, 48.95815101361782],
                            [2.124008480816989, 48.95763495050819],
                            [2.124915992428352, 48.957424777452],
                            [2.12539347128279, 48.957297175832075],
                            [2.126178595154797, 48.95704403509915],
                            [2.126703321605904, 48.95684989304958],
                            [2.127304104646893, 48.956610682942866],
                            [2.127894166345738, 48.95634289591625],
                            [2.128563966706861, 48.95601338786181],
                            [2.129364252725261, 48.95558180229322],
                        ],
                    },
                },
                986: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.85264108758529, 2.2829290553326875],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 582.139134328,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.279487064962566,
                            48.852244619597045,
                            2.286419448213008,
                            48.85364805716894,
                        ),
                        "coordinates": [
                            [2.286419448213008, 48.853033488503854],
                            [2.285796621620032, 48.85262928085654],
                            [2.285660399489906, 48.8525635499946],
                            [2.285500376202803, 48.852504946380414],
                            [2.285281959050423, 48.85243061288087],
                            [2.285041902970752, 48.85236197933479],
                            [2.284873202528443, 48.852326212657104],
                            [2.284741336067407, 48.85230072888726],
                            [2.284632337864564, 48.85228359286626],
                            [2.284490636321752, 48.85226464323339],
                            [2.284361189858992, 48.85225469199297],
                            [2.284237188834877, 48.85224923941597],
                            [2.284100922211517, 48.85224647795981],
                            [2.283971466867833, 48.852244619597045],
                            [2.283798400945888, 48.85224633853385],
                            [2.283682569325693, 48.85224808330548],
                            [2.283532665373111, 48.85225430781955],
                            [2.283404566687152, 48.85225874440302],
                            [2.283246481129349, 48.85226946223325],
                            [2.283099292086696, 48.85228468079375],
                            [2.282931660327877, 48.85230258716652],
                            [2.282803538454569, 48.85232770648341],
                            [2.282656332186916, 48.85235821174271],
                            [2.282408255470531, 48.8524165470169],
                            [2.281871197902879, 48.85255208105997],
                            [2.281443182768892, 48.85266248469554],
                            [2.281334132773428, 48.85269210855454],
                            [2.281201901818647, 48.85273341066626],
                            [2.281042405338812, 48.85278638979378],
                            [2.280938792056676, 48.85282770617837],
                            [2.28078393915913, 48.85289463857518],
                            [2.280634746387634, 48.852967843667884],
                            [2.280525531876965, 48.85302400864467],
                            [2.280430213651343, 48.853076555320634],
                            [2.280212025595497, 48.85320954006952],
                            [2.279957019483357, 48.85336318961356],
                            [2.279487064962566, 48.85364805716894],
                        ],
                    },
                },
                987: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.93290374538443, 2.5152949374750166],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 2970.57753651,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.495513142584314,
                            48.93186318839768,
                            2.534714974742524,
                            48.93628018565177,
                        ),
                        "coordinates": [
                            [2.495513142584314, 48.93219600596196],
                            [2.496840135010492, 48.93222232191138],
                            [2.497785955199344, 48.932229620949464],
                            [2.498829914690119, 48.932223834707656],
                            [2.504747939281772, 48.932200278608676],
                            [2.505691099886219, 48.93220436669105],
                            [2.507153726961957, 48.93224052521622],
                            [2.508038741924935, 48.9322501569209],
                            [2.508894596512746, 48.93223792259556],
                            [2.509646496422219, 48.932201203928194],
                            [2.510485530429816, 48.93213149761696],
                            [2.511224846103302, 48.932061939035634],
                            [2.511930979106314, 48.93200884859771],
                            [2.51262472371931, 48.93197767383939],
                            [2.515844297567993, 48.93186318839768],
                            [2.516895498306539, 48.93187248982931],
                            [2.517668438667157, 48.931912334059334],
                            [2.518603555712695, 48.931990239213626],
                            [2.519301866079423, 48.93207125218204],
                            [2.519975337870622, 48.9321769384203],
                            [2.520661328123656, 48.93229628685087],
                            [2.521289201626911, 48.93242941260758],
                            [2.521946257786894, 48.93258712612503],
                            [2.522724024590236, 48.93280212396912],
                            [2.525327835753683, 48.933553406834356],
                            [2.528796948978665, 48.93455776646745],
                            [2.53207915600295, 48.93553045504139],
                            [2.532896322318356, 48.93577175173164],
                            [2.533630327330832, 48.93598701443105],
                            [2.534107583631052, 48.93611943664953],
                            [2.534714974742524, 48.93628018565177],
                        ],
                    },
                },
                988: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.8816800661722, 2.2912170288033753],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1300.40567099,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.284431219916768,
                            48.87790843816007,
                            2.29803330457685,
                            48.8854042809258,
                        ),
                        "coordinates": [
                            [2.284431219916768, 48.87790843816007],
                            [2.284637913298522, 48.87806762103028],
                            [2.28512705878747, 48.87837359725023],
                            [2.288183582753859, 48.880032301006736],
                            [2.28927924077639, 48.880625383994165],
                            [2.289461851970203, 48.88072527907499],
                            [2.28985569655129, 48.88093856992243],
                            [2.290573895455465, 48.88132554987828],
                            [2.291211696658164, 48.88167022841889],
                            [2.291861773542192, 48.88202120301819],
                            [2.293625319392737, 48.88299489788621],
                            [2.295172239169192, 48.88383539405694],
                            [2.296742382001151, 48.884687567547985],
                            [2.297362300724286, 48.885028422180405],
                            [2.297937730828242, 48.885352544004384],
                            [2.29803330457685, 48.8854042809258],
                        ],
                    },
                },
                989: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.92688448806625, 2.310889021082025],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1405.03200914,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307943234074898,
                            48.92087280435657,
                            2.313835382457718,
                            48.93289616644866,
                        ),
                        "coordinates": [
                            [2.313835382457718, 48.92087280435657],
                            [2.312920716694121, 48.922753897165464],
                            [2.312118859006341, 48.92438591480862],
                            [2.311338806360375, 48.92597656560873],
                            [2.31055733947707, 48.92756631083003],
                            [2.310135172037232, 48.928405238887535],
                            [2.30957499500258, 48.92951751200181],
                            [2.309211532629846, 48.93027012032423],
                            [2.308884935299763, 48.930976872436],
                            [2.308710017569288, 48.931354525770544],
                            [2.308588406511641, 48.93159640155675],
                            [2.307943234074898, 48.93289616644866],
                        ],
                    },
                },
                990: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.93321924525004, 2.5215044099627923],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2052.71609895,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.508038741924935,
                            48.93186318839768,
                            2.534714974742524,
                            48.93628018565177,
                        ),
                        "coordinates": [
                            [2.508038741924935, 48.9322501569209],
                            [2.508894596512746, 48.93223792259556],
                            [2.509646496422219, 48.932201203928194],
                            [2.510485530429816, 48.93213149761696],
                            [2.511224846103302, 48.932061939035634],
                            [2.511930979106314, 48.93200884859771],
                            [2.51262472371931, 48.93197767383939],
                            [2.515844297567993, 48.93186318839768],
                            [2.516895498306539, 48.93187248982931],
                            [2.517668438667157, 48.931912334059334],
                            [2.518603555712695, 48.931990239213626],
                            [2.519301866079423, 48.93207125218204],
                            [2.519975337870622, 48.9321769384203],
                            [2.520661328123656, 48.93229628685087],
                            [2.521289201626911, 48.93242941260758],
                            [2.521946257786894, 48.93258712612503],
                            [2.522724024590236, 48.93280212396912],
                            [2.525327835753683, 48.933553406834356],
                            [2.528796948978665, 48.93455776646745],
                            [2.53207915600295, 48.93553045504139],
                            [2.532896322318356, 48.93577175173164],
                            [2.533630327330832, 48.93598701443105],
                            [2.534107583631052, 48.93611943664953],
                            [2.534714974742524, 48.93628018565177],
                        ],
                    },
                },
                991: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.927531565634325, 2.4060922439431613],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 2973.3485505,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.386388291064694,
                            48.92435387966092,
                            2.425791425559954,
                            48.93073957031752,
                        ),
                        "coordinates": [
                            [2.386388291064694, 48.92435387966092],
                            [2.389018133977532, 48.92478587365258],
                            [2.392434522542798, 48.92533388242894],
                            [2.395446508129437, 48.92582965320484],
                            [2.397133090234305, 48.92609525835423],
                            [2.398863006496915, 48.9263512970188],
                            [2.401131064422231, 48.92668553071205],
                            [2.402452937452991, 48.926901301573565],
                            [2.404948641933777, 48.927313850034764],
                            [2.410962349463101, 48.92831419740778],
                            [2.413640642494941, 48.92875601693751],
                            [2.417329632422147, 48.929355067842664],
                            [2.420180742751204, 48.929829553573626],
                            [2.421591578284466, 48.93005923482367],
                            [2.423738953800848, 48.93040693302665],
                            [2.425791425559954, 48.93073957031752],
                        ],
                    },
                },
                992: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.16581109158064, 2.7524007084203292],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4368.74848605,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.736249842909681,
                            48.14721803991587,
                            2.762728388543796,
                            48.18093685577102,
                        ),
                        "coordinates": [
                            [2.736249842909681, 48.18093685577102],
                            [2.736549476318923, 48.18074156354518],
                            [2.737184907658812, 48.18033466094019],
                            [2.737564817925184, 48.18009052225245],
                            [2.737934040262179, 48.179855412464484],
                            [2.738348669391475, 48.17958237349362],
                            [2.738715224459543, 48.1793508671196],
                            [2.739085765253007, 48.17911395063355],
                            [2.739860297542952, 48.17862111092302],
                            [2.740340483600252, 48.17831006265926],
                            [2.740696270966813, 48.178079488185745],
                            [2.741148327892601, 48.17778292468837],
                            [2.741543075275918, 48.177515242949276],
                            [2.741937080331481, 48.17722437640993],
                            [2.742108148299678, 48.17709697262238],
                            [2.742343318962928, 48.1769162831369],
                            [2.742555748444884, 48.17675006292257],
                            [2.742778839023255, 48.1765721140085],
                            [2.743017864959095, 48.17636982886234],
                            [2.743147415617269, 48.17626325373302],
                            [2.743413108179515, 48.17603389465804],
                            [2.743741432880336, 48.175735968528194],
                            [2.743924219372154, 48.175562659260436],
                            [2.744138978551282, 48.17535326456177],
                            [2.744337748549166, 48.175161912937234],
                            [2.744783230334725, 48.17472328188314],
                            [2.745068210567798, 48.174428627913635],
                            [2.745404707126345, 48.17410506716919],
                            [2.746175600703086, 48.17334692910488],
                            [2.74635038361684, 48.173183536155776],
                            [2.746771822619082, 48.17276836382672],
                            [2.747051887525487, 48.172492185338214],
                            [2.747277249817869, 48.17226746004631],
                            [2.747873519063828, 48.17166572052666],
                            [2.748262724878751, 48.17128911615547],
                            [2.748680033001713, 48.17086585999694],
                            [2.749292144586664, 48.170264744006666],
                            [2.750148198133348, 48.169414546045594],
                            [2.750561532457673, 48.16900208832466],
                            [2.750802853436614, 48.16876021207523],
                            [2.751574891897511, 48.16799753694753],
                            [2.752525569974998, 48.16705795017672],
                            [2.753457483174225, 48.166129216405636],
                            [2.753872176193039, 48.16571632529828],
                            [2.754301397293108, 48.16529072235943],
                            [2.754738191952682, 48.16485733296897],
                            [2.755226622004906, 48.16437368883336],
                            [2.755591993337679, 48.164022537051395],
                            [2.756041243172716, 48.16357575470574],
                            [2.756381171676828, 48.16323728465241],
                            [2.756687779829053, 48.16293310714495],
                            [2.757327697976592, 48.16230486718554],
                            [2.757718261976247, 48.16191584809277],
                            [2.758102159232569, 48.16153404580232],
                            [2.758673807989749, 48.16094292141336],
                            [2.758865527767544, 48.16072549295695],
                            [2.759049317625836, 48.16052427892667],
                            [2.759278311143215, 48.160264447119665],
                            [2.759460535377595, 48.160037162301286],
                            [2.759661301331632, 48.1597774350064],
                            [2.759911278362852, 48.159456376686386],
                            [2.760425226906565, 48.158721585298615],
                            [2.760667937297798, 48.15833670857637],
                            [2.761102467291841, 48.157589624838245],
                            [2.761468552850808, 48.15685538615972],
                            [2.761699206228547, 48.15631768541728],
                            [2.761942534355285, 48.155690015610475],
                            [2.762165350258637, 48.15502105850282],
                            [2.76237514006443, 48.15424244621479],
                            [2.762522272923913, 48.153524318345454],
                            [2.762629026878261, 48.15279914858905],
                            [2.762650715441822, 48.15250322542895],
                            [2.762683479658239, 48.152086765908216],
                            [2.762703038162292, 48.15137991050965],
                            [2.762713339856609, 48.150531912831596],
                            [2.762723172162356, 48.1496281667607],
                            [2.762718245215227, 48.14872717452237],
                            [2.762723164930163, 48.147878298862885],
                            [2.762726197584857, 48.14744216918701],
                            [2.762728388543796, 48.14721803991587],
                        ],
                    },
                },
                993: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.90211574537828, 1.8653499616634424],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 2116.78611661,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.857227537127738,
                            48.893238595694605,
                            1.871738475714576,
                            48.90930537596191,
                        ),
                        "coordinates": [
                            [1.871738475714576, 48.893238595694605],
                            [1.871582764656284, 48.89355451252227],
                            [1.871531452566473, 48.89364513283113],
                            [1.871482943936253, 48.89372766980096],
                            [1.871346981453043, 48.89397352157298],
                            [1.871198768426265, 48.89421662607558],
                            [1.870985533794781, 48.89455748812633],
                            [1.870874731954356, 48.89473779385778],
                            [1.870657232165005, 48.895096623301164],
                            [1.870341807396979, 48.89557106134978],
                            [1.869844655939476, 48.89636940069622],
                            [1.868415110236178, 48.89869811179744],
                            [1.867753085932334, 48.89976015798868],
                            [1.867672718056363, 48.89989292341102],
                            [1.867235009858375, 48.90059886898659],
                            [1.86633874776849, 48.902047539353646],
                            [1.86575853402498, 48.902960629130874],
                            [1.865249796899448, 48.90367077059337],
                            [1.865173970170793, 48.90375499095625],
                            [1.865033313318742, 48.903914484420405],
                            [1.864851390144611, 48.90410977925254],
                            [1.864577294637015, 48.904386527911484],
                            [1.864166099684214, 48.904734652491186],
                            [1.863804546229426, 48.905026326013854],
                            [1.862979914862162, 48.905668601551],
                            [1.862412455513467, 48.90609251148615],
                            [1.861216833956546, 48.90686542982669],
                            [1.859416378378991, 48.90796764844396],
                            [1.859261366847702, 48.90805603040124],
                            [1.858042787614553, 48.90879464677143],
                            [1.857227537127738, 48.90930537596191],
                        ],
                    },
                },
                994: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.842896759259546, 2.598026194495337],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2665.58690024,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.580085911974356,
                            48.84204971875604,
                            2.615952488508274,
                            48.843491647846726,
                        ),
                        "coordinates": [
                            [2.615952488508274, 48.843491647846726],
                            [2.615837074738989, 48.84348845065291],
                            [2.615395552537972, 48.84347424157585],
                            [2.614279555796584, 48.84345088011513],
                            [2.613318889205941, 48.843428930435216],
                            [2.611991664493459, 48.843397064697804],
                            [2.610894704039925, 48.84336642982896],
                            [2.610225522018801, 48.843328465685325],
                            [2.609801587438874, 48.843290811416864],
                            [2.609085837719131, 48.843207988061415],
                            [2.608736780447435, 48.84315935895579],
                            [2.608191289903595, 48.84306713212622],
                            [2.605244055036712, 48.84252014044103],
                            [2.604650811756844, 48.84241272074888],
                            [2.604076679236485, 48.84231154793238],
                            [2.603638954345024, 48.84224062862992],
                            [2.603186307551998, 48.84218143423094],
                            [2.602380689279563, 48.84210327461122],
                            [2.602072662164879, 48.84208150882863],
                            [2.601505766560001, 48.84205854386109],
                            [2.601045217035628, 48.84204971875604],
                            [2.600474363211513, 48.84205103867478],
                            [2.599768744462803, 48.8420742483809],
                            [2.599451391733889, 48.842092065253084],
                            [2.598628855273778, 48.842163198473536],
                            [2.598114163480345, 48.84222193071582],
                            [2.597762875581323, 48.842264101157426],
                            [2.595151401101436, 48.84258838380809],
                            [2.59390282685696, 48.84274138151668],
                            [2.592880257503511, 48.84286418281807],
                            [2.590783395256782, 48.84312246269351],
                            [2.590236007927198, 48.843185728494525],
                            [2.589802973508141, 48.843230753137846],
                            [2.58902669989288, 48.84329631941892],
                            [2.588293928127195, 48.84334289954104],
                            [2.587845364275664, 48.84336518580333],
                            [2.587202319276384, 48.84337801737851],
                            [2.586461164637751, 48.8433796396237],
                            [2.586028548097905, 48.843372971259335],
                            [2.585605862316524, 48.8433595771598],
                            [2.585153437653214, 48.843342576398385],
                            [2.584575573397319, 48.84330696085468],
                            [2.583329748210856, 48.84319994377182],
                            [2.581629932237573, 48.84303273547159],
                            [2.580085911974356, 48.8428848408236],
                        ],
                    },
                },
                995: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.55099986160079, 2.609233018540175],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 3724.30098091,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.594551816007613,
                            48.538775256627815,
                            2.625522155066302,
                            48.564949495670916,
                        ),
                        "coordinates": [
                            [2.625522155066302, 48.538775256627815],
                            [2.624776075314098, 48.53927050573528],
                            [2.623773668056681, 48.539923214706796],
                            [2.621886582463923, 48.54122651069726],
                            [2.620600906228615, 48.5420903309967],
                            [2.62016785267195, 48.542383674367116],
                            [2.619575609748064, 48.54278622409057],
                            [2.619358423228824, 48.54293694225777],
                            [2.618162728204673, 48.54373677681227],
                            [2.615466359895904, 48.54551006899454],
                            [2.612957391262936, 48.547184692917895],
                            [2.612344481644246, 48.54764836369889],
                            [2.611726401402525, 48.54815159979666],
                            [2.610171376480844, 48.549506804871186],
                            [2.608755488832815, 48.55076172354525],
                            [2.607453748761432, 48.55193069679502],
                            [2.605149641679002, 48.55398951274059],
                            [2.603968136056954, 48.55504505232757],
                            [2.602431242894382, 48.55642903058628],
                            [2.601858207182686, 48.55693575710002],
                            [2.600732321721419, 48.55793026945286],
                            [2.599306285855718, 48.55917104011397],
                            [2.598596250642165, 48.559791303229716],
                            [2.597929111450562, 48.560392429278025],
                            [2.597558172959759, 48.56074542162348],
                            [2.59715174336718, 48.561167493858214],
                            [2.596734664983745, 48.561611003661056],
                            [2.596414028489294, 48.56199004836417],
                            [2.596040049681421, 48.56245249167125],
                            [2.595406892080137, 48.56339852389335],
                            [2.594826443424239, 48.56440594919895],
                            [2.594551816007613, 48.564949495670916],
                        ],
                    },
                },
                996: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.81379763817774, 2.599340702456658],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3501.36963764,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.579837253911679,
                            48.80577037511879,
                            2.619395781719303,
                            48.823151855834304,
                        ),
                        "coordinates": [
                            [2.579837253911679, 48.823151855834304],
                            [2.581155115207787, 48.822485147533854],
                            [2.581903655396125, 48.82210674278792],
                            [2.583772966236383, 48.82117105773609],
                            [2.584755116675035, 48.820674323635544],
                            [2.585718270738693, 48.8201956079777],
                            [2.587732764523767, 48.81918310213227],
                            [2.588892832544682, 48.81860770290041],
                            [2.58997945661268, 48.8180558366566],
                            [2.591739847255778, 48.817183211036536],
                            [2.593047809445939, 48.816522007670784],
                            [2.596057164017709, 48.81501142567895],
                            [2.597463202560697, 48.81430696788385],
                            [2.601688035105247, 48.81217763115321],
                            [2.602899419478348, 48.81158308451889],
                            [2.603615272568844, 48.81125336823382],
                            [2.60426040544961, 48.81096209537898],
                            [2.604814585533072, 48.81072440047871],
                            [2.605364211069727, 48.810498588395],
                            [2.606162384032739, 48.81017884333655],
                            [2.606962718033112, 48.80987928904391],
                            [2.607975113109869, 48.8095189727751],
                            [2.608923743215775, 48.8092028645714],
                            [2.610235267042617, 48.808773469632065],
                            [2.611328027659545, 48.80842821916969],
                            [2.612176119719753, 48.8081581898816],
                            [2.614861444541515, 48.807260487950884],
                            [2.616367137447408, 48.80676303587094],
                            [2.617409824810454, 48.80641546873197],
                            [2.618337498783522, 48.80611576400223],
                            [2.618952317516781, 48.80591200030611],
                            [2.619395781719303, 48.80577037511879],
                        ],
                    },
                },
                997: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.86835393814357, 2.3593373251244056],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 731.866560459,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.354603790708304,
                            48.86715872534515,
                            2.363957837859411,
                            48.8692241707531,
                        ),
                        "coordinates": [
                            [2.363957837859411, 48.86715872534515],
                            [2.363793803780822, 48.86726572863457],
                            [2.363622184945398, 48.86736741942554],
                            [2.363443370004752, 48.867463564126446],
                            [2.363257774708015, 48.86755394368031],
                            [2.363189100155265, 48.867585151484754],
                            [2.363065820168313, 48.867638347153886],
                            [2.362867957255941, 48.867716583559556],
                            [2.362664632662775, 48.86778846998345],
                            [2.362456317417096, 48.86785384073091],
                            [2.362243489140825, 48.867912549031104],
                            [2.362026640348221, 48.867964457188656],
                            [2.361806268782234, 48.86800944642526],
                            [2.361582877457654, 48.86804741328271],
                            [2.361565472058887, 48.86805005713664],
                            [2.358173198819874, 48.868560898711706],
                            [2.356237303022795, 48.86887087427413],
                            [2.354603790708304, 48.8692241707531],
                        ],
                    },
                },
                998: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.86222130395875, 2.3669617249474233],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 235.9598537,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.366661093353452,
                            48.86116886459571,
                            2.367210867785615,
                            48.8632579449589,
                        ),
                        "coordinates": [
                            [2.367210867785615, 48.86116886459571],
                            [2.366864751470929, 48.86267743615081],
                            [2.36677568226235, 48.86298030490477],
                            [2.366661093353452, 48.8632579449589],
                        ],
                    },
                },
                999: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.874180486426724, 2.357034714289241],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 420.078193978,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356044909035453,
                            48.87242491449633,
                            2.357880771925327,
                            48.8759910648072,
                        ),
                        "coordinates": [
                            [2.356044909035453, 48.87242491449633],
                            [2.356332765799362, 48.872935815255325],
                            [2.356523734579195, 48.87326695816418],
                            [2.357573315385507, 48.8750868639077],
                            [2.357781457973243, 48.8754878280079],
                            [2.357880771925327, 48.8759910648072],
                        ],
                    },
                },
                1000: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.74131845691756, 2.2921333740266983],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 767.944860871,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.287667495463073,
                            48.73968104253053,
                            2.296393158896152,
                            48.74337340202939,
                        ),
                        "coordinates": [
                            [2.287667495463073, 48.73968104253053],
                            [2.28787234499148, 48.739752061103594],
                            [2.289138911301557, 48.740193729129366],
                            [2.290024908287365, 48.74050612572745],
                            [2.290499281626199, 48.740661894547294],
                            [2.291401806517862, 48.7409743069735],
                            [2.292240455948941, 48.74126690298058],
                            [2.293167467699213, 48.74159010179954],
                            [2.293455628059363, 48.74169632699938],
                            [2.294129783870213, 48.74198345026301],
                            [2.294412489240916, 48.74211395111215],
                            [2.294696538830439, 48.74226243646788],
                            [2.294918075879812, 48.742374927534556],
                            [2.295178792006659, 48.74252709294049],
                            [2.295399173298387, 48.74265837469831],
                            [2.295753862551301, 48.74289501266348],
                            [2.296143872521953, 48.743175726458084],
                            [2.296393158896152, 48.74337340202939],
                        ],
                    },
                },
                1001: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.52752506040805, 2.6537166502262974],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 198.07000157,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.652441044420506,
                            48.52724332146015,
                            2.654990282141887,
                            48.5277977343036,
                        ),
                        "coordinates": [
                            [2.654990282141887, 48.52724332146015],
                            [2.654417667755585, 48.527373220137065],
                            [2.653539149006601, 48.527567222324514],
                            [2.652441044420506, 48.5277977343036],
                        ],
                    },
                },
                1002: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.694412290415755, 2.314205660283161],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1937.89988409,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307841188697314,
                            48.68571362817925,
                            2.31762640494754,
                            48.700680803710014,
                        ),
                        "coordinates": [
                            [2.307841188697314, 48.700680803710014],
                            [2.308060492335775, 48.700621314441115],
                            [2.308496658628785, 48.700500920955015],
                            [2.309046973424329, 48.700322101277074],
                            [2.309257589823621, 48.700248411589364],
                            [2.30954701978214, 48.700141467984565],
                            [2.309901672201181, 48.70000756046726],
                            [2.310101843355535, 48.69992686847791],
                            [2.310295737363296, 48.69984308702621],
                            [2.310574266227183, 48.69971997721804],
                            [2.310846076597988, 48.69959411601077],
                            [2.311024088223121, 48.699508725084954],
                            [2.311270048560566, 48.69938018515689],
                            [2.311507855093035, 48.699252542105484],
                            [2.311797305550721, 48.6990844429409],
                            [2.31201473312595, 48.698954995661104],
                            [2.312211625356501, 48.69883523479572],
                            [2.312400667760392, 48.698717671650385],
                            [2.312592280311594, 48.69858821750055],
                            [2.312797479879726, 48.69845247119749],
                            [2.312991815656252, 48.698306830650594],
                            [2.313133152358122, 48.69819535086259],
                            [2.313328845049483, 48.69804970946394],
                            [2.313481054366961, 48.69792564155337],
                            [2.313774603832589, 48.69767300725701],
                            [2.313906431843856, 48.697551632395616],
                            [2.314168395365838, 48.69730383358898],
                            [2.314334529342819, 48.69713398279375],
                            [2.314541662691648, 48.69690418132748],
                            [2.314673282649053, 48.696745743965415],
                            [2.314880728304293, 48.696493853297916],
                            [2.314968896717843, 48.69636748972243],
                            [2.315070322157489, 48.696213329980544],
                            [2.315204122840613, 48.695990650048095],
                            [2.315368144891214, 48.695696597757],
                            [2.315465274335875, 48.695495325991445],
                            [2.315549467333629, 48.6952854860777],
                            [2.315637994271597, 48.69502425295953],
                            [2.31570062234614, 48.69481155380333],
                            [2.315752506223614, 48.69451034146246],
                            [2.315793586028409, 48.69425338274853],
                            [2.315826066371573, 48.693939318656874],
                            [2.315854188550386, 48.6937266119863],
                            [2.315882410206213, 48.693281209577364],
                            [2.315917132941752, 48.69275729059034],
                            [2.315936684692231, 48.69241181750756],
                            [2.315954057640198, 48.692120591401256],
                            [2.316024213501852, 48.691183592517824],
                            [2.316053829381143, 48.690728709350765],
                            [2.316069342227258, 48.690453395739624],
                            [2.316082057816258, 48.690257610219724],
                            [2.316097246868391, 48.69003205328465],
                            [2.316117186824867, 48.68972050122383],
                            [2.316164396581444, 48.689292573421255],
                            [2.316192503817615, 48.689112702416004],
                            [2.316234346087684, 48.68887880781639],
                            [2.316285414633234, 48.68864018618043],
                            [2.316358853446466, 48.68832898539418],
                            [2.316414987576488, 48.68814911834479],
                            [2.316471128984852, 48.687956403910746],
                            [2.316544523127048, 48.687746561315954],
                            [2.316758194109892, 48.68722695632568],
                            [2.316982614302826, 48.68676873940675],
                            [2.317304105815702, 48.68618205504511],
                            [2.31762640494754, 48.68571362817925],
                        ],
                    },
                },
                1003: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.87045701489729, 2.3099899881556567],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 427.653580557,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.309505157337887,
                            48.86869984735294,
                            2.310051332735712,
                            48.87242238455812,
                        ),
                        "coordinates": [
                            [2.309505157337887, 48.86869984735294],
                            [2.309714050704595, 48.86881646257349],
                            [2.309790075965128, 48.86887311458463],
                            [2.30985745902478, 48.86893434384405],
                            [2.309915568102955, 48.86899957653823],
                            [2.309935388700378, 48.869026528172164],
                            [2.309935812084289, 48.869027087307785],
                            [2.309963863193555, 48.869068205207],
                            [2.310001891976034, 48.86913958871921],
                            [2.31002930062749, 48.86921305952937],
                            [2.310045832329692, 48.869287933561445],
                            [2.310051332735712, 48.869363509340516],
                            [2.310051294611669, 48.86936947537466],
                            [2.310024403425482, 48.871593430365856],
                            [2.310015906824184, 48.87229608376553],
                            [2.310015881120888, 48.87229997956905],
                            [2.310021500829709, 48.872361629512035],
                            [2.310038345971296, 48.87242238455812],
                        ],
                    },
                },
                1004: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.873221354891236, 2.3122508534778423],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 373.436983576,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.310038345971296,
                            48.87242238455812,
                            2.314606322970783,
                            48.8737095286447,
                        ),
                        "coordinates": [
                            [2.310038345971296, 48.87242238455812],
                            [2.310066167960612, 48.87248135561882],
                            [2.310104563731149, 48.87253768508888],
                            [2.310152971595888, 48.87259055042061],
                            [2.310210687389624, 48.87263918040542],
                            [2.310276869742171, 48.87268286869546],
                            [2.310350550971325, 48.87272097476643],
                            [2.310430658621598, 48.872752944727615],
                            [2.310431213693162, 48.87275313678712],
                            [2.31109705445966, 48.87298339532176],
                            [2.311952400755109, 48.87321557319413],
                            [2.312617694456817, 48.87335992476567],
                            [2.314467989568736, 48.87368521063635],
                            [2.314606322970783, 48.8737095286447],
                        ],
                    },
                },
                1005: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.87460525688338, 2.320639314058641],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 107.041669822,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.319916077554934,
                            48.87455838471093,
                            2.321361928104079,
                            48.8746257853424,
                        ),
                        "coordinates": [
                            [2.319916077554934, 48.87457851276328],
                            [2.319980507219545, 48.87458797471408],
                            [2.320157173103899, 48.874607735714065],
                            [2.32033533663201, 48.874620354306664],
                            [2.320514332977755, 48.8746257853424],
                            [2.320693501086448, 48.8746240079793],
                            [2.320872170008018, 48.8746150283031],
                            [2.321049677972865, 48.87459888033514],
                            [2.321361928104079, 48.87455838471093],
                        ],
                    },
                },
                1006: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.873326751736364, 2.33058743591581],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 432.918762837,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.327695409630174,
                            48.872937657673795,
                            2.333479131845597,
                            48.87371340670774,
                        ),
                        "coordinates": [
                            [2.327695409630174, 48.87371340670774],
                            [2.329012205984622, 48.8735374612216],
                            [2.332698226499536, 48.87304486097324],
                            [2.333257090439438, 48.872968139904444],
                            [2.333477622676746, 48.872937865111936],
                            [2.333479131845597, 48.872937657673795],
                        ],
                    },
                },
                1007: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84590852487496, 2.2687801858958503],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 377.676533116,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.266441541719401,
                            48.845204703581174,
                            2.271115349613071,
                            48.846625048719645,
                        ),
                        "coordinates": [
                            [2.271115349613071, 48.846625048719645],
                            [2.266716580804538, 48.845274731864265],
                            [2.266587787113133, 48.845238442479314],
                            [2.266441541719401, 48.845204703581174],
                        ],
                    },
                },
                1008: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.742840185557135, 2.7428177300496306],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2558.51201639,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.727229371429766,
                            48.73948720730179,
                            2.758824548674894,
                            48.746452320704556,
                        ),
                        "coordinates": [
                            [2.758824548674894, 48.73948720730179],
                            [2.757463153104825, 48.73992300184102],
                            [2.755815676866813, 48.740457855891115],
                            [2.755213628316272, 48.740653415483834],
                            [2.753632277764686, 48.74116286995946],
                            [2.752746065101737, 48.74144687524047],
                            [2.751953159560979, 48.74170436051471],
                            [2.751124289360127, 48.74196434953959],
                            [2.750342140477953, 48.74221940453988],
                            [2.749793146582966, 48.74239271141803],
                            [2.74940920181095, 48.742513070996154],
                            [2.749107760020873, 48.74260457858254],
                            [2.74882064994764, 48.74268889594417],
                            [2.748498111428065, 48.7427786199245],
                            [2.74822812030214, 48.74285063912414],
                            [2.748034078807947, 48.74289900239088],
                            [2.747778961740407, 48.74296107384181],
                            [2.747518547365853, 48.743020849027594],
                            [2.74724286191312, 48.743081712886344],
                            [2.746940721709728, 48.74313655151526],
                            [2.746653441037735, 48.743189669748624],
                            [2.746365778130365, 48.74324044619832],
                            [2.746113191513724, 48.74328002417393],
                            [2.745942068107599, 48.743304919344126],
                            [2.745659538454691, 48.74334100586608],
                            [2.745469357047838, 48.74336327124011],
                            [2.745272370539994, 48.74338466105186],
                            [2.745107971776274, 48.74340053834247],
                            [2.744942205102114, 48.74341552116371],
                            [2.74476147497997, 48.74342965779589],
                            [2.744542688273962, 48.74344572922272],
                            [2.744357878048428, 48.74345987989882],
                            [2.744162139971035, 48.743467774823486],
                            [2.743808747418527, 48.74348522480896],
                            [2.743519571546724, 48.743490109272265],
                            [2.743284480852506, 48.743491593525064],
                            [2.743085420140631, 48.74349230310473],
                            [2.742783528808296, 48.74348888380099],
                            [2.742458485902403, 48.7434810489327],
                            [2.742199233724328, 48.74346781575678],
                            [2.741850157497902, 48.74344966320503],
                            [2.741617806472173, 48.743437276614756],
                            [2.741342441262852, 48.74341626183757],
                            [2.740945726052493, 48.743392000722906],
                            [2.739929502656484, 48.74333085272223],
                            [2.738226255276761, 48.74322535702782],
                            [2.73715831957738, 48.74315807112082],
                            [2.736823660136452, 48.74313766457197],
                            [2.73647403012768, 48.743115510654086],
                            [2.736142112869119, 48.743097789404686],
                            [2.735773547631447, 48.74308828954061],
                            [2.735526069480017, 48.743087357539466],
                            [2.735254144235954, 48.74309010789132],
                            [2.734942895406095, 48.7431064837264],
                            [2.734656121499252, 48.74312277373787],
                            [2.734321880609803, 48.743154516442054],
                            [2.734056968219893, 48.74318421718361],
                            [2.733798876921888, 48.74321659211917],
                            [2.733578834398465, 48.743246136400366],
                            [2.73333435331182, 48.74328026128418],
                            [2.733073626086733, 48.74332343524674],
                            [2.732876741095101, 48.74335829248691],
                            [2.732612006844383, 48.74341047222009],
                            [2.732362235230184, 48.74346349797909],
                            [2.732098950879702, 48.74352736233483],
                            [2.731842479611189, 48.743593000667566],
                            [2.731595561497767, 48.743663101238646],
                            [2.731420558593534, 48.74371406792822],
                            [2.731195428804425, 48.74378858873805],
                            [2.730935075927499, 48.74387941889811],
                            [2.730537964968577, 48.74404356246989],
                            [2.730262986426534, 48.74417670801468],
                            [2.730022118880164, 48.74432502224007],
                            [2.729844987446206, 48.74445153356572],
                            [2.729481333043577, 48.74472077575101],
                            [2.728179796656208, 48.74572975657104],
                            [2.727229371429766, 48.746452320704556],
                        ],
                    },
                },
                1009: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.860435157217054, 2.285920671424502],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 754.942265394,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.284671504169904,
                            48.8574486900758,
                            2.287580162529652,
                            48.86361093764567,
                        ),
                        "coordinates": [
                            [2.287580162529652, 48.86361093764567],
                            [2.287446163372081, 48.863431845183435],
                            [2.287166876865423, 48.86307378223337],
                            [2.287042136889467, 48.86290986337978],
                            [2.286923421537254, 48.86274642094721],
                            [2.286823845375502, 48.86259906852679],
                            [2.286771244764816, 48.862515335590274],
                            [2.286723782738497, 48.862434721627636],
                            [2.286681180927224, 48.86235674832957],
                            [2.286643265074544, 48.862281098990344],
                            [2.286609868185678, 48.86220742457003],
                            [2.286580947964645, 48.862135626791265],
                            [2.286556441294785, 48.86206553530377],
                            [2.286536303452745, 48.861997030230086],
                            [2.286520972007373, 48.86193279605307],
                            [2.286508171507004, 48.86186500292936],
                            [2.286479400579245, 48.86165483686381],
                            [2.286466485062415, 48.86157763579369],
                            [2.28644801953262, 48.86149692472347],
                            [2.286424333926695, 48.86141936802931],
                            [2.28638080509936, 48.86130806166393],
                            [2.286324010089886, 48.861188474049435],
                            [2.286252972491546, 48.86105776187819],
                            [2.28614974250906, 48.8608828899952],
                            [2.286000247676248, 48.860644234958926],
                            [2.285829090889109, 48.86038990685808],
                            [2.285632130588842, 48.860113526921076],
                            [2.285388004761616, 48.85978508276523],
                            [2.284771425531797, 48.85899108515106],
                            [2.284737567879862, 48.85894228429127],
                            [2.284704701412001, 48.8588789728396],
                            [2.284682590683305, 48.85881365894863],
                            [2.284671504169904, 48.85874713656165],
                            [2.28467157384578, 48.85868021409247],
                            [2.284682800809477, 48.85861370186782],
                            [2.284705048521948, 48.85854840848922],
                            [2.284738048445702, 48.858485127376916],
                            [2.284781396131294, 48.8584246241555],
                            [2.284834570312345, 48.85836763586937],
                            [2.284838817818533, 48.8583636321375],
                            [2.285567724290176, 48.857682758251144],
                            [2.285812444146408, 48.8574486900758],
                        ],
                    },
                },
                1010: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.81566265602977, 2.2834403248277875],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 1393.62176248,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.274489672177882,
                            48.81423944550172,
                            2.292061814554318,
                            48.81838763956164,
                        ),
                        "coordinates": [
                            [2.274489672177882, 48.81423944550172],
                            [2.275701339241957, 48.81433722414059],
                            [2.277689860029413, 48.81450482747072],
                            [2.278911079583619, 48.81460538603321],
                            [2.279523485459035, 48.814662799578],
                            [2.280125086670432, 48.814717824489364],
                            [2.280503332003678, 48.81475846037191],
                            [2.280845543234628, 48.81480621645205],
                            [2.28120935891414, 48.8148634982778],
                            [2.281544357517018, 48.814918386128774],
                            [2.282293591089642, 48.815054368950776],
                            [2.282815890430948, 48.815152171217434],
                            [2.283284150745847, 48.815249944055765],
                            [2.283687574903952, 48.81533578922809],
                            [2.284361133768253, 48.81549551717757],
                            [2.285059890572856, 48.81568142392574],
                            [2.28607919747397, 48.81597454071003],
                            [2.286648278644856, 48.81614610534814],
                            [2.287267771603163, 48.81634861985592],
                            [2.287912470100058, 48.81657255537023],
                            [2.288459916480592, 48.8167726531065],
                            [2.289090191692901, 48.81702036967745],
                            [2.289828504851223, 48.81732761026884],
                            [2.290354322884574, 48.81755862203575],
                            [2.291297906892865, 48.817992040533404],
                            [2.291683254683314, 48.818184920450896],
                            [2.292061814554318, 48.81838763956164],
                        ],
                    },
                },
                1011: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.87335163701068, 2.298037034784526],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 529.634946533,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.295904904713175,
                            48.87202381039972,
                            2.300560451236721,
                            48.87514981972761,
                        ),
                        "coordinates": [
                            [2.300560451236721, 48.87202381039972],
                            [2.297964404536526, 48.872843931070015],
                            [2.297919475842498, 48.872858929412565],
                            [2.297822550860577, 48.87289720621064],
                            [2.297731777016911, 48.87294156710087],
                            [2.297648034002297, 48.872991582875486],
                            [2.297572125890951, 48.873046770823],
                            [2.297504783758137, 48.87310660283694],
                            [2.297446653483461, 48.87317049994747],
                            [2.297398300996899, 48.87323784764031],
                            [2.297360186351802, 48.87330799750273],
                            [2.29733267862187, 48.8733802745051],
                            [2.297316043569859, 48.87345398142479],
                            [2.29731044214822, 48.87352840872988],
                            [2.297315924971646, 48.87360283994244],
                            [2.297316417063845, 48.87360608046487],
                            [2.297322765207438, 48.87365487559324],
                            [2.297328222294361, 48.873759513764185],
                            [2.297322599164314, 48.8738641489371],
                            [2.297305924454217, 48.87396827045247],
                            [2.297278279934152, 48.8740713706578],
                            [2.297239799097196, 48.87417294849687],
                            [2.297190669911737, 48.87427250772748],
                            [2.297131131999215, 48.87436956409952],
                            [2.297061475284356, 48.87446364444847],
                            [2.296982038596607, 48.87455428938511],
                            [2.296893208210618, 48.87464106048236],
                            [2.296795419331868, 48.87472353129092],
                            [2.296689144996643, 48.87480130166408],
                            [2.296574907039644, 48.87487399332581],
                            [2.29645325835873, 48.87494125066659],
                            [2.296324793736605, 48.87500274710269],
                            [2.296190137607074, 48.875058182306944],
                            [2.296049948083499, 48.87510728672947],
                            [2.296033814838449, 48.87511201682187],
                            [2.295904904713175, 48.87514981972761],
                        ],
                    },
                },
                1012: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.875052055833166, 2.292597433616531],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 528.339887475,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.289322589613774,
                            48.87460592299079,
                            2.295904904713175,
                            48.87559404986667,
                        ),
                        "coordinates": [
                            [2.295904904713175, 48.87514981972761],
                            [2.29575571792184, 48.87518557681647],
                            [2.29560311276233, 48.875214381479765],
                            [2.295447834257395, 48.875236093295634],
                            [2.295290636491363, 48.875250607872715],
                            [2.295132285372336, 48.87525785416856],
                            [2.294973555879231, 48.87525779627232],
                            [2.294815218414883, 48.87525043422377],
                            [2.294658045608946, 48.875235804952844],
                            [2.294502802809521, 48.875213979525356],
                            [2.294350246706387, 48.87518506403423],
                            [2.294201118524293, 48.875149198659734],
                            [2.294056149451574, 48.87510655950008],
                            [2.293916041636953, 48.87505735216352],
                            [2.293781480361006, 48.87500181903448],
                            [2.293653119173221, 48.874940229292875],
                            [2.293531583919862, 48.874872883433916],
                            [2.293437466786098, 48.874813614394824],
                            [2.293414493082194, 48.87479875026391],
                            [2.293332636049065, 48.87475234304934],
                            [2.293244083780053, 48.87471163764708],
                            [2.293149740020383, 48.87467704947975],
                            [2.293050576125041, 48.87464893411503],
                            [2.292947609320845, 48.87462758174226],
                            [2.292841896000851, 48.87461320903889],
                            [2.292734520747192, 48.87460596450252],
                            [2.292626585499203, 48.87460592299079],
                            [2.29251919593574, 48.87461308474182],
                            [2.292413458750013, 48.87462737535823],
                            [2.292310452974152, 48.87464864923471],
                            [2.292217678361452, 48.87467462412368],
                            [2.289322589613774, 48.87559404986667],
                        ],
                    },
                },
                1013: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.81343684350115, 2.2576414460161507],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 2513.01998193,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.240919294866535,
                            48.8126035833289,
                            2.274489672177882,
                            48.81488431421452,
                        ),
                        "coordinates": [
                            [2.240919294866535, 48.81488431421452],
                            [2.241726748463877, 48.81466133223218],
                            [2.242339521055581, 48.814502426292414],
                            [2.242876561607956, 48.81438152371835],
                            [2.243601010146782, 48.814225082183285],
                            [2.244044311335397, 48.814137408477],
                            [2.244811968641806, 48.81399051098299],
                            [2.248041096454325, 48.81338396064823],
                            [2.24933488683262, 48.81314226835762],
                            [2.250109707258579, 48.813000099215266],
                            [2.250834043158753, 48.812884060873834],
                            [2.251551137127898, 48.81278704631829],
                            [2.252282597272691, 48.812713831706816],
                            [2.253006824031245, 48.81265726293035],
                            [2.253734617081729, 48.81261972527513],
                            [2.254440759709511, 48.8126035833289],
                            [2.255172077863239, 48.8126136261862],
                            [2.255899761086372, 48.81264269745161],
                            [2.25662740828471, 48.8126955566814],
                            [2.257481113554087, 48.812769912924445],
                            [2.258331227074339, 48.812839502753405],
                            [2.259177735732794, 48.81291146287018],
                            [2.260020642353675, 48.81298579336772],
                            [2.263165351898009, 48.81326149121986],
                            [2.265387930932504, 48.81345087413204],
                            [2.270589594529998, 48.81391560582077],
                            [2.272977807351703, 48.81411477416988],
                            [2.273475067343621, 48.81415755907355],
                            [2.274489672177882, 48.81423944550172],
                        ],
                    },
                },
                1014: {
                    "attributes": {
                        "reseau": "ORLYVAL",
                        "val": 1,
                        "metro": 0,
                        "res_com": "ORLYVAL",
                        "rer": 0,
                        "extcode": "100110200:ORLYVAL",
                        "geo_point_2d": [48.72910711502528, 2.3649309002697234],
                        "indice_lig": "ORL",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Navette",
                        "tramway": 0,
                        "idrefligc": "C01388",
                        "navette": 1,
                        "idrefliga": "A01551",
                        "shape_leng": 816.878878474,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.360013412858126,
                            48.72831964884852,
                            2.369913227510133,
                            48.729969602199716,
                        ),
                        "coordinates": [
                            [2.360013412858126, 48.72964735584993],
                            [2.361537221297242, 48.72993050213219],
                            [2.361830102669491, 48.7299625103359],
                            [2.362032959203282, 48.729969602199716],
                            [2.362258431263568, 48.72996382019547],
                            [2.362580245772425, 48.72993067384142],
                            [2.362908295056362, 48.72987478941074],
                            [2.363145724879654, 48.729806523566914],
                            [2.363531581885845, 48.72963664277003],
                            [2.363745472128637, 48.729494259588336],
                            [2.363945349426182, 48.72932058229832],
                            [2.364401850942933, 48.728839485456405],
                            [2.364592275885659, 48.728700557343714],
                            [2.364801041593093, 48.72855763941851],
                            [2.365063432599524, 48.72844388778747],
                            [2.365297729502446, 48.728377684091704],
                            [2.365657014880005, 48.7283217828089],
                            [2.365919467360493, 48.72831964884852],
                            [2.366191312256152, 48.7283485170098],
                            [2.368516138168356, 48.7287704516787],
                            [2.369913227510133, 48.72902398514276],
                        ],
                    },
                },
                1015: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.84454111554991, 2.321120916391926],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 520.812250511,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.317852783041332,
                            48.84373548931853,
                            2.324353041157966,
                            48.845012660501645,
                        ),
                        "coordinates": [
                            [2.317852783041332, 48.84447014129586],
                            [2.31848319338898, 48.84463122460463],
                            [2.319634812799994, 48.84493976882509],
                            [2.319690473594323, 48.84495500580324],
                            [2.319803623886384, 48.84498005432406],
                            [2.319919792541097, 48.844998104858846],
                            [2.320037992229098, 48.8450090051914],
                            [2.320157206253145, 48.845012660501645],
                            [2.320276423905453, 48.84500903896279],
                            [2.320394630920101, 48.844998172586585],
                            [2.320510812223628, 48.84498015544004],
                            [2.320603633132294, 48.84496020769213],
                            [2.320844963187526, 48.84489601704816],
                            [2.32262977649064, 48.844304608348374],
                            [2.323956054419485, 48.843865772381335],
                            [2.324353041157966, 48.84373548931853],
                        ],
                    },
                },
                1016: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.8866595620841, 2.2542206060776446],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 1020.6378473,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.247932435311872,
                            48.88470820133095,
                            2.260515079251701,
                            48.88863121867044,
                        ),
                        "coordinates": [
                            [2.260515079251701, 48.88470820133095],
                            [2.256203093905055, 48.886030275334065],
                            [2.249429358657001, 48.88816055413873],
                            [2.247932435311872, 48.88863121867044],
                        ],
                    },
                },
                1017: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.88294986050467, 2.2661008994758385],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 907.829769227,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.260515077888117,
                            48.881191519686794,
                            2.27168672106356,
                            48.88470820132253,
                        ),
                        "coordinates": [
                            [2.27168672106356, 48.881191519686794],
                            [2.260515077888117, 48.88470820132253],
                        ],
                    },
                },
                1018: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.64878906112415, 2.559649723799478],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4702.9854373,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.547548045814366,
                            48.62837555172384,
                            2.56958354823646,
                            48.66790196104987,
                        ),
                        "coordinates": [
                            [2.56958354823646, 48.62837555172384],
                            [2.569406439175108, 48.62889890137802],
                            [2.56913342267403, 48.62962039695549],
                            [2.568629048530896, 48.63081638115946],
                            [2.568266513822785, 48.631590401960274],
                            [2.567391618190399, 48.63334812704903],
                            [2.566950589204467, 48.634234132914834],
                            [2.566449473902916, 48.6353272596119],
                            [2.565994695460244, 48.63635366933025],
                            [2.56568511442547, 48.637066496834905],
                            [2.565340977921392, 48.637766824389495],
                            [2.564894971173897, 48.63874253154561],
                            [2.564635729043129, 48.63931858668684],
                            [2.564051150823877, 48.6406129906347],
                            [2.563723760738216, 48.64135086234981],
                            [2.56330872968431, 48.642282506963454],
                            [2.563018228015947, 48.64294067665082],
                            [2.562630848528986, 48.64381206177847],
                            [2.562312511904095, 48.644500385980066],
                            [2.561942507202297, 48.64535552551547],
                            [2.561587925483845, 48.64620923051155],
                            [2.561053363199314, 48.64732311202191],
                            [2.55973832591891, 48.650149252410294],
                            [2.55962275481229, 48.650405771799306],
                            [2.559009989226959, 48.651776564824345],
                            [2.558813759673332, 48.65220859982774],
                            [2.558609478770262, 48.65266223198352],
                            [2.558406499926798, 48.653104171436375],
                            [2.558151110818841, 48.653664916390206],
                            [2.557979153435526, 48.654064528093244],
                            [2.557813708441414, 48.65440297737949],
                            [2.557525663005992, 48.654948496784925],
                            [2.557179414908994, 48.655531897920326],
                            [2.556766882555606, 48.656168482914076],
                            [2.556536225230001, 48.65649716443471],
                            [2.556108453040318, 48.65706723109287],
                            [2.555622429634984, 48.657666184527585],
                            [2.555091932232451, 48.658340760760815],
                            [2.554545342900555, 48.659063925760314],
                            [2.554210584935686, 48.65949531875231],
                            [2.553481552192786, 48.66041127221636],
                            [2.553119710579877, 48.66086249832071],
                            [2.552562120158716, 48.66156589038121],
                            [2.552000468691985, 48.662275583110564],
                            [2.551502236174676, 48.662899721998],
                            [2.551272712301752, 48.66319151972034],
                            [2.550593088637024, 48.66399975558181],
                            [2.550260789836023, 48.664407245867245],
                            [2.549846390610607, 48.66493623613217],
                            [2.549421184863024, 48.66546048499634],
                            [2.548967377971035, 48.666018096460355],
                            [2.548387495128188, 48.6667635390484],
                            [2.548050814835807, 48.667245184400095],
                            [2.547730847990273, 48.66766933678332],
                            [2.547548045814366, 48.66790196104987],
                        ],
                    },
                },
                1019: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.82662512935481, 2.561416453473115],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3060.8398722,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.542679794015853,
                            48.823151855834304,
                            2.579837253911679,
                            48.82891571807522,
                        ),
                        "coordinates": [
                            [2.542679794015853, 48.823266634124074],
                            [2.54319738223279, 48.82338471744232],
                            [2.543768420899775, 48.823522702070726],
                            [2.544135028007035, 48.823620902156875],
                            [2.544519516486454, 48.82372389086675],
                            [2.544909853942727, 48.82383934236116],
                            [2.545704764477432, 48.82409216533853],
                            [2.546404616029224, 48.824334809483716],
                            [2.546729249941615, 48.82445112001773],
                            [2.547585891862722, 48.82476698733664],
                            [2.550071962898491, 48.82572584429529],
                            [2.55133196244352, 48.82619076630898],
                            [2.552655102877416, 48.826692469934414],
                            [2.554434357872877, 48.82738363684643],
                            [2.555078456953258, 48.8276222441678],
                            [2.555655915997571, 48.82781862551826],
                            [2.556139496028702, 48.827972356133905],
                            [2.556662675469705, 48.82811649061705],
                            [2.557279454291553, 48.82826487072206],
                            [2.557957044876824, 48.828411042333876],
                            [2.558610088654659, 48.828537438840264],
                            [2.55932468798049, 48.828660963895196],
                            [2.560034359742709, 48.82875412311142],
                            [2.56059443107277, 48.828812379401555],
                            [2.561050894207676, 48.82885015310555],
                            [2.561606775303715, 48.828885031160354],
                            [2.562196656524036, 48.828908148790205],
                            [2.562875590550873, 48.82891571807522],
                            [2.563639072825642, 48.828904393445136],
                            [2.564257328554799, 48.828877083955135],
                            [2.5648196817397, 48.82883729344595],
                            [2.565429590017577, 48.828772224897726],
                            [2.56603944629848, 48.828696361668],
                            [2.566601596526989, 48.82861339741075],
                            [2.567301127896613, 48.82849058427833],
                            [2.567927089355076, 48.82836431845818],
                            [2.568374753950253, 48.828267189121206],
                            [2.56885377192259, 48.82814690297063],
                            [2.56932022524758, 48.82801976331371],
                            [2.569992099984153, 48.827811558659405],
                            [2.570618989808419, 48.82759624746719],
                            [2.571215913056742, 48.827381893966056],
                            [2.571856173993155, 48.82711618819398],
                            [2.572448720058697, 48.82684248486357],
                            [2.572864563004583, 48.826645582308366],
                            [2.573401306854942, 48.82638278014],
                            [2.573918951437667, 48.82611462014532],
                            [2.574482801824951, 48.825831879093215],
                            [2.577113247823859, 48.824509017813746],
                            [2.579837253911679, 48.823151855834304],
                        ],
                    },
                },
                1020: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.78038186975661, 2.0258616290799933],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 3145.01228687,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.006566869057667,
                            48.77480280977951,
                            2.044621987173176,
                            48.787390238280715,
                        ),
                        "coordinates": [
                            [2.006566869057667, 48.77480280977951],
                            [2.009207627400197, 48.77551998221428],
                            [2.012150762593544, 48.77632073131186],
                            [2.013135320830001, 48.776604296916304],
                            [2.013800047485958, 48.776801289944],
                            [2.014321057356297, 48.776955044031524],
                            [2.014838545728923, 48.777096890365996],
                            [2.015273377671665, 48.77721708596506],
                            [2.015790903839563, 48.77735416849987],
                            [2.016340756002657, 48.777503236601405],
                            [2.016991261209501, 48.777676377637114],
                            [2.017799895689103, 48.7778927864028],
                            [2.018586969518075, 48.77810436950985],
                            [2.021627507027376, 48.778921801016935],
                            [2.022874635557149, 48.779260733614514],
                            [2.02367252431761, 48.77947707071204],
                            [2.025383362444883, 48.77993621619956],
                            [2.026896514915116, 48.78034721175265],
                            [2.028894962887152, 48.78088322525144],
                            [2.029732462123214, 48.78110676527361],
                            [2.03116305426704, 48.78148892845829],
                            [2.032309533113018, 48.7818227289014],
                            [2.032880911060994, 48.78200032632209],
                            [2.03345940904871, 48.782192215908246],
                            [2.034469285971461, 48.7825525525616],
                            [2.035018876698637, 48.78276339320652],
                            [2.03554684069051, 48.782978932581834],
                            [2.036074765672647, 48.783201606342466],
                            [2.036588280324179, 48.783426619685514],
                            [2.037187879655413, 48.78370658173795],
                            [2.037826906024246, 48.784017576032426],
                            [2.039083350065184, 48.78464425604487],
                            [2.040031099034028, 48.78511546056952],
                            [2.040684464390339, 48.78544313177748],
                            [2.042483131752127, 48.78633291093265],
                            [2.044621987173176, 48.787390238280715],
                        ],
                    },
                },
                1021: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.55099986160079, 2.609233018540175],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 3724.30098091,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.594551816007613,
                            48.538775256627815,
                            2.625522155066302,
                            48.564949495670916,
                        ),
                        "coordinates": [
                            [2.625522155066302, 48.538775256627815],
                            [2.624776075314098, 48.53927050573528],
                            [2.623773668056681, 48.539923214706796],
                            [2.621886582463923, 48.54122651069726],
                            [2.620600906228615, 48.5420903309967],
                            [2.62016785267195, 48.542383674367116],
                            [2.619575609748064, 48.54278622409057],
                            [2.619358423228824, 48.54293694225777],
                            [2.618162728204673, 48.54373677681227],
                            [2.615466359895904, 48.54551006899454],
                            [2.612957391262936, 48.547184692917895],
                            [2.612344481644246, 48.54764836369889],
                            [2.611726401402525, 48.54815159979666],
                            [2.610171376480844, 48.549506804871186],
                            [2.608755488832815, 48.55076172354525],
                            [2.607453748761432, 48.55193069679502],
                            [2.605149641679002, 48.55398951274059],
                            [2.603968136056954, 48.55504505232757],
                            [2.602431242894382, 48.55642903058628],
                            [2.601858207182686, 48.55693575710002],
                            [2.600732321721419, 48.55793026945286],
                            [2.599306285855718, 48.55917104011397],
                            [2.598596250642165, 48.559791303229716],
                            [2.597929111450562, 48.560392429278025],
                            [2.597558172959759, 48.56074542162348],
                            [2.59715174336718, 48.561167493858214],
                            [2.596734664983745, 48.561611003661056],
                            [2.596414028489294, 48.56199004836417],
                            [2.596040049681421, 48.56245249167125],
                            [2.595406892080137, 48.56339852389335],
                            [2.594826443424239, 48.56440594919895],
                            [2.594551816007613, 48.564949495670916],
                        ],
                    },
                },
                1022: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.61716779170965, 2.473182538955527],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 914.283323533,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.470234997616056,
                            48.61342791359473,
                            2.474579769444083,
                            48.620290259939715,
                        ),
                        "coordinates": [
                            [2.470234997616056, 48.620290259939715],
                            [2.471777328715822, 48.61934060522176],
                            [2.472297319932593, 48.61902973707068],
                            [2.472645815143424, 48.61880952341326],
                            [2.472978319447921, 48.61857748834226],
                            [2.473255783820958, 48.61836492739091],
                            [2.473518326049831, 48.61815238345555],
                            [2.473703005494726, 48.61798365258037],
                            [2.473934178186055, 48.61774751120026],
                            [2.474124599490352, 48.617504589569954],
                            [2.474279961748753, 48.61723672817859],
                            [2.474408300480816, 48.61692964124391],
                            [2.474512306178045, 48.61658332540271],
                            [2.474553308539166, 48.61637327964186],
                            [2.474567710935143, 48.61617996461952],
                            [2.474579769444083, 48.615991059501745],
                            [2.474569042398426, 48.61568744500637],
                            [2.474522565500613, 48.615425183204074],
                            [2.474427612616452, 48.61515048730265],
                            [2.474292271982762, 48.61486870369535],
                            [2.474148958216899, 48.61462261932493],
                            [2.473968042513261, 48.61440334729717],
                            [2.473757513890328, 48.61418054117189],
                            [2.473350067517041, 48.61378844777394],
                            [2.472933650458744, 48.61342791359473],
                        ],
                    },
                },
                1023: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.841442066812576, 2.316738310443694],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 788.601158263,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.312812774836902,
                            48.840531485226656,
                            2.321278562744627,
                            48.842676819983716,
                        ),
                        "coordinates": [
                            [2.312812774836902, 48.842676819983716],
                            [2.313259566425739, 48.842147278265],
                            [2.313787194064523, 48.84150908180732],
                            [2.314761787564493, 48.840583326816436],
                            [2.31479537920587, 48.840569118559515],
                            [2.314857701011672, 48.84054961298884],
                            [2.314923953488818, 48.84053695969504],
                            [2.31499242377308, 48.840531485226656],
                            [2.315061337394325, 48.8405333314127],
                            [2.315128910115134, 48.84054245026363],
                            [2.315190426488495, 48.84055768608028],
                            [2.319145089817505, 48.841728647189036],
                            [2.319682092392484, 48.8418894296066],
                            [2.31972265629113, 48.84190137723019],
                            [2.319733221306652, 48.84190421185426],
                            [2.319907718817056, 48.841951021332186],
                            [2.320096641985276, 48.84199386269642],
                            [2.320288853839092, 48.84202976764785],
                            [2.320483771163629, 48.8420586294318],
                            [2.320680800979335, 48.8420803583295],
                            [2.32087934451258, 48.842094890674645],
                            [2.321078801389707, 48.84210218078291],
                            [2.321278562744627, 48.84210220720859],
                        ],
                    },
                },
                1024: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.835936000376265, 2.321180603508725],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 697.843105205,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.31807828549193,
                            48.83393639265079,
                            2.323140637288033,
                            48.83863164623715,
                        ),
                        "coordinates": [
                            [2.31807828549193, 48.83393639265079],
                            [2.318330776713798, 48.834071101862556],
                            [2.318453535108658, 48.834136639892336],
                            [2.320259355343377, 48.83510961469408],
                            [2.322958682071524, 48.83666001258314],
                            [2.323005178868548, 48.83669900892613],
                            [2.323052959039032, 48.8367499714351],
                            [2.323090891401536, 48.83680442260957],
                            [2.323118399447043, 48.836861537172055],
                            [2.323135065190419, 48.836920452067325],
                            [2.323140637288033, 48.836980271004634],
                            [2.323135032064134, 48.8370400905449],
                            [2.323118333490362, 48.83709900189917],
                            [2.323099167599489, 48.837141121544924],
                            [2.322855146915585, 48.83774030601557],
                            [2.322714092251333, 48.8380862897491],
                            [2.322491748462238, 48.83863164623715],
                        ],
                    },
                },
                1025: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.844372058879884, 2.311322535082977],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 421.44489329,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.309531491460945,
                            48.842676819983716,
                            2.312812774836902,
                            48.845626966747176,
                        ),
                        "coordinates": [
                            [2.309531491460945, 48.845626966747176],
                            [2.310045601655878, 48.84547865885467],
                            [2.310150028624514, 48.84545041125204],
                            [2.310249584570054, 48.845421401593306],
                            [2.31035602063851, 48.84539227052668],
                            [2.310478524573903, 48.84535121556852],
                            [2.310574925808503, 48.8453114796248],
                            [2.310675349087898, 48.84525981782309],
                            [2.310763728070648, 48.84520020181934],
                            [2.310844082333125, 48.84513130754608],
                            [2.310908372740852, 48.84505578230914],
                            [2.31100682313594, 48.844936531506114],
                            [2.311147469934398, 48.84475632991626],
                            [2.312443370657256, 48.84311462772962],
                            [2.312607051012364, 48.842920619092425],
                            [2.312812774836902, 48.842676819983716],
                        ],
                    },
                },
                1026: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.839912536323375, 2.3286375862032744],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 379.426367464,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.326384610792847,
                            48.838964280710556,
                            2.330754192086216,
                            48.840663229299565,
                        ),
                        "coordinates": [
                            [2.326384610792847, 48.840663229299565],
                            [2.328034259642426, 48.8401167104851],
                            [2.330101830156279, 48.839454160506676],
                            [2.330186969665794, 48.839426875610414],
                            [2.330190771746368, 48.83942565127661],
                            [2.33028483766617, 48.83939119437512],
                            [2.330373140948916, 48.83935063081467],
                            [2.330454772840585, 48.839304381820995],
                            [2.330528896191261, 48.839252916688395],
                            [2.330594754830574, 48.83919676542263],
                            [2.330651666940404, 48.839136504313345],
                            [2.330699052348423, 48.83907275248852],
                            [2.330736424467831, 48.83900616287519],
                            [2.330754192086216, 48.838964280710556],
                        ],
                    },
                },
                1027: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.8541558679803, 2.314738538274714],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 605.630915504,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.314408121472487,
                            48.851441707440316,
                            2.315056637317088,
                            48.85687137924918,
                        ),
                        "coordinates": [
                            [2.314408121472487, 48.851441707440316],
                            [2.31443156302243, 48.85163385578223],
                            [2.315001650347769, 48.85630651163444],
                            [2.315056637317088, 48.85687137924918],
                        ],
                    },
                },
                1028: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.87818691232744, 2.397461440066625],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 792.661344951,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.392983964817394,
                            48.876949848110215,
                            2.400601391217022,
                            48.879995794367346,
                        ),
                        "coordinates": [
                            [2.398946662455969, 48.879995794367346],
                            [2.39991443798042, 48.87948780740504],
                            [2.400364492857791, 48.87925539533599],
                            [2.400413483767132, 48.87922723182556],
                            [2.400468782624613, 48.87918683574239],
                            [2.400515425784902, 48.87914194011655],
                            [2.400552579137029, 48.87909334388133],
                            [2.400579582312665, 48.87904191518794],
                            [2.400595950274893, 48.8789885716273],
                            [2.400601391217022, 48.878934265030736],
                            [2.400595810836236, 48.87887996530288],
                            [2.400579307114599, 48.878826639711086],
                            [2.400552173177815, 48.87877524120839],
                            [2.400514896177151, 48.87872668684458],
                            [2.400468138364674, 48.878681843282706],
                            [2.400412737288418, 48.87864150971359],
                            [2.400349680010004, 48.8786064069357],
                            [2.400280089667304, 48.8785771602016],
                            [2.400205211923112, 48.87855429195627],
                            [2.400126381005381, 48.87853821087598],
                            [2.400125478621855, 48.87853807055559],
                            [2.398259540776787, 48.8782478068546],
                            [2.396180252428219, 48.87779989610834],
                            [2.396009495768213, 48.877752622086724],
                            [2.395865363193245, 48.87770824222404],
                            [2.395807512648836, 48.877688105648225],
                            [2.39574858303244, 48.877665200855105],
                            [2.395687948573522, 48.87763928816025],
                            [2.395624397721492, 48.877609848825905],
                            [2.395510910692916, 48.877552716950895],
                            [2.395256106897456, 48.87741725806008],
                            [2.395135035918174, 48.87735787784807],
                            [2.395029704205668, 48.8773125409534],
                            [2.394929204505455, 48.877276148845475],
                            [2.394779462510296, 48.87723079769345],
                            [2.394613460467757, 48.8771871744769],
                            [2.394427535942647, 48.87714424076052],
                            [2.394203218833257, 48.87709771839959],
                            [2.393937409518323, 48.87704719218178],
                            [2.39371529930243, 48.87701086229458],
                            [2.393611509346691, 48.87699651658229],
                            [2.393511936231955, 48.87698466350442],
                            [2.393415801125448, 48.87697521009155],
                            [2.393322615082973, 48.87696810890761],
                            [2.393113217803316, 48.87695453873809],
                            [2.392983964817394, 48.876949848110215],
                        ],
                    },
                },
                1029: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.87275428773027, 2.3262131426544883],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 627.532108454,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325157783576582,
                            48.87009973284847,
                            2.327011609495396,
                            48.875453770461874,
                        ),
                        "coordinates": [
                            [2.325164109535879, 48.87009973284847],
                            [2.325158794515701, 48.87055660130001],
                            [2.325157808605802, 48.870572509605346],
                            [2.325157783576582, 48.87067556600467],
                            [2.325168780072074, 48.8707783688639],
                            [2.325190742125063, 48.87088040254114],
                            [2.325223557723617, 48.870981162767215],
                            [2.325267067197617, 48.87108014050491],
                            [2.32532105193954, 48.87117685066455],
                            [2.325374456124977, 48.87125619122765],
                            [2.325787279584193, 48.87182676889467],
                            [2.326869580370984, 48.87332790780029],
                            [2.326874725100023, 48.87333702995763],
                            [2.326923691384705, 48.87343530187859],
                            [2.326962028570453, 48.873535608569476],
                            [2.326989541307011, 48.873637448009745],
                            [2.327006096985115, 48.87374031583101],
                            [2.327011609495396, 48.873843696232164],
                            [2.327006055402925, 48.8739470764598],
                            [2.326989727511297, 48.87404868286292],
                            [2.326688762607036, 48.87515295067109],
                            [2.326688545276684, 48.87515362575125],
                            [2.326677430521275, 48.87520573745742],
                            [2.326677419658138, 48.8752583612869],
                            [2.326688512294226, 48.87531047558884],
                            [2.326710492582892, 48.87536106109493],
                            [2.326742932811529, 48.87540913961164],
                            [2.326785200261765, 48.875453770461874],
                        ],
                    },
                },
                1030: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.819384530063836, 2.3595144137457154],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 47.4053594243,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35935548759399,
                            48.819223349609054,
                            2.359705216746021,
                            48.81957651845754,
                        ),
                        "coordinates": [
                            [2.359705216746021, 48.819223349609054],
                            [2.359621606160516, 48.819278598692286],
                            [2.359546070729723, 48.81933870265323],
                            [2.359479252716618, 48.81940315499813],
                            [2.359421729588379, 48.81947140301733],
                            [2.359373982471305, 48.81954286560328],
                            [2.35935548759399, 48.81957651845754],
                        ],
                    },
                },
                1031: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.90934249489265, 2.398359503009341],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 1529.00283449,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.392287060995953,
                            48.90375993107707,
                            2.404409088781864,
                            48.91494975727622,
                        ),
                        "coordinates": [
                            [2.392287060995953, 48.90375993107707],
                            [2.396992808023321, 48.90807463826909],
                            [2.400622207369983, 48.91141199543863],
                            [2.404016166947592, 48.91458271306457],
                            [2.404409088781864, 48.91494975727622],
                        ],
                    },
                },
                1032: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.89182320303897, 2.3413860173616476],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 617.512236569,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.338760650528743,
                            48.88967407389343,
                            2.344657004117301,
                            48.89274636203567,
                        ),
                        "coordinates": [
                            [2.338760650528743, 48.88967407389343],
                            [2.33882900833165, 48.88975955722701],
                            [2.339710173970994, 48.891054715838116],
                            [2.33989393508455, 48.891259804523],
                            [2.340085862193064, 48.891434825819864],
                            [2.341717887847413, 48.892569651794126],
                            [2.341778801275678, 48.89260805226966],
                            [2.341856598667668, 48.89264760401148],
                            [2.34194072537428, 48.89268104900774],
                            [2.34203008621434, 48.89270795315058],
                            [2.342123516751676, 48.89272796559108],
                            [2.342219796877385, 48.89274082331133],
                            [2.342317672496586, 48.89274636203567],
                            [2.342415867918286, 48.892744507306126],
                            [2.342507010481851, 48.89273608289092],
                            [2.342551511143375, 48.89273035571602],
                            [2.344391130922904, 48.89249355410783],
                            [2.344657004117301, 48.89243959138138],
                        ],
                    },
                },
                1033: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.840742833480235, 2.330051984777186],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 395.525501032,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.329008926235403,
                            48.838964280710556,
                            2.330754192086216,
                            48.84221841361352,
                        ),
                        "coordinates": [
                            [2.330754192086216, 48.838964280710556],
                            [2.32976179506702, 48.841683602309246],
                            [2.329741995542461, 48.841730780903575],
                            [2.329703450190466, 48.841799456310895],
                            [2.329654576083834, 48.8418652066474],
                            [2.329595876530581, 48.84192735300288],
                            [2.329527952354369, 48.84198526287999],
                            [2.329451497935872, 48.842038340279466],
                            [2.329367303776522, 48.842086038306405],
                            [2.329276230472601, 48.84212786981772],
                            [2.329179211475028, 48.84216340474],
                            [2.329178427464263, 48.84216365846134],
                            [2.329008926235403, 48.84221841361352],
                        ],
                    },
                },
                1034: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.881176884401825, 2.3962767438772197],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 466.565451002,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.393445455116349,
                            48.879995794367346,
                            2.398946662455969,
                            48.88193199962059,
                        ),
                        "coordinates": [
                            [2.393445455116349, 48.88193199962059],
                            [2.393489368708808, 48.881924807142774],
                            [2.393669031900532, 48.88188737077528],
                            [2.396531901958131, 48.88129079048284],
                            [2.396635284473055, 48.8812661384833],
                            [2.39674641011633, 48.88123222906652],
                            [2.396852399607747, 48.881191796032276],
                            [2.396952373644788, 48.881145173111506],
                            [2.396997977791166, 48.8811207099893],
                            [2.398651494922837, 48.88016536156448],
                            [2.398946662455969, 48.879995794367346],
                        ],
                    },
                },
                1035: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.82585963205598, 2.3262333343641637],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 546.280251685,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325575636212245,
                            48.82341162898738,
                            2.327164649607824,
                            48.82818847631351,
                        ),
                        "coordinates": [
                            [2.325575636212245, 48.82341162898738],
                            [2.326420289001192, 48.826773839882144],
                            [2.326465282808807, 48.82693449009475],
                            [2.32652478816522, 48.82710904811702],
                            [2.326594889314913, 48.82728188407826],
                            [2.326675478336704, 48.82745271314928],
                            [2.32676641851418, 48.82762126472653],
                            [2.326867563706339, 48.82778725915759],
                            [2.326978752596576, 48.82795043109263],
                            [2.327099806165259, 48.82811051418114],
                            [2.327164649607824, 48.82818847631351],
                        ],
                    },
                },
                1036: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.892709402835834, 2.3488070877615983],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 317.336643509,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347765501718976,
                            48.89141683421295,
                            2.349738407022142,
                            48.89394138802911,
                        ),
                        "coordinates": [
                            [2.349738407022142, 48.89141683421295],
                            [2.349729200701145, 48.8914793285364],
                            [2.349728897251639, 48.891480911495634],
                            [2.349720567328859, 48.89152444745078],
                            [2.349693217242836, 48.89160936407824],
                            [2.349655188882796, 48.89169247261769],
                            [2.349606745890049, 48.89177318993179],
                            [2.349551335309663, 48.89184720809119],
                            [2.348233045833096, 48.893393136186425],
                            [2.347765501718976, 48.89394138802911],
                        ],
                    },
                },
                1037: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.89194595091504, 2.3472350138924027],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 393.468951197,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344657004117301,
                            48.89146500033268,
                            2.349815453218361,
                            48.89243959138138,
                        ),
                        "coordinates": [
                            [2.344657004117301, 48.89243959138138],
                            [2.345207725054369, 48.89232781179425],
                            [2.348052314276385, 48.89178908803659],
                            [2.349728897251639, 48.891480911495634],
                            [2.349729746163292, 48.891480754227466],
                            [2.349815453218361, 48.89146500033268],
                        ],
                    },
                },
                1038: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.899480120734864, 2.4389965699843223],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 2386.2278191,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.425326890166255,
                            48.89545467305271,
                            2.449263306463531,
                            48.90637477116928,
                        ),
                        "coordinates": [
                            [2.425326890166255, 48.89545467305271],
                            [2.426003880765198, 48.895562205942554],
                            [2.426171980647048, 48.89559578069606],
                            [2.426341129931883, 48.895633411642656],
                            [2.426511625292221, 48.8956751631498],
                            [2.426683840826958, 48.89572112873193],
                            [2.426858037773212, 48.89577137078438],
                            [2.427034909618848, 48.89582608686714],
                            [2.427215087199394, 48.895885467041644],
                            [2.427399448456041, 48.89594980506828],
                            [2.427578871201361, 48.8960156399372],
                            [2.427764376868691, 48.896086756480514],
                            [2.427957668786792, 48.896163805813096],
                            [2.428161918073017, 48.89624804678613],
                            [2.428570419050958, 48.8964231996653],
                            [2.429367404052019, 48.896775557796914],
                            [2.429700706263865, 48.89692044805776],
                            [2.430051829825129, 48.897067538257296],
                            [2.430298329976816, 48.897171840538434],
                            [2.430558806832673, 48.89727336963023],
                            [2.430735561677472, 48.89734309536984],
                            [2.430912303525909, 48.89740669107653],
                            [2.431077892335781, 48.89747029738592],
                            [2.431284403938469, 48.897544901221096],
                            [2.431477860758986, 48.89759745007558],
                            [2.43172709522301, 48.897651178792096],
                            [2.432463604994977, 48.89779030712257],
                            [2.434145013594557, 48.89814314610051],
                            [2.435145651054085, 48.89833474095251],
                            [2.436711783077486, 48.89866680221323],
                            [2.438034220801494, 48.89892305781449],
                            [2.438826560151466, 48.89906945023157],
                            [2.439584677755828, 48.8991999825009],
                            [2.440487527508028, 48.8993842139072],
                            [2.4428628109821, 48.89985519594244],
                            [2.443919421557349, 48.90010550149989],
                            [2.445277410674717, 48.90043028599416],
                            [2.446142443032237, 48.900637850264225],
                            [2.446328466172912, 48.900679350050495],
                            [2.44648845402727, 48.900719648258615],
                            [2.446723003500457, 48.9007791006177],
                            [2.446921932471891, 48.90083568381041],
                            [2.447117295916192, 48.900896786312],
                            [2.447314536495965, 48.900965239991],
                            [2.447511813699904, 48.90105085587537],
                            [2.447686785086569, 48.90113771842395],
                            [2.447874806168123, 48.90124050463143],
                            [2.448083313674344, 48.90135797887978],
                            [2.44823974614144, 48.90146814970864],
                            [2.448371989684412, 48.90157098928498],
                            [2.448504255368773, 48.901683633938916],
                            [2.448627252203181, 48.901808546362155],
                            [2.448754008834526, 48.9019506167151],
                            [2.448860307085543, 48.90209025367928],
                            [2.448947998595686, 48.90222378137511],
                            [2.449031986853907, 48.902364667156895],
                            [2.449101116659344, 48.90251169691977],
                            [2.44914789427106, 48.90264158558681],
                            [2.449196614297108, 48.90280824854146],
                            [2.449224826271649, 48.902950414506925],
                            [2.449249362546684, 48.90311097141499],
                            [2.449263306463531, 48.90331987566904],
                            [2.449222527537568, 48.90477964799448],
                            [2.449189904479336, 48.90637477116928],
                        ],
                    },
                },
                1039: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.81905046552828, 2.3735449196682854],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 859.369431593,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.369290587346029,
                            48.81593076305631,
                            2.377267201513739,
                            48.82135578381408,
                        ),
                        "coordinates": [
                            [2.377267201513739, 48.81593076305631],
                            [2.376592958165556, 48.81662556962008],
                            [2.3762274313143, 48.81701733756991],
                            [2.374970709448653, 48.81836901807783],
                            [2.374827720866205, 48.81850405441225],
                            [2.374659586359856, 48.81865088123252],
                            [2.374482853506878, 48.81879323607553],
                            [2.374297793223378, 48.81893089907535],
                            [2.374104687243925, 48.81906365761755],
                            [2.37390383902825, 48.81919130549726],
                            [2.373695554608325, 48.81931365001429],
                            [2.373480157720128, 48.81943049946114],
                            [2.373371995815122, 48.819485753544804],
                            [2.371047201969727, 48.82067011280455],
                            [2.370687823704638, 48.82085063748695],
                            [2.36985186009521, 48.82127055711877],
                            [2.369797861185291, 48.821286516208424],
                            [2.369741133155053, 48.82130097961369],
                            [2.369681905527059, 48.821313889181695],
                            [2.369620448726192, 48.821325183377894],
                            [2.369557016639239, 48.821334816769784],
                            [2.369491968184823, 48.82134273098841],
                            [2.369425649840339, 48.82134888288935],
                            [2.369358437893606, 48.821353242077414],
                            [2.369290587346029, 48.82135578381408],
                        ],
                    },
                },
                1040: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.88041601129155, 2.3374204723106384],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 482.401508152,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.337080012192856,
                            48.87842525852037,
                            2.337825539238269,
                            48.88251938564386,
                        ),
                        "coordinates": [
                            [2.337595081445481, 48.87842525852037],
                            [2.337203000410095, 48.878801309006825],
                            [2.337186978135304, 48.87881681386057],
                            [2.337144902832308, 48.87886609106296],
                            [2.33711272610995, 48.878918512273344],
                            [2.337090977081359, 48.87897321706807],
                            [2.337080012192856, 48.87902930629307],
                            [2.337080012264386, 48.87908586003382],
                            [2.337090976885227, 48.87914194927552],
                            [2.337112726908441, 48.8791966539035],
                            [2.337113288162254, 48.87919776589032],
                            [2.337813088139251, 48.880736244381474],
                            [2.33782006982977, 48.88076871923699],
                            [2.337825539238269, 48.88083294476614],
                            [2.337820072838611, 48.88089717006033],
                            [2.337803735409103, 48.88096058697649],
                            [2.337776734746425, 48.8810223998512],
                            [2.337739410703073, 48.88108182993698],
                            [2.337732348587124, 48.88109127883025],
                            [2.337364510382619, 48.88178360179828],
                            [2.337279811030496, 48.88196563802012],
                            [2.337225993816525, 48.88208725533571],
                            [2.337224877456049, 48.882090007406404],
                            [2.337180808267031, 48.882198670718445],
                            [2.337144521485869, 48.88230011768719],
                            [2.337085136498658, 48.88244269088155],
                            [2.337081683878512, 48.88251938564386],
                        ],
                    },
                },
                1041: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.88681939503095, 2.2901195664276623],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 499.06782016,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.288083633048504,
                            48.88576554913601,
                            2.292582314102913,
                            48.88870601977514,
                        ),
                        "coordinates": [
                            [2.292582314102913, 48.885793105231],
                            [2.292416460463367, 48.885776642271026],
                            [2.292249317693157, 48.88576744256982],
                            [2.292081620174687, 48.88576554913601],
                            [2.291914100062745, 48.8857709680963],
                            [2.291747487189086, 48.8857836758896],
                            [2.291582513166301, 48.885803618391954],
                            [2.291419897815131, 48.88583070633941],
                            [2.291260351782214, 48.88586482343737],
                            [2.291104575276742, 48.885905819158204],
                            [2.290953245712849, 48.88595351496313],
                            [2.290807028656619, 48.88600770166868],
                            [2.290666558699732, 48.88606814203115],
                            [2.290532454435511, 48.8861345726333],
                            [2.290405300745193, 48.886206702880045],
                            [2.290285651488234, 48.8862842177115],
                            [2.290174033606104, 48.886366776727826],
                            [2.290070933388176, 48.88645402130173],
                            [2.289976799296438, 48.88654556740033],
                            [2.289892047272883, 48.88664101640799],
                            [2.289835687579624, 48.886713781707854],
                            [2.289528668650469, 48.88713526809282],
                            [2.288558747233346, 48.88818408465499],
                            [2.288083633048504, 48.88870601977514],
                        ],
                    },
                },
                1042: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.884391164698044, 2.3012056245249255],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 524.461702107,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.297724346480178,
                            48.883809201233376,
                            2.304674440528396,
                            48.88489625515051,
                        ),
                        "coordinates": [
                            [2.304674440528396, 48.883809201233376],
                            [2.303232757426102, 48.884105101285044],
                            [2.302141165668999, 48.8842988157152],
                            [2.29932207912629, 48.88465470920833],
                            [2.299094269082507, 48.88468593167263],
                            [2.298169017617476, 48.8848113870885],
                            [2.298084194595178, 48.88482288694978],
                            [2.298003210729854, 48.884835062176975],
                            [2.297862022173537, 48.88486217656773],
                            [2.297724346480178, 48.88489625515051],
                        ],
                    },
                },
                1043: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3bis",
                        "rer": 0,
                        "extcode": "100110103:3B",
                        "geo_point_2d": [48.87023574306186, 2.4030929519721695],
                        "indice_lig": "3b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01386",
                        "navette": 0,
                        "idrefliga": "A01549",
                        "shape_leng": 462.397393741,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.401561774610831,
                            48.86844023643111,
                            2.404514942379104,
                            48.872101442131545,
                        ),
                        "coordinates": [
                            [2.401561774610831, 48.86844023643111],
                            [2.402876369713208, 48.869992102032434],
                            [2.40412458619085, 48.87138337499257],
                            [2.404324724161916, 48.871690959625376],
                            [2.404514942379104, 48.872101442131545],
                        ],
                    },
                },
                1044: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.876192365384064, 2.335214895200358],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 393.664233778,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332543027297523,
                            48.87602621160099,
                            2.337886487705904,
                            48.876334823563695,
                        ),
                        "coordinates": [
                            [2.332543027297523, 48.87631796226447],
                            [2.332693279700885, 48.876328268146004],
                            [2.332965854436896, 48.876334823563695],
                            [2.333313129243283, 48.87632354056346],
                            [2.336904039271934, 48.87607912076946],
                            [2.337290274223867, 48.87605832111619],
                            [2.337886487705904, 48.87602621160099],
                        ],
                    },
                },
                1045: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.890394402870896, 2.286546567215459],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 437.955611802,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.285009501382414,
                            48.88870601977514,
                            2.288083633048504,
                            48.89208278596665,
                        ),
                        "coordinates": [
                            [2.288083633048504, 48.88870601977514],
                            [2.285009501382414, 48.89208278596665],
                        ],
                    },
                },
                1046: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.87427950779824, 2.3378997778944957],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 362.426172743,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.335599675289124,
                            48.87368465719511,
                            2.34019988438517,
                            48.87487434337737,
                        ),
                        "coordinates": [
                            [2.335599675289124, 48.87368465719511],
                            [2.339481405082566, 48.874688549396076],
                            [2.34019988438517, 48.87487434337737],
                        ],
                    },
                },
                1047: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.883352096989746, 2.306863672114731],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 336.86708456,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.304674440528396,
                            48.88289191745413,
                            2.309052264550479,
                            48.883809201233376,
                        ),
                        "coordinates": [
                            [2.309052264550479, 48.88289191745413],
                            [2.305425448753597, 48.8836550519825],
                            [2.304674440528396, 48.883809201233376],
                        ],
                    },
                },
                1048: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.96820640618312, 2.329563826993754],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2292.27150128,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.323367369423834,
                            48.95987163649979,
                            2.338524070645141,
                            48.9760542531305,
                        ),
                        "coordinates": [
                            [2.32609015753849, 48.95987163649979],
                            [2.324885630232892, 48.96076982868086],
                            [2.324571202075725, 48.961026764774104],
                            [2.324285678592874, 48.961286082271954],
                            [2.324018214026023, 48.961562057256074],
                            [2.323804941054537, 48.96186420909687],
                            [2.323653101596296, 48.962144953733834],
                            [2.323526551115186, 48.96243521832882],
                            [2.32345421960038, 48.96266124737491],
                            [2.323392724389629, 48.962901553974454],
                            [2.323367369423834, 48.96312520947326],
                            [2.323370909353959, 48.963386936511526],
                            [2.323406962418852, 48.963693875855114],
                            [2.323479157749756, 48.9639794051549],
                            [2.323580261005653, 48.96426255786572],
                            [2.323735571127393, 48.96454571665097],
                            [2.323916179734658, 48.96482887839174],
                            [2.324107644110294, 48.96506445343938],
                            [2.324317178915503, 48.96529051410366],
                            [2.324598989257063, 48.965530857954995],
                            [2.324906099623052, 48.965759305956404],
                            [2.325292715948479, 48.96598776159834],
                            [2.32566488971572, 48.966175765892196],
                            [2.326102114516491, 48.96635901503515],
                            [2.326589940313568, 48.966525613560286],
                            [2.327446352769263, 48.96681834442656],
                            [2.327923342359423, 48.966999211779054],
                            [2.328346129488286, 48.96718007309296],
                            [2.328696643555899, 48.96735616871943],
                            [2.329036314637615, 48.967544160100424],
                            [2.329365144468706, 48.9677583213095],
                            [2.329668676877239, 48.96798437767777],
                            [2.329928847129441, 48.96820567216525],
                            [2.330196241987498, 48.968460277233376],
                            [2.330460021564683, 48.968741053312165],
                            [2.334724277539246, 48.97337615805659],
                            [2.335143519601112, 48.97382586077935],
                            [2.335396513383135, 48.97408283224838],
                            [2.335682040432722, 48.97433742401675],
                            [2.336003713630905, 48.97459439582541],
                            [2.336390449475247, 48.97485612402674],
                            [2.336842248107739, 48.97512974896363],
                            [2.337883211512192, 48.97569840494845],
                            [2.338524070645141, 48.9760542531305],
                        ],
                    },
                },
                1049: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.98940490744247, 2.3617927853946363],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1756.98324336,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.353407245869684,
                            48.984315962065935,
                            2.368684562796334,
                            48.996006830493926,
                        ),
                        "coordinates": [
                            [2.353407245869684, 48.984315962065935],
                            [2.353757288256642, 48.98451021557755],
                            [2.360689271665839, 48.98834209199464],
                            [2.362765100830239, 48.98949561924234],
                            [2.363416078162131, 48.98985950816034],
                            [2.363817530110666, 48.990102106668836],
                            [2.364175590152148, 48.990330437599106],
                            [2.364544510621891, 48.99057780155343],
                            [2.364855575633539, 48.99080376191301],
                            [2.365184736257229, 48.99105826994945],
                            [2.365513909887416, 48.99132943366328],
                            [2.365922685925408, 48.991693368807674],
                            [2.366233809964462, 48.99200022371598],
                            [2.366505149146215, 48.992278536297285],
                            [2.366729466309284, 48.99252117097596],
                            [2.367008076768097, 48.99285420501942],
                            [2.36727223330656, 48.99319676052654],
                            [2.367489362082486, 48.993498877874025],
                            [2.368003310338213, 48.99431485299605],
                            [2.368191568426409, 48.994688358895914],
                            [2.368332785243835, 48.99500477160592],
                            [2.368466783972825, 48.9953378430455],
                            [2.368571835309858, 48.99563523045974],
                            [2.368669666441447, 48.99595165605619],
                            [2.368684562796334, 48.996006830493926],
                        ],
                    },
                },
                1050: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.79529174311868, 2.325973218588077],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 839.473827031,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.322201633670121,
                            48.793336296236205,
                            2.328136923064751,
                            48.79889250008067,
                        ),
                        "coordinates": [
                            [2.322201633670121, 48.793336296236205],
                            [2.322372018006576, 48.793350702252205],
                            [2.322622450853271, 48.79337950973075],
                            [2.322913713662139, 48.793420011823045],
                            [2.323191365056307, 48.79346410928622],
                            [2.323452682138062, 48.793515397909076],
                            [2.32372080275085, 48.79357388101565],
                            [2.324069221829623, 48.79366024952615],
                            [2.324393140631845, 48.79374931253022],
                            [2.324699364992649, 48.79384826524168],
                            [2.325038250073296, 48.79397599636455],
                            [2.325332220808229, 48.794101924187],
                            [2.325634353113746, 48.79425393055649],
                            [2.32593784513973, 48.79443021690212],
                            [2.326174645893281, 48.794589410134435],
                            [2.326419610078367, 48.794774682101426],
                            [2.326601966685242, 48.79494376229435],
                            [2.326693146192296, 48.79502650302575],
                            [2.326874140659553, 48.795210869426136],
                            [2.32707009987894, 48.79544739518492],
                            [2.327177603844868, 48.79558499292998],
                            [2.327369469873212, 48.79588716491342],
                            [2.327478323636789, 48.79609400678965],
                            [2.327559961289141, 48.7962720692388],
                            [2.327676964118055, 48.796591320749364],
                            [2.327715054082233, 48.79671362517258],
                            [2.327840191846614, 48.797222623837314],
                            [2.327981612552328, 48.79804097435622],
                            [2.328011528983057, 48.798216334954105],
                            [2.328099927647174, 48.79868216533868],
                            [2.328136923064751, 48.79889250008067],
                        ],
                    },
                },
                1051: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.82979372430994, 2.309836683742124],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 773.56316375,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.305534669653895,
                            48.82779554349536,
                            2.314122323459022,
                            48.83182565048562,
                        ),
                        "coordinates": [
                            [2.305534669653895, 48.82779554349536],
                            [2.305872264966219, 48.827945152635095],
                            [2.305918938258286, 48.827965160388835],
                            [2.306104077002321, 48.82805147335063],
                            [2.310404110216645, 48.83005601362815],
                            [2.313512851383361, 48.831509020218036],
                            [2.313587667871101, 48.83154398742904],
                            [2.314122323459022, 48.83182565048562],
                        ],
                    },
                },
                1052: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.84050518001824, 2.3045295861034547],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 548.800074958,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.301107516242396,
                            48.839516585402485,
                            2.307948677974289,
                            48.84150552236008,
                        ),
                        "coordinates": [
                            [2.301107516242396, 48.839516585402485],
                            [2.301406790816113, 48.83961332411134],
                            [2.301686346307207, 48.83970696733172],
                            [2.302286264754095, 48.839880085493675],
                            [2.30303577058561, 48.84007393391877],
                            [2.304686850617788, 48.84054054410961],
                            [2.30631623341385, 48.84100712314518],
                            [2.307285807902157, 48.84130354239608],
                            [2.307948677974289, 48.84150552236008],
                        ],
                    },
                },
                1053: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.9416979122256, 2.361787033976952],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 1242.01491864,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.359398261032672,
                            48.93652685258673,
                            2.364541763486513,
                            48.945845657765744,
                        ),
                        "coordinates": [
                            [2.359398261032672, 48.93652685258673],
                            [2.359563252388028, 48.93676072640993],
                            [2.359738142184725, 48.93699145856642],
                            [2.359922785309825, 48.937218869281864],
                            [2.360117040736358, 48.93744277880237],
                            [2.360320751004835, 48.93766301088218],
                            [2.360533759977898, 48.937879391979486],
                            [2.360755900555823, 48.93809175119086],
                            [2.360986994654176, 48.938299922050085],
                            [2.36122686414489, 48.938503740787944],
                            [2.361295754833718, 48.93856015482556],
                            [2.361300111064774, 48.93856424639507],
                            [2.361440112838086, 48.93870218065233],
                            [2.361570850542994, 48.93884400603711],
                            [2.361692070790665, 48.93898945414208],
                            [2.361803547625925, 48.939138245014306],
                            [2.361905066016263, 48.93929009785838],
                            [2.361996432849041, 48.93944472479972],
                            [2.36207747557849, 48.93960182997795],
                            [2.362148039441219, 48.93976111402822],
                            [2.362207990198308, 48.93992227319623],
                            [2.362236509203866, 48.940011977215775],
                            [2.36227704440983, 48.94013528026241],
                            [2.362311274546096, 48.94033606509914],
                            [2.362316488617106, 48.94051985468395],
                            [2.362292701774738, 48.94072135326865],
                            [2.362232234948993, 48.940938317631215],
                            [2.361992767767454, 48.941504915638156],
                            [2.361827485707312, 48.941989157927864],
                            [2.361698048034318, 48.94249671474283],
                            [2.361610420578727, 48.94300819799866],
                            [2.361553395936302, 48.94344366244529],
                            [2.361557888232408, 48.94456814770218],
                            [2.361557060205588, 48.944662852543665],
                            [2.361567950357916, 48.9447675406191],
                            [2.361600509437781, 48.94486746640205],
                            [2.361658359954847, 48.944979283103514],
                            [2.361745107355167, 48.94508633367693],
                            [2.361828226237524, 48.945162454894955],
                            [2.361954701755993, 48.945257600822224],
                            [2.362088390591295, 48.94532657105861],
                            [2.362240136844826, 48.94538840072584],
                            [2.362373809668139, 48.9454264399092],
                            [2.362518316140434, 48.94545733963848],
                            [2.364541763486513, 48.945845657765744],
                        ],
                    },
                },
                1054: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.919416682719934, 2.290187655449192],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 980.812056225,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.286279577529783,
                            48.9163823099221,
                            2.294685111702555,
                            48.92310377966602,
                        ),
                        "coordinates": [
                            [2.294685111702555, 48.9163823099221],
                            [2.294494620101476, 48.916516464892545],
                            [2.294255390095281, 48.91669437065093],
                            [2.294042757059334, 48.916831434106356],
                            [2.293316289424921, 48.91725718023927],
                            [2.292355071497763, 48.917773286449695],
                            [2.290906484027062, 48.918636425977475],
                            [2.290188787686607, 48.919094253223015],
                            [2.288001431194491, 48.920917896540566],
                            [2.287911506844065, 48.920993357886815],
                            [2.287726847129177, 48.92115693465886],
                            [2.287551109199382, 48.92132472705951],
                            [2.287384518435299, 48.921496523331136],
                            [2.287227285279156, 48.92167210712999],
                            [2.287079605221875, 48.921851258425],
                            [2.286941664286126, 48.922033751731796],
                            [2.286839680533838, 48.92218014678576],
                            [2.286279577529783, 48.92310377966602],
                        ],
                    },
                },
                1055: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3bis",
                        "rer": 0,
                        "extcode": "100110103:3B",
                        "geo_point_2d": [48.87464033284401, 2.4055595964300465],
                        "indice_lig": "3b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01386",
                        "navette": 0,
                        "idrefliga": "A01549",
                        "shape_leng": 581.124702892,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.404514942379104,
                            48.872101442131545,
                            2.40672924554309,
                            48.87711051176336,
                        ),
                        "coordinates": [
                            [2.404514942379104, 48.872101442131545],
                            [2.40565243467852, 48.874922981593386],
                            [2.406452130961275, 48.87675740213674],
                            [2.406593408251267, 48.87694798523512],
                            [2.40672924554309, 48.87711051176336],
                        ],
                    },
                },
                1056: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.551489104389844, 3.2946261826903953],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1653.67622259,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.287312848478531,
                            48.54559534692547,
                            3.302871222591063,
                            48.555591556048306,
                        ),
                        "coordinates": [
                            [3.287312848478531, 48.54559534692547],
                            [3.287568655372128, 48.545741331629586],
                            [3.287781074265248, 48.545871752151996],
                            [3.28805412293034, 48.54605652197306],
                            [3.288350727669155, 48.5462689730041],
                            [3.288585861797545, 48.54645406016901],
                            [3.288813437506623, 48.546668888605055],
                            [3.289182919080543, 48.54700932945987],
                            [3.289633144769486, 48.5474642056814],
                            [3.290091196706864, 48.54790282654034],
                            [3.290595938057459, 48.54837432830119],
                            [3.2911091399494, 48.54886284297508],
                            [3.291656039296536, 48.549413126548004],
                            [3.292305833014094, 48.5500308897694],
                            [3.292758326298606, 48.550459654026724],
                            [3.293304969496752, 48.550994643779305],
                            [3.293691263768697, 48.551361010152284],
                            [3.294175877368175, 48.55183896093851],
                            [3.294671146706245, 48.55230692775362],
                            [3.295108729768593, 48.55273311149466],
                            [3.295594355034449, 48.55312111553125],
                            [3.295987032983331, 48.55339478899385],
                            [3.296443564877925, 48.5536778130241],
                            [3.296984386598901, 48.55397630953523],
                            [3.29748097495064, 48.55422841325643],
                            [3.298102629630461, 48.554502837086645],
                            [3.298666052427576, 48.554707603486236],
                            [3.298989294076225, 48.55482087434832],
                            [3.299546543826789, 48.55498611825275],
                            [3.299866457615405, 48.55506703976932],
                            [3.3002645573872, 48.55516184566639],
                            [3.300777998014327, 48.555268838196255],
                            [3.30156471015599, 48.55538985366729],
                            [3.302871222591063, 48.555591556048306],
                        ],
                    },
                },
                1057: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.876107623694594, 2.3959242185693768],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 505.295765625,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.393056091960662,
                            48.875416463015156,
                            2.398867596625601,
                            48.876967883509884,
                        ),
                        "coordinates": [
                            [2.393056091960662, 48.876806389212895],
                            [2.393146275381751, 48.87681863664649],
                            [2.393351167537197, 48.8768434210732],
                            [2.39432085769874, 48.87696071424622],
                            [2.394379178684613, 48.87696607164043],
                            [2.394466946613937, 48.876967883509884],
                            [2.394554344020682, 48.87696227755937],
                            [2.394639938160782, 48.87694934637032],
                            [2.394722320828332, 48.87692930046449],
                            [2.394800142411608, 48.876902471173715],
                            [2.394872122948305, 48.876869298104516],
                            [2.394937082153726, 48.87683032659113],
                            [2.394993951837693, 48.876786195166815],
                            [2.395020567402431, 48.876760876813115],
                            [2.395809393864412, 48.87595559304097],
                            [2.395863827430859, 48.875903175930645],
                            [2.395950621686761, 48.87583043711541],
                            [2.396045799249073, 48.87576241525539],
                            [2.396148774456742, 48.875699527365185],
                            [2.396258914255034, 48.87564216324068],
                            [2.396375535583679, 48.87559067555393],
                            [2.396497921704971, 48.87554538263411],
                            [2.396625318186338, 48.87550656215239],
                            [2.396756938321093, 48.87547445384775],
                            [2.396891972702594, 48.87544925687763],
                            [2.397029586557819, 48.875431124409],
                            [2.397168934659911, 48.87542017088847],
                            [2.397309154613739, 48.875416463015156],
                            [2.397424384813724, 48.87541885346384],
                            [2.39843885928013, 48.875461537932516],
                            [2.398867596625601, 48.875474456679164],
                        ],
                    },
                },
                1058: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.895388948025, 2.4704655160288738],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1400.08129764,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461119310778047,
                            48.89401251501928,
                            2.479793329961401,
                            48.89660443742263,
                        ),
                        "coordinates": [
                            [2.461119310778047, 48.89660443742263],
                            [2.461738202346405, 48.89656859352891],
                            [2.462168760216375, 48.89653865460159],
                            [2.462597686871036, 48.89650456189185],
                            [2.463041100390823, 48.89646443888365],
                            [2.463698059792477, 48.89639389562711],
                            [2.464405130247954, 48.896302694529815],
                            [2.465474273048822, 48.896143366243585],
                            [2.468911962696823, 48.89562312740705],
                            [2.472493893137381, 48.89509071815194],
                            [2.476065006438233, 48.894589139317695],
                            [2.478928382273328, 48.89414048098197],
                            [2.479793329961401, 48.89401251501928],
                        ],
                    },
                },
                1059: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.87951177074579, 2.5389265225235627],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2173.91762563,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.525434250765843,
                            48.877157839702775,
                            2.552881649780832,
                            48.88373428097723,
                        ),
                        "coordinates": [
                            [2.525434250765843, 48.88373428097723],
                            [2.526666287004969, 48.88322464273962],
                            [2.529893665234711, 48.88189251276156],
                            [2.532193078549603, 48.88094638425414],
                            [2.53263711346043, 48.880766017590894],
                            [2.533258374056588, 48.88052186468117],
                            [2.533787208099623, 48.880321963756685],
                            [2.534420641712197, 48.88009741051807],
                            [2.535060507629551, 48.87988882378437],
                            [2.53570041386419, 48.87969165420274],
                            [2.536810253929025, 48.87937564330709],
                            [2.53760020105514, 48.87917439357388],
                            [2.538355588221693, 48.87899223367205],
                            [2.538972613438071, 48.87885219000443],
                            [2.539638713895057, 48.878715863499934],
                            [2.540322132397052, 48.87858140561485],
                            [2.54108058223252, 48.878446808795324],
                            [2.541775614810747, 48.87833135645167],
                            [2.542626436694511, 48.878204198988534],
                            [2.543448481188119, 48.87809802464671],
                            [2.5444321247588, 48.87798964755984],
                            [2.545955286181782, 48.87784791717988],
                            [2.54833518545465, 48.87762083257569],
                            [2.552881649780832, 48.877157839702775],
                        ],
                    },
                },
                1060: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.891686890332686, 2.4962094717582097],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2467.88253877,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.479793329961401,
                            48.88907659470566,
                            2.512566821462173,
                            48.89401251501928,
                        ),
                        "coordinates": [
                            [2.479793329961401, 48.89401251501928],
                            [2.481197722405834, 48.893804725496125],
                            [2.482784825989295, 48.89358618952957],
                            [2.486294326270926, 48.89306533586322],
                            [2.489865193721433, 48.892576412576965],
                            [2.49315463000745, 48.8921163153306],
                            [2.496267288843588, 48.89168611101783],
                            [2.499755003990543, 48.891207702729695],
                            [2.501755019254608, 48.89093049383821],
                            [2.506235894697583, 48.89031483248706],
                            [2.50687858796131, 48.89022644904722],
                            [2.50855849299117, 48.88998777777983],
                            [2.508957648940871, 48.88992236626066],
                            [2.509392246574917, 48.88985137720946],
                            [2.509862766838769, 48.889763963817956],
                            [2.510292260577928, 48.88967870192147],
                            [2.510730698786668, 48.88958666904331],
                            [2.511151789939301, 48.889487047296036],
                            [2.511647841755376, 48.88936256437549],
                            [2.512112092573541, 48.88922480279171],
                            [2.512566821462173, 48.88907659470566],
                        ],
                    },
                },
                1061: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.872943803183254, 2.3809378322681547],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 680.820954198,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.376593684096822,
                            48.871848794661254,
                            2.385316215101792,
                            48.87388185415816,
                        ),
                        "coordinates": [
                            [2.376593684096822, 48.871848794661254],
                            [2.377029776704534, 48.8719936917602],
                            [2.377667996892694, 48.872192222482894],
                            [2.378662097400257, 48.872467904361415],
                            [2.379991043796697, 48.872812465195814],
                            [2.381393182685953, 48.87308796697833],
                            [2.382690709834244, 48.87335659492436],
                            [2.383559195582597, 48.8735080650316],
                            [2.384385794879732, 48.87361123856342],
                            [2.384560217040379, 48.87364973123738],
                            [2.384769585212634, 48.87370290323641],
                            [2.384974747612023, 48.873762787470504],
                            [2.38517520426707, 48.873829241095734],
                            [2.385316215101792, 48.87388185415816],
                        ],
                    },
                },
                1062: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.86877415717536, 2.3674449004816425],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 599.372228244,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.363826143977408,
                            48.86750342377884,
                            2.371094839731201,
                            48.86995751270301,
                        ),
                        "coordinates": [
                            [2.363826143977408, 48.86750342377884],
                            [2.364319375751504, 48.86770605158711],
                            [2.364951776992595, 48.867952448351076],
                            [2.365634688650188, 48.86820706407364],
                            [2.370558945305434, 48.869787327937246],
                            [2.371094839731201, 48.86995751270301],
                        ],
                    },
                },
                1063: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.93056577715358, 2.018818905070078],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 3875.60340782,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.999603609660236,
                            48.92749432052858,
                            2.041072289675926,
                            48.93948681080073,
                        ),
                        "coordinates": [
                            [1.999603609660236, 48.93948681080073],
                            [1.999745478814779, 48.93880673258692],
                            [1.999860332839626, 48.938381164256135],
                            [1.999956433436328, 48.938057853551705],
                            [2.000088777529168, 48.93771561386505],
                            [2.000217299794479, 48.93740429598073],
                            [2.000367538745524, 48.93708590414306],
                            [2.00052498252498, 48.936769910372384],
                            [2.000766180951774, 48.936351852996204],
                            [2.001061921934988, 48.93587922875607],
                            [2.001258908111934, 48.93558952511411],
                            [2.001492180159692, 48.93527375240844],
                            [2.001772641436504, 48.93492242967672],
                            [2.002074845731686, 48.93455927312396],
                            [2.002369585781313, 48.93423178392727],
                            [2.002762339087557, 48.93382843904429],
                            [2.003191250370267, 48.9334180621935],
                            [2.003539951811205, 48.933119281041144],
                            [2.003928485189991, 48.93280395666924],
                            [2.004367667103087, 48.93247450241822],
                            [2.004817502139509, 48.93217125332143],
                            [2.005361478288389, 48.93183020440016],
                            [2.005858137663208, 48.93154373923018],
                            [2.006340173391652, 48.93128340488281],
                            [2.006890970120898, 48.9309994725025],
                            [2.007405446844218, 48.93074636618486],
                            [2.007945165016606, 48.93049808646754],
                            [2.008513780312058, 48.93024750997885],
                            [2.009259712665592, 48.929940332446385],
                            [2.009983778343435, 48.92966163940012],
                            [2.010790986660044, 48.929368904471005],
                            [2.011558213243689, 48.92911411977606],
                            [2.012325340075177, 48.9288736071436],
                            [2.01305972765501, 48.928668685330386],
                            [2.013830172796917, 48.92847099771639],
                            [2.014705358833772, 48.92826884327863],
                            [2.015403277938154, 48.92811614985625],
                            [2.016166128380683, 48.9279731523932],
                            [2.017178270840227, 48.927809432896616],
                            [2.01813232326213, 48.927693130038854],
                            [2.019035633850587, 48.92760522962063],
                            [2.019953220732404, 48.92754353509037],
                            [2.021011493040057, 48.927503637068874],
                            [2.021946797439078, 48.92749432052858],
                            [2.022661654665784, 48.92751294519864],
                            [2.023361994446083, 48.92754342097989],
                            [2.024062214136317, 48.927592926031316],
                            [2.024733503113487, 48.927649486895945],
                            [2.025462388942178, 48.92773475231132],
                            [2.026162359721935, 48.927824694025766],
                            [2.026894640334668, 48.92794565111718],
                            [2.027554718119948, 48.928064028457506],
                            [2.028265175235255, 48.928211090112995],
                            [2.028957480750428, 48.92837475493428],
                            [2.029682109026624, 48.928567052182764],
                            [2.030323752556166, 48.92874960735206],
                            [2.031062604959402, 48.92898000696472],
                            [2.031783243750481, 48.929236524159506],
                            [2.032417330717282, 48.92947615106812],
                            [2.033202606317243, 48.92979469453686],
                            [2.033800465418992, 48.93005563156655],
                            [2.034358695409448, 48.930302185188765],
                            [2.035133032821583, 48.93064210246535],
                            [2.03703827540336, 48.93148465053155],
                            [2.038615843263528, 48.93217879336028],
                            [2.041072289675926, 48.93326540612854],
                        ],
                    },
                },
                1064: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.70076268372693, 2.397716409956707],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 3295.00360366,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.38352086738215,
                            48.6892154808985,
                            2.414358881169592,
                            48.70836643170258,
                        ),
                        "coordinates": [
                            [2.38352086738215, 48.6892154808985],
                            [2.383894028197155, 48.689634032941775],
                            [2.384278616175597, 48.69005873390678],
                            [2.385479790088652, 48.69125757124366],
                            [2.386523171967934, 48.692284898663],
                            [2.386761932936588, 48.69251329218662],
                            [2.386984944401149, 48.6927559967599],
                            [2.387365266967555, 48.69320524087359],
                            [2.387745152794411, 48.69362794858049],
                            [2.388110971545361, 48.69403335416916],
                            [2.388690680593495, 48.69468822343342],
                            [2.390584909277121, 48.69685051786862],
                            [2.391111294308735, 48.69745637388897],
                            [2.392306913714768, 48.69882088657027],
                            [2.393197881257704, 48.69982942744301],
                            [2.394097060252197, 48.70085864067013],
                            [2.394637125653265, 48.70147436674775],
                            [2.395057483727772, 48.7019489661446],
                            [2.395298292520537, 48.702201060675606],
                            [2.395532217123596, 48.70243173400354],
                            [2.395769717324348, 48.702645750579755],
                            [2.39597481521078, 48.70281457608702],
                            [2.396189406302, 48.70298235730664],
                            [2.396406557798256, 48.703133179000226],
                            [2.396643995910609, 48.70328770974431],
                            [2.39685984031959, 48.703420837713225],
                            [2.397072067759133, 48.70353493314181],
                            [2.397323839792489, 48.703651386682914],
                            [2.397561222941077, 48.70375594980878],
                            [2.397812974568241, 48.70385336675225],
                            [2.398075509274095, 48.70394839910329],
                            [2.398332908023177, 48.70402455212743],
                            [2.398620821477941, 48.70410647918709],
                            [2.398906191402911, 48.704181121433805],
                            [2.399219021531195, 48.704247570417955],
                            [2.399495884554309, 48.70429738448351],
                            [2.399902172445371, 48.704356642200516],
                            [2.400236535120796, 48.70439452450339],
                            [2.400719876289084, 48.70444226683377],
                            [2.401174884521062, 48.704479649740584],
                            [2.402661987861868, 48.70459196310277],
                            [2.403978447190441, 48.70469067441559],
                            [2.404503348506374, 48.70473318882034],
                            [2.404952769538661, 48.70478526444756],
                            [2.405391419191974, 48.70484448311557],
                            [2.405750977128509, 48.7048989887829],
                            [2.406106956968306, 48.704965392571495],
                            [2.406520475199899, 48.70504603495306],
                            [2.406955583215603, 48.70514093990563],
                            [2.407379928147749, 48.70525012367403],
                            [2.407894195455449, 48.70539256204712],
                            [2.40845165404197, 48.705570659368],
                            [2.408796934739997, 48.70568940573772],
                            [2.409196186853166, 48.705841428741955],
                            [2.409606251581351, 48.70601009721467],
                            [2.410059505998962, 48.706212047533896],
                            [2.41051999358486, 48.70644016305795],
                            [2.411113589335084, 48.70673005332934],
                            [2.414358881169592, 48.70836643170258],
                        ],
                    },
                },
                1065: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.041791667925565, 2.1187300111148657],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 2180.50810562,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.107233059674136,
                            49.033987636271455,
                            2.128263873923673,
                            49.04558799326531,
                        ),
                        "coordinates": [
                            [2.128263873923673, 49.033987636271455],
                            [2.128129194074634, 49.034113715787555],
                            [2.127001222509834, 49.03514131753568],
                            [2.126554371205225, 49.03555093473141],
                            [2.126148450092699, 49.035907090451964],
                            [2.125911377526481, 49.03612793351793],
                            [2.12554623049908, 49.036468101551904],
                            [2.12521636011758, 49.036808334727496],
                            [2.125137259772239, 49.03689919806773],
                            [2.124921739789295, 49.03715576938806],
                            [2.124701970925326, 49.03741818034744],
                            [2.124508532850205, 49.037707907023204],
                            [2.12440497701337, 49.03785768139787],
                            [2.124326846051249, 49.037970682918875],
                            [2.124059183968403, 49.03838472483637],
                            [2.123776786101228, 49.038804811006315],
                            [2.123509210313695, 49.03921103870588],
                            [2.123276559854186, 49.03955502910891],
                            [2.123100396882108, 49.03980470005338],
                            [2.122898114370557, 49.04008399728096],
                            [2.12250205708275, 49.04057156555514],
                            [2.121908172963902, 49.041253005346746],
                            [2.121542675220651, 49.041629116409815],
                            [2.121276213118279, 49.04187861479338],
                            [2.120950794296375, 49.042158576515476],
                            [2.120635065769966, 49.042411577662996],
                            [2.12029610305886, 49.04265913833664],
                            [2.119932502105776, 49.04290935003786],
                            [2.11951273202694, 49.04317743811158],
                            [2.119077985287255, 49.04342841147821],
                            [2.118628222981144, 49.043671260106215],
                            [2.118168981940748, 49.04389070806361],
                            [2.117752285473035, 49.04407876024903],
                            [2.117253422064275, 49.04428553856905],
                            [2.116779262196315, 49.044473477956316],
                            [2.11632440698335, 49.04462638000719],
                            [2.115877800296, 49.04476940466895],
                            [2.115450420487825, 49.04489537797772],
                            [2.115038154341169, 49.045006091655345],
                            [2.114254838940086, 49.04518712632793],
                            [2.113839944694883, 49.0452726509574],
                            [2.113425656976553, 49.045347331347266],
                            [2.11300892676945, 49.045412217757935],
                            [2.112633856150531, 49.04546364254553],
                            [2.112022053058747, 49.04552899151093],
                            [2.11138984248111, 49.04556911615135],
                            [2.110894539819698, 49.04558612667887],
                            [2.110754998510663, 49.04558675096887],
                            [2.110445627189619, 49.04558799326531],
                            [2.110005283062125, 49.045570484125804],
                            [2.109539658597023, 49.04554626751525],
                            [2.109099345927297, 49.04552209925562],
                            [2.108193440028024, 49.04546705174223],
                            [2.107233059674136, 49.04539401994291],
                        ],
                    },
                },
                1066: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84596980537092, 2.3843774283726638],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2079.37005688,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.373259976710645,
                            48.842509356152746,
                            2.395823588826127,
                            48.849117409522194,
                        ),
                        "coordinates": [
                            [2.395823588826127, 48.84823711041019],
                            [2.395317447775613, 48.848345901513525],
                            [2.39485291374797, 48.848442362137405],
                            [2.394753468858856, 48.84846309645121],
                            [2.39438293480749, 48.84854332074405],
                            [2.393975618667434, 48.848632554376],
                            [2.393418449942715, 48.84875243690588],
                            [2.393239991953595, 48.84879119530625],
                            [2.392956627589163, 48.84884349340391],
                            [2.392524766562436, 48.848921044461626],
                            [2.391989354898886, 48.84900628697254],
                            [2.391602393993325, 48.84905316917147],
                            [2.391185027088838, 48.84909060867554],
                            [2.390588486799669, 48.849117409522194],
                            [2.389982093654974, 48.84911403060866],
                            [2.389461227445747, 48.8490890841989],
                            [2.388972554752637, 48.84905740279139],
                            [2.388621303261493, 48.8490231318465],
                            [2.388246195434504, 48.84896281760558],
                            [2.387943079741865, 48.84888893859528],
                            [2.387564421711169, 48.84878322801927],
                            [2.387117217929758, 48.84863115054504],
                            [2.386592439065595, 48.84841248206107],
                            [2.386100389973109, 48.84815726029376],
                            [2.38574474352825, 48.84793222576395],
                            [2.385305056014745, 48.84760737329011],
                            [2.384989313768015, 48.847290513914416],
                            [2.384683099797264, 48.84693193111179],
                            [2.384304720052467, 48.84638008475368],
                            [2.383664029240761, 48.8454490784583],
                            [2.382957087020159, 48.84445197586756],
                            [2.382537924123199, 48.8439802995186],
                            [2.382178844531257, 48.84366476819367],
                            [2.381688896141165, 48.84333419029112],
                            [2.381032043714462, 48.84301697556601],
                            [2.380490345645952, 48.84283420251204],
                            [2.380069284264383, 48.84271903199726],
                            [2.379722334566101, 48.84264873021381],
                            [2.379362771565082, 48.84259201426206],
                            [2.378991571392292, 48.842550534028334],
                            [2.378630582890566, 48.84251933320322],
                            [2.378293430365041, 48.84251106473616],
                            [2.377863751363083, 48.842509356152746],
                            [2.377532874176594, 48.84252773384298],
                            [2.377253639357144, 48.84255054080351],
                            [2.376878949142934, 48.84261194603048],
                            [2.376488878809395, 48.84270341647721],
                            [2.375892141593777, 48.84286584908553],
                            [2.375188569238011, 48.84311263204697],
                            [2.374760331651485, 48.84330201766579],
                            [2.374756134440075, 48.84330387359257],
                            [2.374231143268418, 48.843596873153125],
                            [2.373916469806499, 48.84377257685145],
                            [2.373259976710645, 48.84413934985302],
                        ],
                    },
                },
                1067: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.077356465579214, 2.1902180994569003],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3024.8644252,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.17530420994616,
                            49.07046236344271,
                            2.200978026879316,
                            49.08930709608885,
                        ),
                        "coordinates": [
                            [2.17530420994616, 49.07046236344271],
                            [2.176502735182653, 49.070800828510784],
                            [2.17723567597815, 49.071015877714025],
                            [2.177399767025015, 49.07106466703065],
                            [2.179608192614743, 49.07171609196469],
                            [2.181123406166229, 49.07214711277687],
                            [2.18264000980854, 49.07257991387108],
                            [2.184155276543216, 49.07301089431915],
                            [2.185336860290723, 49.073351487144635],
                            [2.186610126684593, 49.07370657658923],
                            [2.186958872886292, 49.07380505390974],
                            [2.187523670157187, 49.07397665244145],
                            [2.187819031123659, 49.07407685512089],
                            [2.188281209806101, 49.07423662638641],
                            [2.189016876617136, 49.07448937306324],
                            [2.189730670975323, 49.074759450521285],
                            [2.190384129375513, 49.075019899659026],
                            [2.191213958322949, 49.07537796780438],
                            [2.191395765574382, 49.07546273068268],
                            [2.191697840368354, 49.07561329156911],
                            [2.192457737448099, 49.07602634120472],
                            [2.193224298779143, 49.07649200484572],
                            [2.193762501216803, 49.07688476001333],
                            [2.193895001677773, 49.076982046479586],
                            [2.194412585405919, 49.077408046821475],
                            [2.194734770147043, 49.07771330017156],
                            [2.195170155702176, 49.07816617295605],
                            [2.195413029641761, 49.07844434839856],
                            [2.195726746600739, 49.07884311254356],
                            [2.19589853035864, 49.07908972462166],
                            [2.196068883235101, 49.07935881620565],
                            [2.196123362377816, 49.07945690434504],
                            [2.196215983867895, 49.07962158450512],
                            [2.196338559986879, 49.079843854981476],
                            [2.196550909890396, 49.08027037059615],
                            [2.196764612401425, 49.08070408181002],
                            [2.197869890237941, 49.08296350063568],
                            [2.198083565392199, 49.08341519426123],
                            [2.1984075261658, 49.08408771308517],
                            [2.199153171729724, 49.08559234742135],
                            [2.199410836755904, 49.08614068948192],
                            [2.200078802745266, 49.08752785009951],
                            [2.200559892669533, 49.0885008521167],
                            [2.200781858852642, 49.08894265839431],
                            [2.200978026879316, 49.08930709608885],
                        ],
                    },
                },
                1068: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.94009088399499, 2.550616210006712],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 2485.82994821,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.534714974742524,
                            48.93628018565177,
                            2.566448016963,
                            48.94418106597472,
                        ),
                        "coordinates": [
                            [2.534714974742524, 48.93628018565177],
                            [2.535340370734915, 48.93642662289816],
                            [2.535962129245601, 48.93656592503689],
                            [2.537332129872436, 48.93686095462459],
                            [2.537917744457916, 48.93699079325262],
                            [2.538601003272541, 48.93715138676137],
                            [2.540918322655967, 48.93769453308393],
                            [2.543683993892404, 48.938343894483246],
                            [2.544656530410048, 48.93857531034312],
                            [2.545538668164763, 48.93878071039493],
                            [2.54620751804285, 48.93893890513631],
                            [2.548626257665795, 48.93951026287049],
                            [2.549765126932029, 48.93977463943],
                            [2.550694334226996, 48.93999656709117],
                            [2.5514427700577, 48.940175997923625],
                            [2.551959857044305, 48.94031065011705],
                            [2.552824110079801, 48.94054220031732],
                            [2.554205472265827, 48.9409083884766],
                            [2.556928501227496, 48.94163602933851],
                            [2.559405672499717, 48.94229270450478],
                            [2.560599066535213, 48.94260683298388],
                            [2.561441695287231, 48.942831221353366],
                            [2.562157770590603, 48.943024923588446],
                            [2.563249943759487, 48.94331305085653],
                            [2.564117913392034, 48.94354450877578],
                            [2.564797843137347, 48.94372874544],
                            [2.566448016963, 48.94418106597472],
                        ],
                    },
                },
                1069: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.986643147363, 1.7091422868963677],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1107.77054667,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.703016134167223,
                            48.983654507541004,
                            1.715210986447546,
                            48.989502508030505,
                        ),
                        "coordinates": [
                            [1.715210986447546, 48.983654507541004],
                            [1.714876713955381, 48.983788316553415],
                            [1.713600965108449, 48.98433101806053],
                            [1.712641222925728, 48.984754079445864],
                            [1.712284705578705, 48.98493058933371],
                            [1.711411070835274, 48.98540407886332],
                            [1.708445222531689, 48.9871303023471],
                            [1.707197842322636, 48.987799197118015],
                            [1.706378210456435, 48.98818807925704],
                            [1.705757817330407, 48.98845115279417],
                            [1.704968622676812, 48.98871963626297],
                            [1.70427599037051, 48.9889759579842],
                            [1.703016134167223, 48.989502508030505],
                        ],
                    },
                },
                1070: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98791766527209, 1.9696860535955014],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2400.43254417,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.955479247534605,
                            48.98144596941029,
                            1.983143352086498,
                            48.992613881639144,
                        ),
                        "coordinates": [
                            [1.955479247534605, 48.992613881639144],
                            [1.958410208905752, 48.99185031963231],
                            [1.959493512426805, 48.99155885623629],
                            [1.960660072257731, 48.99125337848831],
                            [1.961823005469121, 48.990947879632216],
                            [1.96358732940907, 48.99048015461005],
                            [1.964826506702233, 48.99012728583892],
                            [1.966297780375974, 48.9896776003621],
                            [1.967337946717621, 48.98934071587559],
                            [1.96833111582847, 48.9890012887529],
                            [1.96919027253338, 48.9886923570231],
                            [1.970093117239252, 48.988340729064085],
                            [1.971137547301475, 48.98790864868745],
                            [1.972330708894163, 48.987405650985686],
                            [1.973948342561463, 48.98669698356846],
                            [1.974996768279388, 48.98620301726783],
                            [1.97661871831096, 48.985387255040436],
                            [1.97832460287864, 48.98445514381108],
                            [1.979243090830599, 48.98392028118249],
                            [1.980368620212517, 48.98324567510205],
                            [1.981472547679287, 48.98255433420734],
                            [1.983143352086498, 48.98144596941029],
                        ],
                    },
                },
                1071: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.93233098386442, 2.440228169391454],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 2149.90241574,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.425791425559954,
                            48.93073957031752,
                            2.454766382765777,
                            48.93276675757436,
                        ),
                        "coordinates": [
                            [2.425791425559954, 48.93073957031752],
                            [2.428528152212983, 48.93121178102294],
                            [2.430449835739028, 48.931570316835035],
                            [2.431520359358567, 48.931769964868174],
                            [2.433019732132433, 48.93203392978435],
                            [2.433756318582966, 48.93215836933001],
                            [2.434427421807771, 48.93226561039017],
                            [2.435154163202631, 48.93237280145819],
                            [2.436119854435582, 48.93250134014763],
                            [2.436673064985291, 48.932565545240536],
                            [2.437330991420099, 48.93262534376327],
                            [2.438231110321013, 48.932689237300416],
                            [2.439023182895177, 48.932729502346184],
                            [2.439838142529295, 48.93275895904921],
                            [2.440751239867408, 48.93276675757436],
                            [2.441906477903701, 48.93275707894835],
                            [2.443500240424713, 48.93274051079149],
                            [2.446327784323606, 48.932714121405446],
                            [2.447404462303159, 48.93269799355768],
                            [2.448147360264926, 48.932697272787074],
                            [2.448936099679803, 48.93270728607904],
                            [2.450788480793716, 48.93272486113904],
                            [2.453118638538401, 48.93272683062279],
                            [2.454766382765777, 48.93270621869947],
                        ],
                    },
                },
                1072: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98018510759822, 2.3459656582574127],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 1425.13783518,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.338524070645141,
                            48.9760542531305,
                            2.353407245869684,
                            48.984315962065935,
                        ),
                        "coordinates": [
                            [2.338524070645141, 48.9760542531305],
                            [2.353407245869684, 48.984315962065935],
                        ],
                    },
                },
                1073: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.95568359366042, 3.0755669614314884],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 7364.99319997,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.026111294286066,
                            48.95045023942411,
                            3.124909020747328,
                            48.95947688730028,
                        ),
                        "coordinates": [
                            [3.026111294286066, 48.959164063062694],
                            [3.028700339714932, 48.959193407815334],
                            [3.033946724675614, 48.95925150744609],
                            [3.036649619814603, 48.95928211943009],
                            [3.045346964591205, 48.95937421664601],
                            [3.054158214157287, 48.959469220501],
                            [3.054984354226941, 48.95947688730028],
                            [3.055621642034194, 48.95946860277293],
                            [3.056213158979291, 48.95944346934821],
                            [3.056849887850346, 48.959396634586696],
                            [3.057479831969095, 48.95933056502685],
                            [3.058148361922584, 48.95923426809352],
                            [3.058836055738936, 48.95911428921469],
                            [3.059672640722872, 48.95894625269894],
                            [3.06121578830073, 48.958615266944285],
                            [3.066240709199769, 48.95754471309947],
                            [3.069939562176635, 48.95675655335456],
                            [3.070561972051204, 48.95662407343478],
                            [3.071194070612321, 48.956487243887274],
                            [3.071657652190732, 48.95639004146513],
                            [3.072286557106454, 48.95625750909456],
                            [3.072928493980969, 48.95612703193325],
                            [3.073473295421727, 48.95602501605137],
                            [3.073933935981002, 48.95594923815714],
                            [3.077012249740354, 48.95545238059269],
                            [3.081461644560318, 48.954742722850455],
                            [3.084169028973149, 48.95430512396928],
                            [3.084719225170145, 48.954228242540474],
                            [3.085264437290602, 48.95415638618454],
                            [3.085876360562912, 48.954096069899954],
                            [3.086699114158378, 48.9540511101323],
                            [3.089247190882916, 48.953947043576704],
                            [3.0902886086884, 48.95390854339689],
                            [3.09109494003099, 48.95387824503366],
                            [3.091878339602421, 48.95384887334951],
                            [3.093106365654227, 48.95378500340465],
                            [3.093460417621238, 48.95376102214178],
                            [3.094061543767709, 48.95371114683146],
                            [3.094882389551664, 48.953635015922984],
                            [3.095445459643547, 48.95357465254015],
                            [3.095937671185737, 48.95351142518824],
                            [3.097449368054931, 48.953299843715264],
                            [3.10039458288502, 48.95289379700788],
                            [3.103709434527481, 48.95242926121986],
                            [3.104407135569551, 48.952332250555486],
                            [3.105514713256113, 48.95216891903031],
                            [3.106833856894506, 48.951948789644746],
                            [3.107848778818346, 48.95175569470668],
                            [3.108771581874937, 48.95156240587081],
                            [3.110671654770488, 48.951167342277074],
                            [3.111304695356839, 48.951036599676925],
                            [3.111977229784618, 48.95091534073006],
                            [3.112423718937953, 48.950842354777215],
                            [3.112889737442756, 48.950771518644686],
                            [3.113397872871054, 48.95071248301526],
                            [3.11399370778419, 48.95064846998484],
                            [3.114476089073836, 48.95060687892097],
                            [3.114938396771792, 48.950575416264996],
                            [3.115476616716733, 48.95054676620583],
                            [3.116558532170003, 48.95051607115102],
                            [3.118356037172339, 48.95047880705511],
                            [3.11937238606898, 48.95046019309725],
                            [3.119852731638431, 48.95045023942411],
                            [3.120520409928101, 48.95045232628279],
                            [3.120968117863072, 48.95045758289322],
                            [3.121426100081013, 48.950472761382535],
                            [3.122393058777563, 48.95052941163141],
                            [3.122856415399733, 48.95056453520726],
                            [3.123439016891862, 48.95062382107558],
                            [3.124103346364604, 48.95070058178538],
                            [3.124909020747328, 48.95081998757722],
                        ],
                    },
                },
                1074: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [49.02582179995458, 2.0854330285425045],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 3199.48278728,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.078284568034463,
                            49.014133684983044,
                            2.091284826714122,
                            49.03646398072535,
                        ),
                        "coordinates": [
                            [2.079534939997374, 49.03646398072535],
                            [2.080630001149099, 49.035737394307],
                            [2.080866042491933, 49.03558504482191],
                            [2.082089687714947, 49.03488273695746],
                            [2.082608216810195, 49.03458532855274],
                            [2.083715127867986, 49.03396727747421],
                            [2.085266399054012, 49.03310199153051],
                            [2.086471977933504, 49.032431971975036],
                            [2.087653404473906, 49.03182396298089],
                            [2.088109707639061, 49.03157842727302],
                            [2.088577135965932, 49.03133606941406],
                            [2.088909010527916, 49.03115659802896],
                            [2.089230299877848, 49.03095838270194],
                            [2.089540462554628, 49.03074865824792],
                            [2.089860131583701, 49.03049951689638],
                            [2.090190951038185, 49.0301909135544],
                            [2.090503909471019, 49.02983468530743],
                            [2.090729820570972, 49.02951871767404],
                            [2.090915940711826, 49.02920028563079],
                            [2.091102600190946, 49.02877240220407],
                            [2.09120916929756, 49.02844190295927],
                            [2.091257649225088, 49.028151727236015],
                            [2.091284826714122, 49.027778226909874],
                            [2.09126486096519, 49.02742604039942],
                            [2.09123328898478, 49.0272261076615],
                            [2.091169575734375, 49.0269404500029],
                            [2.091069790340119, 49.026633298933156],
                            [2.090948286030414, 49.02632848133386],
                            [2.09080509517082, 49.02601885922264],
                            [2.090622451782062, 49.025640150706785],
                            [2.0897081715483, 49.0239678770201],
                            [2.089367338866619, 49.02339133901145],
                            [2.08915179808744, 49.02308393661535],
                            [2.088939651991842, 49.022821749101894],
                            [2.088720081508918, 49.02259761557288],
                            [2.088467998049307, 49.022363891604115],
                            [2.088259011867006, 49.02219450423433],
                            [2.088028330661265, 49.022022690971745],
                            [2.087743454737624, 49.021836481311986],
                            [2.087440481655731, 49.02165261348585],
                            [2.087112127813076, 49.02148058373926],
                            [2.086697126961103, 49.02127267595191],
                            [2.086238788952715, 49.02105039333346],
                            [2.085859890840416, 49.02085921436126],
                            [2.085488264964706, 49.02066091356204],
                            [2.084914668611982, 49.020340820748515],
                            [2.08427264509612, 49.019961090340075],
                            [2.081239292224347, 49.01818888125132],
                            [2.080748757798128, 49.01790702035803],
                            [2.080373766846072, 49.017668246014985],
                            [2.080020509629092, 49.01742476035577],
                            [2.079743134769261, 49.01719809931921],
                            [2.079487493825301, 49.01696672850629],
                            [2.079293140001917, 49.01677594262866],
                            [2.079084567036572, 49.016537539993905],
                            [2.078872676435314, 49.01624202174061],
                            [2.078718306011328, 49.01601563543059],
                            [2.078578678793434, 49.01573693577666],
                            [2.07846081767029, 49.01544639168923],
                            [2.078379108064912, 49.01516068325311],
                            [2.078326163420755, 49.014908353596375],
                            [2.078284568034463, 49.01456087315983],
                            [2.078289810937325, 49.014249190822],
                            [2.078306591409993, 49.014133684983044],
                        ],
                    },
                },
                1075: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.8717501836472, 2.2901470273475435],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 858.162232066,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.285335094686169,
                            48.86979855646068,
                            2.294490592832005,
                            48.874238476656075,
                        ),
                        "coordinates": [
                            [2.285335094686169, 48.86979855646068],
                            [2.285472074441788, 48.86981330514845],
                            [2.285606810753325, 48.869835277333756],
                            [2.285738429038159, 48.86986433020432],
                            [2.285866079873734, 48.869900275234926],
                            [2.285988929429481, 48.86994287992847],
                            [2.286059023264315, 48.869971108542956],
                            [2.293847236974745, 48.873277765156075],
                            [2.293902803116133, 48.8733040866631],
                            [2.293966455697641, 48.87334226241801],
                            [2.294022184063418, 48.873385493376],
                            [2.294069074806563, 48.87343307087449],
                            [2.294106357301265, 48.873484212447075],
                            [2.294133419820363, 48.873538079904776],
                            [2.294149814879736, 48.8735937874607],
                            [2.294155278083373, 48.873650419827634],
                            [2.294152946541562, 48.87368705160723],
                            [2.294149463693696, 48.87374173630178],
                            [2.294154895562316, 48.873810843261055],
                            [2.294171248876999, 48.87387919711197],
                            [2.294198342934435, 48.873946050329906],
                            [2.294235882328528, 48.87401066820171],
                            [2.294283456741172, 48.874072344113415],
                            [2.294340543630234, 48.874130402264655],
                            [2.294406519037151, 48.874184204927985],
                            [2.294480657427667, 48.87423316413967],
                            [2.294490592832005, 48.874238476656075],
                        ],
                    },
                },
                1076: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.749008291026875, 2.4185503110281754],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 900.737445286,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.417520977896491,
                            48.745072166893884,
                            2.419295469321415,
                            48.75288655674139,
                        ),
                        "coordinates": [
                            [2.417520977896491, 48.745072166893884],
                            [2.417559694134845, 48.74544278037653],
                            [2.417595364677613, 48.74563789761012],
                            [2.417725869572168, 48.74613350845395],
                            [2.4177936903694, 48.746349079793504],
                            [2.417929698571815, 48.7466944082515],
                            [2.41812683826887, 48.74712111819496],
                            [2.418276276263958, 48.747417952017706],
                            [2.418475450665925, 48.747766142519914],
                            [2.41889971977792, 48.74846535830931],
                            [2.419038315363134, 48.748727936264515],
                            [2.41909250837702, 48.748862091012214],
                            [2.419185230450416, 48.74913495356007],
                            [2.419241479165207, 48.74939117360156],
                            [2.419278572259143, 48.74961866253804],
                            [2.41929383748868, 48.74980390156787],
                            [2.419295469321415, 48.74996756799391],
                            [2.419278185604111, 48.750178200573124],
                            [2.419235022955878, 48.75041994623721],
                            [2.419203423280662, 48.75055133411644],
                            [2.419178299335482, 48.75065739495887],
                            [2.419156643455977, 48.750719459979486],
                            [2.419099773387582, 48.75086878091593],
                            [2.419036105714618, 48.75101900504099],
                            [2.418875794858536, 48.75144249373356],
                            [2.418463407659742, 48.75226736495072],
                            [2.418113047325797, 48.75288655674139],
                        ],
                    },
                },
                1077: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89664213176752, 2.4597416844786677],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 202.215865307,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.458363412015992,
                            48.89660443742263,
                            2.461119310778047,
                            48.896652451144085,
                        ),
                        "coordinates": [
                            [2.458363412015992, 48.896652451144085],
                            [2.459993941439638, 48.896649064128454],
                            [2.46018274150254, 48.896644334185666],
                            [2.460390875309296, 48.89663911910006],
                            [2.461119310778047, 48.89660443742263],
                        ],
                    },
                },
                1078: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.87631484467661, 2.2969175291008295],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 426.131985703,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.295567369745454,
                            48.874613927042155,
                            2.298310373761529,
                            48.87797270141955,
                        ),
                        "coordinates": [
                            [2.295567369745454, 48.874613927042155],
                            [2.29565204969576, 48.87467241310784],
                            [2.29572844392757, 48.874735670834305],
                            [2.295795932155491, 48.87480319025819],
                            [2.295852653649448, 48.8748726257571],
                            [2.296133880772596, 48.87525617523049],
                            [2.297791401286339, 48.877516648582386],
                            [2.297829726335717, 48.877566494438],
                            [2.297908159644132, 48.87765620670134],
                            [2.29799588929949, 48.877742090971914],
                            [2.298092490097375, 48.87782372924215],
                            [2.298197487450596, 48.87790072479874],
                            [2.298310373761529, 48.87797270141955],
                        ],
                    },
                },
                1079: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.8539425566956, 2.396430506811422],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 606.812022107,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.394561944549864,
                            48.85151027816436,
                            2.398302344267162,
                            48.85637735808082,
                        ),
                        "coordinates": [
                            [2.394561944549864, 48.85637735808082],
                            [2.395366730253959, 48.855329178554115],
                            [2.396066250424606, 48.85441805924036],
                            [2.396911280822292, 48.8533109440524],
                            [2.397808230033287, 48.852149902807696],
                            [2.398302344267162, 48.85151027816436],
                        ],
                    },
                },
                1080: {
                    "attributes": {
                        "reseau": "FUNICULAIRE MONTMARTRE",
                        "val": 1,
                        "metro": 0,
                        "res_com": "FUNICULAIRE MONTMARTRE",
                        "rer": 0,
                        "extcode": "100110100:FUN",
                        "geo_point_2d": [48.88517104321466, 2.3426048452974206],
                        "indice_lig": "FUN",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Navette",
                        "tramway": 0,
                        "idrefligc": "C01385",
                        "navette": 1,
                        "idrefliga": "A01548",
                        "shape_leng": 109.289581629,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.342549653258489,
                            48.884680973727825,
                            2.342660037336352,
                            48.8856611127015,
                        ),
                        "coordinates": [
                            [2.342549653258489, 48.8856611127015],
                            [2.342660037336352, 48.884680973727825],
                        ],
                    },
                },
                1081: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.881638610601115, 2.3182336382412885],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 463.640346692,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.315176626220464,
                            48.881150028474686,
                            2.321274926766349,
                            48.88222690081934,
                        ),
                        "coordinates": [
                            [2.315176626220464, 48.881150028474686],
                            [2.315589074648051, 48.881201814478665],
                            [2.315593903328888, 48.88120241855634],
                            [2.315754069188332, 48.88121863085074],
                            [2.316520614754836, 48.88130015528808],
                            [2.317007215732988, 48.88137389875281],
                            [2.321274926766349, 48.88222690081934],
                        ],
                    },
                },
                1082: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.87984042535727, 2.3064882367164516],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 455.597464239,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.303528725370108,
                            48.879214134245586,
                            2.309451167991542,
                            48.8804494561385,
                        ),
                        "coordinates": [
                            [2.303528725370108, 48.879214134245586],
                            [2.304570753849386, 48.879434720743376],
                            [2.308567602480712, 48.88028302899543],
                            [2.308682363043526, 48.880306488110165],
                            [2.308773835955807, 48.880325186474046],
                            [2.309451167991542, 48.8804494561385],
                        ],
                    },
                },
                1083: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.83516358569444, 2.203728357002271],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 1745.98014057,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.200721257947835,
                            48.8272387754095,
                            2.209938360929272,
                            48.840517349814164,
                        ),
                        "coordinates": [
                            [2.200721257947835, 48.8272387754095],
                            [2.200961674989991, 48.828525941410284],
                            [2.201011184720281, 48.8288506396897],
                            [2.201013852316059, 48.82887132637703],
                            [2.201017877705458, 48.82889381371847],
                            [2.20103398391032, 48.82898106224347],
                            [2.201091691210765, 48.82929677715687],
                            [2.201161483197946, 48.8296763555138],
                            [2.201170876139126, 48.829728525231864],
                            [2.201181629975536, 48.82978069594199],
                            [2.201205767498219, 48.829920113078174],
                            [2.201251404308715, 48.83016746816239],
                            [2.20128361680769, 48.8303428652195],
                            [2.201326561826797, 48.83057852724593],
                            [2.20137893256546, 48.83085466792961],
                            [2.201408438807621, 48.83102376724514],
                            [2.201431241458818, 48.83115329009304],
                            [2.201460771208559, 48.83131429591918],
                            [2.201497041507713, 48.831500489084185],
                            [2.201570839075754, 48.83191244590117],
                            [2.201631230999146, 48.832245250661146],
                            [2.201687609378266, 48.832551071193336],
                            [2.20174800853441, 48.83288207697096],
                            [2.201803056318744, 48.83317710564945],
                            [2.201847332099155, 48.8334262575317],
                            [2.201903346434993, 48.833867869772206],
                            [2.201998554608239, 48.834423735830875],
                            [2.202071239480442, 48.8347466627161],
                            [2.202171187212725, 48.83506332632614],
                            [2.202271308131837, 48.835316140945395],
                            [2.202341714433056, 48.83547539672392],
                            [2.202548995907909, 48.83589830109822],
                            [2.202776875189194, 48.83626187680524],
                            [2.202926778311895, 48.83650930588347],
                            [2.20303990252678, 48.83666290528936],
                            [2.203226345695151, 48.83689511065908],
                            [2.203357847892823, 48.83705087371665],
                            [2.203435446003965, 48.83714661351711],
                            [2.203729820944669, 48.83745532043108],
                            [2.204051247864232, 48.83775834705329],
                            [2.204469864853319, 48.8381121659406],
                            [2.204877828163665, 48.838407438230334],
                            [2.205053770935466, 48.83852684747304],
                            [2.20527614237085, 48.838673433020745],
                            [2.205649714075431, 48.83889228743554],
                            [2.205934777811782, 48.83905036476533],
                            [2.206285392814635, 48.839228145581515],
                            [2.206497063820767, 48.8393340300196],
                            [2.206637474461507, 48.83939771921528],
                            [2.206851337174804, 48.83949289872554],
                            [2.207175979179549, 48.83962544926493],
                            [2.207363642258585, 48.83970049783722],
                            [2.207576896671259, 48.83978020264471],
                            [2.207856952896149, 48.8398702354335],
                            [2.208696666682112, 48.84013208396308],
                            [2.208854158946474, 48.840179775591274],
                            [2.209284475922477, 48.84031051075772],
                            [2.209938360929272, 48.840517349814164],
                        ],
                    },
                },
                1084: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.97028780889855, 2.3813228872928898],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1980.06913723,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.372103138402569,
                            48.96375542962029,
                            2.390593652641838,
                            48.976747848293925,
                        ),
                        "coordinates": [
                            [2.390593652641838, 48.976747848293925],
                            [2.389074440432978, 48.975694505290775],
                            [2.386774020009822, 48.97407758080194],
                            [2.384350850926132, 48.972444006492786],
                            [2.382029040997859, 48.970817480279564],
                            [2.379645899112885, 48.96913382405482],
                            [2.377631751779957, 48.967721233206106],
                            [2.375828980372487, 48.96645332426752],
                            [2.374388358663936, 48.965409627836195],
                            [2.372300682997742, 48.96389115417943],
                            [2.372103138402569, 48.96375542962029],
                        ],
                    },
                },
                1085: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.80551435006896, 2.1599646976370726],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1268.99470657,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.151500117388586,
                            48.80533082762157,
                            2.168520392870995,
                            48.80637744816838,
                        ),
                        "coordinates": [
                            [2.151500117388586, 48.80637744816838],
                            [2.152164018998779, 48.80616428401233],
                            [2.152946841798407, 48.805951308631016],
                            [2.153646602021987, 48.80578342216126],
                            [2.15437352064191, 48.805646202149454],
                            [2.15502196442568, 48.80553572742709],
                            [2.155726144107613, 48.80544692118562],
                            [2.155967198749822, 48.80542392288856],
                            [2.156600432102512, 48.80537636491192],
                            [2.157068848752969, 48.805351924731816],
                            [2.157657043449016, 48.805334865555444],
                            [2.158292835433872, 48.805332266630394],
                            [2.158522919843482, 48.80533082762157],
                            [2.159271637524482, 48.80534818396782],
                            [2.160108848139583, 48.80536567263949],
                            [2.160630242987768, 48.80537367369589],
                            [2.161236034129933, 48.80538540004907],
                            [2.162019649160445, 48.80539189427478],
                            [2.162902330857863, 48.80540863880485],
                            [2.163635108431909, 48.80541871394147],
                            [2.164171497817305, 48.805430569395746],
                            [2.165650902374453, 48.80544787228554],
                            [2.166867964596255, 48.80546228359888],
                            [2.168031905928778, 48.80548379771743],
                            [2.168322353775233, 48.80548928968287],
                            [2.168520392870995, 48.80549303372225],
                        ],
                    },
                },
                1086: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.80907493779271, 2.2972621903964243],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 638.405958817,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.294091244318829,
                            48.807169846835585,
                            2.300357474428133,
                            48.8108247885412,
                        ),
                        "coordinates": [
                            [2.294091244318829, 48.807169846835585],
                            [2.29530958184332, 48.80787022927825],
                            [2.296311325220149, 48.80844439163221],
                            [2.297321659794309, 48.80902430682497],
                            [2.297834342862214, 48.809318589018204],
                            [2.298136660465713, 48.80950312123065],
                            [2.298318644177575, 48.809634118694326],
                            [2.298502367195921, 48.80979653740197],
                            [2.298841697785762, 48.81012263632423],
                            [2.299349251423578, 48.810607978336684],
                            [2.299489323013662, 48.810742969747096],
                            [2.299535001698856, 48.810770410756994],
                            [2.299586618827286, 48.81079279417644],
                            [2.299642901749171, 48.81080956930927],
                            [2.299702464305819, 48.81082032240315],
                            [2.299763840715371, 48.8108247885412],
                            [2.299825519519108, 48.810822859036016],
                            [2.299885981734633, 48.81081457985479],
                            [2.299943738923454, 48.81080015633909],
                            [2.300357474428133, 48.810601094494544],
                        ],
                    },
                },
                1087: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.79227783065741, 2.2680779793586323],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 823.067528679,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263389166015155,
                            48.79033300192819,
                            2.272650344658386,
                            48.79446888451292,
                        ),
                        "coordinates": [
                            [2.263389166015155, 48.79033300192819],
                            [2.264464560298661, 48.79076939943397],
                            [2.265597031107258, 48.79122041682464],
                            [2.267475310164635, 48.79196156019427],
                            [2.269052326789753, 48.79258922312717],
                            [2.269613998736213, 48.79286037302103],
                            [2.27106284773482, 48.79356527961088],
                            [2.271411398081907, 48.79375302070399],
                            [2.271906184872095, 48.79404397933159],
                            [2.272308149287348, 48.7942760673659],
                            [2.272650344658386, 48.79446888451292],
                        ],
                    },
                },
                1088: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78428775419463, 2.234042023229531],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 480.004806768,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.230983558938873,
                            48.783500975704136,
                            2.237132704968193,
                            48.78490216629835,
                        ),
                        "coordinates": [
                            [2.230983558938873, 48.783500975704136],
                            [2.231802231731005, 48.783727651707515],
                            [2.232387833054097, 48.7838703911448],
                            [2.233077894464239, 48.784060440386426],
                            [2.233709300100347, 48.784223456878216],
                            [2.234392490119503, 48.78439156153648],
                            [2.234700750118008, 48.78448967718565],
                            [2.234912956305219, 48.78455671634373],
                            [2.235089391090652, 48.784607343753294],
                            [2.235396632216457, 48.78467689444661],
                            [2.235507245328274, 48.78469759182933],
                            [2.235981413417268, 48.78477867994971],
                            [2.236238676423403, 48.7848183997965],
                            [2.236494651769574, 48.78484764070569],
                            [2.237132704968193, 48.78490216629835],
                        ],
                    },
                },
                1089: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.952339237541736, 2.3177733607397712],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 391.099653533,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.315403612112168,
                            48.951708783590085,
                            2.320216521669494,
                            48.95316824676445,
                        ),
                        "coordinates": [
                            [2.315403612112168, 48.95316824676445],
                            [2.315640553911899, 48.953035404228],
                            [2.315945185832528, 48.9528594827643],
                            [2.316049189266547, 48.95281314113229],
                            [2.316164477528183, 48.95276559040084],
                            [2.31628151579723, 48.95272128153344],
                            [2.316400847524606, 48.952680008092685],
                            [2.316522855419788, 48.95264163826168],
                            [2.316647991870628, 48.95260603702178],
                            [2.316776406245474, 48.95257316474716],
                            [2.31690833554313, 48.95254296342559],
                            [2.31891194127027, 48.95201473847945],
                            [2.319918767344206, 48.951769195344454],
                            [2.320216521669494, 48.951708783590085],
                        ],
                    },
                },
                1090: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78221284472658, 2.243403202380946],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 619.480846327,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.23983201762499,
                            48.780730969150184,
                            2.246977649164128,
                            48.78368721522512,
                        ),
                        "coordinates": [
                            [2.23983201762499, 48.780730969150184],
                            [2.240881385493957, 48.78118443473426],
                            [2.241833681785723, 48.78156647865029],
                            [2.243093697678425, 48.78208491820407],
                            [2.244470141399594, 48.782646916176574],
                            [2.246399492281132, 48.78345035769807],
                            [2.246977649164128, 48.78368721522512],
                        ],
                    },
                },
                1091: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.820858927540556, 2.3508212734533824],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 16.755342402,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350710129390121,
                            48.82084126211055,
                            2.350932878064576,
                            48.82087335522631,
                        ),
                        "coordinates": [
                            [2.350710129390121, 48.82084126211055],
                            [2.35082790489736, 48.820861535033195],
                            [2.350932878064576, 48.82087335522631],
                        ],
                    },
                },
                1092: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.782513904168475, 2.2117816014262495],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 461.355671278,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.209129227294876,
                            48.78140432088544,
                            2.214433502050177,
                            48.78362462215807,
                        ),
                        "coordinates": [
                            [2.209129227294876, 48.78140432088544],
                            [2.210902684423633, 48.78214353182834],
                            [2.212583756423375, 48.7828514076817],
                            [2.214433502050177, 48.78362462215807],
                        ],
                    },
                },
                1093: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.10807034910381, 2.364028073180766],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2239.15674596,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.361270555241057,
                            49.09840026247686,
                            2.368253547610188,
                            49.11662788250494,
                        ),
                        "coordinates": [
                            [2.361270555241057, 49.09840026247686],
                            [2.362062590776779, 49.09956315003074],
                            [2.362824110582927, 49.100671748793864],
                            [2.36302719039292, 49.10097387691294],
                            [2.363458734315033, 49.101592403412866],
                            [2.363643684749181, 49.10186122437385],
                            [2.364086153341926, 49.10254874665016],
                            [2.36423849673914, 49.10281567122578],
                            [2.364384338418487, 49.103115431989465],
                            [2.364504085955837, 49.10340806016973],
                            [2.364578150812803, 49.10365644460161],
                            [2.364637000765387, 49.10391197044147],
                            [2.364676269162893, 49.104146085801695],
                            [2.364704653762687, 49.104355936037415],
                            [2.364713473413738, 49.10457292904414],
                            [2.364694166146042, 49.1050383299128],
                            [2.364650829736394, 49.105306728004024],
                            [2.364585736554953, 49.10555229070535],
                            [2.36447068962991, 49.10590207922699],
                            [2.363760567705506, 49.10755825937952],
                            [2.363534704893292, 49.10808224073455],
                            [2.362861414029594, 49.10959992809776],
                            [2.362733307733037, 49.109963994705666],
                            [2.362676894709396, 49.11020669801297],
                            [2.362633522758999, 49.11043512374182],
                            [2.362609704593121, 49.11063356526742],
                            [2.362601165096047, 49.11093764437324],
                            [2.36263244696275, 49.11116233131592],
                            [2.362662684569032, 49.11135656706981],
                            [2.362702506731108, 49.111541808269415],
                            [2.362743041910457, 49.111714529157005],
                            [2.362817781896, 49.11193746172329],
                            [2.362897338387295, 49.11213798091797],
                            [2.363066002338962, 49.11246078113935],
                            [2.363208591072139, 49.11269006257599],
                            [2.363359387763146, 49.11289506208049],
                            [2.363545811998252, 49.11311803831664],
                            [2.363813090931222, 49.11339495196457],
                            [2.364085833801011, 49.1136376908166],
                            [2.364366785601948, 49.11385614723502],
                            [2.364625805889736, 49.114048529150864],
                            [2.364998572180839, 49.114311025571034],
                            [2.365331593911791, 49.114536660651076],
                            [2.365757824856041, 49.114851299427535],
                            [2.366466382942405, 49.115354711909866],
                            [2.368132993855112, 49.116541309626264],
                            [2.368253547610188, 49.11662788250494],
                        ],
                    },
                },
                1094: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.901431666290144, 2.355692365820211],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 4541.6145148,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352105705816552,
                            48.88076895833307,
                            2.362665598830465,
                            48.9181138030661,
                        ),
                        "coordinates": [
                            [2.357115334947971, 48.88076895833307],
                            [2.357224397262525, 48.880988328674505],
                            [2.357445256042034, 48.88147424717533],
                            [2.357621439110227, 48.881871422258904],
                            [2.35774914983309, 48.882202947538026],
                            [2.357832083614176, 48.88244802807216],
                            [2.357892965018944, 48.88266961754862],
                            [2.357929690564065, 48.882926256465836],
                            [2.357949099642765, 48.883182353683466],
                            [2.357987231679084, 48.88377480212628],
                            [2.35797711174668, 48.88415874398148],
                            [2.35776859674016, 48.88584618505727],
                            [2.35771581244326, 48.886426164530604],
                            [2.357672776648871, 48.88704955877387],
                            [2.357622547948076, 48.88773481642559],
                            [2.357514564652608, 48.88836298218558],
                            [2.357406615422702, 48.88907680292586],
                            [2.35732021320441, 48.88955268597487],
                            [2.357212161668813, 48.89002857305947],
                            [2.35702476399322, 48.890604406366215],
                            [2.356866168146696, 48.89102319759584],
                            [2.356671515411152, 48.89151813463572],
                            [2.356188407767444, 48.89257940363092],
                            [2.355726862337239, 48.893459837040616],
                            [2.355279785936971, 48.894483026670464],
                            [2.354955332043211, 48.89535391720402],
                            [2.354760668682024, 48.89592023004912],
                            [2.354573252941464, 48.89658647405615],
                            [2.354400303679799, 48.89735264752717],
                            [2.354321102683396, 48.89790466678896],
                            [2.354243027550289, 48.89844847923835],
                            [2.354148424680226, 48.89948338357097],
                            [2.353906105047874, 48.90043998621057],
                            [2.353278831413479, 48.90253866092549],
                            [2.352860729356008, 48.90428515788201],
                            [2.352396188268603, 48.90767816593894],
                            [2.352342196388262, 48.90815880031198],
                            [2.352273798625216, 48.90875602475913],
                            [2.352210056592285, 48.90957789507191],
                            [2.352177649040248, 48.909832489206664],
                            [2.352152445463866, 48.91004187447977],
                            [2.352130844433447, 48.910232225568045],
                            [2.352109255641117, 48.91045588612407],
                            [2.352105705816552, 48.91065337184244],
                            [2.352123814122804, 48.91085323371987],
                            [2.352174431988979, 48.91111495570954],
                            [2.352253936570604, 48.91140760357833],
                            [2.352383984953965, 48.91172165915649],
                            [2.352510404644672, 48.911959574937896],
                            [2.352672926938664, 48.91221890023702],
                            [2.352806550119313, 48.91240209040332],
                            [2.352958591601471, 48.91258752650817],
                            [2.35307378633796, 48.912728022078205],
                            [2.353250726293694, 48.91290168899872],
                            [2.353413217384326, 48.913042045626646],
                            [2.353608203857694, 48.913194294391865],
                            [2.353886235519248, 48.91339411698931],
                            [2.354084823170449, 48.91351543297699],
                            [2.354352010214886, 48.913665290853174],
                            [2.354843052535474, 48.91391266391197],
                            [2.355391879240095, 48.91421237233093],
                            [2.356077914021508, 48.91457153659441],
                            [2.357258650022995, 48.915211372236534],
                            [2.359176046589199, 48.916226987040226],
                            [2.361057416606341, 48.91723781822859],
                            [2.362665598830465, 48.9181138030661],
                        ],
                    },
                },
                1095: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.04923516685733, 2.115634104154819],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1621.37120524,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.107233059674136,
                            49.04539401994291,
                            2.122735908273571,
                            49.05510176049028,
                        ),
                        "coordinates": [
                            [2.107233059674136, 49.04539401994291],
                            [2.108136477562507, 49.04551189824994],
                            [2.108740469746825, 49.04561541338749],
                            [2.109232236145258, 49.04572346070429],
                            [2.109691383926692, 49.04584096050178],
                            [2.110045600330533, 49.04595111052167],
                            [2.110262426900967, 49.0460276793396],
                            [2.110941680988262, 49.0462978858753],
                            [2.112086523335931, 49.046866418921624],
                            [2.112592143336525, 49.04711724077516],
                            [2.113378651037956, 49.047529451110684],
                            [2.115749294818896, 49.048734071786484],
                            [2.116048234886255, 49.0488857271039],
                            [2.11674795521901, 49.04924721447272],
                            [2.117195745839415, 49.04948838555114],
                            [2.117639847013364, 49.049746205520144],
                            [2.118018869659705, 49.04998724318897],
                            [2.11834727982538, 49.05021390645694],
                            [2.118685888003766, 49.05045641849523],
                            [2.119218937350977, 49.050889085065876],
                            [2.119690735073348, 49.051323309934894],
                            [2.119950270856517, 49.05157505979811],
                            [2.120051396568381, 49.051687421730406],
                            [2.12032205009989, 49.051988340151055],
                            [2.120909893430428, 49.0527960519349],
                            [2.121177645922871, 49.05320662637218],
                            [2.121400590726058, 49.05353887922251],
                            [2.121403308274942, 49.05354337986806],
                            [2.121505229437814, 49.05370364262508],
                            [2.121883523535363, 49.05418276809344],
                            [2.122051018320342, 49.05436743394621],
                            [2.122400970914177, 49.05475837514959],
                            [2.122417319959997, 49.05477459313916],
                            [2.122424126367783, 49.05478269888339],
                            [2.122735908273571, 49.05510176049028],
                        ],
                    },
                },
                1096: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.918807223348814, 2.2652069343553594],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1410.3565588,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25934570305215,
                            48.91424647429558,
                            2.271598750389755,
                            48.923918626560365,
                        ),
                        "coordinates": [
                            [2.271598750389755, 48.91424647429558],
                            [2.270532945876196, 48.91500938112961],
                            [2.270139074361969, 48.915287536801934],
                            [2.269723507352697, 48.91559184934864],
                            [2.269235674719603, 48.91593656632342],
                            [2.268101078561584, 48.91667110755421],
                            [2.266174994851476, 48.91797857288676],
                            [2.26402825131479, 48.919509524027916],
                            [2.262242762116137, 48.92081463095848],
                            [2.261671656306205, 48.92124492007583],
                            [2.261266744071509, 48.92159679535038],
                            [2.260916014822611, 48.92192729234508],
                            [2.260362777223492, 48.922462274479905],
                            [2.25988531362348, 48.9230187198303],
                            [2.259639252488354, 48.92336593882241],
                            [2.25942563414716, 48.92374410948801],
                            [2.25934570305215, 48.923918626560365],
                        ],
                    },
                },
                1097: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.91289833026332, 2.33503943873511],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 263.390219068,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.333924890479715,
                            48.911964897880885,
                            2.336177340425487,
                            48.91380735381973,
                        ),
                        "coordinates": [
                            [2.333924890479715, 48.911964897880885],
                            [2.334008448012597, 48.91206150201879],
                            [2.334101318271287, 48.912154337596455],
                            [2.334203113315469, 48.91224301573478],
                            [2.334313402671717, 48.912327165303815],
                            [2.334384938278545, 48.91237630884501],
                            [2.336177340425487, 48.91380735381973],
                        ],
                    },
                },
                1098: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.927538935302024, 2.2594319486728183],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 812.556138388,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25890223580021,
                            48.923918626560365,
                            2.260602314246561,
                            48.93105422781371,
                        ),
                        "coordinates": [
                            [2.25934570305215, 48.923918626560365],
                            [2.259242690685924, 48.924161829185316],
                            [2.25914654050798, 48.924426791415236],
                            [2.259044843227303, 48.924807416548504],
                            [2.258968397437719, 48.92520233379846],
                            [2.258931748247874, 48.92554731403057],
                            [2.25890223580021, 48.92594464268499],
                            [2.258905290105806, 48.9262991661213],
                            [2.258930064197831, 48.92662039577116],
                            [2.258976468072476, 48.92696067231551],
                            [2.259051762539378, 48.92730334775074],
                            [2.259141518144067, 48.92763413642275],
                            [2.259234960436355, 48.927917340461626],
                            [2.259353635180461, 48.92822911553918],
                            [2.259508342731763, 48.92859325725773],
                            [2.259709849054022, 48.929050227627464],
                            [2.260602314246561, 48.93105422781371],
                        ],
                    },
                },
                1099: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.79555547220965, 2.139090971211456],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 450.857659874,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.136050489663708,
                            48.79528024627206,
                            2.142141851963426,
                            48.795715917344765,
                        ),
                        "coordinates": [
                            [2.136050489663708, 48.79528024627206],
                            [2.136078615729023, 48.795284586940234],
                            [2.136184386259406, 48.79530090881185],
                            [2.136923051747886, 48.79540922138856],
                            [2.137193773686322, 48.79544566723029],
                            [2.137540717011488, 48.7954831446176],
                            [2.137935303232737, 48.79551980530034],
                            [2.138672898157999, 48.79555706102029],
                            [2.139428190102225, 48.79559434337222],
                            [2.141261337567381, 48.79567663989319],
                            [2.142141851963426, 48.795715917344765],
                        ],
                    },
                },
                1100: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.713808555193395, 2.4484606589676785],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2595.4241406,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.438093383889102,
                            48.70823782858165,
                            2.462282244689792,
                            48.72115958316324,
                        ),
                        "coordinates": [
                            [2.462282244689792, 48.70823782858165],
                            [2.460983910433233, 48.70879460381943],
                            [2.460264468713545, 48.70910940162476],
                            [2.45989156299872, 48.70928770107002],
                            [2.459540394511254, 48.70947546745735],
                            [2.459186371898107, 48.70968137901128],
                            [2.458828870992446, 48.70990805478701],
                            [2.4581193284077, 48.710365645385814],
                            [2.45788462065311, 48.71051697335805],
                            [2.4573934369007, 48.710810659335635],
                            [2.457066390778859, 48.71098996065503],
                            [2.456146253745974, 48.71147204257776],
                            [2.455711881415892, 48.71166494265567],
                            [2.455406437124127, 48.711790260756786],
                            [2.45442359216518, 48.71220045254005],
                            [2.453762414097586, 48.71245293242585],
                            [2.451625523919498, 48.7133130196957],
                            [2.451142189484145, 48.713502354460644],
                            [2.450760658087116, 48.713643024944055],
                            [2.450474138316585, 48.713735037731645],
                            [2.45012376227197, 48.71383340884293],
                            [2.449712228421354, 48.71392914211516],
                            [2.449243587887568, 48.71401144056516],
                            [2.448787122355311, 48.71407034461838],
                            [2.448427319688785, 48.7141076013759],
                            [2.448015377294803, 48.71412506080166],
                            [2.447647093473568, 48.71411822694539],
                            [2.446926798726546, 48.71408835290434],
                            [2.446281276317311, 48.714072790965105],
                            [2.445407435106446, 48.71404755225977],
                            [2.44471845892446, 48.7140464104308],
                            [2.444150481297779, 48.714070330422494],
                            [2.443659987170575, 48.714105865696325],
                            [2.443169542254486, 48.71416477873885],
                            [2.442869323816343, 48.714213620946566],
                            [2.442552623224028, 48.71426550651059],
                            [2.442255364780425, 48.71434368775591],
                            [2.441614354305444, 48.71453582667013],
                            [2.441231430498669, 48.71467646649414],
                            [2.440803740234079, 48.714856713288114],
                            [2.440404624068385, 48.71505491884784],
                            [2.44005715933288, 48.71526026876353],
                            [2.439504846271283, 48.715639363933136],
                            [2.439275602654027, 48.715844604756086],
                            [2.439032833066198, 48.71608133259323],
                            [2.438822682066663, 48.71632072727946],
                            [2.438653267876831, 48.71654479851283],
                            [2.438431101762117, 48.716906959958216],
                            [2.438249711512178, 48.71729614086154],
                            [2.438178333422549, 48.717559518330255],
                            [2.438116704366139, 48.7179021951341],
                            [2.438093383889102, 48.71822263243712],
                            [2.438108347463893, 48.71850813798271],
                            [2.43815434831925, 48.7187313567867],
                            [2.438233522983043, 48.71911851748304],
                            [2.438364435249654, 48.7194806567947],
                            [2.43852495245468, 48.71982326862533],
                            [2.438704570856386, 48.720127660535574],
                            [2.43895095254639, 48.72041813306976],
                            [2.439645733248798, 48.72115958316324],
                        ],
                    },
                },
                1101: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.67516040842263, 2.540926256650133],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1829.78536074,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.533130656571037,
                            48.66790196104987,
                            2.547548045814366,
                            48.681016616342724,
                        ),
                        "coordinates": [
                            [2.547548045814366, 48.66790196104987],
                            [2.547348686316046, 48.66815565279031],
                            [2.546936715185344, 48.66865821031244],
                            [2.546187249572257, 48.66951793741603],
                            [2.545703076215958, 48.670105095825214],
                            [2.545268515695883, 48.67064647776249],
                            [2.544849737351404, 48.67120789293389],
                            [2.544595890033647, 48.67155440833831],
                            [2.544327250061974, 48.671919274446985],
                            [2.543841130820052, 48.67256404023298],
                            [2.543631723390859, 48.6728171170834],
                            [2.542789732901142, 48.67387787296055],
                            [2.542248530670807, 48.6745615186306],
                            [2.54196611267488, 48.67489476031959],
                            [2.541182059662686, 48.675748683993945],
                            [2.540682882707013, 48.67620821032145],
                            [2.540118697984313, 48.67671191427601],
                            [2.539770922870442, 48.677008397381165],
                            [2.538973727723166, 48.67765279794266],
                            [2.538375311458164, 48.678095404188156],
                            [2.537373162911307, 48.67878213970355],
                            [2.536577987693703, 48.67927590337635],
                            [2.535782643729166, 48.67973159245183],
                            [2.535396400589289, 48.67994363163423],
                            [2.53475743599448, 48.68027452171034],
                            [2.53415927174302, 48.68056679224762],
                            [2.533636323913351, 48.6808003978775],
                            [2.533130656571037, 48.681016616342724],
                        ],
                    },
                },
                1102: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.7063564569781, 2.4731877714913058],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1679.0416788,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.462282244689792,
                            48.70563117036449,
                            2.484245146583624,
                            48.70823782858165,
                        ),
                        "coordinates": [
                            [2.484245146583624, 48.70661094689584],
                            [2.483999090311285, 48.706578257972986],
                            [2.48299836448982, 48.70643143780319],
                            [2.482413004274576, 48.7063340427909],
                            [2.481458498299263, 48.7061728730927],
                            [2.480704140633706, 48.70604107453491],
                            [2.48011354949652, 48.70594646880368],
                            [2.479517385293175, 48.705865980715004],
                            [2.478807926423619, 48.70578953251095],
                            [2.478110095024648, 48.705730431143486],
                            [2.477258683545632, 48.70567275667939],
                            [2.476822478805115, 48.705649914143045],
                            [2.476243636639174, 48.70563623900458],
                            [2.475977319575276, 48.70563117036449],
                            [2.475494992029789, 48.70563445835077],
                            [2.474875455476397, 48.70564420577465],
                            [2.474666234679159, 48.705650755584216],
                            [2.474510000606064, 48.70565634035054],
                            [2.474245076312613, 48.70566385562254],
                            [2.473408270082582, 48.70571792284229],
                            [2.472821455820152, 48.70576988616582],
                            [2.472192567143237, 48.705838983167816],
                            [2.471522957362155, 48.70592341216338],
                            [2.471028580198388, 48.705994141285274],
                            [2.470418799794077, 48.706097377111234],
                            [2.469476054655626, 48.70628194199456],
                            [2.468648054671239, 48.70647714204885],
                            [2.468087275787389, 48.706618079066395],
                            [2.466859775096365, 48.70691715067424],
                            [2.4655133330434, 48.70724299521899],
                            [2.464567693276872, 48.707482698255745],
                            [2.46392409849711, 48.70765877891531],
                            [2.463453002050065, 48.70781128272832],
                            [2.462804681259587, 48.708024074480846],
                            [2.462437563629043, 48.7081712211007],
                            [2.462282244689792, 48.70823782858165],
                        ],
                    },
                },
                1103: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.61195541721638, 2.5767288541006903],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 3798.63575937,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.56958354823646,
                            48.595563837991776,
                            2.58394771106125,
                            48.62837555172384,
                        ),
                        "coordinates": [
                            [2.58394771106125, 48.595563837991776],
                            [2.583117344654084, 48.59747915687793],
                            [2.582574627318395, 48.598818573486696],
                            [2.582073603471251, 48.59996344602832],
                            [2.581087273327229, 48.60219500150275],
                            [2.580061588083991, 48.60446708110959],
                            [2.57951153778809, 48.605705508428805],
                            [2.578744745254357, 48.60738457044565],
                            [2.578446637034757, 48.60805855514081],
                            [2.577967609656476, 48.60916120253005],
                            [2.577655265455324, 48.60986376665252],
                            [2.577413868423425, 48.61039962783699],
                            [2.57667563520148, 48.61207861536173],
                            [2.576015382845692, 48.61356708785904],
                            [2.575553905565817, 48.61461020447449],
                            [2.575163322747977, 48.61547472146526],
                            [2.574698130966103, 48.61649880773506],
                            [2.574378699718054, 48.61723944756969],
                            [2.574123182059039, 48.617839572326695],
                            [2.573853385855744, 48.61845638251498],
                            [2.573217440869168, 48.619818948949],
                            [2.572913166623866, 48.620506889587936],
                            [2.57278970824799, 48.62078771955357],
                            [2.572663601230039, 48.62108204337581],
                            [2.572528048157026, 48.62138717766877],
                            [2.572392486483136, 48.62169051357187],
                            [2.572189848438892, 48.62215226050985],
                            [2.572032792067063, 48.622500604154915],
                            [2.571867703899166, 48.622872345615335],
                            [2.571656994738576, 48.62335029486997],
                            [2.571456971374416, 48.62379404918274],
                            [2.571285164909932, 48.62418109122728],
                            [2.570953586615855, 48.62492007805811],
                            [2.570797867899989, 48.625268416959315],
                            [2.570660987433426, 48.62558434382758],
                            [2.570541557777406, 48.625861565249814],
                            [2.570313429010005, 48.6264135510181],
                            [2.57010763665612, 48.62696626527897],
                            [2.569971896368711, 48.627297121567615],
                            [2.569800402378706, 48.62775385935917],
                            [2.569698750821867, 48.62803512581767],
                            [2.56958354823646, 48.62837555172384],
                        ],
                    },
                },
                1104: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.846836692583395, 2.4917993337281956],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1701.44033125,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.489167460948015,
                            48.839341939180265,
                            2.494188055346116,
                            48.85426899363537,
                        ),
                        "coordinates": [
                            [2.489167460948015, 48.85426899363537],
                            [2.489441244458785, 48.85350539416663],
                            [2.490005965305802, 48.85189382114354],
                            [2.490577868338836, 48.85028461304433],
                            [2.491113984856464, 48.84877300403469],
                            [2.491678865449789, 48.84724707839666],
                            [2.492243249362621, 48.84557362952163],
                            [2.492675472029595, 48.84437157499402],
                            [2.492897141309431, 48.84378595362841],
                            [2.493075866128748, 48.8433027016065],
                            [2.493186673629519, 48.84300275211929],
                            [2.493301182367373, 48.84273372791304],
                            [2.493419234998187, 48.84244566579689],
                            [2.493522978770402, 48.84219331280554],
                            [2.493633737464267, 48.84187908611802],
                            [2.493708573693987, 48.841605358805346],
                            [2.493812044012337, 48.841267349070705],
                            [2.493893947463762, 48.84094840320628],
                            [2.493972167761648, 48.840605670838706],
                            [2.494064475159349, 48.8401582260201],
                            [2.494120997567285, 48.83979410847092],
                            [2.494188055346116, 48.839341939180265],
                        ],
                    },
                },
                1105: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.52548204661493, 2.659085047135647],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 757.135303279,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.654990282141887,
                            48.52299439391623,
                            2.662762979853312,
                            48.52724332146015,
                        ),
                        "coordinates": [
                            [2.662762979853312, 48.52299439391623],
                            [2.662367729584691, 48.5234163855458],
                            [2.66187938625594, 48.52388810259803],
                            [2.661552206633087, 48.5241616612084],
                            [2.661067551298998, 48.524529262119025],
                            [2.660754469951943, 48.52473303483431],
                            [2.660391868384008, 48.52497507379692],
                            [2.659807924496361, 48.52532295561293],
                            [2.659168178246081, 48.525648157075636],
                            [2.658010948626033, 48.526186144151836],
                            [2.65724369114478, 48.52652408139624],
                            [2.65690973922152, 48.526656115732926],
                            [2.656347964922313, 48.52686151098016],
                            [2.655904859934028, 48.52701113843918],
                            [2.655425094624118, 48.527144679624996],
                            [2.654990282141887, 48.52724332146015],
                        ],
                    },
                },
                1106: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.83883990857013, 2.37633502152069],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 646.996876035,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.372825724542572,
                            48.837045120157924,
                            2.379911271454398,
                            48.84039247329462,
                        ),
                        "coordinates": [
                            [2.372825724542572, 48.837045120157924],
                            [2.373476410933694, 48.83735998826331],
                            [2.373789695040654, 48.83749506121187],
                            [2.373919228775215, 48.837554654846805],
                            [2.378758553720501, 48.84015728728493],
                            [2.378775236255153, 48.84016596552728],
                            [2.378884928767388, 48.84021759910732],
                            [2.379000706163748, 48.84026307926014],
                            [2.379121775079775, 48.840302093370006],
                            [2.379247315720055, 48.84033437365461],
                            [2.379376464105263, 48.84035970067068],
                            [2.379508340716563, 48.840377900765155],
                            [2.379642043631585, 48.84038885053656],
                            [2.379776659468358, 48.84039247329462],
                            [2.379911271454398, 48.84038874809586],
                        ],
                    },
                },
                1107: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.379909393743745, 2.9393628830651086],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 476.033427847,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.936180968314843,
                            48.37952610418487,
                            2.94252341270237,
                            48.38004841334399,
                        ),
                        "coordinates": [
                            [2.94252341270237, 48.37952610418487],
                            [2.941970327788975, 48.37962642828399],
                            [2.941460098137519, 48.37971729379121],
                            [2.940931959914021, 48.379805869296995],
                            [2.940525101059726, 48.37986997552031],
                            [2.939971731722615, 48.379942007947484],
                            [2.939550282439154, 48.37998236820579],
                            [2.939189472191447, 48.380010493721166],
                            [2.938846325386872, 48.380028017386],
                            [2.938538049320152, 48.38004196664145],
                            [2.938188668747306, 48.38004507507702],
                            [2.937833464348154, 48.38004841334399],
                            [2.937551595785191, 48.38004230483279],
                            [2.936854495968621, 48.380025737774496],
                            [2.936180968314843, 48.37999957527981],
                        ],
                    },
                },
                1108: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.89664213176752, 2.4597416844786677],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 202.215865307,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.458363412015992,
                            48.89660443742263,
                            2.461119310778047,
                            48.896652451144085,
                        ),
                        "coordinates": [
                            [2.458363412015992, 48.896652451144085],
                            [2.459993941439638, 48.896649064128454],
                            [2.46018274150254, 48.896644334185666],
                            [2.460390875309296, 48.89663911910006],
                            [2.461119310778047, 48.89660443742263],
                        ],
                    },
                },
                1109: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.888945659419655, 2.3230260360833785],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 560.977746986,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.320174757151551,
                            48.88718394686578,
                            2.325779674806892,
                            48.8905871866118,
                        ),
                        "coordinates": [
                            [2.325779674806892, 48.88718394686578],
                            [2.325720351394929, 48.88727237655301],
                            [2.325651058160634, 48.88735759431116],
                            [2.325572190041987, 48.887439113113686],
                            [2.325484199015256, 48.88751646513995],
                            [2.325387587218383, 48.88758920623371],
                            [2.325320959134181, 48.88763348158161],
                            [2.320900472029906, 48.89017402958246],
                            [2.320174757151551, 48.8905871866118],
                        ],
                    },
                },
                1110: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.81337075804287, 2.3803135766331796],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 714.862194009,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.377267201513739,
                            48.81109919771153,
                            2.383551479649113,
                            48.81593076305631,
                        ),
                        "coordinates": [
                            [2.383551479649113, 48.81109919771153],
                            [2.382430936711201, 48.811632091226194],
                            [2.38228985327535, 48.811703182713075],
                            [2.382154591125821, 48.811778282991796],
                            [2.382025147575906, 48.81185738846987],
                            [2.381913579361338, 48.811931905823194],
                            [2.381807974350878, 48.81200857465186],
                            [2.381708973996186, 48.81208693150801],
                            [2.381617089736885, 48.812166568034456],
                            [2.381519232190829, 48.812261041304474],
                            [2.381413104725259, 48.8123745323458],
                            [2.381379066605469, 48.812414536207775],
                            [2.381343829239648, 48.81246023504832],
                            [2.38120073592523, 48.81266183430514],
                            [2.381162276243653, 48.81270937093517],
                            [2.381124197426276, 48.81275108601285],
                            [2.381051977942893, 48.81281867768303],
                            [2.38096306491015, 48.812890105984216],
                            [2.380871901351089, 48.81295619461307],
                            [2.380642512155245, 48.8131149124034],
                            [2.380529088370745, 48.813200796893405],
                            [2.380400965176281, 48.813310276864634],
                            [2.380117288267923, 48.81356745824486],
                            [2.380044685485201, 48.81362939915677],
                            [2.379976533377467, 48.813684199516395],
                            [2.37979211083764, 48.81382263386099],
                            [2.37960026522024, 48.81395685085764],
                            [2.379400996514395, 48.814086850472144],
                            [2.379194308787505, 48.814212633589364],
                            [2.378675659932628, 48.814578028875175],
                            [2.378233630318412, 48.81501081618639],
                            [2.377267201513739, 48.81593076305631],
                        ],
                    },
                },
                1111: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.88317299153898, 2.3610938895869977],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 905.680600044,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.357459347963283,
                            48.87985014162011,
                            2.365893819935268,
                            48.88452287646552,
                        ),
                        "coordinates": [
                            [2.357459347963283, 48.87985014162011],
                            [2.357871450808818, 48.88066480600621],
                            [2.358870836196884, 48.8823864017506],
                            [2.358905392432931, 48.882441029508925],
                            [2.3589633834782, 48.88251683423698],
                            [2.35903091689695, 48.882589121479214],
                            [2.359107498688431, 48.88265736966266],
                            [2.35919258125488, 48.88272109020181],
                            [2.359285553934561, 48.88277982115348],
                            [2.359291280011327, 48.882783125355076],
                            [2.359509745486482, 48.882908578863685],
                            [2.361459044876611, 48.88402791612907],
                            [2.361588972246126, 48.884102522061774],
                            [2.361713836179836, 48.884169831585815],
                            [2.361851800167209, 48.88423498765901],
                            [2.361995933294446, 48.884294052919124],
                            [2.362145615444033, 48.884346774028224],
                            [2.362300205704942, 48.88439292451976],
                            [2.362459039602264, 48.88443230838143],
                            [2.36262144274527, 48.88446475922897],
                            [2.362786717280375, 48.884490133039584],
                            [2.362954153967099, 48.884508324404536],
                            [2.363123033696126, 48.88451925394686],
                            [2.363292636937789, 48.88452287646552],
                            [2.363355486203871, 48.884522358112754],
                            [2.36493032304424, 48.88447941513124],
                            [2.365893819935268, 48.88442088636331],
                        ],
                    },
                },
                1112: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.85474159850424, 2.3695449856872584],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 321.019479437,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368736572626169,
                            48.853436962301636,
                            2.370209339755371,
                            48.856140711155,
                        ),
                        "coordinates": [
                            [2.368736572626169, 48.853436962301636],
                            [2.36895160940256, 48.85365673087589],
                            [2.369027171316422, 48.85373698012128],
                            [2.369073377733921, 48.85378986283818],
                            [2.369114635683124, 48.853840834401915],
                            [2.369151885093969, 48.8538910554406],
                            [2.369185575067858, 48.853941140784315],
                            [2.369244516519342, 48.85404152416754],
                            [2.369306608331366, 48.85415920155979],
                            [2.370209339755371, 48.856140711155],
                        ],
                    },
                },
                1113: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.92476483911881, 2.3496656462451635],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 1483.17556915,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.343305929159434,
                            48.919573073151824,
                            2.356035794172797,
                            48.92993588967869,
                        ),
                        "coordinates": [
                            [2.343305929159434, 48.919573073151824],
                            [2.344254945466325, 48.920339517605605],
                            [2.345682355426226, 48.92148283386725],
                            [2.349306765251169, 48.92444187194159],
                            [2.351940554624435, 48.92659733187899],
                            [2.354279131988382, 48.928645378690554],
                            [2.355726567229061, 48.929745822607806],
                            [2.355960389351383, 48.929889541497786],
                            [2.356035794172797, 48.92993588967869],
                        ],
                    },
                },
                1114: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.8750255845114, 2.318974723960949],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 935.424482876,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.314337194721316,
                            48.87376998959543,
                            2.324818285061554,
                            48.87535495768347,
                        ),
                        "coordinates": [
                            [2.31445603617697, 48.87376998959543],
                            [2.314344611179586, 48.874969175785495],
                            [2.314337214989775, 48.87500322289879],
                            [2.314337194721316, 48.87504826082242],
                            [2.314348127692364, 48.875092713957976],
                            [2.314369727683048, 48.87513543760227],
                            [2.314401439433418, 48.87517532058287],
                            [2.314442438024853, 48.87521133202112],
                            [2.314491664111216, 48.87524253772279],
                            [2.314547843941364, 48.87526813267033],
                            [2.314609517847278, 48.87528745197897],
                            [2.314675094494075, 48.875299992792776],
                            [2.314742868344953, 48.875305434170926],
                            [2.314811090604781, 48.8753036338971],
                            [2.314856761912849, 48.875298300515325],
                            [2.316326274154273, 48.87523632178083],
                            [2.319157522684538, 48.87486329436721],
                            [2.32086494045486, 48.87499433672929],
                            [2.323625225227904, 48.8751480764836],
                            [2.324818285061554, 48.87535495768347],
                        ],
                    },
                },
                1115: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.814853670784004, 2.3608108447854876],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 1071.8568079,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35935548759399,
                            48.81012995727393,
                            2.362263387127349,
                            48.81957651845754,
                        ),
                        "coordinates": [
                            [2.362263387127349, 48.81012995727393],
                            [2.362165708510125, 48.81044828161261],
                            [2.361273126539535, 48.813356906994024],
                            [2.35935548759399, 48.81957651845754],
                        ],
                    },
                },
                1116: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.88985518587493, 2.3972358767541686],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 809.614489109,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.39211370183691,
                            48.888503688781846,
                            2.402352143900472,
                            48.89122859320346,
                        ),
                        "coordinates": [
                            [2.39211370183691, 48.888503688781846],
                            [2.399999412943242, 48.890578942541],
                            [2.40140569969558, 48.8909672631911],
                            [2.402352143900472, 48.89122859320346],
                        ],
                    },
                },
                1117: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.836963078925635, 2.359892588260497],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 361.956979551,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358823490459311,
                            48.83549535538991,
                            2.360966902272541,
                            48.838426942998495,
                        ),
                        "coordinates": [
                            [2.358823490459311, 48.83549535538991],
                            [2.360676366210785, 48.83804056474119],
                            [2.360966902272541, 48.838426942998495],
                        ],
                    },
                },
                1118: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.88782008891582, 2.3895366451613924],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 407.41950199,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.386960017135177,
                            48.887134869076554,
                            2.39211370183691,
                            48.888503688781846,
                        ),
                        "coordinates": [
                            [2.386960017135177, 48.887134869076554],
                            [2.391386944827169, 48.88831239579479],
                            [2.39211370183691, 48.888503688781846],
                        ],
                    },
                },
                1119: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.85964904878825, 2.322076526100935],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 298.459644318,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.320998191954085,
                            48.85851112987378,
                            2.323154855841107,
                            48.860786963526714,
                        ),
                        "coordinates": [
                            [2.323154855841107, 48.85851112987378],
                            [2.321174917046643, 48.86060048204472],
                            [2.320998191954085, 48.860786963526714],
                        ],
                    },
                },
                1120: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.847846267567554, 2.3601757394195775],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 1004.62330305,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.355050264434754,
                            48.845950665750145,
                            2.363559738776456,
                            48.851237611581645,
                        ),
                        "coordinates": [
                            [2.355050264434754, 48.845950665750145],
                            [2.355153482344124, 48.84595575401786],
                            [2.355162064544813, 48.84595617710772],
                            [2.355169286693653, 48.84595627988933],
                            [2.356038424614968, 48.84596675049833],
                            [2.356646728587109, 48.84597407485936],
                            [2.356795175691347, 48.84597586414667],
                            [2.356877875177874, 48.84597751298029],
                            [2.35707292490625, 48.84598660161101],
                            [2.357266882140217, 48.846002958971084],
                            [2.357459126251589, 48.8460265313677],
                            [2.357649042314411, 48.84605724445727],
                            [2.357836022510585, 48.846094999655215],
                            [2.358019467479672, 48.846139675042686],
                            [2.358198787636889, 48.84619112897053],
                            [2.358373412764624, 48.84624919561395],
                            [2.358542779682571, 48.84631369030214],
                            [2.358706345927613, 48.846384405094454],
                            [2.358863591049657, 48.84646111418332],
                            [2.359014008468533, 48.846543571151905],
                            [2.359143630983422, 48.84662278856469],
                            [2.363278159249896, 48.849282151693366],
                            [2.363298944579304, 48.849295801212754],
                            [2.363365542822898, 48.84934623264694],
                            [2.363423330268105, 48.84940119218675],
                            [2.363471605032874, 48.849460015083636],
                            [2.363509783039733, 48.84952198595159],
                            [2.363537400566997, 48.84958635316966],
                            [2.363554118293887, 48.849652332500554],
                            [2.363559738776456, 48.849719126968644],
                            [2.36355419014149, 48.849785923175794],
                            [2.363537542210622, 48.849851910273316],
                            [2.363509992744452, 48.84991629068131],
                            [2.363471881082552, 48.849978279262004],
                            [2.363423668826711, 48.85003712300327],
                            [2.363365938359439, 48.85009211090415],
                            [2.363359713517177, 48.85009733361471],
                            [2.361985224973328, 48.851237611581645],
                        ],
                    },
                },
                1121: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.82100713365665, 2.3589145495503745],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 324.671960269,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358473883876467,
                            48.81957651845754,
                            2.35935548759399,
                            48.822437832786854,
                        ),
                        "coordinates": [
                            [2.35935548759399, 48.81957651845754],
                            [2.358991992079644, 48.8207552960421],
                            [2.358583716394522, 48.822081169154806],
                            [2.358473883876467, 48.822437832786854],
                        ],
                    },
                },
                1122: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.892811455883965, 2.379920033190816],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 590.17882784,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.377315755595574,
                            48.89078896952844,
                            2.382522343415364,
                            48.89483646840174,
                        ),
                        "coordinates": [
                            [2.377315755595574, 48.89078896952844],
                            [2.37936312240004, 48.892377824527],
                            [2.382082935925813, 48.89449231381501],
                            [2.382522343415364, 48.89483646840174],
                        ],
                    },
                },
                1123: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3bis",
                        "rer": 0,
                        "extcode": "100110103:3B",
                        "geo_point_2d": [48.866795970439846, 2.40016098852565],
                        "indice_lig": "3b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01386",
                        "navette": 0,
                        "idrefliga": "A01549",
                        "shape_leng": 418.835980188,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.398746593442592,
                            48.86516343488148,
                            2.401561774610831,
                            48.86844023643111,
                        ),
                        "coordinates": [
                            [2.398746593442592, 48.86516343488148],
                            [2.399901827732541, 48.866480528173454],
                            [2.401561774610831, 48.86844023643111],
                        ],
                    },
                },
                1124: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.89608911274676, 2.384036595526158],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 358.756133505,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.382522343415364,
                            48.89483646840174,
                            2.385508387668673,
                            48.89738989158186,
                        ),
                        "coordinates": [
                            [2.382522343415364, 48.89483646840174],
                            [2.38465016676894, 48.89657156776731],
                            [2.385508387668673, 48.89738989158186],
                        ],
                    },
                },
                1125: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.37482480188876, 2.875600021721714],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 9994.39269455,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.815956767081606,
                            48.367190895517794,
                            2.936180968314843,
                            48.38576231209905,
                        ),
                        "coordinates": [
                            [2.815956767081606, 48.38235800575609],
                            [2.816424735307878, 48.38260704631034],
                            [2.816686619743611, 48.38274711897492],
                            [2.817732785995672, 48.38330380916832],
                            [2.818247720099427, 48.38357399930214],
                            [2.818701355416031, 48.38381088731778],
                            [2.819172416306831, 48.38406204557408],
                            [2.819534605990315, 48.38422972009238],
                            [2.819915115535525, 48.384400542280574],
                            [2.820225829996955, 48.38452426113052],
                            [2.820514491860014, 48.38463902999724],
                            [2.821149782071103, 48.384859326138624],
                            [2.821484202591806, 48.38496225715613],
                            [2.821828181435355, 48.38506567841368],
                            [2.822163849218797, 48.385158027409496],
                            [2.822403379741653, 48.38521724943301],
                            [2.822747104849736, 48.38530120228682],
                            [2.823056366079861, 48.38536902643884],
                            [2.823293644064093, 48.38541665459795],
                            [2.823789939754715, 48.38550931205613],
                            [2.824378096823145, 48.38559273435663],
                            [2.824769976531524, 48.38564308507773],
                            [2.825281492634446, 48.38568688223101],
                            [2.825905045650505, 48.385734517826],
                            [2.826426367653502, 48.38575474310667],
                            [2.826962416347579, 48.38576231209905],
                            [2.827803356234711, 48.38574697272214],
                            [2.828547590654962, 48.3857046916981],
                            [2.828952865177653, 48.38567093483378],
                            [2.829430281415242, 48.385619395807865],
                            [2.829941288275303, 48.385551522704255],
                            [2.830925178770439, 48.38538356300131],
                            [2.831800814082275, 48.38519088859024],
                            [2.832387858016491, 48.385030946664074],
                            [2.833067574027909, 48.38482293504924],
                            [2.833807491435419, 48.38455979995775],
                            [2.834556405948256, 48.38425165668802],
                            [2.835101479502257, 48.383989346134804],
                            [2.835465911472907, 48.38380251700426],
                            [2.835883477780491, 48.38357226285843],
                            [2.836381328823507, 48.38327061103163],
                            [2.837183663688102, 48.38277247106844],
                            [2.838489090354446, 48.38196095166346],
                            [2.839433734655103, 48.38138842474266],
                            [2.840227675569959, 48.38086691998524],
                            [2.84384326547858, 48.37864038740063],
                            [2.845951723326151, 48.37730450692988],
                            [2.847675446156696, 48.37624100253817],
                            [2.849355979695551, 48.37518486138256],
                            [2.850253379871377, 48.374636737845584],
                            [2.851336325745876, 48.374020319647386],
                            [2.85170721895275, 48.3738302769835],
                            [2.852243571951266, 48.37356047862151],
                            [2.8528904187244, 48.37325773732393],
                            [2.853665494540937, 48.37292249151412],
                            [2.854820101836237, 48.37245678717978],
                            [2.855586807701359, 48.37217789511868],
                            [2.856269820121924, 48.3719474496943],
                            [2.8569066778139, 48.37175227418366],
                            [2.857722982746169, 48.37151271626407],
                            [2.858257315542556, 48.371369069154426],
                            [2.858825911138618, 48.371226849552],
                            [2.859470290627415, 48.371079220039874],
                            [2.860460231875475, 48.370874186211964],
                            [2.861092031287584, 48.370759749310494],
                            [2.861539374687759, 48.37068843136944],
                            [2.861901401257238, 48.370634042437366],
                            [2.862285058996281, 48.37057957767159],
                            [2.86258781687, 48.37053608128211],
                            [2.862851330832802, 48.37049874561821],
                            [2.863133619996968, 48.37045890294477],
                            [2.863621362567767, 48.370397561677],
                            [2.864124443119251, 48.37034412260346],
                            [2.864948172674665, 48.3702606964414],
                            [2.866028112343367, 48.37015380644426],
                            [2.869502385497447, 48.36979779202158],
                            [2.872189339257764, 48.36952791040866],
                            [2.874577611794342, 48.369279632274406],
                            [2.876936191285402, 48.369044009271725],
                            [2.87951785843928, 48.36877985203348],
                            [2.882214043694582, 48.3684997956207],
                            [2.884486948050287, 48.36826758800281],
                            [2.886239425890192, 48.368084627715355],
                            [2.889593405878244, 48.367738247645434],
                            [2.890785086308874, 48.367615510424265],
                            [2.892784229813828, 48.36740875778046],
                            [2.893934110382386, 48.36729068878646],
                            [2.894348067756967, 48.36725807255834],
                            [2.89472686378117, 48.36723291532234],
                            [2.895159330427727, 48.36721305672575],
                            [2.895516362794517, 48.367202332033536],
                            [2.895887216759905, 48.36719381723744],
                            [2.896296104355527, 48.367190895517794],
                            [2.896630829926781, 48.36719373407371],
                            [2.896972393402851, 48.367204631600664],
                            [2.897319276246225, 48.36721998258931],
                            [2.897780581900788, 48.36724684920646],
                            [2.898341649485913, 48.367289131164],
                            [2.898760567895927, 48.367324350745825],
                            [2.899168620433533, 48.367367284286274],
                            [2.899466014569671, 48.36741076766648],
                            [2.899971586675504, 48.36748468706781],
                            [2.900554385518433, 48.3675851963135],
                            [2.901088623459158, 48.36768774223018],
                            [2.901503966466886, 48.36777829135195],
                            [2.901949241889289, 48.367890271749445],
                            [2.902706075460861, 48.368104104309424],
                            [2.903112320908136, 48.36822344095219],
                            [2.903559309957025, 48.36836870673431],
                            [2.904063428026052, 48.368551424995935],
                            [2.9044930906711, 48.36871383194075],
                            [2.904890141905091, 48.368879294350585],
                            [2.905290428340586, 48.3690461471033],
                            [2.906096300471423, 48.36941618275929],
                            [2.907002482536981, 48.369823475445216],
                            [2.907650899539358, 48.37011246104281],
                            [2.908101301584673, 48.370316115869144],
                            [2.909147253230239, 48.37078653274147],
                            [2.909651959922243, 48.37101688433679],
                            [2.910746844181375, 48.37151491553284],
                            [2.911925839557148, 48.372048477853575],
                            [2.91294747502414, 48.37251089107902],
                            [2.913885017897449, 48.372935954214995],
                            [2.916169838504803, 48.373964710637104],
                            [2.918486004377086, 48.375011245657966],
                            [2.919706440050377, 48.37556171379814],
                            [2.920656346519714, 48.37598977790715],
                            [2.92127583874443, 48.37627110906197],
                            [2.922970106203779, 48.37704901359043],
                            [2.92376068324006, 48.377410188137695],
                            [2.924331942854127, 48.37765671745608],
                            [2.924878436399788, 48.377877391369225],
                            [2.925400474669468, 48.37807700840293],
                            [2.925899382666067, 48.37826055662401],
                            [2.926722567216694, 48.37853503866487],
                            [2.927543233443624, 48.378808621808815],
                            [2.928357499789204, 48.379061552283645],
                            [2.92869411293988, 48.37916045507439],
                            [2.929052215263586, 48.379249458040334],
                            [2.92940549484377, 48.37933033837415],
                            [2.929988734516592, 48.37945137755812],
                            [2.930428417366936, 48.37953270078945],
                            [2.930849011442576, 48.37959793585176],
                            [2.931328904293654, 48.37965476393379],
                            [2.931885760246334, 48.3797129838341],
                            [2.932321075490881, 48.37975628624159],
                            [2.932764914470996, 48.3797944412437],
                            [2.933469822259073, 48.37983598023287],
                            [2.933945729794594, 48.37986443321458],
                            [2.934666232192033, 48.3799096381512],
                            [2.936180968314843, 48.37999957527981],
                        ],
                    },
                },
                1126: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.553528893643616, 2.3989149592302397],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 6622.26901469,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.370518497736708,
                            48.53150198648683,
                            2.432098533660357,
                            48.57059685871919,
                        ),
                        "coordinates": [
                            [2.432098533660357, 48.57059685871919],
                            [2.43156512678642, 48.57034924502551],
                            [2.43111020030546, 48.570144908874916],
                            [2.430430853905163, 48.56984409796278],
                            [2.429660712035877, 48.56955287530511],
                            [2.429148913212003, 48.56937564158158],
                            [2.428555804891, 48.569169920783736],
                            [2.427710154900222, 48.568874039720264],
                            [2.426670234872951, 48.56850707735079],
                            [2.425162580988905, 48.567975908544874],
                            [2.423783733595665, 48.56747609497536],
                            [2.421068196893732, 48.56652045012077],
                            [2.42047711263709, 48.56631406121991],
                            [2.419556592735418, 48.565985612961356],
                            [2.418432730796398, 48.56558266700876],
                            [2.418039711557192, 48.56543284336869],
                            [2.417584032101552, 48.565245158240515],
                            [2.417110019449177, 48.5650232347414],
                            [2.416673798476314, 48.56480694509628],
                            [2.41614671966389, 48.564520479562866],
                            [2.415579845097209, 48.56417286482945],
                            [2.415056326043261, 48.56382162107946],
                            [2.414737564770574, 48.563579941713726],
                            [2.414150188541275, 48.56310374130323],
                            [2.412725730911972, 48.56184844871287],
                            [2.412401506965594, 48.56156270425335],
                            [2.410225644195213, 48.55964693010663],
                            [2.408694262399068, 48.55832151567011],
                            [2.408100177031749, 48.55780662078112],
                            [2.407926518526026, 48.557667783221966],
                            [2.407464141080939, 48.5573133302008],
                            [2.407205138618597, 48.55712554771528],
                            [2.406711601865298, 48.55680841892105],
                            [2.406406554356651, 48.55662605875832],
                            [2.405084723761878, 48.5558490132238],
                            [2.404772920517701, 48.5556711496539],
                            [2.402477845410793, 48.55436049976756],
                            [2.401891452374309, 48.55402684938435],
                            [2.400731888535987, 48.55337052797659],
                            [2.400036498698321, 48.55296985340054],
                            [2.398380090732973, 48.552031045238685],
                            [2.398170010797068, 48.55192504722285],
                            [2.397953159888735, 48.551819951911504],
                            [2.397614346036745, 48.55166726062445],
                            [2.397198300176537, 48.55149212910018],
                            [2.396958293490437, 48.55140552868736],
                            [2.396626501214567, 48.55128580737516],
                            [2.396295718748811, 48.551175364027586],
                            [2.395977725335227, 48.55107850000594],
                            [2.395648042690318, 48.55099018471809],
                            [2.395395498025166, 48.55092800219151],
                            [2.395117046818187, 48.55086194420799],
                            [2.394734161474601, 48.55078452046978],
                            [2.394462429419717, 48.55072999088811],
                            [2.394113152621567, 48.55067091589334],
                            [2.393766348219074, 48.55062073224175],
                            [2.393468324676117, 48.5505867108608],
                            [2.393235326146788, 48.55056254706332],
                            [2.393007750362699, 48.55054107864427],
                            [2.3918062259139, 48.55044904648033],
                            [2.390963677324719, 48.55038920276718],
                            [2.389732371969956, 48.550306154846474],
                            [2.389409882897858, 48.550277068670624],
                            [2.389068616694133, 48.550244415474374],
                            [2.388621726859338, 48.55019185305908],
                            [2.3881989236338, 48.5501243133686],
                            [2.387908295634654, 48.55006539850766],
                            [2.387673520412669, 48.55001638254928],
                            [2.387381317849337, 48.54995270758493],
                            [2.387077178909364, 48.549880221036304],
                            [2.386804444140788, 48.549809731671736],
                            [2.386487486152852, 48.549724637313886],
                            [2.386154540610589, 48.54962613855373],
                            [2.385774793342537, 48.54949692465543],
                            [2.3854311990586, 48.54936285508132],
                            [2.38506871874248, 48.54921815721396],
                            [2.384743777696503, 48.54907920825262],
                            [2.384487933975958, 48.54896590151627],
                            [2.384183037500693, 48.54880866002238],
                            [2.383905234611818, 48.54865590306811],
                            [2.383669438328765, 48.54852021325466],
                            [2.383435393354493, 48.54836993087676],
                            [2.383218138534695, 48.54822274600157],
                            [2.382761393581946, 48.54788840977811],
                            [2.381984758677325, 48.5472673383694],
                            [2.381134953317288, 48.5465869389641],
                            [2.38054131550523, 48.546102472479454],
                            [2.380407139524894, 48.54599281468167],
                            [2.380132013206092, 48.54577170369212],
                            [2.379741693288608, 48.545458912579434],
                            [2.379457085590212, 48.54522971084169],
                            [2.37876091583282, 48.54466498995169],
                            [2.378170960000866, 48.5441852554305],
                            [2.378057121967823, 48.54409267363602],
                            [2.377729156081261, 48.54381762074114],
                            [2.377548908340998, 48.54366301421627],
                            [2.377288685612061, 48.543416712772306],
                            [2.377058270211949, 48.54318388795905],
                            [2.37682377853356, 48.542932179601394],
                            [2.376419816425015, 48.54244132951898],
                            [2.376156809130255, 48.54208261956789],
                            [2.375929018852932, 48.54172929157484],
                            [2.375807765128369, 48.54150876836237],
                            [2.3756794820536, 48.54126895954263],
                            [2.375580471573856, 48.54107295597891],
                            [2.375511296606956, 48.540931796900985],
                            [2.375443461762999, 48.54077085380949],
                            [2.375340352166408, 48.5405244936223],
                            [2.375203251090066, 48.54009829375359],
                            [2.375072895409732, 48.5396379202553],
                            [2.374760484100466, 48.53838446509549],
                            [2.37451057689767, 48.53739716821473],
                            [2.374305564480881, 48.53667513557321],
                            [2.374156674711918, 48.53627246650217],
                            [2.373981330495695, 48.535861418433896],
                            [2.373648835459785, 48.53529539033638],
                            [2.373257393654299, 48.53468363243417],
                            [2.372978201680428, 48.53432492024865],
                            [2.371755892005162, 48.53293955602105],
                            [2.37154178078185, 48.53268243607095],
                            [2.371166420107656, 48.5322392187577],
                            [2.370518497736708, 48.53150198648683],
                        ],
                    },
                },
                1127: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.45631319229628, 2.3595411235982473],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 6667.66788397,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35075644587352,
                            48.43449061286291,
                            2.376672818506992,
                            48.484957377176464,
                        ),
                        "coordinates": [
                            [2.351858421416974, 48.484957377176464],
                            [2.351405902238156, 48.48413090444215],
                            [2.351268938818177, 48.48385792740903],
                            [2.351133849648378, 48.48356711076029],
                            [2.35103444133562, 48.48327378364652],
                            [2.350922657103347, 48.482943059327695],
                            [2.350825143855014, 48.48251233118855],
                            [2.3507709350422, 48.482142747503204],
                            [2.35075644587352, 48.481735979389335],
                            [2.350761185732615, 48.48137669554729],
                            [2.350796307541765, 48.48098181447191],
                            [2.350876523481057, 48.48057727564855],
                            [2.350986801916553, 48.480205739448124],
                            [2.351127091858427, 48.4798379061864],
                            [2.351361191593127, 48.47926867511752],
                            [2.351798468486187, 48.47815671009806],
                            [2.351976125128622, 48.47770480119509],
                            [2.352168029424266, 48.47721648298775],
                            [2.352941018182111, 48.47524702135996],
                            [2.353060975078973, 48.47487808414182],
                            [2.353176105212351, 48.47452399236065],
                            [2.353262534629082, 48.47414809423692],
                            [2.353303037687098, 48.47393766408106],
                            [2.353348939291469, 48.473696659311],
                            [2.35339480658462, 48.47335403899284],
                            [2.353414996971655, 48.47306807578504],
                            [2.353424106387569, 48.47247316760274],
                            [2.353405315695303, 48.47203993655243],
                            [2.353376680957404, 48.47172011006947],
                            [2.353311633543518, 48.47119544002627],
                            [2.353257364387439, 48.470780414776826],
                            [2.353178081619358, 48.470196860677234],
                            [2.353068938414427, 48.46939380332815],
                            [2.352810069920779, 48.467583656488486],
                            [2.352551219488649, 48.46577261139009],
                            [2.352231158161814, 48.46356060894541],
                            [2.35209729314173, 48.46270444653591],
                            [2.352049858938415, 48.462344754785164],
                            [2.352032118953565, 48.46181420175633],
                            [2.352049605615055, 48.46151924654373],
                            [2.352123821855585, 48.461040837598006],
                            [2.352284526929289, 48.46043112684651],
                            [2.352454739547952, 48.459968890430176],
                            [2.352606067281748, 48.459655932172076],
                            [2.352845234598728, 48.45921886442479],
                            [2.352969556535749, 48.45902550903081],
                            [2.353457411500139, 48.45837438349188],
                            [2.353789871255042, 48.45799754938406],
                            [2.354175056193571, 48.45762700088548],
                            [2.354480506382826, 48.45736437336508],
                            [2.354922477738559, 48.45703517860243],
                            [2.355472582990637, 48.45666639802756],
                            [2.355952415468522, 48.45638755059195],
                            [2.356548493352793, 48.456072710987236],
                            [2.357163502950564, 48.455792504035024],
                            [2.358658432507235, 48.455127212649174],
                            [2.36052261265637, 48.45427731028444],
                            [2.361397386690067, 48.453878469272055],
                            [2.361738705615174, 48.45371925173526],
                            [2.362029284225525, 48.45357620618419],
                            [2.362227950535608, 48.45346555476043],
                            [2.362485990370791, 48.453311127160916],
                            [2.362807712915706, 48.45311291733177],
                            [2.363068951864235, 48.45291499654968],
                            [2.363380662429135, 48.452678448428436],
                            [2.363655308374399, 48.45243304069442],
                            [2.363984611011225, 48.45208839909412],
                            [2.364153479853971, 48.451891422993114],
                            [2.364454706350717, 48.45147949553674],
                            [2.364601910887606, 48.45122497235047],
                            [2.364744283718034, 48.45092701921636],
                            [2.364858421946664, 48.450639501017534],
                            [2.364943449105445, 48.45040028055223],
                            [2.365013596213124, 48.45014307903372],
                            [2.365054012366695, 48.449902071432476],
                            [2.365083256064401, 48.449610840988996],
                            [2.365088794942146, 48.44926000199992],
                            [2.365064230847622, 48.44884815361311],
                            [2.364999156137261, 48.448510953309956],
                            [2.364927247745353, 48.44826646915804],
                            [2.364812679580815, 48.44797825099737],
                            [2.364407711839693, 48.44716762919587],
                            [2.363866561541021, 48.44628919977242],
                            [2.363459359017608, 48.44562745332588],
                            [2.362787022318159, 48.44453323153953],
                            [2.362513742649885, 48.444041407879254],
                            [2.362364895688256, 48.44370602369769],
                            [2.362298730145185, 48.44346832335294],
                            [2.362230821251746, 48.44318269492373],
                            [2.362202326264681, 48.44296238667724],
                            [2.362185247522446, 48.44274980845169],
                            [2.362182430564277, 48.4424975687991],
                            [2.362212772820529, 48.44224568723672],
                            [2.362262659411531, 48.44200647712082],
                            [2.362396244434661, 48.441582003061825],
                            [2.362501532020942, 48.441325694505586],
                            [2.362644661159188, 48.44107027729168],
                            [2.362889670518025, 48.44071848802755],
                            [2.363229463907992, 48.44030308604966],
                            [2.363549604575344, 48.43999726719883],
                            [2.363828087803435, 48.4397682046902],
                            [2.364162703412983, 48.439525121433526],
                            [2.364447984348996, 48.43934330006837],
                            [2.364850598586229, 48.43912198646962],
                            [2.36507487810536, 48.43900862532138],
                            [2.36535186037546, 48.43888805681435],
                            [2.36566127657184, 48.43877107615785],
                            [2.366073387621316, 48.43862888866173],
                            [2.366394976962169, 48.43853168634317],
                            [2.366812514498875, 48.43843175906023],
                            [2.367559773588883, 48.43828048447045],
                            [2.369258337546512, 48.43796976726835],
                            [2.370237397058841, 48.43779648016587],
                            [2.37075444848589, 48.43769175459093],
                            [2.371352840274441, 48.437558216829196],
                            [2.371885507102863, 48.43740816031888],
                            [2.372395851187614, 48.437237733719776],
                            [2.373061912986628, 48.436980336702185],
                            [2.373324002322468, 48.43686425016002],
                            [2.373846805129614, 48.43660689545984],
                            [2.374327038131681, 48.43631731201956],
                            [2.374676964486855, 48.436089586467276],
                            [2.375040840818764, 48.43581875932086],
                            [2.375340656815391, 48.43557226442181],
                            [2.376672818506992, 48.43449061286291],
                        ],
                    },
                },
                1128: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.39414324789303, 2.8160168742601543],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 5136.87881929,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.79881830701568,
                            48.38677098743939,
                            2.842037388815223,
                            48.406805624897885,
                        ),
                        "coordinates": [
                            [2.842037388815223, 48.38677098743939],
                            [2.841698881704751, 48.386999855953114],
                            [2.839878665702851, 48.388226761946115],
                            [2.838143556900413, 48.38939972730359],
                            [2.837544526780852, 48.3897806892631],
                            [2.837134553605594, 48.390044821344645],
                            [2.836607065462349, 48.39034694415141],
                            [2.836119512082447, 48.390623907423375],
                            [2.835668945823051, 48.39084895411695],
                            [2.83408240518332, 48.39162148003852],
                            [2.831103505507769, 48.39303713316291],
                            [2.830528054791314, 48.39329765203071],
                            [2.83014956152507, 48.39346073478158],
                            [2.829881566168277, 48.393570672299724],
                            [2.829475620129279, 48.393706276319996],
                            [2.829154593818274, 48.393803848238434],
                            [2.828783556965095, 48.39390201192865],
                            [2.828467665926816, 48.39396967455417],
                            [2.82819794773668, 48.39402411696262],
                            [2.827832568496383, 48.39408122055157],
                            [2.827554901269172, 48.394120146885705],
                            [2.827264014486758, 48.39414773189826],
                            [2.826947988577312, 48.39416337781052],
                            [2.826575607155586, 48.39417034414367],
                            [2.826206466922244, 48.39417185217857],
                            [2.825833254602233, 48.394168191691634],
                            [2.825493437900992, 48.394164144647036],
                            [2.823783457785881, 48.39415226351903],
                            [2.822075734626787, 48.39415188405467],
                            [2.821592307910325, 48.39414946085202],
                            [2.821004911651968, 48.39414748154223],
                            [2.820705133902505, 48.39414606685596],
                            [2.820512033981404, 48.39414509454646],
                            [2.820186600917884, 48.394143788154],
                            [2.818838946406499, 48.39413695136086],
                            [2.818134064314846, 48.39413365817376],
                            [2.817606926935894, 48.3941249601547],
                            [2.817134530248559, 48.394100139419905],
                            [2.81668732339413, 48.39406819439624],
                            [2.816189815861812, 48.394009725785196],
                            [2.815771432355487, 48.39394251182733],
                            [2.815344499143934, 48.39386402912943],
                            [2.814991137657181, 48.39377915781205],
                            [2.814626141900765, 48.39368131112806],
                            [2.814188401472606, 48.39355691528615],
                            [2.813810556940763, 48.393435269505986],
                            [2.81333235213053, 48.39327092283402],
                            [2.812866592582483, 48.39310485479284],
                            [2.810843540665898, 48.39238392395131],
                            [2.808921195536454, 48.39168293027749],
                            [2.808442865797487, 48.39153324602262],
                            [2.807978570626317, 48.39140221830429],
                            [2.807614516569224, 48.39131201022576],
                            [2.807227671772651, 48.391238981846094],
                            [2.806732858670969, 48.391170897165715],
                            [2.806365347543632, 48.39113681719301],
                            [2.805944332402294, 48.39111327451771],
                            [2.805494019388149, 48.39109600426463],
                            [2.805111107451884, 48.391102760838336],
                            [2.804690703437515, 48.391129483769184],
                            [2.804291947776909, 48.39117931388007],
                            [2.803946614445723, 48.39123369876228],
                            [2.80366598979983, 48.39128718308189],
                            [2.803361137018171, 48.391350897184736],
                            [2.803099018722284, 48.391415250073045],
                            [2.802767779300291, 48.391513735138396],
                            [2.802447273412157, 48.39161698111626],
                            [2.802160754888316, 48.3917212653797],
                            [2.80189543125758, 48.391833807340085],
                            [2.80161448719968, 48.39195945593684],
                            [2.801339809708058, 48.39209977357042],
                            [2.801083953852368, 48.39224715035056],
                            [2.800780296939549, 48.39244111928857],
                            [2.800553958666709, 48.392593726580365],
                            [2.800295944181789, 48.39279821346106],
                            [2.800104647443416, 48.39297387530976],
                            [2.799905606796075, 48.39318168871287],
                            [2.799719898161118, 48.39338230983161],
                            [2.799531687052304, 48.39360256885954],
                            [2.799354223955843, 48.39387084124223],
                            [2.799233652168398, 48.39407439127353],
                            [2.799058488530579, 48.39445103470504],
                            [2.798960953198262, 48.39472267337228],
                            [2.798878916885008, 48.39500891820664],
                            [2.798842060542242, 48.39525906216381],
                            [2.79881830701568, 48.39552745645012],
                            [2.798819688616015, 48.39576273790373],
                            [2.7988629031904, 48.39610306069818],
                            [2.798896612390761, 48.39627185304748],
                            [2.798955570222556, 48.39646671462843],
                            [2.79905535965127, 48.396720382766084],
                            [2.799164181649549, 48.39701357850241],
                            [2.799300111446354, 48.397343466945806],
                            [2.799693675869852, 48.39824578350198],
                            [2.800055071403618, 48.39911101458101],
                            [2.800343730305794, 48.399787607719276],
                            [2.800588390616098, 48.40035353915334],
                            [2.800757533644887, 48.40074478578029],
                            [2.800895851718446, 48.4010985264152],
                            [2.801012627868062, 48.40139531976349],
                            [2.801069428520899, 48.4016139890723],
                            [2.801119812843373, 48.40195100447751],
                            [2.801144531048189, 48.40228722641916],
                            [2.801125588776809, 48.40259362862679],
                            [2.801084528943882, 48.40288344168194],
                            [2.801028098486295, 48.40313210892875],
                            [2.800936066678826, 48.40340316470453],
                            [2.800810398204481, 48.4036600247816],
                            [2.799779951109957, 48.405739683526534],
                            [2.799282511992191, 48.40672011416103],
                            [2.79923356025455, 48.406805624897885],
                        ],
                    },
                },
                1129: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.378933796069596, 2.869080995539171],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 4449.42887632,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.842037388815223,
                            48.3761682673058,
                            2.89720177783042,
                            48.38677098743939,
                        ),
                        "coordinates": [
                            [2.89720177783042, 48.378795760781145],
                            [2.896808464150924, 48.37872317951363],
                            [2.895639687658116, 48.37850054973934],
                            [2.894571115865848, 48.37830529105546],
                            [2.893578169186761, 48.37811234791602],
                            [2.892981467176332, 48.37798489145734],
                            [2.89244256301096, 48.377863485287264],
                            [2.8919041416398, 48.37772850096775],
                            [2.891068893646203, 48.37751227981643],
                            [2.890001920226928, 48.377213555220024],
                            [2.888797735035791, 48.37683365742108],
                            [2.888329206536057, 48.37669835702407],
                            [2.887818580375002, 48.37654715989875],
                            [2.887383867015373, 48.376442598239244],
                            [2.886997652809127, 48.376351071676034],
                            [2.886589345654188, 48.37628636100634],
                            [2.886188371497628, 48.376238289216815],
                            [2.885859085772801, 48.37620654141172],
                            [2.885538922258274, 48.376186766320494],
                            [2.884786031423821, 48.3761682673058],
                            [2.883226695837259, 48.37618717385729],
                            [2.881731571873894, 48.37623036041627],
                            [2.880367253481564, 48.37626210744904],
                            [2.878842429865258, 48.37630539852298],
                            [2.877583363129011, 48.37633456160693],
                            [2.876421665460311, 48.37636393163492],
                            [2.87528851703477, 48.37638839098344],
                            [2.874037357953064, 48.37641101734882],
                            [2.873215386859092, 48.37643972326668],
                            [2.872779305231565, 48.376454806032044],
                            [2.872375676808823, 48.376495123927846],
                            [2.871979860689369, 48.376548518511726],
                            [2.870719442483533, 48.376755448397276],
                            [2.869366534734984, 48.37696191568133],
                            [2.868488425371061, 48.37709943923884],
                            [2.867778046882965, 48.37720758549761],
                            [2.867163495805184, 48.37729601772687],
                            [2.866602919070646, 48.3773867738123],
                            [2.866077453908983, 48.37747916114854],
                            [2.865591073074123, 48.37756596749361],
                            [2.865123551383109, 48.37764908572968],
                            [2.864608193861114, 48.3777554491332],
                            [2.864099952770061, 48.37786698889568],
                            [2.863284224689854, 48.37806468067677],
                            [2.863001247975378, 48.37813199348046],
                            [2.862792612933853, 48.37818871881505],
                            [2.862094024119183, 48.37837901300959],
                            [2.861787142284975, 48.37846719278623],
                            [2.861431959308621, 48.37857722604059],
                            [2.860889853245013, 48.3787586928607],
                            [2.857547790288095, 48.379889638425695],
                            [2.854287494424182, 48.38100031892755],
                            [2.849483847615191, 48.38261336466326],
                            [2.848885050020713, 48.38282979143653],
                            [2.84818378651001, 48.38311708626159],
                            [2.84750735106731, 48.3834107452318],
                            [2.847101493865976, 48.3836049226816],
                            [2.846633021671185, 48.38384192856431],
                            [2.846169642172232, 48.384092001528636],
                            [2.845723941072985, 48.384350322262804],
                            [2.844873247542179, 48.38486672485294],
                            [2.843765717606249, 48.38561987909138],
                            [2.843153460059032, 48.38602537529961],
                            [2.842636480875915, 48.38636592596165],
                            [2.842037388815223, 48.38677098743939],
                        ],
                    },
                },
                1130: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.95080907103659, 2.3552965775880255],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4035.11503375,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344386363594881,
                            48.93445554506131,
                            2.372103138402569,
                            48.96375542962029,
                        ),
                        "coordinates": [
                            [2.345604378196291, 48.93445554506131],
                            [2.34552682729569, 48.934759881220835],
                            [2.345435526614926, 48.935194669214006],
                            [2.345360667089803, 48.93555115323384],
                            [2.345304411272231, 48.935866884124174],
                            [2.345187141814928, 48.936525023869564],
                            [2.345094819779337, 48.93693648596403],
                            [2.344825212527904, 48.938001662135036],
                            [2.344718752966593, 48.93841979525869],
                            [2.344611081014025, 48.93884268321627],
                            [2.344492760423405, 48.939715484610716],
                            [2.344449451713561, 48.94002023074903],
                            [2.344426725934739, 48.940216765315945],
                            [2.344406526368034, 48.94038831718981],
                            [2.344398960539695, 48.9405215612369],
                            [2.344388869813095, 48.94067479150671],
                            [2.344386363594881, 48.940819693614955],
                            [2.344391450840797, 48.94102455463337],
                            [2.344394007356398, 48.941211094180694],
                            [2.344406677124401, 48.94139263774116],
                            [2.344421878962407, 48.94161082197553],
                            [2.344454785915123, 48.94186398073844],
                            [2.344480761382309, 48.94203325430529],
                            [2.344505400498639, 48.942167105925336],
                            [2.344543354885731, 48.94235031275322],
                            [2.344591425426755, 48.942551839250726],
                            [2.344657201755636, 48.942788342004455],
                            [2.344773562352791, 48.943123105910715],
                            [2.344841858252559, 48.94328965547715],
                            [2.344905093424825, 48.94343455322234],
                            [2.344978444802704, 48.94359443964079],
                            [2.345056852649428, 48.9437476629708],
                            [2.345160554023738, 48.94393919254359],
                            [2.345251605312194, 48.94409574554805],
                            [2.3453628903806, 48.944273949404725],
                            [2.345479233030904, 48.94445215376108],
                            [2.345630988745441, 48.94465927517137],
                            [2.345744792574485, 48.94481522076713],
                            [2.345866846172878, 48.944981240905655],
                            [2.345993796188436, 48.94513674175982],
                            [2.346081166795825, 48.94523990525407],
                            [2.34620256560829, 48.945378134589895],
                            [2.346344192807948, 48.94552635625603],
                            [2.346485822191318, 48.94567457684265],
                            [2.34666032877667, 48.94585110854772],
                            [2.346910710341534, 48.946095920969036],
                            [2.347077629787674, 48.946247470074574],
                            [2.347310303207732, 48.946438984731834],
                            [2.347467104395332, 48.94656721653107],
                            [2.347616318620489, 48.94668212448929],
                            [2.347755417327525, 48.946788705656054],
                            [2.347919807494888, 48.94691193855022],
                            [2.348160067789278, 48.94708346577434],
                            [2.348367451062664, 48.94722834625719],
                            [2.349632014884843, 48.948115941355844],
                            [2.351614937136265, 48.94950309253226],
                            [2.352925502951169, 48.95042330992545],
                            [2.354537664028993, 48.95155011271105],
                            [2.356157561485857, 48.9527088039936],
                            [2.358757902510807, 48.95454963877417],
                            [2.36106372220096, 48.95614927708678],
                            [2.363384152136846, 48.957766710501666],
                            [2.365578229885342, 48.95931393844462],
                            [2.367595302377924, 48.96072436064664],
                            [2.370028171937784, 48.96232973251893],
                            [2.372103138402569, 48.96375542962029],
                        ],
                    },
                },
                1131: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [49.1131808382978, 3.066219739939638],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 5184.71959853,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.057990651830578,
                            49.09188299627486,
                            3.075626562947475,
                            49.13547414375095,
                        ),
                        "coordinates": [
                            [3.075626562947475, 49.13547414375095],
                            [3.075229177092534, 49.13190698075701],
                            [3.074997143799277, 49.13004330645605],
                            [3.074880647023124, 49.129400150628506],
                            [3.074796957967831, 49.12893484720719],
                            [3.074690527752866, 49.12850656150359],
                            [3.074296624005067, 49.12708818517078],
                            [3.074212240827551, 49.12685131034866],
                            [3.074006491847284, 49.12623970998088],
                            [3.07383913453677, 49.12581500497667],
                            [3.073689679786, 49.12541727398567],
                            [3.073383919928233, 49.12469289303281],
                            [3.073212495371251, 49.12431538425196],
                            [3.072943941492871, 49.12373980592],
                            [3.072148843658405, 49.122266385691184],
                            [3.071721662778833, 49.12155057470113],
                            [3.071222571206968, 49.12078935761827],
                            [3.071003987075186, 49.120463407544555],
                            [3.070896118711915, 49.12030402067948],
                            [3.07016330651083, 49.119302380178446],
                            [3.067868341767203, 49.116335817344265],
                            [3.067689644712098, 49.11611033080519],
                            [3.066311206965854, 49.11433307627346],
                            [3.064332290773528, 49.11177361927007],
                            [3.062157512880818, 49.10898468349302],
                            [3.060935266785134, 49.10740019075615],
                            [3.060078533206293, 49.1063045379949],
                            [3.05977653731974, 49.105908351704336],
                            [3.059576345916269, 49.105612841486064],
                            [3.059189236953362, 49.10499431934409],
                            [3.058920692941152, 49.1045180156823],
                            [3.058682210216297, 49.10397483406948],
                            [3.058476461338707, 49.103434809652406],
                            [3.058327783238762, 49.102981036714304],
                            [3.058247193039191, 49.102673408270064],
                            [3.058174780306424, 49.10239764300285],
                            [3.058120632498592, 49.10215966663203],
                            [3.058059303621754, 49.10180482502257],
                            [3.057990651830578, 49.10104174296728],
                            [3.058000798243712, 49.100562978293475],
                            [3.058027201540221, 49.09993821346115],
                            [3.058106338331776, 49.099276469995374],
                            [3.058153399582697, 49.099024667705116],
                            [3.058243661281336, 49.09860436702784],
                            [3.058443706778534, 49.09788523342769],
                            [3.058597054600228, 49.09744288194165],
                            [3.058790516908031, 49.09696863312417],
                            [3.058945315833268, 49.09662620902377],
                            [3.059071015311288, 49.09637557735779],
                            [3.059465263713218, 49.095664468464236],
                            [3.05986614788201, 49.095071394540284],
                            [3.060092331018913, 49.094755168188364],
                            [3.060336291436921, 49.09444049506401],
                            [3.060907230864604, 49.09376565264417],
                            [3.06131428920744, 49.09333169078106],
                            [3.062690406987056, 49.09188299627486],
                        ],
                    },
                },
                1132: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.75467867609251, 2.2038294013060167],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1985.18553797,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192135811302312,
                            48.751023275119756,
                            2.215860857351649,
                            48.759188983210805,
                        ),
                        "coordinates": [
                            [2.192135811302312, 48.759188983210805],
                            [2.192320295965514, 48.75912019839031],
                            [2.192735754017968, 48.75895476520949],
                            [2.193001263151286, 48.75884133884353],
                            [2.193287060346749, 48.758711876895596],
                            [2.193599060163824, 48.75856523638349],
                            [2.193978336575828, 48.758363430093056],
                            [2.194410190890567, 48.758123061830254],
                            [2.194880593796777, 48.757850620377695],
                            [2.195338822175807, 48.75758619182713],
                            [2.196180252821235, 48.75709872601463],
                            [2.196490461734187, 48.75691976667476],
                            [2.196847284302947, 48.75671944964583],
                            [2.197212207914581, 48.75651646336663],
                            [2.197858828330062, 48.75619202905052],
                            [2.198262146184473, 48.75600916260317],
                            [2.198740407447174, 48.75580764841711],
                            [2.199277369976179, 48.75560486464357],
                            [2.199650165152142, 48.755476830508016],
                            [2.199996568122687, 48.75537686915249],
                            [2.200387541905624, 48.75526223753631],
                            [2.20075215605973, 48.75516497194742],
                            [2.201137008433436, 48.75506773090279],
                            [2.202749322800128, 48.7546587579631],
                            [2.203421791543456, 48.75448689809706],
                            [2.204171207126212, 48.75430173895138],
                            [2.204651240043608, 48.754181844062494],
                            [2.2052750772666, 48.75402463735915],
                            [2.206903515335009, 48.753616964132846],
                            [2.209643863433497, 48.75292410213543],
                            [2.210739572781773, 48.752648277623415],
                            [2.211800839615893, 48.75238177236793],
                            [2.212465136522924, 48.7522152025814],
                            [2.213097016310792, 48.75206063988817],
                            [2.213532642345973, 48.75194076297731],
                            [2.21385655596099, 48.7518421927508],
                            [2.213968158913719, 48.751807241817914],
                            [2.214093372846426, 48.75176780936496],
                            [2.214335654850682, 48.75168263839982],
                            [2.214620230422876, 48.75157278451845],
                            [2.214799847905534, 48.75149968568269],
                            [2.215860857351649, 48.751023275119756],
                        ],
                    },
                },
                1133: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.9258307173004, 2.3972529419069972],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 786.167058001,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.392471119316831,
                            48.9243751434303,
                            2.40207341299691,
                            48.92740289165737,
                        ),
                        "coordinates": [
                            [2.40207341299691, 48.9243751434303],
                            [2.401570685541663, 48.92450288620431],
                            [2.400916816278584, 48.9246932821194],
                            [2.400361380572825, 48.92486044558554],
                            [2.399797604914131, 48.92502210600029],
                            [2.399345389845236, 48.92514373083921],
                            [2.398607073262765, 48.92531330476496],
                            [2.39750310470379, 48.925566496678854],
                            [2.397418523428818, 48.92558870921517],
                            [2.397302625933477, 48.9256258524819],
                            [2.397192003551715, 48.9256694242221],
                            [2.397087474758746, 48.92571910032692],
                            [2.396989813495747, 48.925774514198565],
                            [2.396905564541592, 48.92583099910123],
                            [2.39663502315939, 48.926044342734194],
                            [2.396579689030133, 48.92607887203027],
                            [2.396478765647579, 48.92613397767619],
                            [2.396371197015402, 48.92618332577922],
                            [2.396257737798189, 48.92622656850195],
                            [2.396171494031204, 48.92625336535022],
                            [2.396037721822755, 48.92628811872454],
                            [2.395675305833947, 48.9263692807288],
                            [2.395531301325174, 48.9264034558489],
                            [2.395411621826812, 48.92643893879116],
                            [2.39412579639638, 48.92689812463391],
                            [2.393783955016823, 48.927007530901804],
                            [2.393130038293068, 48.927211788764644],
                            [2.392471119316831, 48.92740289165737],
                        ],
                    },
                },
                1134: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [49.16029172996976, 3.0952712416096126],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 6051.41950253,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.075626562947475,
                            49.13547414375095,
                            3.12061291667141,
                            49.179504949934255,
                        ),
                        "coordinates": [
                            [3.075626562947475, 49.13547414375095],
                            [3.07593991650652, 49.13828659666273],
                            [3.076101032370153, 49.139069755821595],
                            [3.076317468340032, 49.13970237391073],
                            [3.076430597472889, 49.13993456608019],
                            [3.087687495154015, 49.153982716666256],
                            [3.099703478640675, 49.16733030611128],
                            [3.1116530363399, 49.17602932425011],
                            [3.12061291667141, 49.179504949934255],
                        ],
                    },
                },
                1135: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.27733864127247, 2.1614853825365987],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 41134.5418033,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.088506972546535,
                            49.148967156548686,
                            2.284900339194614,
                            49.42620159228318,
                        ),
                        "coordinates": [
                            [2.281752268322335, 49.148967156548686],
                            [2.282208800343669, 49.14917802353894],
                            [2.282462562174711, 49.149304248285276],
                            [2.28282510504158, 49.14948294705987],
                            [2.283088143753219, 49.14964224096266],
                            [2.283510094198281, 49.1499077226569],
                            [2.2839716967429, 49.15027483732596],
                            [2.284376983990668, 49.150749837219635],
                            [2.284621977694921, 49.151131239010915],
                            [2.284740987716886, 49.15137949098699],
                            [2.284805204975493, 49.15158635146099],
                            [2.284891132159011, 49.152006348967696],
                            [2.284900339194614, 49.15237775148358],
                            [2.284882196887253, 49.15268079694366],
                            [2.284854582186587, 49.15286603381959],
                            [2.284802312502798, 49.15302967692484],
                            [2.28471706587342, 49.15326164932998],
                            [2.284565945738875, 49.153553843298525],
                            [2.284424488385595, 49.15378309238998],
                            [2.28427483863905, 49.15397996436704],
                            [2.284154021897541, 49.154135482454464],
                            [2.283691518073509, 49.15457051499451],
                            [2.283142689301167, 49.154951550226215],
                            [2.282694089308317, 49.155194141859255],
                            [2.28222083475179, 49.15541244027126],
                            [2.281729808841196, 49.155578570897596],
                            [2.281471979270276, 49.1556404964075],
                            [2.280902842750697, 49.15576701766519],
                            [2.280668348037227, 49.15580377288218],
                            [2.279579523847433, 49.15596960032767],
                            [2.278991233465018, 49.15605293809132],
                            [2.274612557269267, 49.15670441866811],
                            [2.270970200434434, 49.157245545922244],
                            [2.270727456413732, 49.15728857142475],
                            [2.270472369929036, 49.15733248908211],
                            [2.269775641111518, 49.15748136343086],
                            [2.268848420826032, 49.1577308148818],
                            [2.268565851845469, 49.15781517855494],
                            [2.268416337324365, 49.15786005329294],
                            [2.268036342479907, 49.15799741465808],
                            [2.267921109309415, 49.15803961108037],
                            [2.26760008527707, 49.15816711403324],
                            [2.265077311053331, 49.15902796501905],
                            [2.26368078540024, 49.159488409002556],
                            [2.262794568315026, 49.1597801037764],
                            [2.261205913200599, 49.16031952960806],
                            [2.259827123347985, 49.16079072966096],
                            [2.259094552299854, 49.161009657558054],
                            [2.258394984706167, 49.161164755726794],
                            [2.25786967894301, 49.16124533040704],
                            [2.257293675728573, 49.1613006876837],
                            [2.256671103323684, 49.16132273613457],
                            [2.256152790573384, 49.16131607889674],
                            [2.255812757711801, 49.1612969549692],
                            [2.254791355353263, 49.16120090800118],
                            [2.25404555386318, 49.16111494250424],
                            [2.253488941203321, 49.16105428910913],
                            [2.251560006755283, 49.16083974698874],
                            [2.250959536026688, 49.16077095554749],
                            [2.250675746383173, 49.160741966652964],
                            [2.250356301806535, 49.16071474840029],
                            [2.250058791143893, 49.16069114274945],
                            [2.249750291282771, 49.160678320044966],
                            [2.24955969930027, 49.16067547789061],
                            [2.249404759172001, 49.16067176259686],
                            [2.249063308783547, 49.16068229367342],
                            [2.24869442294606, 49.160699996449694],
                            [2.24828984938539, 49.16073745513254],
                            [2.247923646597093, 49.160786631885685],
                            [2.247616400125971, 49.16083945049576],
                            [2.247235059157207, 49.160919189039184],
                            [2.246841339691573, 49.16101780021518],
                            [2.246385844635974, 49.16115503098664],
                            [2.246012634266445, 49.161284231191594],
                            [2.24561469978392, 49.161435892230045],
                            [2.245134411890227, 49.16162795376544],
                            [2.244713137113575, 49.16179218325989],
                            [2.244523772843707, 49.16186307348382],
                            [2.243878825868534, 49.1621098517654],
                            [2.243340892135866, 49.16232344168008],
                            [2.242786492894021, 49.162539712836626],
                            [2.242227976056201, 49.16275597798592],
                            [2.241528105498188, 49.1630278784329],
                            [2.240839206709898, 49.16329528642173],
                            [2.240243614062444, 49.163528597338555],
                            [2.239259639656321, 49.16391355246353],
                            [2.238875366921242, 49.1640696982737],
                            [2.238473234267046, 49.164241114393064],
                            [2.238084796635583, 49.164419735789714],
                            [2.237644154777562, 49.16464417349631],
                            [2.237284432183001, 49.16486058611547],
                            [2.236953485848667, 49.16508691454454],
                            [2.236637572426544, 49.165336636595356],
                            [2.236232272133976, 49.165707679879404],
                            [2.235920286669351, 49.16604463203876],
                            [2.235784164013781, 49.16621987014],
                            [2.235588931761599, 49.16646339967408],
                            [2.235224495395907, 49.16696037368135],
                            [2.235218997553521, 49.166966663018144],
                            [2.234992151476035, 49.167241638886644],
                            [2.234743304154243, 49.16754447144504],
                            [2.23431292541112, 49.168089044841274],
                            [2.23395129781889, 49.168542852181766],
                            [2.233789052494224, 49.16874234454763],
                            [2.233335262492552, 49.16932286366657],
                            [2.233107002193131, 49.169608625501496],
                            [2.232952998114879, 49.16979913134455],
                            [2.232781091742076, 49.1700237928286],
                            [2.232523920700929, 49.170358086675165],
                            [2.232156799302258, 49.17080019332255],
                            [2.231749847486397, 49.17126564223539],
                            [2.231386925830382, 49.17166098774691],
                            [2.230984197017191, 49.172069784535154],
                            [2.230633705216934, 49.172419276711594],
                            [2.23034102817004, 49.17266990165946],
                            [2.229957636662602, 49.17300767035579],
                            [2.229363972558951, 49.17353768503739],
                            [2.228959960560576, 49.17389071894753],
                            [2.228680998038859, 49.17413415824048],
                            [2.22802824738282, 49.174700980197414],
                            [2.227452414442501, 49.17521211748601],
                            [2.227023648518356, 49.175582206876],
                            [2.226623728190921, 49.17593073986092],
                            [2.226223812087924, 49.176274775105874],
                            [2.225826635858965, 49.17661791217564],
                            [2.225557260538959, 49.17685415961566],
                            [2.225019920001279, 49.177305070000365],
                            [2.224175987094311, 49.17806232889526],
                            [2.223811743368068, 49.1783875058189],
                            [2.223271327630748, 49.17896879998512],
                            [2.22301409257423, 49.17928328905592],
                            [2.222806307704781, 49.179566352497716],
                            [2.221553717835592, 49.18141309754983],
                            [2.220893116094803, 49.18232608929807],
                            [2.22075549743758, 49.182512098294545],
                            [2.220426741587652, 49.18289035786455],
                            [2.220037616077181, 49.183270352767146],
                            [2.219702163384578, 49.183575762491216],
                            [2.219414885572807, 49.18381197698613],
                            [2.218797809652118, 49.18427806462617],
                            [2.217932180379868, 49.184840113944226],
                            [2.216995122924123, 49.185431757916966],
                            [2.21639880157706, 49.185807927212785],
                            [2.213897994546784, 49.18738799044159],
                            [2.213456878910664, 49.1876761825188],
                            [2.213217699022653, 49.18785937649558],
                            [2.213023810603334, 49.18803542416777],
                            [2.212974306843408, 49.188080334443676],
                            [2.212880796531971, 49.188166563055795],
                            [2.212839544085083, 49.188203388701794],
                            [2.212768043422621, 49.18826625994995],
                            [2.212403480260452, 49.18865884604325],
                            [2.212033356996799, 49.18907750294869],
                            [2.210617550907806, 49.19064967444208],
                            [2.209311815449277, 49.1920690753875],
                            [2.208239931206791, 49.19323333092482],
                            [2.206459229563656, 49.1951962239326],
                            [2.205988545981807, 49.19572535674587],
                            [2.205762911622804, 49.19594991684414],
                            [2.205228872740735, 49.196560807745385],
                            [2.204873997659248, 49.19687694279088],
                            [2.204234706940536, 49.19732763939909],
                            [2.202890536703796, 49.19811293944197],
                            [2.202425816726813, 49.1984433277618],
                            [2.202172764916482, 49.19864716528216],
                            [2.201951423128724, 49.19879618361331],
                            [2.201615883768336, 49.19905387914094],
                            [2.200878819876131, 49.199606958415934],
                            [2.200515785370533, 49.199878106412235],
                            [2.200199553094643, 49.20009625346048],
                            [2.199718414988082, 49.200395137133704],
                            [2.199234640480974, 49.20065354848586],
                            [2.198991439135116, 49.20076116921626],
                            [2.198735930921028, 49.20085258816219],
                            [2.198251010756081, 49.20102646349629],
                            [2.19783070685755, 49.20115814927319],
                            [2.196406451612349, 49.2015601912174],
                            [2.196057594524798, 49.2016586842345],
                            [2.195604289705862, 49.201809205054126],
                            [2.195447660514661, 49.20187196193196],
                            [2.190641377719702, 49.20511055502064],
                            [2.184487723575927, 49.20907980707016],
                            [2.181555060915173, 49.21052640818711],
                            [2.178838890023609, 49.21122457658761],
                            [2.173694015248828, 49.212012845194074],
                            [2.170050113860247, 49.21242874112071],
                            [2.156623173429692, 49.21231491631781],
                            [2.153336912416072, 49.21254367885833],
                            [2.147691713832732, 49.21328319553407],
                            [2.143757955232373, 49.21468039345287],
                            [2.141538034790111, 49.21612716934435],
                            [2.139814623723986, 49.21841699142516],
                            [2.136287504492427, 49.22505522068837],
                            [2.133622426649532, 49.23033792694531],
                            [2.132755558863006, 49.232629150516836],
                            [2.132238502485929, 49.2366990447326],
                            [2.131529495206815, 49.25251310652985],
                            [2.131799833970203, 49.25625685618238],
                            [2.13250478585831, 49.25864444160128],
                            [2.133854199054327, 49.26079920566149],
                            [2.136773577867149, 49.263705343236644],
                            [2.139263923088123, 49.266704251920025],
                            [2.140754622870191, 49.2694206637359],
                            [2.141460197935926, 49.27180819070626],
                            [2.141523167987087, 49.273960672389016],
                            [2.141303245570464, 49.275317230299066],
                            [2.13999992735952, 49.279339014049874],
                            [2.137038417898883, 49.28653968533707],
                            [2.135670569218657, 49.28868967737242],
                            [2.132505087645742, 49.29303564091912],
                            [2.130275415583123, 49.29588589574677],
                            [2.129481939307394, 49.29742856303058],
                            [2.129045558153464, 49.29911223932146],
                            [2.129390266762544, 49.30220104564267],
                            [2.133388745348578, 49.32153270680241],
                            [2.13373426832722, 49.3245279127965],
                            [2.133583549539344, 49.326352479245074],
                            [2.133005226333033, 49.32770838479052],
                            [2.128189095714313, 49.33233203458737],
                            [2.121289844934893, 49.33826174082732],
                            [2.119059949005965, 49.34055028637304],
                            [2.116310715830815, 49.3468149858708],
                            [2.114490434162251, 49.353408943182075],
                            [2.114268770125549, 49.354905808301254],
                            [2.115252780017247, 49.35907204784842],
                            [2.116665961214938, 49.36342625863486],
                            [2.117803867970606, 49.36530003740532],
                            [2.120874045739219, 49.36769213236899],
                            [2.124874367631671, 49.37046017939753],
                            [2.127445028228768, 49.37252364623333],
                            [2.128086932430777, 49.37322666329907],
                            [2.128583158434803, 49.3744908980695],
                            [2.128410043691577, 49.381509122103466],
                            [2.128687188221026, 49.383755552785686],
                            [2.131165655947664, 49.39091889436254],
                            [2.134002144045466, 49.39836354533685],
                            [2.13456062272576, 49.40201415851596],
                            [2.135104535853551, 49.40922080048745],
                            [2.135447112136225, 49.413104981889376],
                            [2.135152362005094, 49.41502286232502],
                            [2.134428819703839, 49.41656566965103],
                            [2.133492597588171, 49.41749982584135],
                            [2.13104940805754, 49.41861845825205],
                            [2.125231891352458, 49.42047954240386],
                            [2.116041298714637, 49.42266146013339],
                            [2.105845444836949, 49.42488742782943],
                            [2.100390542605239, 49.42557823344088],
                            [2.088506972546535, 49.42620159228318],
                        ],
                    },
                },
                1136: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.3825872516373, 2.3905094977079777],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2602.09303424,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.3872097971981,
                            48.371383292302916,
                            2.393410724066637,
                            48.393641547740856,
                        ),
                        "coordinates": [
                            [2.393410724066637, 48.393641547740856],
                            [2.392363245233849, 48.39244565517714],
                            [2.391376347627626, 48.39131219590069],
                            [2.391192469856157, 48.391080280611796],
                            [2.390890909515063, 48.39064699187898],
                            [2.390688003023055, 48.39029368829583],
                            [2.390555416520312, 48.39004286291452],
                            [2.39043519223075, 48.38976585499594],
                            [2.390304998401631, 48.38944588736297],
                            [2.390183025699551, 48.38901700778393],
                            [2.390108396843718, 48.38866903641563],
                            [2.390066176819767, 48.38832644628677],
                            [2.390046926542853, 48.388000930808275],
                            [2.390056021324612, 48.38766910666529],
                            [2.390074576128582, 48.38734537169897],
                            [2.390116079410822, 48.38701982666575],
                            [2.390176548237062, 48.38675542174208],
                            [2.39023971584347, 48.38648921683037],
                            [2.390296192294752, 48.38627966734489],
                            [2.390354017312367, 48.38606921694245],
                            [2.390421230179562, 48.38580031282357],
                            [2.390495161489406, 48.38550442703605],
                            [2.390668622631973, 48.3848649848604],
                            [2.390776205861406, 48.38448005848611],
                            [2.391020958130526, 48.383611275986176],
                            [2.391127156125663, 48.383199372456616],
                            [2.391289843624423, 48.382598602373776],
                            [2.391413538314752, 48.382142628173135],
                            [2.391515715419836, 48.38176219993214],
                            [2.391574788723748, 48.381469019134975],
                            [2.39161631461713, 48.38117674595306],
                            [2.391640316999381, 48.38090786224897],
                            [2.391649450820205, 48.38062189962918],
                            [2.391650525947396, 48.38037280942493],
                            [2.391638074423584, 48.38009854808377],
                            [2.39161479157921, 48.379794616516534],
                            [2.391587487906523, 48.37951676458136],
                            [2.391527765806273, 48.379218246456965],
                            [2.391457235931949, 48.3789107414013],
                            [2.391393560108212, 48.37869855169373],
                            [2.391105230243751, 48.377952323190854],
                            [2.390873879646332, 48.37746324894091],
                            [2.390599354064213, 48.37698768333285],
                            [2.390095086486107, 48.37624605215743],
                            [2.389608399651747, 48.37552329472637],
                            [2.388991974367018, 48.374629739912734],
                            [2.388475578257414, 48.37386112937614],
                            [2.387976776941254, 48.3731248820972],
                            [2.387696893197486, 48.37263852160785],
                            [2.387494890478292, 48.372241834414595],
                            [2.387277493897655, 48.37165314609449],
                            [2.3872097971981, 48.371383292302916],
                        ],
                    },
                },
                1137: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.88939035402716, 2.366021984427431],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2124.47495445,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358833235621349,
                            48.88091352744822,
                            2.37412297552969,
                            48.89667381116845,
                        ),
                        "coordinates": [
                            [2.358833235621349, 48.88091352744822],
                            [2.359224804499837, 48.8814665042771],
                            [2.359378977809214, 48.88168409759705],
                            [2.359615003171946, 48.881986206863495],
                            [2.359906965105339, 48.88235574869018],
                            [2.360125244354309, 48.88260120573624],
                            [2.360507182619527, 48.88301291599308],
                            [2.360798351881631, 48.8833113725665],
                            [2.361095232714786, 48.88359192980177],
                            [2.361470336311405, 48.88391655859905],
                            [2.361658586053607, 48.884071192824706],
                            [2.361931407865383, 48.88428426072439],
                            [2.362227420608013, 48.88451260965039],
                            [2.362543894188839, 48.88474904735172],
                            [2.362898222443151, 48.88504653675245],
                            [2.363139215282974, 48.88527755012504],
                            [2.363687134516854, 48.8859397172883],
                            [2.364025519188199, 48.88638594226535],
                            [2.364675543719203, 48.8874469673656],
                            [2.365661339747672, 48.889113515421656],
                            [2.366650972292101, 48.89078355226665],
                            [2.367304735218245, 48.89187311439831],
                            [2.367532275645794, 48.89222043533884],
                            [2.36772729270491, 48.892484488590725],
                            [2.367958405126996, 48.89276518683221],
                            [2.368175059060795, 48.893000681279],
                            [2.368395324960341, 48.893238553239556],
                            [2.368662524410929, 48.89350972307389],
                            [2.368886387850427, 48.8937237998869],
                            [2.369222175483918, 48.89402825834659],
                            [2.36947851715923, 48.894239946434915],
                            [2.369720419303542, 48.89443736128105],
                            [2.370034521737102, 48.894675202977886],
                            [2.370355832276493, 48.89489638673899],
                            [2.37066630726123, 48.89509853702541],
                            [2.370937066742667, 48.89526500964294],
                            [2.371344995508631, 48.8954909227114],
                            [2.371684334318134, 48.89567402759272],
                            [2.372001710155025, 48.89584075304363],
                            [2.372312457870593, 48.895985525618165],
                            [2.372698712991364, 48.896163854314324],
                            [2.373030811637182, 48.896301749106065],
                            [2.37332680343868, 48.896411103953625],
                            [2.373727472580184, 48.896551354743856],
                            [2.37412297552969, 48.89667381116845],
                        ],
                    },
                },
                1138: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.64878906112415, 2.559649723799478],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 4702.9854373,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.547548045814366,
                            48.62837555172384,
                            2.56958354823646,
                            48.66790196104987,
                        ),
                        "coordinates": [
                            [2.56958354823646, 48.62837555172384],
                            [2.569406439175108, 48.62889890137802],
                            [2.56913342267403, 48.62962039695549],
                            [2.568629048530896, 48.63081638115946],
                            [2.568266513822785, 48.631590401960274],
                            [2.567391618190399, 48.63334812704903],
                            [2.566950589204467, 48.634234132914834],
                            [2.566449473902916, 48.6353272596119],
                            [2.565994695460244, 48.63635366933025],
                            [2.56568511442547, 48.637066496834905],
                            [2.565340977921392, 48.637766824389495],
                            [2.564894971173897, 48.63874253154561],
                            [2.564635729043129, 48.63931858668684],
                            [2.564051150823877, 48.6406129906347],
                            [2.563723760738216, 48.64135086234981],
                            [2.56330872968431, 48.642282506963454],
                            [2.563018228015947, 48.64294067665082],
                            [2.562630848528986, 48.64381206177847],
                            [2.562312511904095, 48.644500385980066],
                            [2.561942507202297, 48.64535552551547],
                            [2.561587925483845, 48.64620923051155],
                            [2.561053363199314, 48.64732311202191],
                            [2.55973832591891, 48.650149252410294],
                            [2.55962275481229, 48.650405771799306],
                            [2.559009989226959, 48.651776564824345],
                            [2.558813759673332, 48.65220859982774],
                            [2.558609478770262, 48.65266223198352],
                            [2.558406499926798, 48.653104171436375],
                            [2.558151110818841, 48.653664916390206],
                            [2.557979153435526, 48.654064528093244],
                            [2.557813708441414, 48.65440297737949],
                            [2.557525663005992, 48.654948496784925],
                            [2.557179414908994, 48.655531897920326],
                            [2.556766882555606, 48.656168482914076],
                            [2.556536225230001, 48.65649716443471],
                            [2.556108453040318, 48.65706723109287],
                            [2.555622429634984, 48.657666184527585],
                            [2.555091932232451, 48.658340760760815],
                            [2.554545342900555, 48.659063925760314],
                            [2.554210584935686, 48.65949531875231],
                            [2.553481552192786, 48.66041127221636],
                            [2.553119710579877, 48.66086249832071],
                            [2.552562120158716, 48.66156589038121],
                            [2.552000468691985, 48.662275583110564],
                            [2.551502236174676, 48.662899721998],
                            [2.551272712301752, 48.66319151972034],
                            [2.550593088637024, 48.66399975558181],
                            [2.550260789836023, 48.664407245867245],
                            [2.549846390610607, 48.66493623613217],
                            [2.549421184863024, 48.66546048499634],
                            [2.548967377971035, 48.666018096460355],
                            [2.548387495128188, 48.6667635390484],
                            [2.548050814835807, 48.667245184400095],
                            [2.547730847990273, 48.66766933678332],
                            [2.547548045814366, 48.66790196104987],
                        ],
                    },
                },
                1139: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [49.071548767664495, 2.518825766579545],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 6139.99703832,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.501758065846462,
                            49.049325600885666,
                            2.525531713992054,
                            49.0995869391937,
                        ),
                        "coordinates": [
                            [2.525531713992054, 49.0995869391937],
                            [2.525456205313082, 49.09878998487126],
                            [2.525388807844771, 49.09815501736476],
                            [2.525263989645341, 49.09677758485618],
                            [2.525101742246043, 49.09508376028289],
                            [2.525018928933173, 49.09426778171277],
                            [2.524959021857032, 49.09375870102211],
                            [2.524831400626698, 49.09259065398214],
                            [2.52469274286543, 49.091377416045574],
                            [2.524564372804595, 49.09000950569161],
                            [2.524288894852118, 49.087102399979976],
                            [2.52412655899805, 49.085368124784615],
                            [2.523979264220945, 49.083776585137386],
                            [2.523817004176479, 49.08205658528732],
                            [2.523515479146732, 49.07894251669787],
                            [2.523353439169441, 49.07727248194281],
                            [2.523194870490833, 49.07555961244652],
                            [2.522912032892946, 49.0725787534216],
                            [2.52273882057365, 49.07081594102618],
                            [2.522508581232654, 49.06832752099011],
                            [2.522437138104643, 49.06762334965069],
                            [2.522403183300106, 49.0672593650209],
                            [2.522347545763149, 49.0669073122521],
                            [2.522310524646228, 49.0666908521814],
                            [2.522244354928861, 49.06642685171675],
                            [2.522181879154814, 49.06618187949972],
                            [2.522097669226215, 49.06593456386146],
                            [2.52198433097011, 49.06564446700814],
                            [2.521831020417443, 49.06531636517778],
                            [2.521655871261256, 49.06495736540949],
                            [2.521528319923761, 49.06473867131059],
                            [2.521335239632957, 49.064424909180275],
                            [2.521084066929011, 49.06406841077629],
                            [2.520894885212112, 49.06382840005642],
                            [2.520683929563137, 49.063574148388575],
                            [2.520487562929214, 49.06334842472652],
                            [2.520273094665979, 49.063122730026926],
                            [2.520047775783673, 49.062899430981616],
                            [2.5197898164025, 49.06266190841207],
                            [2.519441131173611, 49.06236742448827],
                            [2.519056215702498, 49.06206586008418],
                            [2.518576955294328, 49.061707338191916],
                            [2.517505982336898, 49.060926224305746],
                            [2.513382018222184, 49.057884700325715],
                            [2.511305705461247, 49.056353196937266],
                            [2.507785014010126, 49.053765007923765],
                            [2.506044060374637, 49.05249549806436],
                            [2.504291141078054, 49.05118942944881],
                            [2.502068583516813, 49.049554300205486],
                            [2.501758065846462, 49.049325600885666],
                        ],
                    },
                },
                1140: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.041791667925565, 2.1187300111148657],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2180.50810562,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.107233059674136,
                            49.033987636271455,
                            2.128263873923673,
                            49.04558799326531,
                        ),
                        "coordinates": [
                            [2.128263873923673, 49.033987636271455],
                            [2.128129194074634, 49.034113715787555],
                            [2.127001222509834, 49.03514131753568],
                            [2.126554371205225, 49.03555093473141],
                            [2.126148450092699, 49.035907090451964],
                            [2.125911377526481, 49.03612793351793],
                            [2.12554623049908, 49.036468101551904],
                            [2.12521636011758, 49.036808334727496],
                            [2.125137259772239, 49.03689919806773],
                            [2.124921739789295, 49.03715576938806],
                            [2.124701970925326, 49.03741818034744],
                            [2.124508532850205, 49.037707907023204],
                            [2.12440497701337, 49.03785768139787],
                            [2.124326846051249, 49.037970682918875],
                            [2.124059183968403, 49.03838472483637],
                            [2.123776786101228, 49.038804811006315],
                            [2.123509210313695, 49.03921103870588],
                            [2.123276559854186, 49.03955502910891],
                            [2.123100396882108, 49.03980470005338],
                            [2.122898114370557, 49.04008399728096],
                            [2.12250205708275, 49.04057156555514],
                            [2.121908172963902, 49.041253005346746],
                            [2.121542675220651, 49.041629116409815],
                            [2.121276213118279, 49.04187861479338],
                            [2.120950794296375, 49.042158576515476],
                            [2.120635065769966, 49.042411577662996],
                            [2.12029610305886, 49.04265913833664],
                            [2.119932502105776, 49.04290935003786],
                            [2.11951273202694, 49.04317743811158],
                            [2.119077985287255, 49.04342841147821],
                            [2.118628222981144, 49.043671260106215],
                            [2.118168981940748, 49.04389070806361],
                            [2.117752285473035, 49.04407876024903],
                            [2.117253422064275, 49.04428553856905],
                            [2.116779262196315, 49.044473477956316],
                            [2.11632440698335, 49.04462638000719],
                            [2.115877800296, 49.04476940466895],
                            [2.115450420487825, 49.04489537797772],
                            [2.115038154341169, 49.045006091655345],
                            [2.114254838940086, 49.04518712632793],
                            [2.113839944694883, 49.0452726509574],
                            [2.113425656976553, 49.045347331347266],
                            [2.11300892676945, 49.045412217757935],
                            [2.112633856150531, 49.04546364254553],
                            [2.112022053058747, 49.04552899151093],
                            [2.11138984248111, 49.04556911615135],
                            [2.110894539819698, 49.04558612667887],
                            [2.110754998510663, 49.04558675096887],
                            [2.110445627189619, 49.04558799326531],
                            [2.110005283062125, 49.045570484125804],
                            [2.109539658597023, 49.04554626751525],
                            [2.109099345927297, 49.04552209925562],
                            [2.108193440028024, 49.04546705174223],
                            [2.107233059674136, 49.04539401994291],
                        ],
                    },
                },
                1141: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.88807321421946, 2.3656839612278047],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2462.435463,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.359456616944207,
                            48.877375619879636,
                            2.37412297552969,
                            48.89667381116845,
                        ),
                        "coordinates": [
                            [2.359456616944207, 48.877375619879636],
                            [2.359812092572549, 48.877962273326986],
                            [2.360064276433283, 48.878386746095494],
                            [2.36042280758036, 48.878983408628955],
                            [2.360583852309661, 48.87926772577507],
                            [2.360825675702478, 48.8797388019523],
                            [2.360950727590288, 48.88005499726818],
                            [2.361037416069371, 48.8803326302404],
                            [2.361082530912409, 48.880544994411764],
                            [2.361139955494417, 48.88084379592806],
                            [2.361249935984651, 48.881251176902275],
                            [2.361368498320344, 48.881557335241546],
                            [2.361510281666975, 48.88185311843682],
                            [2.361737381049066, 48.88228022486055],
                            [2.362135024314978, 48.882974413779664],
                            [2.362743466558654, 48.884021183150494],
                            [2.363097360205704, 48.88464924555404],
                            [2.363393513000418, 48.88523449373252],
                            [2.363657162285453, 48.88574360918681],
                            [2.364025519188199, 48.88638594226535],
                            [2.364675543719203, 48.8874469673656],
                            [2.365661339747672, 48.889113515421656],
                            [2.366650972292101, 48.89078355226665],
                            [2.367304735218245, 48.89187311439831],
                            [2.367532275645794, 48.89222043533884],
                            [2.36772729270491, 48.892484488590725],
                            [2.367958405126996, 48.89276518683221],
                            [2.368175059060795, 48.893000681279],
                            [2.368395324960341, 48.893238553239556],
                            [2.368662524410929, 48.89350972307389],
                            [2.368886387850427, 48.8937237998869],
                            [2.369222175483918, 48.89402825834659],
                            [2.36947851715923, 48.894239946434915],
                            [2.369720419303542, 48.89443736128105],
                            [2.370034521737102, 48.894675202977886],
                            [2.370355832276493, 48.89489638673899],
                            [2.37066630726123, 48.89509853702541],
                            [2.370937066742667, 48.89526500964294],
                            [2.371344995508631, 48.8954909227114],
                            [2.371684334318134, 48.89567402759272],
                            [2.372001710155025, 48.89584075304363],
                            [2.372312457870593, 48.895985525618165],
                            [2.372698712991364, 48.896163854314324],
                            [2.373030811637182, 48.896301749106065],
                            [2.37332680343868, 48.896411103953625],
                            [2.373727472580184, 48.896551354743856],
                            [2.37412297552969, 48.89667381116845],
                        ],
                    },
                },
                1142: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.919708670210525, 1.4744553072152993],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 4787.05000308,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.443790938714628,
                            48.915096742859646,
                            1.505347805525029,
                            48.92509435108641,
                        ),
                        "coordinates": [
                            [1.505347805525029, 48.915096742859646],
                            [1.505060034537414, 48.91511372470848],
                            [1.504290746378087, 48.91517836656964],
                            [1.502886220498638, 48.91528683405577],
                            [1.500142744059125, 48.91549790214337],
                            [1.500071600953736, 48.91550907279658],
                            [1.500021075036265, 48.915511400185814],
                            [1.498847752217717, 48.91566378081511],
                            [1.498734207336774, 48.915680934830355],
                            [1.49835115721472, 48.915739279489536],
                            [1.49721656816392, 48.915940491507634],
                            [1.497054935679958, 48.915977075600466],
                            [1.496587864466357, 48.91608156104872],
                            [1.49640020066553, 48.91612424763014],
                            [1.496053647887832, 48.91620263818476],
                            [1.495318858310154, 48.91640317553705],
                            [1.494478137109605, 48.916654189131734],
                            [1.494141895985944, 48.916767723300715],
                            [1.493752075561863, 48.91690244543482],
                            [1.493647680234354, 48.916943043753555],
                            [1.493459538177072, 48.91701360224067],
                            [1.492735736286938, 48.917288848606276],
                            [1.492606536121315, 48.91734365260938],
                            [1.492506200693217, 48.91738607830858],
                            [1.491771766348876, 48.917724193205586],
                            [1.491401524702987, 48.91791031408827],
                            [1.491020273832016, 48.91810174842941],
                            [1.490118759837137, 48.918553729776036],
                            [1.49004307146016, 48.918590940627276],
                            [1.489373176174851, 48.91890343880303],
                            [1.486343129897882, 48.91994544813564],
                            [1.483708233401701, 48.92039375033408],
                            [1.474903837013015, 48.92037447565069],
                            [1.462695742920925, 48.92009456430005],
                            [1.458451997240279, 48.92015999885075],
                            [1.457131798825645, 48.9202814530951],
                            [1.45428281185653, 48.92102282238729],
                            [1.448892778128993, 48.92313946825617],
                            [1.443790938714628, 48.92509435108641],
                        ],
                    },
                },
                1143: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.87602588943969, 2.343466385478143],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2604.52317382,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.326717840220577,
                            48.87485177510826,
                            2.358833235621349,
                            48.88091352744822,
                        ),
                        "coordinates": [
                            [2.326717840220577, 48.87502934185029],
                            [2.330067192718978, 48.87496773696305],
                            [2.332007208857291, 48.87493365658635],
                            [2.333168763133175, 48.87489952314828],
                            [2.334136435825398, 48.87487200476471],
                            [2.337615313967533, 48.87485177510826],
                            [2.33858765730156, 48.87489292542079],
                            [2.339081836711515, 48.874928605727526],
                            [2.33997099944716, 48.875002340647875],
                            [2.340966578334892, 48.8750986688345],
                            [2.341417477494118, 48.875154563806554],
                            [2.34199102215441, 48.87523186641291],
                            [2.343069580030702, 48.87537456856343],
                            [2.34401082278417, 48.875491553753655],
                            [2.346577390363243, 48.87581256581644],
                            [2.350298341869732, 48.876277335058674],
                            [2.351413016670032, 48.87641757568126],
                            [2.352026272074424, 48.87649482207367],
                            [2.352466378451743, 48.87656376238593],
                            [2.352857786239938, 48.87663389654013],
                            [2.35312113627949, 48.87668977282033],
                            [2.35337185897268, 48.87674802919635],
                            [2.353664073400605, 48.87682531415533],
                            [2.353979746080762, 48.876931147553144],
                            [2.354347733783631, 48.87705719421718],
                            [2.354712123389904, 48.87720703559976],
                            [2.355169684920749, 48.877425519387586],
                            [2.355440934955368, 48.87757809344499],
                            [2.355763863756807, 48.87777433423034],
                            [2.356240155605246, 48.87808832483545],
                            [2.356839182555239, 48.87860453587027],
                            [2.357331782422946, 48.8790660379055],
                            [2.35774319737712, 48.87946569037395],
                            [2.358067860609454, 48.87983094792641],
                            [2.358211109628591, 48.880031458403714],
                            [2.358670880996659, 48.88068334465473],
                            [2.358833235621349, 48.88091352744822],
                        ],
                    },
                },
                1144: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.76262564815412, 2.178164023862933],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2178.90646637,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.163947085881832,
                            48.759188983210805,
                            2.192135811302312,
                            48.764776012952915,
                        ),
                        "coordinates": [
                            [2.163947085881832, 48.764776012952915],
                            [2.165808565692433, 48.76474682827451],
                            [2.16636636533764, 48.764725182138726],
                            [2.166711951730226, 48.76470501582243],
                            [2.167008588533025, 48.76467847995979],
                            [2.167267146073519, 48.76464918911724],
                            [2.169603889605043, 48.76432081087228],
                            [2.171324116990315, 48.76407512337822],
                            [2.173382013116744, 48.763727377125676],
                            [2.174532676696627, 48.76352954063185],
                            [2.17558009481833, 48.76334651926196],
                            [2.176790738675328, 48.76313773937385],
                            [2.177907114911465, 48.76295159402869],
                            [2.17899150692073, 48.762770902003666],
                            [2.179941107105414, 48.762610671609615],
                            [2.180426597314621, 48.762521447666686],
                            [2.181280003145922, 48.762350855004804],
                            [2.181835356775912, 48.7622302099448],
                            [2.18228727129237, 48.762128306431066],
                            [2.182871248356519, 48.761987011506676],
                            [2.184046176126185, 48.76166726152205],
                            [2.185325858203075, 48.7612846337467],
                            [2.188120020256358, 48.76043309274623],
                            [2.189276966459176, 48.76007992739549],
                            [2.190494666869141, 48.75971344431436],
                            [2.19161970551149, 48.75937261692995],
                            [2.19196971349315, 48.75925091425239],
                            [2.192135811302312, 48.759188983210805],
                        ],
                    },
                },
                1145: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.16581109158064, 2.7524007084203292],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 4368.74848605,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.736249842909681,
                            48.14721803991587,
                            2.762728388543796,
                            48.18093685577102,
                        ),
                        "coordinates": [
                            [2.736249842909681, 48.18093685577102],
                            [2.736549476318923, 48.18074156354518],
                            [2.737184907658812, 48.18033466094019],
                            [2.737564817925184, 48.18009052225245],
                            [2.737934040262179, 48.179855412464484],
                            [2.738348669391475, 48.17958237349362],
                            [2.738715224459543, 48.1793508671196],
                            [2.739085765253007, 48.17911395063355],
                            [2.739860297542952, 48.17862111092302],
                            [2.740340483600252, 48.17831006265926],
                            [2.740696270966813, 48.178079488185745],
                            [2.741148327892601, 48.17778292468837],
                            [2.741543075275918, 48.177515242949276],
                            [2.741937080331481, 48.17722437640993],
                            [2.742108148299678, 48.17709697262238],
                            [2.742343318962928, 48.1769162831369],
                            [2.742555748444884, 48.17675006292257],
                            [2.742778839023255, 48.1765721140085],
                            [2.743017864959095, 48.17636982886234],
                            [2.743147415617269, 48.17626325373302],
                            [2.743413108179515, 48.17603389465804],
                            [2.743741432880336, 48.175735968528194],
                            [2.743924219372154, 48.175562659260436],
                            [2.744138978551282, 48.17535326456177],
                            [2.744337748549166, 48.175161912937234],
                            [2.744783230334725, 48.17472328188314],
                            [2.745068210567798, 48.174428627913635],
                            [2.745404707126345, 48.17410506716919],
                            [2.746175600703086, 48.17334692910488],
                            [2.74635038361684, 48.173183536155776],
                            [2.746771822619082, 48.17276836382672],
                            [2.747051887525487, 48.172492185338214],
                            [2.747277249817869, 48.17226746004631],
                            [2.747873519063828, 48.17166572052666],
                            [2.748262724878751, 48.17128911615547],
                            [2.748680033001713, 48.17086585999694],
                            [2.749292144586664, 48.170264744006666],
                            [2.750148198133348, 48.169414546045594],
                            [2.750561532457673, 48.16900208832466],
                            [2.750802853436614, 48.16876021207523],
                            [2.751574891897511, 48.16799753694753],
                            [2.752525569974998, 48.16705795017672],
                            [2.753457483174225, 48.166129216405636],
                            [2.753872176193039, 48.16571632529828],
                            [2.754301397293108, 48.16529072235943],
                            [2.754738191952682, 48.16485733296897],
                            [2.755226622004906, 48.16437368883336],
                            [2.755591993337679, 48.164022537051395],
                            [2.756041243172716, 48.16357575470574],
                            [2.756381171676828, 48.16323728465241],
                            [2.756687779829053, 48.16293310714495],
                            [2.757327697976592, 48.16230486718554],
                            [2.757718261976247, 48.16191584809277],
                            [2.758102159232569, 48.16153404580232],
                            [2.758673807989749, 48.16094292141336],
                            [2.758865527767544, 48.16072549295695],
                            [2.759049317625836, 48.16052427892667],
                            [2.759278311143215, 48.160264447119665],
                            [2.759460535377595, 48.160037162301286],
                            [2.759661301331632, 48.1597774350064],
                            [2.759911278362852, 48.159456376686386],
                            [2.760425226906565, 48.158721585298615],
                            [2.760667937297798, 48.15833670857637],
                            [2.761102467291841, 48.157589624838245],
                            [2.761468552850808, 48.15685538615972],
                            [2.761699206228547, 48.15631768541728],
                            [2.761942534355285, 48.155690015610475],
                            [2.762165350258637, 48.15502105850282],
                            [2.76237514006443, 48.15424244621479],
                            [2.762522272923913, 48.153524318345454],
                            [2.762629026878261, 48.15279914858905],
                            [2.762650715441822, 48.15250322542895],
                            [2.762683479658239, 48.152086765908216],
                            [2.762703038162292, 48.15137991050965],
                            [2.762713339856609, 48.150531912831596],
                            [2.762723172162356, 48.1496281667607],
                            [2.762718245215227, 48.14872717452237],
                            [2.762723164930163, 48.147878298862885],
                            [2.762726197584857, 48.14744216918701],
                            [2.762728388543796, 48.14721803991587],
                        ],
                    },
                },
                1146: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.10807034910381, 2.364028073180766],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2239.15674596,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.361270555241057,
                            49.09840026247686,
                            2.368253547610188,
                            49.11662788250494,
                        ),
                        "coordinates": [
                            [2.361270555241057, 49.09840026247686],
                            [2.362062590776779, 49.09956315003074],
                            [2.362824110582927, 49.100671748793864],
                            [2.36302719039292, 49.10097387691294],
                            [2.363458734315033, 49.101592403412866],
                            [2.363643684749181, 49.10186122437385],
                            [2.364086153341926, 49.10254874665016],
                            [2.36423849673914, 49.10281567122578],
                            [2.364384338418487, 49.103115431989465],
                            [2.364504085955837, 49.10340806016973],
                            [2.364578150812803, 49.10365644460161],
                            [2.364637000765387, 49.10391197044147],
                            [2.364676269162893, 49.104146085801695],
                            [2.364704653762687, 49.104355936037415],
                            [2.364713473413738, 49.10457292904414],
                            [2.364694166146042, 49.1050383299128],
                            [2.364650829736394, 49.105306728004024],
                            [2.364585736554953, 49.10555229070535],
                            [2.36447068962991, 49.10590207922699],
                            [2.363760567705506, 49.10755825937952],
                            [2.363534704893292, 49.10808224073455],
                            [2.362861414029594, 49.10959992809776],
                            [2.362733307733037, 49.109963994705666],
                            [2.362676894709396, 49.11020669801297],
                            [2.362633522758999, 49.11043512374182],
                            [2.362609704593121, 49.11063356526742],
                            [2.362601165096047, 49.11093764437324],
                            [2.36263244696275, 49.11116233131592],
                            [2.362662684569032, 49.11135656706981],
                            [2.362702506731108, 49.111541808269415],
                            [2.362743041910457, 49.111714529157005],
                            [2.362817781896, 49.11193746172329],
                            [2.362897338387295, 49.11213798091797],
                            [2.363066002338962, 49.11246078113935],
                            [2.363208591072139, 49.11269006257599],
                            [2.363359387763146, 49.11289506208049],
                            [2.363545811998252, 49.11311803831664],
                            [2.363813090931222, 49.11339495196457],
                            [2.364085833801011, 49.1136376908166],
                            [2.364366785601948, 49.11385614723502],
                            [2.364625805889736, 49.114048529150864],
                            [2.364998572180839, 49.114311025571034],
                            [2.365331593911791, 49.114536660651076],
                            [2.365757824856041, 49.114851299427535],
                            [2.366466382942405, 49.115354711909866],
                            [2.368132993855112, 49.116541309626264],
                            [2.368253547610188, 49.11662788250494],
                        ],
                    },
                },
                1147: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.11818781333716, 2.383829697888081],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2420.82694951,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368253547610188,
                            49.11662788250494,
                            2.399724852518912,
                            49.11902264630466,
                        ),
                        "coordinates": [
                            [2.368253547610188, 49.11662788250494],
                            [2.368542288383732, 49.1168352344404],
                            [2.368999227039116, 49.11716336598175],
                            [2.369321323384197, 49.11738539561298],
                            [2.369605031528311, 49.11756157260303],
                            [2.369881876928586, 49.11771616802285],
                            [2.370145939355758, 49.11785072350926],
                            [2.370406761983622, 49.1179660138007],
                            [2.370887765575727, 49.118148425109005],
                            [2.371322153303947, 49.11827599220463],
                            [2.371642798976949, 49.11835862855349],
                            [2.371925071673401, 49.11842239151264],
                            [2.372211443882041, 49.11847176398141],
                            [2.372664969762936, 49.118530975467834],
                            [2.372954067335911, 49.1185587624325],
                            [2.373197946231456, 49.11857397347514],
                            [2.37419398801061, 49.1186042304675],
                            [2.375294149138613, 49.118629047945944],
                            [2.37546403794968, 49.11863348701299],
                            [2.376572425439091, 49.11866278618023],
                            [2.376840960048925, 49.11866988699435],
                            [2.377151964906881, 49.11867787246378],
                            [2.377378026581881, 49.11868318858139],
                            [2.377747946564409, 49.11869205016643],
                            [2.378121974775684, 49.11870090937275],
                            [2.37976468962494, 49.1187389777786],
                            [2.379953759484097, 49.1187434032974],
                            [2.380822357903373, 49.118731384501125],
                            [2.381164857820234, 49.11871866286042],
                            [2.381392265572972, 49.1186978920014],
                            [2.38186625987457, 49.118652744043644],
                            [2.382204617159484, 49.11860584933785],
                            [2.382519676448837, 49.118550869633246],
                            [2.382829247198656, 49.11848959583229],
                            [2.383041554475454, 49.11843735318354],
                            [2.383541500184464, 49.118312152117696],
                            [2.384052383662404, 49.11816716125105],
                            [2.384312614122676, 49.118088818213906],
                            [2.385242591742117, 49.11781235449708],
                            [2.385761692517478, 49.11767544552939],
                            [2.386083574277913, 49.11760246742603],
                            [2.386480803077359, 49.11752855644476],
                            [2.386738329747167, 49.11749337313369],
                            [2.386861614939927, 49.11747713306004],
                            [2.387369840188663, 49.117430149046065],
                            [2.38764383177174, 49.11742013599074],
                            [2.388926146071552, 49.11740787222688],
                            [2.389501546110945, 49.11740491260683],
                            [2.390042709313123, 49.11741455592872],
                            [2.390353712575591, 49.11742520287971],
                            [2.390634584022454, 49.117443956669774],
                            [2.390918208160942, 49.11747349977349],
                            [2.391184026893407, 49.11750664750328],
                            [2.391395046772242, 49.11754161956887],
                            [2.391460819503132, 49.11755237948609],
                            [2.39213089826975, 49.11768065514996],
                            [2.393126172129542, 49.11788636619321],
                            [2.394866525621049, 49.11824715921053],
                            [2.396476382616109, 49.11858657970853],
                            [2.397153290509102, 49.1187347761175],
                            [2.397669271646377, 49.118826267127254],
                            [2.397999204548541, 49.118878436882596],
                            [2.398401642801668, 49.118935327299084],
                            [2.398731548854243, 49.11896608134625],
                            [2.399028823724458, 49.1189897140484],
                            [2.399369591416852, 49.11900856404319],
                            [2.399724852518912, 49.11902264630466],
                        ],
                    },
                },
                1148: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.7207721647834, 2.252210953442041],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1333.74503973,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.245672514581905,
                            48.716946287585145,
                            2.258966434308785,
                            48.72430941924522,
                        ),
                        "coordinates": [
                            [2.245672514581905, 48.716946287585145],
                            [2.246034777543006, 48.717387972800324],
                            [2.246204316677468, 48.71757425774311],
                            [2.246472868535013, 48.717869432577665],
                            [2.246959867203935, 48.71836531814013],
                            [2.247407668004298, 48.71874696252554],
                            [2.247824315723169, 48.71907282593091],
                            [2.248327882570167, 48.71943742499263],
                            [2.248846889914126, 48.719796884949325],
                            [2.249211571476426, 48.720045118285924],
                            [2.24951703808496, 48.72023330096099],
                            [2.249852073647294, 48.72040510855996],
                            [2.2501423632802, 48.720531130782845],
                            [2.250416131129757, 48.72063751653223],
                            [2.250682301454209, 48.72071979763813],
                            [2.250932277773671, 48.72077753972411],
                            [2.251134234422072, 48.72081455391798],
                            [2.251269239942499, 48.72083444818901],
                            [2.251386097000232, 48.72084982376131],
                            [2.251390173158251, 48.720850726313614],
                            [2.251686402603537, 48.72088422124369],
                            [2.252168809933953, 48.720930444951414],
                            [2.252545124479655, 48.72095889705154],
                            [2.252946134250102, 48.72098317881403],
                            [2.253530471328401, 48.72103306895195],
                            [2.253754681812687, 48.721059311832775],
                            [2.254006047196299, 48.72110266013017],
                            [2.254223437401574, 48.72114418462824],
                            [2.254387826170632, 48.721183871877145],
                            [2.25459024379729, 48.72123887422372],
                            [2.254753253197302, 48.721291150294675],
                            [2.254923047664286, 48.721349725199715],
                            [2.255058869244265, 48.721404678809826],
                            [2.255172721295973, 48.721453640507434],
                            [2.255250370011018, 48.72148844880569],
                            [2.255401113191451, 48.721562296708505],
                            [2.255569491921798, 48.721655941972216],
                            [2.255728357502925, 48.72175047929366],
                            [2.255857339711307, 48.721834202848626],
                            [2.256002606023467, 48.72193412554421],
                            [2.256172301639649, 48.722055648114875],
                            [2.256324334015052, 48.72217445999796],
                            [2.256502165702031, 48.722309476198994],
                            [2.256671847457176, 48.722441789722346],
                            [2.256876835981825, 48.72259391052944],
                            [2.257095389188995, 48.72276312790991],
                            [2.257345154602163, 48.72296473999034],
                            [2.257605772545708, 48.72318074660959],
                            [2.257611202188494, 48.72318524713502],
                            [2.257928826287949, 48.72345255245048],
                            [2.258203025603181, 48.72367845976152],
                            [2.258463646339781, 48.723897162744876],
                            [2.258966434308785, 48.72430941924522],
                        ],
                    },
                },
                1149: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.59933482719156, 2.4600786395074867],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1563.81877144,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.459287214129387,
                            48.59262774217932,
                            2.462456492779697,
                            48.60555582637839,
                        ),
                        "coordinates": [
                            [2.461806387476935, 48.59262774217932],
                            [2.461684603641595, 48.59271600452639],
                            [2.461288113954069, 48.5929997085439],
                            [2.461018783709827, 48.59322212080777],
                            [2.460837664080301, 48.5933913820872],
                            [2.460628048986627, 48.593596643285736],
                            [2.460484306163603, 48.593782317325626],
                            [2.460347021438299, 48.59396377009736],
                            [2.460255113105078, 48.594090746023426],
                            [2.460117857422402, 48.59431553598374],
                            [2.460011126108635, 48.59452153600796],
                            [2.459905583307632, 48.59474699484268],
                            [2.459826563148424, 48.594979347471465],
                            [2.459776535843602, 48.595179373341786],
                            [2.45970315913686, 48.59566145666046],
                            [2.459672309343372, 48.59599436272],
                            [2.459627911531912, 48.59648616094286],
                            [2.459543969604925, 48.597635507755214],
                            [2.459462736639649, 48.598785750892624],
                            [2.459377431126224, 48.59993509916043],
                            [2.459328188426236, 48.60061761578486],
                            [2.459305443443041, 48.60098641648205],
                            [2.459288864457768, 48.60141268605954],
                            [2.459287214129387, 48.601845233707785],
                            [2.459302764787263, 48.60210420514989],
                            [2.459332445351885, 48.60235334127976],
                            [2.459375770123966, 48.60256994452908],
                            [2.459433188945809, 48.60276142554065],
                            [2.45950961408694, 48.602962777055815],
                            [2.459595472971111, 48.60314073833876],
                            [2.459715941636856, 48.60337221988509],
                            [2.459837896282609, 48.603575718885104],
                            [2.459973953082028, 48.60376441592839],
                            [2.460097744279593, 48.60392704793518],
                            [2.460219432172403, 48.604061951907674],
                            [2.460328077498942, 48.60417440353855],
                            [2.460456559383565, 48.604303625070706],
                            [2.460697175454734, 48.60451900744689],
                            [2.460969941516312, 48.60473562058886],
                            [2.46120067133403, 48.60489811201318],
                            [2.461386083611603, 48.605014969566874],
                            [2.461554224930891, 48.605110432395705],
                            [2.461735301511313, 48.60521444597944],
                            [2.461901846802977, 48.605298243089614],
                            [2.462066111616921, 48.605375397374395],
                            [2.462456492779697, 48.60555582637839],
                        ],
                    },
                },
                1150: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.68897770552408, 2.518668897394993],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 2938.60368335,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.506078153203696,
                            48.681016616342724,
                            2.533130656571037,
                            48.69973243390383,
                        ),
                        "coordinates": [
                            [2.533130656571037, 48.681016616342724],
                            [2.533083199969267, 48.681036908862126],
                            [2.532420245237413, 48.68130501241577],
                            [2.531858424403045, 48.681525827311454],
                            [2.531122229286065, 48.68181260863568],
                            [2.530166395190735, 48.68216971084296],
                            [2.528636439410602, 48.68275970284952],
                            [2.527384140172082, 48.68325092711469],
                            [2.525814500754922, 48.68386873852389],
                            [2.523791239115818, 48.684675135001115],
                            [2.523209316117805, 48.68491878306068],
                            [2.522627803766856, 48.68516714672711],
                            [2.522191252125509, 48.685373793459576],
                            [2.521766940500577, 48.6855858134296],
                            [2.521402301317052, 48.68577525356521],
                            [2.520762555585214, 48.6861279063839],
                            [2.520261087236943, 48.68641378661939],
                            [2.519931057683086, 48.68662008435654],
                            [2.519620171125085, 48.68682218937744],
                            [2.519292327448007, 48.68705023251167],
                            [2.518727460664905, 48.68746030672398],
                            [2.518210210107044, 48.687894582783834],
                            [2.51777291551441, 48.688281967524496],
                            [2.517136591601049, 48.688849148509895],
                            [2.516363556401142, 48.68954408354144],
                            [2.515953333460746, 48.68991343226858],
                            [2.514893183474851, 48.69085663669972],
                            [2.514105095249711, 48.69154131564824],
                            [2.513505313585758, 48.69209080553229],
                            [2.513079321689099, 48.69247661522168],
                            [2.512688850727272, 48.69282947523966],
                            [2.512481714053253, 48.69302493737972],
                            [2.512251587380239, 48.69325011164466],
                            [2.511942940635518, 48.693550943881],
                            [2.511427253655409, 48.694078710836905],
                            [2.510991505145755, 48.69455059822122],
                            [2.510715444432601, 48.69485137801083],
                            [2.510463726849502, 48.69512244423393],
                            [2.509782952423262, 48.69584379944969],
                            [2.509643544375335, 48.69599059291947],
                            [2.50936473457913, 48.69628687684477],
                            [2.508931620430535, 48.69674616261593],
                            [2.508348323378641, 48.69738372928118],
                            [2.508257641925479, 48.69748098686163],
                            [2.507689269499808, 48.69803704997495],
                            [2.507471029928957, 48.69825734323042],
                            [2.507270728216306, 48.69847796559789],
                            [2.506974287412474, 48.698791356624],
                            [2.506750944552601, 48.69902909851392],
                            [2.506562788768913, 48.69922811883625],
                            [2.506385470274386, 48.69941813059212],
                            [2.506078153203696, 48.69973243390383],
                        ],
                    },
                },
                1151: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.69462242324823, 2.1581297695192947],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1052.4309139,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.151642038623571,
                            48.69383953319975,
                            2.164378242774173,
                            48.69625274781443,
                        ),
                        "coordinates": [
                            [2.151642038623571, 48.695264122108014],
                            [2.151790686023894, 48.69522447063804],
                            [2.153006284100272, 48.694903602563876],
                            [2.153506673404419, 48.69476772075906],
                            [2.154149874660813, 48.694593626135706],
                            [2.15476578679843, 48.69442802023626],
                            [2.155311032949026, 48.69428141098225],
                            [2.155971513241761, 48.694106051784594],
                            [2.156272564693826, 48.69402895294252],
                            [2.156449124150132, 48.69398988260689],
                            [2.156697702513228, 48.69393968800571],
                            [2.156969632206638, 48.693900056164395],
                            [2.157193855441208, 48.693874331088665],
                            [2.157389514781785, 48.69385935251617],
                            [2.157562068687256, 48.693847933456915],
                            [2.157745466640258, 48.693842826961],
                            [2.157938366764352, 48.69383953319975],
                            [2.158105441948361, 48.69384069466123],
                            [2.158271135892046, 48.6938481489377],
                            [2.15853957395747, 48.69385836076412],
                            [2.15881844159391, 48.693880481163454],
                            [2.159001749664138, 48.69390055180384],
                            [2.159360846608772, 48.69394815545989],
                            [2.159712101510718, 48.69401579940333],
                            [2.160026668172758, 48.694091951351695],
                            [2.160345462777742, 48.69419237733415],
                            [2.160624968768176, 48.69429335979561],
                            [2.16094509540124, 48.69442065166536],
                            [2.161362769356391, 48.694621833410984],
                            [2.161591889429817, 48.69474898367798],
                            [2.161895525192996, 48.69493200237411],
                            [2.162392970120308, 48.695242114256054],
                            [2.162959530936864, 48.69560089061857],
                            [2.163303879382004, 48.695798356526375],
                            [2.163562879922043, 48.6959300443949],
                            [2.163802938310733, 48.69604012067629],
                            [2.164086526403815, 48.696153919622134],
                            [2.164347151078141, 48.69624425371273],
                            [2.164378242774173, 48.69625274781443],
                        ],
                    },
                },
                1152: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.53282411987321, 2.5583039986274203],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2146.22363593,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.544348950368585,
                            48.529746918576464,
                            2.572073662735742,
                            48.535139766989644,
                        ),
                        "coordinates": [
                            [2.572073662735742, 48.529746918576464],
                            [2.570793017624729, 48.530251184698585],
                            [2.569941468701102, 48.53055689291442],
                            [2.569061437099146, 48.53085366054581],
                            [2.568179931544287, 48.531127043312566],
                            [2.567470035799256, 48.53132812829594],
                            [2.566921078189355, 48.53147915428156],
                            [2.56639902747941, 48.531618587583765],
                            [2.565841859610992, 48.531761282679035],
                            [2.564723298932624, 48.532018032035005],
                            [2.563684406503723, 48.53222990781882],
                            [2.562849420177672, 48.532386026171395],
                            [2.562271586366856, 48.5324906166752],
                            [2.561723843449585, 48.53257260354689],
                            [2.56101855909678, 48.532673933857254],
                            [2.560365476270039, 48.53276142314251],
                            [2.558779480143739, 48.53296058518638],
                            [2.556079734728508, 48.53329857666669],
                            [2.553379950010136, 48.533635604453785],
                            [2.55156094905824, 48.533863247078614],
                            [2.549578768818664, 48.53410933204422],
                            [2.548547568613702, 48.53424450803341],
                            [2.54793537950024, 48.534345582577394],
                            [2.547380498155892, 48.5344441671045],
                            [2.54645559764492, 48.53462524662046],
                            [2.545497731617544, 48.53484262058905],
                            [2.544348950368585, 48.535139766989644],
                        ],
                    },
                },
                1153: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.84651262705647, 2.2220538258873392],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 762.278308445,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.221232683266963,
                            48.843124399912504,
                            2.222487068927055,
                            48.84985048784913,
                        ),
                        "coordinates": [
                            [2.221851494752013, 48.843124399912504],
                            [2.221943515347407, 48.84344292582335],
                            [2.221995130488258, 48.843613735368336],
                            [2.222033005868757, 48.84373247883626],
                            [2.222135804147282, 48.844057220825626],
                            [2.222302012819446, 48.84465450753015],
                            [2.222377468259678, 48.84502148844033],
                            [2.222439344204305, 48.84536867114393],
                            [2.222472666288336, 48.845690645764186],
                            [2.222487068927055, 48.84594515586352],
                            [2.222461052341644, 48.84627772600208],
                            [2.222417189885362, 48.84653940931758],
                            [2.222362591583924, 48.84676539233776],
                            [2.222295285194325, 48.846982729758274],
                            [2.2217139498821, 48.84854059237356],
                            [2.221583700972095, 48.84888668276462],
                            [2.221428752595185, 48.84930558981398],
                            [2.221350741954122, 48.84952160647178],
                            [2.221232683266963, 48.84985048784913],
                        ],
                    },
                },
                1154: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.78761726255465, 2.2924223344539216],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 10.3963377814,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.292351691072184,
                            48.78761467997086,
                            2.292492977835659,
                            48.78761984513844,
                        ),
                        "coordinates": [
                            [2.292351691072184, 48.78761984513844],
                            [2.292492977835659, 48.78761467997086],
                        ],
                    },
                },
                1155: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.41555112110927, 2.7713153104568433],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 5730.51860268,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.751904834473551,
                            48.406805624897885,
                            2.79923356025455,
                            48.430970724114694,
                        ),
                        "coordinates": [
                            [2.79923356025455, 48.406805624897885],
                            [2.799072492906067, 48.40708697156878],
                            [2.79867484562515, 48.40761286402814],
                            [2.798431659214008, 48.4078989229961],
                            [2.798287116450325, 48.408043394528924],
                            [2.798137253492672, 48.40819687949061],
                            [2.797428905141483, 48.40886701740094],
                            [2.796223663116023, 48.40999959196637],
                            [2.795602259098052, 48.41058213654204],
                            [2.794394248880042, 48.411716501013245],
                            [2.792989344490695, 48.413017519939785],
                            [2.792508077041744, 48.41340350555173],
                            [2.792083532475449, 48.413698801684504],
                            [2.791700363849092, 48.41394111986955],
                            [2.791264472289154, 48.41417031611049],
                            [2.790916980824161, 48.414339912425184],
                            [2.790504738964452, 48.41452171142746],
                            [2.789988234889679, 48.414714125671104],
                            [2.789553436335253, 48.414851485254054],
                            [2.78913269431545, 48.414962617216],
                            [2.788718989456961, 48.41506182090557],
                            [2.788276586648537, 48.41514924313738],
                            [2.787891640093051, 48.41520927484739],
                            [2.787442756301341, 48.41526950742816],
                            [2.787102628943957, 48.41530143702232],
                            [2.786662741038076, 48.41533411829984],
                            [2.786239845930466, 48.41534713244729],
                            [2.785718428320555, 48.41534830403235],
                            [2.785310332659736, 48.41533283696512],
                            [2.784900453779014, 48.41529876401361],
                            [2.784417705797117, 48.41524681874924],
                            [2.783975791828507, 48.41519243945447],
                            [2.781479724907929, 48.41487161365356],
                            [2.780932255378192, 48.414800006122256],
                            [2.780506362729724, 48.41473505722359],
                            [2.780166288752163, 48.414674528436755],
                            [2.779797765675095, 48.41459648176391],
                            [2.779352438290774, 48.41449391044911],
                            [2.778919848045636, 48.41437247743765],
                            [2.777892352368236, 48.414050882575296],
                            [2.77721044207148, 48.413850941857305],
                            [2.776744728220558, 48.413726651481504],
                            [2.776350725382032, 48.4136282525323],
                            [2.775990587114377, 48.41353595291372],
                            [2.775222585317681, 48.41336883111024],
                            [2.774054780287646, 48.413105141733226],
                            [2.773269595664325, 48.412933048855884],
                            [2.772905573758838, 48.41285711601474],
                            [2.772157385073164, 48.41272090546711],
                            [2.771241037602005, 48.412573503524136],
                            [2.770618452584293, 48.412490238973184],
                            [2.770081806667879, 48.412425675186284],
                            [2.76930237073166, 48.412345985175094],
                            [2.768440120336602, 48.41227967631133],
                            [2.767338987243908, 48.41222057589135],
                            [2.766949791223278, 48.412205476681784],
                            [2.766613137286354, 48.41219904702445],
                            [2.76629052390608, 48.41219449287268],
                            [2.765834375634037, 48.412201673006074],
                            [2.765330229632203, 48.412210604325495],
                            [2.764922979962904, 48.41222451535868],
                            [2.76422040581056, 48.412265281421995],
                            [2.763794600922663, 48.412303893154764],
                            [2.763218796509414, 48.412368763672575],
                            [2.762530556658693, 48.412478139967725],
                            [2.762080942559337, 48.41256072707248],
                            [2.761563585455199, 48.41266260079373],
                            [2.761025064611816, 48.41279786175095],
                            [2.760019291365712, 48.413044317066976],
                            [2.759316684503863, 48.413218252636085],
                            [2.75862116154522, 48.4133850191897],
                            [2.757907944041439, 48.41357326081361],
                            [2.757319588842031, 48.41373486294929],
                            [2.75686695812904, 48.413886439381145],
                            [2.756443036192114, 48.41405218412817],
                            [2.755980057235826, 48.41424900297609],
                            [2.7555635335856, 48.414445647640306],
                            [2.755111666236446, 48.41469000665039],
                            [2.754778565483647, 48.4148907027214],
                            [2.754375810847667, 48.415168187623465],
                            [2.753973317024598, 48.41547739438108],
                            [2.753635476242541, 48.41576414098161],
                            [2.753334812445446, 48.41606029419747],
                            [2.753032587932407, 48.416394506816665],
                            [2.752751908809898, 48.41678047651531],
                            [2.752566460182669, 48.417078285526564],
                            [2.752327070808497, 48.41752012677244],
                            [2.752191706872143, 48.41786324178563],
                            [2.752056944407048, 48.41827931967993],
                            [2.751951298410519, 48.41875873795634],
                            [2.751925880318116, 48.419142690717436],
                            [2.751904834473551, 48.419479041111146],
                            [2.75191738516436, 48.419843820510486],
                            [2.751958425425438, 48.420195805155785],
                            [2.752017847993785, 48.420465239209776],
                            [2.752088325580623, 48.42070205512957],
                            [2.752198281326492, 48.42095947088061],
                            [2.752436040299621, 48.42146935240028],
                            [2.752978932208324, 48.422565004232254],
                            [2.753246619894984, 48.42323339388371],
                            [2.753364247099733, 48.4236231651128],
                            [2.753428314419767, 48.42387672048399],
                            [2.753454226622768, 48.42412724473554],
                            [2.75346149750553, 48.424428594539805],
                            [2.75344964985324, 48.424723670878976],
                            [2.753427714493442, 48.424952163899405],
                            [2.753363595127807, 48.42526646670219],
                            [2.753197117427577, 48.42588252422285],
                            [2.752886797416735, 48.426971796630504],
                            [2.752813453933754, 48.427324201984256],
                            [2.752764049441432, 48.427689208955876],
                            [2.752725438313367, 48.42820645125176],
                            [2.75271534722732, 48.42871407168776],
                            [2.752733172716005, 48.42913910687007],
                            [2.752790051215376, 48.42967503258873],
                            [2.752895173213066, 48.43013171436322],
                            [2.752931766124795, 48.43027571304698],
                            [2.752977505842713, 48.43044615241056],
                            [2.753126847026339, 48.4308565643828],
                            [2.753177568842823, 48.430970724114694],
                        ],
                    },
                },
                1156: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.78495918877427, 2.1507544268837617],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3620.0302709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.142141851963426,
                            48.77042520300475,
                            2.155740387874207,
                            48.79577385878627,
                        ),
                        "coordinates": [
                            [2.142141851963426, 48.795715917344765],
                            [2.143545354279527, 48.79574977214138],
                            [2.144716461319213, 48.79576745697119],
                            [2.145126997753335, 48.79577385878627],
                            [2.145509491523887, 48.79576736335071],
                            [2.145925753035134, 48.79574480148314],
                            [2.146350271001891, 48.795711667769446],
                            [2.146745880988852, 48.795665217989395],
                            [2.14702908603024, 48.79562999898825],
                            [2.147388032470583, 48.79556492640698],
                            [2.147876801576748, 48.79545438535117],
                            [2.148307251549837, 48.7953366063917],
                            [2.148664217539964, 48.795222988440685],
                            [2.148999626930769, 48.79509505632212],
                            [2.149209553856219, 48.795008319405504],
                            [2.14944767007486, 48.794894501458444],
                            [2.149848676245521, 48.794682438584495],
                            [2.150245665875757, 48.7944336043699],
                            [2.15051320141176, 48.79424954345916],
                            [2.150723377624055, 48.79409427859728],
                            [2.150866488559904, 48.79396031639317],
                            [2.151059472477405, 48.79377932488097],
                            [2.151220013406822, 48.79360637012334],
                            [2.151433426481253, 48.79335450728213],
                            [2.151578218157759, 48.793154878389416],
                            [2.151737627470081, 48.79289816768626],
                            [2.151870265621723, 48.79263198018042],
                            [2.152002653832152, 48.79232279732381],
                            [2.15209373432383, 48.79203980382375],
                            [2.152148835903813, 48.791747234197466],
                            [2.152174918633007, 48.79151172138697],
                            [2.152183216929127, 48.79121669601401],
                            [2.152116802155595, 48.790676476985084],
                            [2.15200029386702, 48.79005052147761],
                            [2.151802393228999, 48.78904135818668],
                            [2.151710779370541, 48.788501099293484],
                            [2.15167922313514, 48.78827263028487],
                            [2.151677587476256, 48.78799566782838],
                            [2.151681375661874, 48.78769445295941],
                            [2.151714604999674, 48.78747322809194],
                            [2.151784047387822, 48.78719733754593],
                            [2.151874140692271, 48.78692460566026],
                            [2.151975780013553, 48.78667387196914],
                            [2.152179860423669, 48.78630096796104],
                            [2.152493302301057, 48.78583748328845],
                            [2.152697374785452, 48.78559514020506],
                            [2.1530096371665, 48.7853176359647],
                            [2.153348222971903, 48.78502231979472],
                            [2.153829690133343, 48.78462857085377],
                            [2.154172628453482, 48.78435638042654],
                            [2.154354227103978, 48.78419120463191],
                            [2.154694294520612, 48.7838581170639],
                            [2.154932057726413, 48.78359051204928],
                            [2.155137188566615, 48.78331476078697],
                            [2.155291819339782, 48.78307939724403],
                            [2.15543023049908, 48.78281343169025],
                            [2.155564860395365, 48.78246472657438],
                            [2.155643817506279, 48.78218263096899],
                            [2.155709824261317, 48.781893016227194],
                            [2.155733705197933, 48.78160041261842],
                            [2.155740387874207, 48.78134720397285],
                            [2.155707557096589, 48.78102071360327],
                            [2.155676921516368, 48.7808390113641],
                            [2.155600339504245, 48.780570005598946],
                            [2.155530296022794, 48.78037385145658],
                            [2.15544525524001, 48.78018576797299],
                            [2.155316909149342, 48.77993286636306],
                            [2.155199274788353, 48.779727643726815],
                            [2.154962370953934, 48.77939363381439],
                            [2.154836367968398, 48.77924505184884],
                            [2.154272411213293, 48.778674008089325],
                            [2.152359254525248, 48.77684719200691],
                            [2.1509952375805, 48.775566203335885],
                            [2.150460888628286, 48.775104901133574],
                            [2.150204525137417, 48.77489494961334],
                            [2.149823301015048, 48.77460205949364],
                            [2.149459620422139, 48.77434876482795],
                            [2.148659100911393, 48.77376291547719],
                            [2.148371486823045, 48.77354571414232],
                            [2.148176193250039, 48.773380823415714],
                            [2.147976883954436, 48.77319883952385],
                            [2.147796640038623, 48.77301238973648],
                            [2.147666590898345, 48.772864693085886],
                            [2.147454036837616, 48.77258916096176],
                            [2.147305328798392, 48.772339813527616],
                            [2.147153960034657, 48.77207517434332],
                            [2.147075741346882, 48.7719102853402],
                            [2.14699213483155, 48.77169900688727],
                            [2.146947437652643, 48.77154228387909],
                            [2.146892852986458, 48.77133373546093],
                            [2.146846019122964, 48.77112862243513],
                            [2.146823463881327, 48.77095621376757],
                            [2.14680807930341, 48.770731977376606],
                            [2.146831644750671, 48.77042520300475],
                        ],
                    },
                },
                1157: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.517452740740175, 2.6717553450146014],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 2006.24086467,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.662762979853312,
                            48.510265175268025,
                            2.678973982691401,
                            48.52299439391623,
                        ),
                        "coordinates": [
                            [2.678973982691401, 48.510265175268025],
                            [2.678911291052324, 48.51039935542868],
                            [2.678763318402873, 48.51072893292476],
                            [2.67845977049246, 48.51146454797857],
                            [2.67811919409925, 48.512328869420735],
                            [2.677701082223583, 48.51333640606802],
                            [2.677217392589403, 48.51445564697227],
                            [2.676929918424447, 48.51517322428874],
                            [2.676558364092724, 48.51586857141742],
                            [2.67631680741913, 48.51617504567932],
                            [2.676111236956814, 48.516399578671184],
                            [2.675948612545475, 48.51657002642979],
                            [2.675758167470161, 48.516741401991915],
                            [2.675522027847842, 48.516938202565726],
                            [2.675178614034519, 48.51719641849439],
                            [2.674638038419924, 48.517523565324325],
                            [2.674103743156945, 48.517779648710196],
                            [2.67359477384754, 48.517976749450064],
                            [2.673344975375998, 48.51806131790666],
                            [2.673001827777494, 48.51816270140315],
                            [2.67268436024891, 48.51824789910001],
                            [2.672310857742187, 48.51832328171358],
                            [2.67200160784018, 48.518385693924834],
                            [2.671481017418396, 48.51846816688819],
                            [2.671196992563666, 48.51850317695549],
                            [2.670305797335057, 48.51862900186174],
                            [2.669428120814302, 48.51875298114754],
                            [2.668970904237088, 48.51882483871247],
                            [2.668541688093856, 48.51890937130873],
                            [2.668143162394347, 48.51899830425915],
                            [2.667768152150849, 48.51909776288853],
                            [2.666922521697137, 48.51936191474642],
                            [2.66648647829863, 48.51954123801786],
                            [2.666181508125755, 48.51968600684416],
                            [2.665927997608471, 48.51983422279796],
                            [2.665711057975537, 48.51998592889472],
                            [2.66543894853341, 48.52018927473443],
                            [2.665173758709285, 48.52041373918773],
                            [2.664877975944047, 48.52072214430546],
                            [2.664336313793262, 48.52131272894271],
                            [2.663599879910186, 48.52214062155105],
                            [2.662762979853312, 48.52299439391623],
                        ],
                    },
                },
                1158: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.88773541385964, 2.235534716234503],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 1020.32214319,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.233871433790775,
                            48.88333487655372,
                            2.237213536457713,
                            48.89212336383249,
                        ),
                        "coordinates": [
                            [2.233871433790775, 48.88333487655372],
                            [2.234148754131475, 48.883645838073846],
                            [2.234284758471906, 48.88381592350307],
                            [2.23437744436641, 48.883949262569736],
                            [2.234526658994834, 48.88421182141586],
                            [2.234688228706901, 48.884550094408354],
                            [2.234867428395821, 48.88493694336998],
                            [2.235003153992904, 48.88524641554787],
                            [2.235167113877548, 48.88564038810854],
                            [2.235380199027492, 48.88624404913415],
                            [2.23546143712516, 48.88652829310576],
                            [2.235511419879626, 48.88675945088598],
                            [2.235555637593615, 48.88714348177108],
                            [2.235570003375878, 48.887396802807466],
                            [2.235576905457804, 48.88755146644107],
                            [2.235583112164333, 48.88771364767339],
                            [2.235582444368546, 48.88804098429989],
                            [2.235580737978458, 48.888209147695584],
                            [2.235574587539867, 48.8885499680067],
                            [2.235579529112764, 48.88880176982434],
                            [2.235614282912365, 48.889146224493146],
                            [2.235688541751657, 48.889512295843375],
                            [2.235814628908966, 48.889875714700786],
                            [2.236015612680972, 48.89029405605375],
                            [2.23640976556258, 48.89095357326097],
                            [2.236620513478538, 48.89126850514581],
                            [2.236899252170144, 48.89168331555279],
                            [2.237213536457713, 48.89212336383249],
                        ],
                    },
                },
                1159: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.82731107176074, 2.261874675640142],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 606.192852125,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.260539912317944,
                            48.824767024606686,
                            2.26317856570046,
                            48.82989015779482,
                        ),
                        "coordinates": [
                            [2.26317856570046, 48.82989015779482],
                            [2.263056147470973, 48.8297177583353],
                            [2.262750465376536, 48.829284521779755],
                            [2.262667758176095, 48.82916312144455],
                            [2.262542308348694, 48.82898012589894],
                            [2.262379232714856, 48.82873181970392],
                            [2.262221981115685, 48.82843237336791],
                            [2.262150202734564, 48.828234842460624],
                            [2.262087408125981, 48.828054474971296],
                            [2.262023711538823, 48.82784220432181],
                            [2.261684860800274, 48.82674576420568],
                            [2.261539819903076, 48.82628793729057],
                            [2.261485603890279, 48.82611434142155],
                            [2.261420480055604, 48.82594883195583],
                            [2.26126400957647, 48.825647917861154],
                            [2.261141769772198, 48.82546224905913],
                            [2.261006098053172, 48.825277697772464],
                            [2.260857904203995, 48.82510763624835],
                            [2.260731464464077, 48.8249618691947],
                            [2.260539912317944, 48.824767024606686],
                        ],
                    },
                },
                1160: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.82011042034616, 2.2450047188853466],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 976.376492979,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.238598337792144,
                            48.819174329133155,
                            2.251336154852571,
                            48.82151752250999,
                        ),
                        "coordinates": [
                            [2.251336154852571, 48.82151752250999],
                            [2.249935877685897, 48.82118304129853],
                            [2.247099526512147, 48.820487057572265],
                            [2.245303275365132, 48.8200543026121],
                            [2.244710569882825, 48.81991141536564],
                            [2.244125252983068, 48.81976885605746],
                            [2.243780852191442, 48.81969483501965],
                            [2.243369209074997, 48.819610176703335],
                            [2.242947780776909, 48.81953607142586],
                            [2.242512054149369, 48.8194770675032],
                            [2.242043601890523, 48.819428253315415],
                            [2.241490877221326, 48.81938269366561],
                            [2.240411637729708, 48.81929840127721],
                            [2.23961868433623, 48.819234531158145],
                            [2.239035456594992, 48.81919253819678],
                            [2.238598337792144, 48.819174329133155],
                        ],
                    },
                },
                1161: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.9310416374126, 2.3815367814010733],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 524.556056053,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.378225490397901,
                            48.92997102620736,
                            2.384758860075984,
                            48.93173482548615,
                        ),
                        "coordinates": [
                            [2.384758860075984, 48.92997102620736],
                            [2.38383766125277, 48.93027730936517],
                            [2.383116452943295, 48.930547483450724],
                            [2.382564897886791, 48.93076448467827],
                            [2.382329341904292, 48.9308688633741],
                            [2.382069177312361, 48.930989471854886],
                            [2.381791427691322, 48.931110087074046],
                            [2.381541793254514, 48.93120751742773],
                            [2.3812991804603, 48.93129103916032],
                            [2.381028418432276, 48.93136530253802],
                            [2.380750609331112, 48.93142334531786],
                            [2.380226617642941, 48.93151160759265],
                            [2.379920203248906, 48.93155770456186],
                            [2.379629148938331, 48.931602759749886],
                            [2.379359766183886, 48.931633603520396],
                            [2.379059019838303, 48.93166267895883],
                            [2.378422442016503, 48.931716214819495],
                            [2.378225490397901, 48.93173482548615],
                        ],
                    },
                },
                1162: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.906624084010666, 2.447001230014643],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 443.75628617,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.443992334554137,
                            48.90653245333453,
                            2.450004663029331,
                            48.90666381123744,
                        ),
                        "coordinates": [
                            [2.450004663029331, 48.90653328847081],
                            [2.449832412139258, 48.90653325465102],
                            [2.449778170804448, 48.90653245333453],
                            [2.449666975806859, 48.90653616473174],
                            [2.44955686733234, 48.90654704216013],
                            [2.449448906439479, 48.906564981684056],
                            [2.449354428356196, 48.906587026353854],
                            [2.449303572765524, 48.90660378217037],
                            [2.449213578838489, 48.90662698046489],
                            [2.449120161479402, 48.9066432653019],
                            [2.449024535766438, 48.90665242463154],
                            [2.448927951279528, 48.90665433829505],
                            [2.448876469605303, 48.90665238287231],
                            [2.447719887289781, 48.90665814513022],
                            [2.446651192025392, 48.90666381123744],
                            [2.445628170673367, 48.90665783719377],
                            [2.445425157696664, 48.906645601316036],
                            [2.445240987590569, 48.90662440088658],
                            [2.444719885879937, 48.906564462468204],
                            [2.444510489895632, 48.90654689046203],
                            [2.444288508399617, 48.90653628055483],
                            [2.443992334554137, 48.906536559058885],
                        ],
                    },
                },
                1163: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.908301665333454, 2.438062310871432],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 315.296141036,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.437487802213591,
                            48.906931832134305,
                            2.438624497227672,
                            48.90966636535197,
                        ),
                        "coordinates": [
                            [2.438624497227672, 48.906931832134305],
                            [2.43802072189364, 48.90841910382095],
                            [2.437487802213591, 48.90966636535197],
                        ],
                    },
                },
                1164: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.046150180136536, 2.0981522761291633],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 446.377365123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.095195067225969,
                            49.04564873988319,
                            2.101108482966614,
                            49.04664576264113,
                        ),
                        "coordinates": [
                            [2.101108482966614, 49.04564873988319],
                            [2.099538274275683, 49.04593526764531],
                            [2.096377570034755, 49.04643086426444],
                            [2.095195067225969, 49.04664576264113],
                        ],
                    },
                },
                1165: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.46379031496342, 2.177928929975727],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 7181.48869734,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.159530553968522,
                            48.43692392480675,
                            2.194581700525426,
                            48.493644578496685,
                        ),
                        "coordinates": [
                            [2.194581700525426, 48.493644578496685],
                            [2.194543419074386, 48.493594987026995],
                            [2.19386812612035, 48.492697598627814],
                            [2.19369535806391, 48.49245769662619],
                            [2.19353620037991, 48.49224663484257],
                            [2.193320342572003, 48.49191262474706],
                            [2.193108997505592, 48.49159682392375],
                            [2.192961367835239, 48.49134785109848],
                            [2.192670817150971, 48.49079984987994],
                            [2.192427998948882, 48.49032169050033],
                            [2.192244289407768, 48.48992400535016],
                            [2.192108231774393, 48.489621952381235],
                            [2.191834057205762, 48.48894199331298],
                            [2.191718547704176, 48.48863844837211],
                            [2.191621231562116, 48.48835768106503],
                            [2.191523962356255, 48.488060227271866],
                            [2.191368018353368, 48.487536667621356],
                            [2.191232570003851, 48.487028303594066],
                            [2.19114239556813, 48.48664742449082],
                            [2.191070394412842, 48.48629539204412],
                            [2.191009681148663, 48.485985849373876],
                            [2.190964827614459, 48.48571576886458],
                            [2.190915523895594, 48.48540623983601],
                            [2.190857863681299, 48.484832746097645],
                            [2.190825095041492, 48.48433058216103],
                            [2.190818202549043, 48.483562979722606],
                            [2.190837702628597, 48.48313521533578],
                            [2.190884981428005, 48.48257095785033],
                            [2.190918457941776, 48.4820446082621],
                            [2.190935833461991, 48.481562229915006],
                            [2.190912151628022, 48.48107524796437],
                            [2.190881627646101, 48.480586740178275],
                            [2.190816892224509, 48.48009363758695],
                            [2.190731579713918, 48.47961567695922],
                            [2.190609765754252, 48.47913615382692],
                            [2.190469712089758, 48.478653572274354],
                            [2.190320377109413, 48.47822407325918],
                            [2.190232071784556, 48.477991860552564],
                            [2.190007648803434, 48.47749399960764],
                            [2.189835240050399, 48.477155488928645],
                            [2.189565148890984, 48.476672738005774],
                            [2.18930624307895, 48.476267366437924],
                            [2.188974499865674, 48.47580577113297],
                            [2.188622215391327, 48.47534869816884],
                            [2.188178902926873, 48.47481565722992],
                            [2.187890107136834, 48.47449519498137],
                            [2.187455691743657, 48.47404407877586],
                            [2.187200927258417, 48.473790406837786],
                            [2.186702681851548, 48.47332706781113],
                            [2.184891492018988, 48.471739405887874],
                            [2.184010989417532, 48.47096000909176],
                            [2.18311461592798, 48.47015783077591],
                            [2.182093129002886, 48.469250801274555],
                            [2.181067123649507, 48.4683407215684],
                            [2.180079862740005, 48.46745344342042],
                            [2.17905621225424, 48.46654335004898],
                            [2.178023475451607, 48.46563323443981],
                            [2.177318269852653, 48.46502848511294],
                            [2.176760930724013, 48.46455440108023],
                            [2.176485685367064, 48.46431736194953],
                            [2.175428529232595, 48.46336939126355],
                            [2.173894623616079, 48.4620086362487],
                            [2.17185792215845, 48.46018554986862],
                            [2.171437076269545, 48.4597994946336],
                            [2.171091233634467, 48.45945161714462],
                            [2.170788250451087, 48.45912521433166],
                            [2.170367753714354, 48.45863922733031],
                            [2.170029372557282, 48.45820332341595],
                            [2.169716043769795, 48.457765077192754],
                            [2.169427783868999, 48.45731972971461],
                            [2.169164609459721, 48.45686252201312],
                            [2.168930047479853, 48.45640773514199],
                            [2.168702698408111, 48.455936303808436],
                            [2.168514675797192, 48.45547206759342],
                            [2.168348141812741, 48.45500072647826],
                            [2.168213804224895, 48.454529433312935],
                            [2.168079779695552, 48.45396534783869],
                            [2.167985110508597, 48.45339894314668],
                            [2.167929514941433, 48.452913491250484],
                            [2.167892076322361, 48.45234717138155],
                            [2.167879683857191, 48.45177850954229],
                            [2.167899168054893, 48.45130268624724],
                            [2.167957908574104, 48.45085309452079],
                            [2.168070262905442, 48.45041309829173],
                            [2.1682729625501, 48.44969486393411],
                            [2.168605621008508, 48.44861517528609],
                            [2.168898359882763, 48.447704353875274],
                            [2.169043011992373, 48.447226337487045],
                            [2.169148061834316, 48.44682677802512],
                            [2.169210200482683, 48.44642477495407],
                            [2.169243745191482, 48.44601797152589],
                            [2.169259655232927, 48.445537384162456],
                            [2.16922914414058, 48.44503531570836],
                            [2.169180675555472, 48.4445570141486],
                            [2.169107182021758, 48.44407629428191],
                            [2.169022691911299, 48.443676453177346],
                            [2.16890958659707, 48.44327894949447],
                            [2.168739267589838, 48.44288136152311],
                            [2.168551069904824, 48.44248374507548],
                            [2.168337748617728, 48.44211464298877],
                            [2.168077934968886, 48.4417478505528],
                            [2.167803796667628, 48.44138817422252],
                            [2.167518846726141, 48.44105465154642],
                            [2.167180286316096, 48.440713910665636],
                            [2.166809484371037, 48.44039215507512],
                            [2.166374403331347, 48.44004650812693],
                            [2.16591067321179, 48.43971509262026],
                            [2.165418270059344, 48.439405044356505],
                            [2.164804460472121, 48.43904722457116],
                            [2.16427267984389, 48.4387537659448],
                            [2.163722920972505, 48.43849120827206],
                            [2.163348023348412, 48.438331223305916],
                            [2.162919515742157, 48.43816401865183],
                            [2.162251690426061, 48.43792506459682],
                            [2.160783927401713, 48.43739935413783],
                            [2.160051905051923, 48.43711983975931],
                            [2.159530553968522, 48.43692392480675],
                        ],
                    },
                },
                1166: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.51687499340416, 2.23513325840009],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3074.56973634,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.21551781194949,
                            48.51424587530033,
                            2.254739702427517,
                            48.52040359106998,
                        ),
                        "coordinates": [
                            [2.254739702427517, 48.52040359106998],
                            [2.253948600552972, 48.520091843351565],
                            [2.252801841891321, 48.519662450163466],
                            [2.252051590599338, 48.519394522000965],
                            [2.251629374628166, 48.51925767636118],
                            [2.251267054343519, 48.51914931959484],
                            [2.250720970607259, 48.51900033982376],
                            [2.250060191933262, 48.51883931577484],
                            [2.249469553175208, 48.51871750271303],
                            [2.248887433793413, 48.518622240606],
                            [2.248436572884771, 48.51855172926467],
                            [2.248042776185105, 48.51849453535685],
                            [2.247320793480767, 48.518402947945546],
                            [2.246487484812948, 48.51831695583189],
                            [2.245639920529656, 48.5182233618472],
                            [2.24480665776147, 48.51811649960592],
                            [2.244198868564363, 48.518019296129],
                            [2.24365388402695, 48.51791834915383],
                            [2.242952019102254, 48.5177622802411],
                            [2.242387140999766, 48.51761769684068],
                            [2.241839410773581, 48.5174636445437],
                            [2.241271756019532, 48.517283024432956],
                            [2.240627126060506, 48.51705682706108],
                            [2.239891256754431, 48.516785039075856],
                            [2.239126856606684, 48.51651132480972],
                            [2.238579204233163, 48.51632881347305],
                            [2.238014399794335, 48.516161453483036],
                            [2.237446705383091, 48.51601494795487],
                            [2.236867566817216, 48.51588359860128],
                            [2.23627696803318, 48.51577499077615],
                            [2.235680630936562, 48.51568344041647],
                            [2.235104235707228, 48.51561086788457],
                            [2.234496406887427, 48.51555722596106],
                            [2.233885689634557, 48.51552064523988],
                            [2.233272076698193, 48.51550491664651],
                            [2.232652732490723, 48.515500556898886],
                            [2.232047595272153, 48.51552654634858],
                            [2.231433862998749, 48.51556769426499],
                            [2.230860042567898, 48.515629734673865],
                            [2.230343281037579, 48.515703204508405],
                            [2.229997802444797, 48.51576166248952],
                            [2.229678008559073, 48.51582014380694],
                            [2.229346777596866, 48.515888095107066],
                            [2.229015549287242, 48.515954148197906],
                            [2.228521553700985, 48.51605607435147],
                            [2.227973314486773, 48.516163634902945],
                            [2.227510748139381, 48.51624852154019],
                            [2.226956857686097, 48.516327626984484],
                            [2.226365899817577, 48.51638962873809],
                            [2.225780688243332, 48.51643267034802],
                            [2.225175533260959, 48.516460519372316],
                            [2.224570414594077, 48.516471299701806],
                            [2.223951072126575, 48.5164612036763],
                            [2.223343188676318, 48.51643215316723],
                            [2.222752483870909, 48.516380362349665],
                            [2.222190344503523, 48.51631911606749],
                            [2.221842244875324, 48.516269460548415],
                            [2.221428523742488, 48.51620836094774],
                            [2.220840792573186, 48.516107260885434],
                            [2.220261674222972, 48.515985308035205],
                            [2.219691143621475, 48.515853879896774],
                            [2.219117810661468, 48.51570158627572],
                            [2.218541681227835, 48.515526534347586],
                            [2.217811594096222, 48.51528305212368],
                            [2.21719851558085, 48.51504727308309],
                            [2.216679586698346, 48.51482865728964],
                            [2.216274748992143, 48.51464239723378],
                            [2.21598111969379, 48.514499867051285],
                            [2.215661879012976, 48.51432696845331],
                            [2.21551781194949, 48.51424587530033],
                        ],
                    },
                },
                1167: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.899130678035, 2.3543348582509314],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 4137.28595631,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350389537889768,
                            48.880922006671476,
                            2.35776859674016,
                            48.91756717658463,
                        ),
                        "coordinates": [
                            [2.356328543670162, 48.880922006671476],
                            [2.356628054656908, 48.88155417154206],
                            [2.356799333165851, 48.881982196383895],
                            [2.356994235882585, 48.88246469507391],
                            [2.357153723092858, 48.882900503241956],
                            [2.357301391124828, 48.88328961735871],
                            [2.357460898560597, 48.88376044832461],
                            [2.357638214045052, 48.88448421689481],
                            [2.357732877413799, 48.885091258325765],
                            [2.35776859674016, 48.88584618505727],
                            [2.35771581244326, 48.886426164530604],
                            [2.357672776648871, 48.88704955877387],
                            [2.357622547948076, 48.88773481642559],
                            [2.357514564652608, 48.88836298218558],
                            [2.357406615422702, 48.88907680292586],
                            [2.35732021320441, 48.88955268597487],
                            [2.357212161668813, 48.89002857305947],
                            [2.35702476399322, 48.890604406366215],
                            [2.356866168146696, 48.89102319759584],
                            [2.356671515411152, 48.89151813463572],
                            [2.356188407767444, 48.89257940363092],
                            [2.355726862337239, 48.893459837040616],
                            [2.355279785936971, 48.894483026670464],
                            [2.354955332043211, 48.89535391720402],
                            [2.354760668682024, 48.89592023004912],
                            [2.354573252941464, 48.89658647405615],
                            [2.354400303679799, 48.89735264752717],
                            [2.354321102683396, 48.89790466678896],
                            [2.354243027550289, 48.89844847923835],
                            [2.354148424680226, 48.89948338357097],
                            [2.353906105047874, 48.90043998621057],
                            [2.353278831413479, 48.90253866092549],
                            [2.352860729356008, 48.90428515788201],
                            [2.352396188268603, 48.90767816593894],
                            [2.352342196388262, 48.90815880031198],
                            [2.352273798625216, 48.90875602475913],
                            [2.35215133701112, 48.909622122033454],
                            [2.352064855283502, 48.910114657431315],
                            [2.351524032040559, 48.912265654778864],
                            [2.351167059230403, 48.91366713435516],
                            [2.350983170912253, 48.914445201971155],
                            [2.350802520014954, 48.91553295868042],
                            [2.350627204005268, 48.91657322295872],
                            [2.350565910713105, 48.916863510991256],
                            [2.350443305575427, 48.91738222188803],
                            [2.350389537889768, 48.91756717658463],
                        ],
                    },
                },
                1168: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.15805354346948, 2.3454425245741204],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 3226.15142055,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325754000363327,
                            49.15518985899016,
                            2.362303528565357,
                            49.166775039807895,
                        ),
                        "coordinates": [
                            [2.362303528565357, 49.166775039807895],
                            [2.362074335113662, 49.16643696546545],
                            [2.361145248304282, 49.16507027734741],
                            [2.360559262285351, 49.16417832460106],
                            [2.36042615428348, 49.16398590872949],
                            [2.359792184544679, 49.16306158890005],
                            [2.359085588562511, 49.16219573169913],
                            [2.358634238179042, 49.161721003962164],
                            [2.358060837577972, 49.16119863531541],
                            [2.357571138925571, 49.16078596061517],
                            [2.357364013773477, 49.16061153924471],
                            [2.356726217456314, 49.16014942667068],
                            [2.356373729826281, 49.15992197148472],
                            [2.356066507421358, 49.15972238550927],
                            [2.355454822592649, 49.159355584167365],
                            [2.354918592556862, 49.15907599666608],
                            [2.354271284751071, 49.15873887048782],
                            [2.353700796897448, 49.158483562406815],
                            [2.353569148969973, 49.15843052477954],
                            [2.352925995959269, 49.15816443189816],
                            [2.352762808685056, 49.15809790916314],
                            [2.35165207152717, 49.157705974886845],
                            [2.350937654292909, 49.15748934028898],
                            [2.350855380406839, 49.15746776797479],
                            [2.350427560239149, 49.157352712141254],
                            [2.350238332465005, 49.157302375655206],
                            [2.349462234237527, 49.157117212820076],
                            [2.34874236608105, 49.15696531264447],
                            [2.348089693506714, 49.156844875312416],
                            [2.347679721029882, 49.15679005931988],
                            [2.346540308926389, 49.156639981641455],
                            [2.346041220522346, 49.156592360868],
                            [2.343873498391758, 49.156434240075015],
                            [2.343522496725693, 49.156410879536146],
                            [2.339776666408477, 49.15615743750605],
                            [2.338804565435459, 49.15609181080169],
                            [2.337495183825846, 49.15600369622208],
                            [2.336527202450748, 49.15593804948208],
                            [2.336077490970535, 49.15590657252303],
                            [2.331282878488239, 49.15556830987274],
                            [2.330709777837645, 49.15552601429727],
                            [2.326469136718663, 49.155236139583884],
                            [2.326027662738145, 49.15520732252403],
                            [2.325754000363327, 49.15518985899016],
                        ],
                    },
                },
                1169: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.50413554434974, 2.2048746491477043],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2766.7826763,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.194581700525426,
                            48.493644578496685,
                            2.21551781194949,
                            48.51424587530033,
                        ),
                        "coordinates": [
                            [2.21551781194949, 48.51424587530033],
                            [2.215405360368091, 48.51418258017618],
                            [2.214952259290799, 48.51389576226815],
                            [2.214561919548776, 48.51362228407414],
                            [2.214259948866942, 48.51339441062135],
                            [2.214017843237929, 48.51319504292397],
                            [2.213704581941054, 48.51291785309105],
                            [2.213428365211385, 48.5126653540132],
                            [2.212969969294566, 48.51222113463921],
                            [2.212491690469514, 48.51174276030041],
                            [2.211612000768824, 48.51087142028032],
                            [2.21108818153573, 48.51035506461171],
                            [2.210589994278624, 48.50986338703759],
                            [2.210254086764688, 48.5095292745408],
                            [2.209451332880974, 48.508733853717196],
                            [2.208279122134472, 48.507575259535955],
                            [2.20771212182366, 48.50701029465384],
                            [2.206917401264375, 48.50622965585639],
                            [2.206209283194002, 48.50551434077401],
                            [2.205546822287511, 48.504806660927215],
                            [2.205114253066435, 48.50436168153248],
                            [2.20416481223477, 48.503420042730916],
                            [2.203285973187758, 48.502552811701314],
                            [2.201560261566552, 48.50084870653122],
                            [2.201202854912382, 48.50049027095643],
                            [2.200503979430126, 48.4997931362266],
                            [2.199866557526376, 48.499167368842635],
                            [2.199488677185091, 48.49879221645242],
                            [2.199001520042713, 48.498315291153915],
                            [2.197373989353448, 48.49670225997784],
                            [2.196900534836992, 48.496237478178465],
                            [2.19630193559668, 48.49563601088248],
                            [2.195871836275718, 48.49518189782661],
                            [2.195516882203582, 48.4947915907083],
                            [2.195239327950306, 48.49447419373923],
                            [2.195057378088698, 48.494247935289636],
                            [2.194770816851011, 48.493889567467946],
                            [2.194581700525426, 48.493644578496685],
                        ],
                    },
                },
                1170: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.87925640813411, 2.377847359399479],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 648.487300654,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.374147155202552,
                            48.87815383100216,
                            2.381614511928966,
                            48.88082126138327,
                        ),
                        "coordinates": [
                            [2.374147155202552, 48.88082126138327],
                            [2.37808483465849, 48.87908493877997],
                            [2.379650971835944, 48.87826383570894],
                            [2.379692228873054, 48.878243651764926],
                            [2.379771555057288, 48.87821198093632],
                            [2.379856090915886, 48.87818684819917],
                            [2.379944604984289, 48.87816861858816],
                            [2.380035804245097, 48.878157559694486],
                            [2.380128358795466, 48.87815383100216],
                            [2.380220919515003, 48.87815748847648],
                            [2.380312137225902, 48.878168478367975],
                            [2.38040068038188, 48.87818664000217],
                            [2.380413572410478, 48.87818994611666],
                            [2.381161001309403, 48.87838680495412],
                            [2.381614511928966, 48.878514114023815],
                        ],
                    },
                },
                1171: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.84921180129406, 2.315276301803482],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 513.604227784,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.314372505690015,
                            48.84705255542816,
                            2.316424352050892,
                            48.851441707440316,
                        ),
                        "coordinates": [
                            [2.316424352050892, 48.84705255542816],
                            [2.316008592787743, 48.84781883066544],
                            [2.31451681422334, 48.85056809358785],
                            [2.314484335084635, 48.850636051983976],
                            [2.314440379948496, 48.85074771734134],
                            [2.314407242954209, 48.850860999654394],
                            [2.314385058319948, 48.850975439228336],
                            [2.314373919374779, 48.85109057703075],
                            [2.314372505690015, 48.851149753962645],
                            [2.314408121472487, 48.851441707440316],
                        ],
                    },
                },
                1172: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.86457291887278, 2.3509428918233555],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 399.62301302,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.348880653940287,
                            48.86380743868794,
                            2.352459745471375,
                            48.866069689122924,
                        ),
                        "coordinates": [
                            [2.348880653940287, 48.86380743868794],
                            [2.349569360855185, 48.8639613824386],
                            [2.351028408916723, 48.864287499551],
                            [2.351062994032514, 48.864294525704956],
                            [2.351170676009732, 48.864321454048905],
                            [2.351273913614918, 48.864355113184246],
                            [2.351371747059289, 48.86439518854518],
                            [2.351463263639009, 48.864441305567674],
                            [2.351547604481409, 48.86449303512104],
                            [2.351623984968116, 48.86454989541688],
                            [2.351648214858211, 48.86457047957938],
                            [2.352459745471375, 48.866069689122924],
                        ],
                    },
                },
                1173: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.90059030310579, 2.388883332114363],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 865.318798727,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.385508387668673,
                            48.89738989158186,
                            2.392287060995953,
                            48.90375993107707,
                        ),
                        "coordinates": [
                            [2.385508387668673, 48.89738989158186],
                            [2.389735501312455, 48.901420009798045],
                            [2.39181965993522, 48.90333132027727],
                            [2.392287060995953, 48.90375993107707],
                        ],
                    },
                },
                1174: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.8820193384486, 2.3676782248701707],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 384.31131319,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.365218781848709,
                            48.88140473224761,
                            2.370157961739611,
                            48.88248688976872,
                        ),
                        "coordinates": [
                            [2.365218781848709, 48.88140473224761],
                            [2.36592103710407, 48.88158425100825],
                            [2.369133214000685, 48.88240531403426],
                            [2.369175919059683, 48.882415807588096],
                            [2.369311668256744, 48.88244409798403],
                            [2.369450305153815, 48.882465452523014],
                            [2.369591011704378, 48.88247974457953],
                            [2.369732963892359, 48.88248688976872],
                            [2.369875330337295, 48.88248684863722],
                            [2.370017272372532, 48.88247962036803],
                            [2.370157961739611, 48.882465245572064],
                        ],
                    },
                },
                1175: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.917867862723284, 2.4075038533129627],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 791.807641003,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.404409088781864,
                            48.91494975727622,
                            2.410598617844061,
                            48.92078596817034,
                        ),
                        "coordinates": [
                            [2.404409088781864, 48.91494975727622],
                            [2.410598617844061, 48.92078596817034],
                        ],
                    },
                },
                1176: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.82965120261502, 2.328434089919221],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 374.834240731,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.327164649607824,
                            48.82818847631351,
                            2.329705012620185,
                            48.831112660375325,
                        ),
                        "coordinates": [
                            [2.327164649607824, 48.82818847631351],
                            [2.327244976794434, 48.828283895162485],
                            [2.327550802892583, 48.82863558131196],
                            [2.329705012620185, 48.831112660375325],
                        ],
                    },
                },
                1177: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.87656659219703, 2.34670916821349],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 407.514069172,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344126030464426,
                            48.87589068189371,
                            2.349293903828172,
                            48.877236320043274,
                        ),
                        "coordinates": [
                            [2.344126030464426, 48.87589068189371],
                            [2.346780023239838, 48.876590673512034],
                            [2.348719660833862, 48.877084040825906],
                            [2.349293903828172, 48.877236320043274],
                        ],
                    },
                },
                1178: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.87095783290814, 2.3552183584930257],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 348.072447394,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.354391768404852,
                            48.869490773602614,
                            2.356044909035453,
                            48.87242491449633,
                        ),
                        "coordinates": [
                            [2.354391768404852, 48.869490773602614],
                            [2.354593803083748, 48.86984926822518],
                            [2.356044348698353, 48.87242392221011],
                            [2.356044909035453, 48.87242491449633],
                        ],
                    },
                },
                1179: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.887111660358116, 2.338418645875171],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 581.413973074,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.33794977569207,
                            48.884594208027806,
                            2.338760650528743,
                            48.88967407389343,
                        ),
                        "coordinates": [
                            [2.33794977569207, 48.884594208027806],
                            [2.338181973981899, 48.88487231799836],
                            [2.338234459945617, 48.884938776272264],
                            [2.338278700390573, 48.88499897098436],
                            [2.33831720652975, 48.88505606457506],
                            [2.338353116003116, 48.88511425537139],
                            [2.338386447517405, 48.885173573156806],
                            [2.338417221119942, 48.88523404952058],
                            [2.338445448687736, 48.88529571510739],
                            [2.338471155573462, 48.88535861322667],
                            [2.338494357573125, 48.88542278803435],
                            [2.338515071754852, 48.88548829088767],
                            [2.338533289171135, 48.88555507407394],
                            [2.338549065017114, 48.8856233006775],
                            [2.338573346864596, 48.88576437852294],
                            [2.338588036770542, 48.885912204980414],
                            [2.338593241315372, 48.88606783105548],
                            [2.33859063734335, 48.88619822288754],
                            [2.338582029424632, 48.88633555492917],
                            [2.338567336562444, 48.8864812611576],
                            [2.33854627280738, 48.88663820164966],
                            [2.338496807768678, 48.88692956242321],
                            [2.338362395820447, 48.88762484797514],
                            [2.338332206046416, 48.88780701612887],
                            [2.338309733989846, 48.88797069086853],
                            [2.338292854975432, 48.888137338187356],
                            [2.338283924958791, 48.88829295330122],
                            [2.338282805156927, 48.88843998521473],
                            [2.338289493997931, 48.88857974334184],
                            [2.338303894675017, 48.88871223074593],
                            [2.338326104390123, 48.88883924661622],
                            [2.338356221249607, 48.888961338282336],
                            [2.338394338595653, 48.88907889116697],
                            [2.338440605279485, 48.889192322474],
                            [2.33849509840404, 48.88930179270099],
                            [2.338557925726461, 48.88940751827103],
                            [2.338629188743546, 48.88950967150377],
                            [2.338760650528743, 48.88967407389343],
                        ],
                    },
                },
                1180: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.88165210098623, 2.312052891035545],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 541.403489607,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.309052264550479,
                            48.88088538194511,
                            2.315176626220464,
                            48.88289191745413,
                        ),
                        "coordinates": [
                            [2.315176626220464, 48.881150028474686],
                            [2.314655633326033, 48.88108666672566],
                            [2.313026821579926, 48.88089330230174],
                            [2.313004004907383, 48.88089082231016],
                            [2.312911807814163, 48.88088538194511],
                            [2.312819282160151, 48.880887172076726],
                            [2.312727727720424, 48.880896167789956],
                            [2.312638427911531, 48.88091224065611],
                            [2.312552638767343, 48.88093516766262],
                            [2.312471561755598, 48.88096462476119],
                            [2.312396335420106, 48.88100020030933],
                            [2.312328017681526, 48.88104139316923],
                            [2.312278496000916, 48.88107840953029],
                            [2.310919677147809, 48.88219787369948],
                            [2.310844190125377, 48.88225726022111],
                            [2.31072786679358, 48.88233911349085],
                            [2.31060367561527, 48.882415773550136],
                            [2.310472145914433, 48.8824869133685],
                            [2.310333844918391, 48.88255222771868],
                            [2.310189364074871, 48.88261143669559],
                            [2.310039317687948, 48.88266428570903],
                            [2.309884352414494, 48.88271054913602],
                            [2.309725132276111, 48.882750029335725],
                            [2.309680626545464, 48.882759686986056],
                            [2.309052264550479, 48.88289191745413],
                        ],
                    },
                },
                1181: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.86347123142794, 2.3213172494045087],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 671.58697108,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.320060690278967,
                            48.860786963526714,
                            2.323175680856619,
                            48.866167114949185,
                        ),
                        "coordinates": [
                            [2.320998191954085, 48.860786963526714],
                            [2.320274132838879, 48.86153174499976],
                            [2.320253109490646, 48.861552595737734],
                            [2.320195456744341, 48.861618446939225],
                            [2.320147551451486, 48.86168761812529],
                            [2.320109828513564, 48.86175947863515],
                            [2.320082627642465, 48.86183338107708],
                            [2.320066200279887, 48.861908653273034],
                            [2.320060690278967, 48.86198461613576],
                            [2.320066148964762, 48.86206057835789],
                            [2.320082525310653, 48.86213585794069],
                            [2.320109675687251, 48.86220976606102],
                            [2.320147351171597, 48.8622816393762],
                            [2.320195208683558, 48.86235082210049],
                            [2.320252818833802, 48.86241669123187],
                            [2.320262168909397, 48.8624261479376],
                            [2.323175680856619, 48.866167114949185],
                        ],
                    },
                },
                1182: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.87592050629113, 2.3296505644594085],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 436.224678551,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.326785200261765,
                            48.875453770461874,
                            2.332543027297523,
                            48.87631796226447,
                        ),
                        "coordinates": [
                            [2.326785200261765, 48.875453770461874],
                            [2.326836475816878, 48.875494087463274],
                            [2.32689575525428, 48.87552930433248],
                            [2.326961892581259, 48.875558737413236],
                            [2.32703359449984, 48.875581811941785],
                            [2.327109466529512, 48.87559808029371],
                            [2.327188030685668, 48.875607225681605],
                            [2.327240037071978, 48.87560925998873],
                            [2.327600926214997, 48.87564235169138],
                            [2.327767707954563, 48.875662227550855],
                            [2.329044486210886, 48.875814380992274],
                            [2.33048805206258, 48.87601945338251],
                            [2.331039411519797, 48.876131894310504],
                            [2.33113552394065, 48.87614906011765],
                            [2.33144294866423, 48.87619905565979],
                            [2.331752809307591, 48.876242020396376],
                            [2.332064731440907, 48.876277904555906],
                            [2.332543027297523, 48.87631796226447],
                        ],
                    },
                },
                1183: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.876818005122814, 2.3233306521898496],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 454.111527933,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.322265213130598,
                            48.87500639715575,
                            2.32457481030558,
                            48.87877036758757,
                        ),
                        "coordinates": [
                            [2.32457481030558, 48.87500639715575],
                            [2.324459512768997, 48.87509103264787],
                            [2.324455201492869, 48.8750941973732],
                            [2.324380555428912, 48.87515128791022],
                            [2.324272469839594, 48.87524316852071],
                            [2.324173344476768, 48.875339343594],
                            [2.32408357012376, 48.875439434937476],
                            [2.324003500986117, 48.87554304706354],
                            [2.323933451916716, 48.8756497707709],
                            [2.323895936276222, 48.875715894087115],
                            [2.323868631741754, 48.875766966179505],
                            [2.322380360875917, 48.87855059393645],
                            [2.322265213130598, 48.87877036758757],
                        ],
                    },
                },
                1184: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.87415750828974, 2.326014911503358],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 283.610333735,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.32457481030558,
                            48.87351338959546,
                            2.327543081726972,
                            48.87500639715575,
                        ),
                        "coordinates": [
                            [2.327543081726972, 48.87351338959546],
                            [2.327360880239139, 48.873644490594664],
                            [2.327233287528458, 48.873737749149655],
                            [2.32717693643847, 48.87376369224345],
                            [2.327121651586517, 48.8737819213729],
                            [2.326999857517563, 48.87380673385489],
                            [2.326547836485668, 48.87386738282456],
                            [2.326206820090448, 48.87391633401898],
                            [2.326115071158798, 48.87394139296055],
                            [2.32602815287961, 48.87397307028964],
                            [2.325947157020384, 48.87401096656202],
                            [2.325873104069781, 48.87405460728888],
                            [2.325840498066106, 48.87407729206388],
                            [2.325591291227608, 48.874260231294656],
                            [2.32457481030558, 48.87500639715575],
                        ],
                    },
                },
                1185: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.87010350122552, 2.334016412886525],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 359.382635206,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.331989522683248,
                            48.869585243484515,
                            2.336218847521674,
                            48.8709917839485,
                        ),
                        "coordinates": [
                            [2.336218847521674, 48.869585243484515],
                            [2.334944259569031, 48.86984500123287],
                            [2.333080968356919, 48.870235388605],
                            [2.332986066968221, 48.87025998110903],
                            [2.332907918335267, 48.87028238887389],
                            [2.33285302409665, 48.870302287534784],
                            [2.332796223255948, 48.8703291571335],
                            [2.332737253907687, 48.870363114020655],
                            [2.332675569426941, 48.870404470814],
                            [2.332616034290908, 48.87044926964827],
                            [2.332551758717488, 48.8705020596496],
                            [2.332354639251744, 48.8706776827435],
                            [2.332119163998116, 48.87088450098179],
                            [2.331989522683248, 48.8709917839485],
                        ],
                    },
                },
                1186: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.828940666735605, 2.356473925329874],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 569.285214125,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.355643643033711,
                            48.826426010875664,
                            2.357245650758686,
                            48.83143363013256,
                        ),
                        "coordinates": [
                            [2.357245650758686, 48.826426010875664],
                            [2.357090249727368, 48.82693056663295],
                            [2.35675022100724, 48.82803452776272],
                            [2.356009515166296, 48.8304962180015],
                            [2.355988584881651, 48.83056894272543],
                            [2.355879947814217, 48.83087469718143],
                            [2.35583489795444, 48.830995302203696],
                            [2.355745665199194, 48.831220322752294],
                            [2.355643643033711, 48.83143363013256],
                        ],
                    },
                },
                1187: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.86777985633446, 2.3534263632680346],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 405.959664567,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352459745471375,
                            48.866069689122924,
                            2.354391768404852,
                            48.869490773602614,
                        ),
                        "coordinates": [
                            [2.352459745471375, 48.866069689122924],
                            [2.352549303024253, 48.86623513389228],
                            [2.352754235336438, 48.86658713904222],
                            [2.354280879075376, 48.86929400766136],
                            [2.354391768404852, 48.869490773602614],
                        ],
                    },
                },
                1188: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86466965760898, 2.377689879646222],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 474.131916509,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.374581969996412,
                            48.86408657565025,
                            2.380797986172988,
                            48.865253786054325,
                        ),
                        "coordinates": [
                            [2.380797986172988, 48.86408657565025],
                            [2.375749354308819, 48.86503349739182],
                            [2.374581969996412, 48.865253786054325],
                        ],
                    },
                },
                1189: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.79486075047856, 2.1040231487081065],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 5003.12924709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.071847005929401,
                            48.79197130289541,
                            2.136050489663708,
                            48.798774681352754,
                        ),
                        "coordinates": [
                            [2.071847005929401, 48.79870763528835],
                            [2.071930959217986, 48.79871552851866],
                            [2.072216710538763, 48.7987359766609],
                            [2.072579474675331, 48.79875781412333],
                            [2.072862898980037, 48.79877217510979],
                            [2.07339670251307, 48.798774681352754],
                            [2.073713874486058, 48.798774514434655],
                            [2.074120918822997, 48.79876825942257],
                            [2.074570257201611, 48.79874411437348],
                            [2.075095898700846, 48.79870575443047],
                            [2.075455455431691, 48.79866970976342],
                            [2.075887224661105, 48.79862123822052],
                            [2.076227752121453, 48.79857975186269],
                            [2.076626900075734, 48.798521310787564],
                            [2.07716506105974, 48.79843081224707],
                            [2.07764852043101, 48.798316933934665],
                            [2.078167738891175, 48.798203905116274],
                            [2.078658217708944, 48.798076532368164],
                            [2.079083828515797, 48.79795614915085],
                            [2.07970072398773, 48.79775767757964],
                            [2.08020225629617, 48.79758035736656],
                            [2.080682237327531, 48.79739108945262],
                            [2.082831239058495, 48.79647994934646],
                            [2.08407821011798, 48.79595569704254],
                            [2.084495051075953, 48.79578292818973],
                            [2.084798183357852, 48.795662251920504],
                            [2.085068779097173, 48.79556529741404],
                            [2.085472803759792, 48.795432945457634],
                            [2.085851533812421, 48.795317192821884],
                            [2.086342037093098, 48.795175510300744],
                            [2.086926168987106, 48.795034032056186],
                            [2.087503001665491, 48.794911569452395],
                            [2.088104956144356, 48.79480581469834],
                            [2.088696007853362, 48.794719067792464],
                            [2.089301405013185, 48.794644244904084],
                            [2.089913909264423, 48.794588469047525],
                            [2.09054429876811, 48.794556522554586],
                            [2.091113408132319, 48.79453633626861],
                            [2.09172199049859, 48.79454478562203],
                            [2.092341270622694, 48.79457466828989],
                            [2.093068461780212, 48.79463095098126],
                            [2.093925150711385, 48.79471843643121],
                            [2.094774639817521, 48.794805900752586],
                            [2.098176203113287, 48.7951604600855],
                            [2.101567045015145, 48.79550775765459],
                            [2.10300329181604, 48.795658232499086],
                            [2.103510872100985, 48.79570448052273],
                            [2.103986129960595, 48.795731624861844],
                            [2.104472236811199, 48.795749272395476],
                            [2.104962034435666, 48.79574789032003],
                            [2.105455511439231, 48.79572985839365],
                            [2.105949086909674, 48.79569041070288],
                            [2.106424732283703, 48.79563426936188],
                            [2.106914848316776, 48.7955638785091],
                            [2.107390620647533, 48.795479181062994],
                            [2.107816052636528, 48.795377724667944],
                            [2.108270390515862, 48.79525491057731],
                            [2.108728360406763, 48.79512496420476],
                            [2.109154025991882, 48.79497115721885],
                            [2.109680764025691, 48.79476520547845],
                            [2.110294111936995, 48.794518974053865],
                            [2.110961593718655, 48.79424667472427],
                            [2.111369258162332, 48.794088065982855],
                            [2.111697533309683, 48.79396498860572],
                            [2.112061828922531, 48.79383960199691],
                            [2.112483806336287, 48.79370005213547],
                            [2.112801132518071, 48.793607882006135],
                            [2.113176151228948, 48.79349916875279],
                            [2.11369172125704, 48.793366936094806],
                            [2.114286612721081, 48.79321344201142],
                            [2.114690340145993, 48.79312619386876],
                            [2.115083250085545, 48.79304130261554],
                            [2.115443696458172, 48.792968243717226],
                            [2.11591216526011, 48.79289777277563],
                            [2.116330153700183, 48.792841477695944],
                            [2.11687422424131, 48.79277590713132],
                            [2.117843448911033, 48.79266118584478],
                            [2.120895214199257, 48.79230058968553],
                            [2.12276515961669, 48.79208045968901],
                            [2.123371895057395, 48.792006960314865],
                            [2.123854964587829, 48.79198209806883],
                            [2.124117106316824, 48.79197237837199],
                            [2.124505010430262, 48.79197130289541],
                            [2.124978607028827, 48.791982975227185],
                            [2.125773213019912, 48.79204200359494],
                            [2.126103812899514, 48.792074090135145],
                            [2.126404451834651, 48.79211061667671],
                            [2.126827479735518, 48.79217254796331],
                            [2.127227320272672, 48.79224612597793],
                            [2.12760129539878, 48.792321452990265],
                            [2.127994261423026, 48.792412101522544],
                            [2.128362701359944, 48.79250989839397],
                            [2.128830302441107, 48.79265463765974],
                            [2.129149705918469, 48.79276223361234],
                            [2.129462265955019, 48.792878809983584],
                            [2.130050581171206, 48.79312718041466],
                            [2.130828967598358, 48.7934927980301],
                            [2.13206509185052, 48.79409304530295],
                            [2.132487588843224, 48.794289846410095],
                            [2.133002509056168, 48.794520084339],
                            [2.13335716335117, 48.7946664018369],
                            [2.13369969439922, 48.79478212009287],
                            [2.13399604854809, 48.79487347462278],
                            [2.134304686413588, 48.794956757804414],
                            [2.134637837020887, 48.79503738448375],
                            [2.135009117560278, 48.7951135822115],
                            [2.1359721799146, 48.79526816122795],
                            [2.136050489663708, 48.79528024627206],
                        ],
                    },
                },
                1190: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.11818781333716, 2.383829697888081],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2420.82694951,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368253547610188,
                            49.11662788250494,
                            2.399724852518912,
                            49.11902264630466,
                        ),
                        "coordinates": [
                            [2.368253547610188, 49.11662788250494],
                            [2.368542288383732, 49.1168352344404],
                            [2.368999227039116, 49.11716336598175],
                            [2.369321323384197, 49.11738539561298],
                            [2.369605031528311, 49.11756157260303],
                            [2.369881876928586, 49.11771616802285],
                            [2.370145939355758, 49.11785072350926],
                            [2.370406761983622, 49.1179660138007],
                            [2.370887765575727, 49.118148425109005],
                            [2.371322153303947, 49.11827599220463],
                            [2.371642798976949, 49.11835862855349],
                            [2.371925071673401, 49.11842239151264],
                            [2.372211443882041, 49.11847176398141],
                            [2.372664969762936, 49.118530975467834],
                            [2.372954067335911, 49.1185587624325],
                            [2.373197946231456, 49.11857397347514],
                            [2.37419398801061, 49.1186042304675],
                            [2.375294149138613, 49.118629047945944],
                            [2.37546403794968, 49.11863348701299],
                            [2.376572425439091, 49.11866278618023],
                            [2.376840960048925, 49.11866988699435],
                            [2.377151964906881, 49.11867787246378],
                            [2.377378026581881, 49.11868318858139],
                            [2.377747946564409, 49.11869205016643],
                            [2.378121974775684, 49.11870090937275],
                            [2.37976468962494, 49.1187389777786],
                            [2.379953759484097, 49.1187434032974],
                            [2.380822357903373, 49.118731384501125],
                            [2.381164857820234, 49.11871866286042],
                            [2.381392265572972, 49.1186978920014],
                            [2.38186625987457, 49.118652744043644],
                            [2.382204617159484, 49.11860584933785],
                            [2.382519676448837, 49.118550869633246],
                            [2.382829247198656, 49.11848959583229],
                            [2.383041554475454, 49.11843735318354],
                            [2.383541500184464, 49.118312152117696],
                            [2.384052383662404, 49.11816716125105],
                            [2.384312614122676, 49.118088818213906],
                            [2.385242591742117, 49.11781235449708],
                            [2.385761692517478, 49.11767544552939],
                            [2.386083574277913, 49.11760246742603],
                            [2.386480803077359, 49.11752855644476],
                            [2.386738329747167, 49.11749337313369],
                            [2.386861614939927, 49.11747713306004],
                            [2.387369840188663, 49.117430149046065],
                            [2.38764383177174, 49.11742013599074],
                            [2.388926146071552, 49.11740787222688],
                            [2.389501546110945, 49.11740491260683],
                            [2.390042709313123, 49.11741455592872],
                            [2.390353712575591, 49.11742520287971],
                            [2.390634584022454, 49.117443956669774],
                            [2.390918208160942, 49.11747349977349],
                            [2.391184026893407, 49.11750664750328],
                            [2.391395046772242, 49.11754161956887],
                            [2.391460819503132, 49.11755237948609],
                            [2.39213089826975, 49.11768065514996],
                            [2.393126172129542, 49.11788636619321],
                            [2.394866525621049, 49.11824715921053],
                            [2.396476382616109, 49.11858657970853],
                            [2.397153290509102, 49.1187347761175],
                            [2.397669271646377, 49.118826267127254],
                            [2.397999204548541, 49.118878436882596],
                            [2.398401642801668, 49.118935327299084],
                            [2.398731548854243, 49.11896608134625],
                            [2.399028823724458, 49.1189897140484],
                            [2.399369591416852, 49.11900856404319],
                            [2.399724852518912, 49.11902264630466],
                        ],
                    },
                },
                1191: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.877639499596135, 2.227261031922183],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 1598.29199204,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.22102955043113,
                            48.87171419115656,
                            2.233691920150409,
                            48.883383813825255,
                        ),
                        "coordinates": [
                            [2.22102955043113, 48.87171419115656],
                            [2.221126874185613, 48.87187749303678],
                            [2.221159476252741, 48.87192698607902],
                            [2.221247785944357, 48.872056571819854],
                            [2.221386396977642, 48.87224645977171],
                            [2.221667761780453, 48.87260375663998],
                            [2.222018574399512, 48.87299709322498],
                            [2.222588500316376, 48.873556115585714],
                            [2.222731324025215, 48.87369654585657],
                            [2.224022550133282, 48.874814730179814],
                            [2.224139563150962, 48.87491736246457],
                            [2.225992791750209, 48.87654057145214],
                            [2.226085312598864, 48.87662519300606],
                            [2.226109802963735, 48.87664769922691],
                            [2.226885384622743, 48.87734448781184],
                            [2.227070441831837, 48.87750923356406],
                            [2.227739960062819, 48.87808900869021],
                            [2.227843383693998, 48.87817813643822],
                            [2.227869239054145, 48.87820064296801],
                            [2.227892372300882, 48.87822134763179],
                            [2.22873337339959, 48.87895235935132],
                            [2.229703643264529, 48.87981478033202],
                            [2.230091538082921, 48.880137084301346],
                            [2.230156866054467, 48.88019200108927],
                            [2.230456228372583, 48.88047285470365],
                            [2.231728756813296, 48.88157114906521],
                            [2.231768226200799, 48.88160535794083],
                            [2.231785919561585, 48.88162066227985],
                            [2.23275087133963, 48.882468662807234],
                            [2.233246223285348, 48.882935837411715],
                            [2.23329385487512, 48.88297994579525],
                            [2.233327878865389, 48.883011450880275],
                            [2.233341487922252, 48.883024053267555],
                            [2.233544230011552, 48.88322927169216],
                            [2.233691920150409, 48.883383813825255],
                        ],
                    },
                },
                1192: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.11709859519964, 2.409968071982185],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1600.26786565,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.399724852518912,
                            49.11563266727845,
                            2.420107032801724,
                            49.11902482682648,
                        ),
                        "coordinates": [
                            [2.399724852518912, 49.11902264630466],
                            [2.40008734999755, 49.11902482682648],
                            [2.400500579906065, 49.11901508224722],
                            [2.400873920669871, 49.11899346156345],
                            [2.401399461678388, 49.11893606394205],
                            [2.401790892200709, 49.11888825801243],
                            [2.402146062795225, 49.1188333329668],
                            [2.40258819233905, 49.118749805125205],
                            [2.402986816247692, 49.118661541654745],
                            [2.403394980924829, 49.11856137571291],
                            [2.403776755699988, 49.11844694694775],
                            [2.405400062315582, 49.11797964398466],
                            [2.407632141340071, 49.11734213696873],
                            [2.409232999447281, 49.11687801721664],
                            [2.409634239450425, 49.116763556597185],
                            [2.411650242876779, 49.11618888064514],
                            [2.412298786824015, 49.11600287124851],
                            [2.412874885408582, 49.11585259479356],
                            [2.413302456566346, 49.11575951745221],
                            [2.4137055537204, 49.1156898800109],
                            [2.414119223945466, 49.115652733193194],
                            [2.414538400083871, 49.11563266727845],
                            [2.414982279602019, 49.11564046079079],
                            [2.4153508336342, 49.1156626915916],
                            [2.415800253071774, 49.115708247129845],
                            [2.416213128094022, 49.115781342787784],
                            [2.416651869174905, 49.115876211610875],
                            [2.417018127179638, 49.11597588943403],
                            [2.41738804421984, 49.11609697674325],
                            [2.417743480455973, 49.116227590065314],
                            [2.418378205353224, 49.116467455248426],
                            [2.420107032801724, 49.11713213147004],
                        ],
                    },
                },
                1193: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.00058748839264, 2.2159551033513307],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 3085.32946945,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.197619813968745,
                            48.99371348038584,
                            2.234276393996537,
                            49.00742329713069,
                        ),
                        "coordinates": [
                            [2.234276393996537, 48.99371348038584],
                            [2.232504861292808, 48.9943803276354],
                            [2.231359427180695, 48.994809666630914],
                            [2.230414903766395, 48.99517521281167],
                            [2.229683920708789, 48.995441016431265],
                            [2.228059050132284, 48.996046217987484],
                            [2.227121731667691, 48.99640222545707],
                            [2.226412418710857, 48.99666327110842],
                            [2.223423033436542, 48.997788159763694],
                            [2.222749859535978, 48.998042080573654],
                            [2.221005371270001, 48.99869702816867],
                            [2.219673320446388, 48.99919434307988],
                            [2.218975661356986, 48.99945531783884],
                            [2.217379205528473, 49.000060675939075],
                            [2.215785462942007, 49.00065882117623],
                            [2.214195783782723, 49.00125604913104],
                            [2.213191621323129, 49.00162906913297],
                            [2.210299417120758, 49.00271403690773],
                            [2.209001026064172, 49.003202701053084],
                            [2.208764333090145, 49.003290566148564],
                            [2.208537212324408, 49.00337664235786],
                            [2.208052885370861, 49.00355325664045],
                            [2.206133475048893, 49.00427013405321],
                            [2.203652642125176, 49.00519570211146],
                            [2.203086170973281, 49.005407272201836],
                            [2.200341329439513, 49.00642831184516],
                            [2.20001154742561, 49.00655471665025],
                            [2.199101295954952, 49.00689817438802],
                            [2.198359101214039, 49.00717090371677],
                            [2.197708619109245, 49.00739456289574],
                            [2.197619813968745, 49.00742329713069],
                        ],
                    },
                },
                1194: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.91138859502196, 2.2754253293176867],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 846.401391278,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.271598750389755,
                            48.908565915509755,
                            2.279278948726629,
                            48.91424647429558,
                        ),
                        "coordinates": [
                            [2.279278948726629, 48.908565915509755],
                            [2.278715110764272, 48.909008167762096],
                            [2.27845174898955, 48.90919967730751],
                            [2.278043500521469, 48.909504024340734],
                            [2.277501569592654, 48.90990823213004],
                            [2.276074501697972, 48.91092346191907],
                            [2.275008709374851, 48.91165810696018],
                            [2.274492039487923, 48.91202900532186],
                            [2.273828487873968, 48.912508176039466],
                            [2.27301910671105, 48.913107322124375],
                            [2.272550015129134, 48.91349096677442],
                            [2.272245761381376, 48.9137397941222],
                            [2.271642274483488, 48.9142153187575],
                            [2.271598750389755, 48.91424647429558],
                        ],
                    },
                },
                1195: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.886415433638916, 2.5190042434335185],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 1115.16191874,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.512566821462173,
                            48.88373428097723,
                            2.525434250765843,
                            48.88907659470566,
                        ),
                        "coordinates": [
                            [2.512566821462173, 48.88907659470566],
                            [2.512998832387353, 48.888924515379514],
                            [2.51336355369073, 48.888784347605245],
                            [2.514432503756536, 48.88834352057677],
                            [2.515351998005951, 48.88794826774535],
                            [2.517499182084499, 48.88705597118021],
                            [2.521107305737947, 48.885521719400764],
                            [2.52210153410764, 48.885103250811575],
                            [2.525434250765843, 48.88373428097723],
                        ],
                    },
                },
                1196: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.07394314421013, 2.3392798008692384],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2085.12463312,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.327669570460789,
                            49.068530235211696,
                            2.35083083355881,
                            49.079470233982065,
                        ),
                        "coordinates": [
                            [2.327669570460789, 49.068530235211696],
                            [2.328714085613412, 49.068980939458065],
                            [2.331555889767361, 49.07034789591556],
                            [2.333152513976816, 49.07108456999683],
                            [2.333887987614685, 49.0714305778981],
                            [2.335303955010883, 49.072089680652134],
                            [2.338052702632552, 49.07337214662515],
                            [2.340682072555365, 49.07459268705621],
                            [2.343282596530885, 49.075801272500435],
                            [2.343619818528195, 49.07596029535128],
                            [2.344972356117883, 49.076599591564225],
                            [2.348765940056676, 49.07836543501684],
                            [2.349157498836323, 49.07854884543927],
                            [2.34971335369105, 49.07881227267111],
                            [2.3501431024938, 49.07905085497304],
                            [2.350581437189748, 49.079312529418345],
                            [2.35083083355881, 49.079470233982065],
                        ],
                    },
                },
                1197: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.071548767664495, 2.518825766579545],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 6139.99703832,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.501758065846462,
                            49.049325600885666,
                            2.525531713992054,
                            49.0995869391937,
                        ),
                        "coordinates": [
                            [2.525531713992054, 49.0995869391937],
                            [2.525456205313082, 49.09878998487126],
                            [2.525388807844771, 49.09815501736476],
                            [2.525263989645341, 49.09677758485618],
                            [2.525101742246043, 49.09508376028289],
                            [2.525018928933173, 49.09426778171277],
                            [2.524959021857032, 49.09375870102211],
                            [2.524831400626698, 49.09259065398214],
                            [2.52469274286543, 49.091377416045574],
                            [2.524564372804595, 49.09000950569161],
                            [2.524288894852118, 49.087102399979976],
                            [2.52412655899805, 49.085368124784615],
                            [2.523979264220945, 49.083776585137386],
                            [2.523817004176479, 49.08205658528732],
                            [2.523515479146732, 49.07894251669787],
                            [2.523353439169441, 49.07727248194281],
                            [2.523194870490833, 49.07555961244652],
                            [2.522912032892946, 49.0725787534216],
                            [2.52273882057365, 49.07081594102618],
                            [2.522508581232654, 49.06832752099011],
                            [2.522437138104643, 49.06762334965069],
                            [2.522403183300106, 49.0672593650209],
                            [2.522347545763149, 49.0669073122521],
                            [2.522310524646228, 49.0666908521814],
                            [2.522244354928861, 49.06642685171675],
                            [2.522181879154814, 49.06618187949972],
                            [2.522097669226215, 49.06593456386146],
                            [2.52198433097011, 49.06564446700814],
                            [2.521831020417443, 49.06531636517778],
                            [2.521655871261256, 49.06495736540949],
                            [2.521528319923761, 49.06473867131059],
                            [2.521335239632957, 49.064424909180275],
                            [2.521084066929011, 49.06406841077629],
                            [2.520894885212112, 49.06382840005642],
                            [2.520683929563137, 49.063574148388575],
                            [2.520487562929214, 49.06334842472652],
                            [2.520273094665979, 49.063122730026926],
                            [2.520047775783673, 49.062899430981616],
                            [2.5197898164025, 49.06266190841207],
                            [2.519441131173611, 49.06236742448827],
                            [2.519056215702498, 49.06206586008418],
                            [2.518576955294328, 49.061707338191916],
                            [2.517505982336898, 49.060926224305746],
                            [2.513382018222184, 49.057884700325715],
                            [2.511305705461247, 49.056353196937266],
                            [2.507785014010126, 49.053765007923765],
                            [2.506044060374637, 49.05249549806436],
                            [2.504291141078054, 49.05118942944881],
                            [2.502068583516813, 49.049554300205486],
                            [2.501758065846462, 49.049325600885666],
                        ],
                    },
                },
                1198: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.752979538534454, 2.3586628108591814],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 556.561816264,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.355360989087524,
                            48.7524011287445,
                            2.361952152582564,
                            48.75329695370965,
                        ),
                        "coordinates": [
                            [2.355360989087524, 48.75267435087357],
                            [2.355618029347783, 48.752870871183596],
                            [2.35577629586804, 48.752994521149084],
                            [2.355874669982757, 48.753072155736504],
                            [2.355897465139014, 48.75308920962243],
                            [2.355924323196555, 48.75310715516942],
                            [2.355954956519576, 48.753125712898466],
                            [2.355989082955736, 48.753144599762486],
                            [2.356026414900788, 48.753163533584235],
                            [2.356066670178172, 48.75318223311541],
                            [2.356109561181049, 48.7532004161792],
                            [2.356154805730184, 48.753217801527626],
                            [2.35620211620444, 48.75323410788377],
                            [2.356251210443797, 48.75324905220158],
                            [2.356301802172813, 48.75326235411155],
                            [2.35635360514775, 48.75327373054651],
                            [2.356406337181347, 48.75328290026042],
                            [2.356459710655487, 48.753289581079045],
                            [2.356513443379727, 48.75329349175734],
                            [2.356567247721881, 48.753294351021424],
                            [2.357499147231351, 48.75329695370965],
                            [2.358094017199612, 48.75328686107217],
                            [2.358204831665632, 48.753282961334364],
                            [2.358314513865551, 48.75327655948354],
                            [2.358423053003386, 48.753267758000156],
                            [2.358530432865463, 48.75325665753679],
                            [2.358636642635831, 48.75324336237261],
                            [2.358741666103326, 48.75322797316018],
                            [2.358845492454075, 48.75321059417871],
                            [2.358948105479247, 48.75319132608082],
                            [2.35904949437832, 48.75317027224631],
                            [2.359149644282602, 48.75314753513387],
                            [2.359248541695452, 48.75312321630999],
                            [2.359346173110322, 48.753097418240614],
                            [2.359442525021777, 48.75307024339167],
                            [2.359537585274402, 48.7530417951358],
                            [2.359631337666262, 48.753012174125594],
                            [2.359723771404017, 48.752981483740946],
                            [2.360727852345335, 48.752454273900746],
                            [2.360796415690531, 48.75243456468619],
                            [2.360863857058823, 48.75241972435493],
                            [2.360929949245549, 48.75240942519875],
                            [2.360994462356317, 48.75240333679712],
                            [2.361057169215157, 48.7524011287445],
                            [2.361117842621244, 48.75240247243442],
                            [2.361176252673707, 48.752407037447455],
                            [2.361232170817814, 48.75241449427111],
                            [2.361285371217157, 48.75242451340772],
                            [2.361335625312606, 48.75243676534531],
                            [2.361382703193636, 48.75245091966538],
                            [2.361426379005799, 48.75246664777022],
                            [2.361466422834601, 48.75248361924153],
                            [2.361502606112528, 48.752501504567704],
                            [2.361534702990688, 48.7525199742516],
                            [2.361562483538403, 48.752538698774096],
                            [2.36171238949517, 48.75264087794122],
                            [2.361952152582564, 48.75281135969812],
                        ],
                    },
                },
                1199: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.79348755572379, 2.17687179283638],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 1987.56589375,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.170967401079032,
                            48.78512141332815,
                            2.179978675640172,
                            48.80107761141682,
                        ),
                        "coordinates": [
                            [2.178798590270473, 48.78512141332815],
                            [2.179281179313725, 48.78539466220411],
                            [2.179342919452818, 48.785435724137606],
                            [2.17940590204873, 48.78548398998044],
                            [2.179470855130901, 48.78554440527751],
                            [2.17951660281827, 48.78559558197101],
                            [2.179560631595126, 48.785658353037356],
                            [2.179604286363515, 48.7857449176325],
                            [2.179630077375243, 48.785822436354664],
                            [2.179646631863295, 48.78591476456126],
                            [2.179630374147197, 48.78611806530697],
                            [2.17935388438798, 48.78821356024124],
                            [2.17936118650151, 48.78848204440793],
                            [2.179394726658522, 48.78863933664058],
                            [2.179441961234696, 48.78884193780667],
                            [2.179598211502784, 48.78921186871811],
                            [2.179809201461744, 48.789765414456866],
                            [2.179909109016988, 48.79005404674244],
                            [2.179978675640172, 48.790440040009116],
                            [2.179973664039647, 48.79075888947756],
                            [2.179911031571571, 48.7910773425481],
                            [2.179838904451807, 48.79131244029682],
                            [2.179723000170746, 48.79158293371963],
                            [2.179567143869642, 48.791874569718786],
                            [2.179452659079708, 48.79205464291156],
                            [2.179269111750802, 48.79227469674752],
                            [2.179082223400986, 48.79247806914583],
                            [2.177866327961809, 48.79375476041298],
                            [2.175092246334868, 48.79668348555242],
                            [2.170967401079032, 48.80107761141682],
                        ],
                    },
                },
                1200: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.91316176384872, 2.351335038605838],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 989.891258787,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350389537889768,
                            48.90875602475913,
                            2.352273798625216,
                            48.91756717658463,
                        ),
                        "coordinates": [
                            [2.352273798625216, 48.90875602475913],
                            [2.35215133701112, 48.909622122033454],
                            [2.352064855283502, 48.910114657431315],
                            [2.351524032040559, 48.912265654778864],
                            [2.351167059230403, 48.91366713435516],
                            [2.350983170912253, 48.914445201971155],
                            [2.350802520014954, 48.91553295868042],
                            [2.350627204005268, 48.91657322295872],
                            [2.350565910713105, 48.916863510991256],
                            [2.350443305575427, 48.91738222188803],
                            [2.350389537889768, 48.91756717658463],
                        ],
                    },
                },
                1201: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.9785290016097, 3.344327922757435],
                        "indice_lig": "P",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 4249.34948913,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.32188681725306,
                            48.969278782071456,
                            3.364927128865269,
                            48.99193822029961,
                        ),
                        "coordinates": [
                            [3.32188681725306, 48.969278782071456],
                            [3.32799486415054, 48.96997246850015],
                            [3.333615172961879, 48.97087541659164],
                            [3.335976076474291, 48.971449692278775],
                            [3.338888718286613, 48.972494992789954],
                            [3.346001312709376, 48.977046514612006],
                            [3.34827305145462, 48.97876648225163],
                            [3.349847019582927, 48.98116183833388],
                            [3.351324951423921, 48.983825722928195],
                            [3.352886892290022, 48.985618823749384],
                            [3.355670361408304, 48.98746795176199],
                            [3.364927128865269, 48.99193822029961],
                        ],
                    },
                },
                1202: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [47.97556951054906, 3.3642125558666116],
                        "indice_lig": "GL",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 4677.53203462,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.33759167637693,
                            47.97186285401785,
                            3.39286472633588,
                            47.986192359878295,
                        ),
                        "coordinates": [
                            [3.33759167637693, 47.986192359878295],
                            [3.353757725731529, 47.976020131466214],
                            [3.357794945719381, 47.974188161620226],
                            [3.366164809169279, 47.97257282490089],
                            [3.371627630238643, 47.972009604833374],
                            [3.378244675405589, 47.97186285401785],
                            [3.39286472633588, 47.97343031566925],
                        ],
                    },
                },
                1203: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98059332055262, 2.2733998353909346],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 192.880431892,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272084772747633,
                            48.98054054067926,
                            2.274714898034236,
                            48.980646100425986,
                        ),
                        "coordinates": [
                            [2.274714898034236, 48.98054054067926],
                            [2.272084772747633, 48.980646100425986],
                        ],
                    },
                },
                1204: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.797580349605624, 2.1406320310669837],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1796.83912,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.129043867370256,
                            48.796178314273135,
                            2.152378660253372,
                            48.80021557813598,
                        ),
                        "coordinates": [
                            [2.152378660253372, 48.79652818117568],
                            [2.152338963680592, 48.79652271537383],
                            [2.151471461789258, 48.796402340222436],
                            [2.150481531964946, 48.79627699980382],
                            [2.149919278022563, 48.796234597562176],
                            [2.149386970964321, 48.79620382486479],
                            [2.148911648288609, 48.796186386585646],
                            [2.148346254825638, 48.796178314273135],
                            [2.147978893252051, 48.796182464964964],
                            [2.147139728577896, 48.79619058794475],
                            [2.14674351935253, 48.7962042040603],
                            [2.146242795216752, 48.79623667880198],
                            [2.14585733505846, 48.79626458503123],
                            [2.145259279419891, 48.79632068578173],
                            [2.144711615802071, 48.796384005867424],
                            [2.144297248504016, 48.796435651809674],
                            [2.143875642409222, 48.79649680172298],
                            [2.143468432092114, 48.796560354944475],
                            [2.143108038006966, 48.79662398431525],
                            [2.142707980272671, 48.796699442413846],
                            [2.142297099246691, 48.79677963970738],
                            [2.141752812458423, 48.796897676941086],
                            [2.141194061865006, 48.79702996254319],
                            [2.140386158644989, 48.797244135999144],
                            [2.13942061427876, 48.79750259791235],
                            [2.137527869103348, 48.798009194274506],
                            [2.136514029104777, 48.79828079712656],
                            [2.135489978018193, 48.7985608854198],
                            [2.134833786095137, 48.79873646316356],
                            [2.134247807910476, 48.79889459527487],
                            [2.133292523448711, 48.79915188493529],
                            [2.133000893591115, 48.799230500080526],
                            [2.132544631484282, 48.79934069288383],
                            [2.131751185260367, 48.79951309439427],
                            [2.131331777615874, 48.79961329329602],
                            [2.130541404082334, 48.799816001623284],
                            [2.129043867370256, 48.80021557813598],
                        ],
                    },
                },
                1205: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80649829543364, 1.790761244746442],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 3874.20161566,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.765056756557643,
                            48.802601980906694,
                            1.816466794198607,
                            48.810402464358575,
                        ),
                        "coordinates": [
                            [1.765056756557643, 48.810402464358575],
                            [1.765578236059365, 48.810323677235814],
                            [1.765713281789975, 48.81030187078084],
                            [1.765848307990154, 48.81028186290839],
                            [1.766470284250454, 48.81018605076781],
                            [1.768641544773686, 48.80986774332251],
                            [1.77007917532504, 48.80964467439468],
                            [1.771833154563744, 48.809379089216684],
                            [1.773430251888483, 48.809138781783844],
                            [1.773917160261275, 48.80906474508711],
                            [1.774770941992939, 48.80893585884246],
                            [1.776433481161241, 48.808685040501096],
                            [1.776871278469499, 48.808618844288524],
                            [1.777864224791863, 48.808462739754354],
                            [1.778652645643295, 48.80833260449746],
                            [1.779678145884585, 48.80818653631542],
                            [1.781373460149095, 48.80792231677589],
                            [1.782849117272393, 48.80769747415338],
                            [1.786176728211459, 48.80719648992155],
                            [1.787248628854193, 48.80703618853358],
                            [1.788013718981526, 48.80691846639314],
                            [1.788687414065552, 48.806816488476215],
                            [1.792529115569641, 48.80622965725163],
                            [1.794120702736462, 48.805976444484706],
                            [1.795612481892875, 48.805760507001644],
                            [1.79650032088141, 48.8056190298184],
                            [1.797236759662873, 48.80550290959039],
                            [1.798199454722226, 48.80536267314405],
                            [1.799949019458404, 48.80509933317677],
                            [1.801256760021642, 48.804902240135576],
                            [1.801804956732735, 48.8048184807739],
                            [1.805334043340158, 48.804284610275445],
                            [1.805668159186067, 48.804231309839885],
                            [1.805902723407634, 48.80419373236873],
                            [1.806559956126206, 48.80409696747534],
                            [1.808209923841685, 48.803846528157784],
                            [1.808962630493156, 48.80373220630825],
                            [1.809861235881343, 48.80359607145867],
                            [1.811511169217694, 48.80334558463799],
                            [1.811673432507989, 48.80332115122481],
                            [1.812423429741043, 48.803204096739385],
                            [1.814014735411301, 48.80295959867648],
                            [1.814272459255679, 48.8029194121295],
                            [1.814841106180383, 48.8028284897656],
                            [1.816193615172426, 48.80263502755033],
                            [1.816466794198607, 48.802601980906694],
                        ],
                    },
                },
                1206: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.00058748839264, 2.2159551033513307],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 3085.32946945,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.197619813968745,
                            48.99371348038584,
                            2.234276393996537,
                            49.00742329713069,
                        ),
                        "coordinates": [
                            [2.234276393996537, 48.99371348038584],
                            [2.232504861292808, 48.9943803276354],
                            [2.231359427180695, 48.994809666630914],
                            [2.230414903766395, 48.99517521281167],
                            [2.229683920708789, 48.995441016431265],
                            [2.228059050132284, 48.996046217987484],
                            [2.227121731667691, 48.99640222545707],
                            [2.226412418710857, 48.99666327110842],
                            [2.223423033436542, 48.997788159763694],
                            [2.222749859535978, 48.998042080573654],
                            [2.221005371270001, 48.99869702816867],
                            [2.219673320446388, 48.99919434307988],
                            [2.218975661356986, 48.99945531783884],
                            [2.217379205528473, 49.000060675939075],
                            [2.215785462942007, 49.00065882117623],
                            [2.214195783782723, 49.00125604913104],
                            [2.213191621323129, 49.00162906913297],
                            [2.210299417120758, 49.00271403690773],
                            [2.209001026064172, 49.003202701053084],
                            [2.208764333090145, 49.003290566148564],
                            [2.208537212324408, 49.00337664235786],
                            [2.208052885370861, 49.00355325664045],
                            [2.206133475048893, 49.00427013405321],
                            [2.203652642125176, 49.00519570211146],
                            [2.203086170973281, 49.005407272201836],
                            [2.200341329439513, 49.00642831184516],
                            [2.20001154742561, 49.00655471665025],
                            [2.199101295954952, 49.00689817438802],
                            [2.198359101214039, 49.00717090371677],
                            [2.197708619109245, 49.00739456289574],
                            [2.197619813968745, 49.00742329713069],
                        ],
                    },
                },
                1207: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.67315556866799, 2.3488048886974147],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 881.966705953,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344492790482471,
                            48.670783940999655,
                            2.352481401048998,
                            48.676446656997726,
                        ),
                        "coordinates": [
                            [2.344492790482471, 48.670783940999655],
                            [2.345057313905659, 48.67094805008256],
                            [2.345549008047062, 48.671109829051694],
                            [2.345980125829444, 48.67126920930853],
                            [2.346332208719983, 48.67140955935653],
                            [2.346517001485164, 48.671491989470326],
                            [2.347168793780418, 48.67180217899401],
                            [2.347782580698658, 48.67213125142602],
                            [2.347968621243447, 48.67224274246058],
                            [2.348525392909058, 48.6725790116448],
                            [2.349311698640001, 48.67314456571711],
                            [2.349766656015362, 48.67349342994597],
                            [2.350101190746646, 48.67377562382039],
                            [2.350349299814329, 48.67400144668846],
                            [2.350591060053158, 48.67424062247734],
                            [2.350984958830975, 48.67468121494793],
                            [2.351504493782131, 48.67535114506738],
                            [2.351748366911131, 48.67566491383806],
                            [2.352067131975409, 48.67603431518159],
                            [2.352328379706742, 48.676298819112354],
                            [2.352481401048998, 48.676446656997726],
                        ],
                    },
                },
                1208: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.986643147363, 1.7091422868963677],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1107.77054667,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.703016134167223,
                            48.983654507541004,
                            1.715210986447546,
                            48.989502508030505,
                        ),
                        "coordinates": [
                            [1.715210986447546, 48.983654507541004],
                            [1.714876713955381, 48.983788316553415],
                            [1.713600965108449, 48.98433101806053],
                            [1.712641222925728, 48.984754079445864],
                            [1.712284705578705, 48.98493058933371],
                            [1.711411070835274, 48.98540407886332],
                            [1.708445222531689, 48.9871303023471],
                            [1.707197842322636, 48.987799197118015],
                            [1.706378210456435, 48.98818807925704],
                            [1.705757817330407, 48.98845115279417],
                            [1.704968622676812, 48.98871963626297],
                            [1.70427599037051, 48.9889759579842],
                            [1.703016134167223, 48.989502508030505],
                        ],
                    },
                },
                1209: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.85267174552513, 2.3375804756080636],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 322.647779825,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.335502051727559,
                            48.852167261116506,
                            2.339646335932881,
                            48.853057609985505,
                        ),
                        "coordinates": [
                            [2.339646335932881, 48.852167261116506],
                            [2.338619825981557, 48.85242360796845],
                            [2.337318685674617, 48.852738908786186],
                            [2.336667253609826, 48.85292033167029],
                            [2.336421584054109, 48.85298874867566],
                            [2.336406428230857, 48.8529928978894],
                            [2.336292297026456, 48.853019665531775],
                            [2.33617494675818, 48.853039473080635],
                            [2.336055356723008, 48.853052155982525],
                            [2.335934513630793, 48.853057609985505],
                            [2.335813418416401, 48.853055791177106],
                            [2.335693074029962, 48.85304671142011],
                            [2.335574485308991, 48.85303044824455],
                            [2.335502051727559, 48.85301676791718],
                        ],
                    },
                },
                1210: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.79555547220965, 2.139090971211456],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 450.857659874,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.136050489663708,
                            48.79528024627206,
                            2.142141851963426,
                            48.795715917344765,
                        ),
                        "coordinates": [
                            [2.136050489663708, 48.79528024627206],
                            [2.136078615729023, 48.795284586940234],
                            [2.136184386259406, 48.79530090881185],
                            [2.136923051747886, 48.79540922138856],
                            [2.137193773686322, 48.79544566723029],
                            [2.137540717011488, 48.7954831446176],
                            [2.137935303232737, 48.79551980530034],
                            [2.138672898157999, 48.79555706102029],
                            [2.139428190102225, 48.79559434337222],
                            [2.141261337567381, 48.79567663989319],
                            [2.142141851963426, 48.795715917344765],
                        ],
                    },
                },
                1211: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84784144335527, 2.3191589057024187],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 373.344685598,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.317005235737245,
                            48.846989106139524,
                            2.321257862893747,
                            48.84881637336959,
                        ),
                        "coordinates": [
                            [2.321257862893747, 48.84881637336959],
                            [2.320595987665104, 48.84847104850133],
                            [2.320056836250492, 48.84817439735414],
                            [2.319371640153863, 48.84789255010885],
                            [2.318473034828099, 48.84752910737848],
                            [2.317005235737245, 48.846989106139524],
                        ],
                    },
                },
                1212: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.046150180136536, 2.0981522761291633],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 446.377365123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.095195067225969,
                            49.04564873988319,
                            2.101108482966614,
                            49.04664576264113,
                        ),
                        "coordinates": [
                            [2.101108482966614, 49.04564873988319],
                            [2.099538274275683, 49.04593526764531],
                            [2.096377570034755, 49.04643086426444],
                            [2.095195067225969, 49.04664576264113],
                        ],
                    },
                },
                1213: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.81230510273162, 3.018014617606854],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3969.32199369,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.993109893419177,
                            48.80750444314894,
                            3.042938266046296,
                            48.81644247834819,
                        ),
                        "coordinates": [
                            [3.042938266046296, 48.81379848212747],
                            [3.042121736623088, 48.81402566644309],
                            [3.040134520287092, 48.81457033480368],
                            [3.038848846660223, 48.814932885511325],
                            [3.037517997304488, 48.81529870021223],
                            [3.036983149926324, 48.81544740237658],
                            [3.036149266509647, 48.815674023001115],
                            [3.035195187868966, 48.815940408448085],
                            [3.034555840731028, 48.81608233036785],
                            [3.03409836533646, 48.81615146640572],
                            [3.033603802272337, 48.8162336895156],
                            [3.032873875474482, 48.816329876820845],
                            [3.03229450164895, 48.81638315591415],
                            [3.031254803834969, 48.816433275268295],
                            [3.030481440442632, 48.81644247834819],
                            [3.029859095588981, 48.81642438750487],
                            [3.029147508365243, 48.816388530498955],
                            [3.028481386535548, 48.81632950098686],
                            [3.027760697889824, 48.81625304917499],
                            [3.027016873319617, 48.8161334472645],
                            [3.026301209629056, 48.815982194364445],
                            [3.025715055928007, 48.81584094616563],
                            [3.025312836935027, 48.81573161481586],
                            [3.024961828243268, 48.81563145562454],
                            [3.024375497514552, 48.81543032096307],
                            [3.02370902294493, 48.81518262535233],
                            [3.022188959029509, 48.814618435481684],
                            [3.020985668437348, 48.81417627447019],
                            [3.020387721286609, 48.81394846425004],
                            [3.019845651514395, 48.813742929557655],
                            [3.018705507240842, 48.81331552376905],
                            [3.017829956321435, 48.81299638352285],
                            [3.015818952293022, 48.81223468241593],
                            [3.015109306501715, 48.81197142548206],
                            [3.014332681127686, 48.81168324844338],
                            [3.013728136601833, 48.811459180713854],
                            [3.012943622694571, 48.81116899076084],
                            [3.012472841736781, 48.810993716457304],
                            [3.012048587207488, 48.81083525268262],
                            [3.011267298597183, 48.81053784648982],
                            [3.010484125032099, 48.810234770222074],
                            [3.009858827340953, 48.81000014038359],
                            [3.009332038999837, 48.809802281541934],
                            [3.008767817612011, 48.80959036791872],
                            [3.008269828674817, 48.80940337365922],
                            [3.007662290909256, 48.80918122122874],
                            [3.006777462474078, 48.808892347458155],
                            [3.006077660480574, 48.80869321207291],
                            [3.005191842813429, 48.80848592628662],
                            [3.004080890590235, 48.808243606338834],
                            [3.002986283382667, 48.808014442237535],
                            [3.001761552473069, 48.807779578905006],
                            [3.001234826746375, 48.80769391875484],
                            [3.000754668518439, 48.80762446875945],
                            [3.00030399721439, 48.80757494478489],
                            [2.999724151455256, 48.80753245907337],
                            [2.999368494150505, 48.807512023358065],
                            [2.999038445899633, 48.80750444314894],
                            [2.998613398490185, 48.80750691041667],
                            [2.998217326903673, 48.807521105166614],
                            [2.997720680679125, 48.8075572977796],
                            [2.997245802480583, 48.807605257859876],
                            [2.996756705984263, 48.80766757575118],
                            [2.996267953656574, 48.807756063028705],
                            [2.995876298519266, 48.807832089257516],
                            [2.995567524821274, 48.80791001584889],
                            [2.995262319211721, 48.80798554138714],
                            [2.99485200910139, 48.808106541390295],
                            [2.99423371223053, 48.80830076228515],
                            [2.993109893419177, 48.80865396493307],
                        ],
                    },
                },
                1214: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.780158328704076, 2.4346983885028064],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 2000.81066407,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.432070116592686,
                            48.771266038121055,
                            2.436086604214256,
                            48.78891489668918,
                        ),
                        "coordinates": [
                            [2.435306339706323, 48.771266038121055],
                            [2.435440225383158, 48.771483751195284],
                            [2.435599222770678, 48.77179292605963],
                            [2.435707728226891, 48.772052178641204],
                            [2.435801803257095, 48.77229478945914],
                            [2.435888725779706, 48.772561198963075],
                            [2.435964941428433, 48.77287282512524],
                            [2.436030391339495, 48.77320111586854],
                            [2.436045485215397, 48.773325107882],
                            [2.436070647682407, 48.77353180770079],
                            [2.436081968925176, 48.77379352470407],
                            [2.436086604214256, 48.774312214586466],
                            [2.436069378558162, 48.774700061127184],
                            [2.436034282355853, 48.77515216508829],
                            [2.435981075256809, 48.77554956048242],
                            [2.435934794066609, 48.775808948132415],
                            [2.435874186419337, 48.77610641735578],
                            [2.435742251869427, 48.77674181418208],
                            [2.435556595845548, 48.77752001822261],
                            [2.435435118980712, 48.77798647205676],
                            [2.435349417951659, 48.77834106731402],
                            [2.435281670358444, 48.77867185364237],
                            [2.435224660798823, 48.778971698871864],
                            [2.435203497645432, 48.77919299477181],
                            [2.435125864478978, 48.779987759728854],
                            [2.435072837405683, 48.7804827069834],
                            [2.435047950953678, 48.780642143702984],
                            [2.435019534129465, 48.78083727365759],
                            [2.434948213410398, 48.78118471805605],
                            [2.434866002252994, 48.7814869643202],
                            [2.434765819013104, 48.781805881325134],
                            [2.434536769171052, 48.782505602836856],
                            [2.434296855593278, 48.78317678079791],
                            [2.43390645793184, 48.7842287804001],
                            [2.433211275030803, 48.785944871156936],
                            [2.432913868180616, 48.786694614061545],
                            [2.432634422468911, 48.7874276843418],
                            [2.432222909326854, 48.78854485112556],
                            [2.432070116592686, 48.78891489668918],
                        ],
                    },
                },
                1215: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.758049042899664, 2.4346175166226756],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 2989.06693123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.433437421055713,
                            48.745230819408114,
                            2.438344239163614,
                            48.771266038121055,
                        ),
                        "coordinates": [
                            [2.438344239163614, 48.745230819408114],
                            [2.438273437857284, 48.745438709334884],
                            [2.438184096111448, 48.7457338260805],
                            [2.437969742303037, 48.74647874632876],
                            [2.43783754994237, 48.74693569602271],
                            [2.437733859271531, 48.74725461899908],
                            [2.437619329574165, 48.74755213737636],
                            [2.437508295033156, 48.747799685309374],
                            [2.437375710285186, 48.74806628850716],
                            [2.4371677731604, 48.74843526830044],
                            [2.436992015157528, 48.748704287466246],
                            [2.436823368444851, 48.748932852049585],
                            [2.43662955448261, 48.74917095568656],
                            [2.436371097049091, 48.74947097724524],
                            [2.435477185273351, 48.750480593926376],
                            [2.434870421722178, 48.751149711661746],
                            [2.434626308838914, 48.751435442046734],
                            [2.434403841699777, 48.751752084286196],
                            [2.434256798804391, 48.751999661119584],
                            [2.434131336835575, 48.752242460603284],
                            [2.434016731663686, 48.752518561377215],
                            [2.433952395286144, 48.75273989404596],
                            [2.433902488034662, 48.75298024865708],
                            [2.433874050444429, 48.75315872192501],
                            [2.433852837131601, 48.75335146642632],
                            [2.433846200429141, 48.75363937180893],
                            [2.433843154641313, 48.75392251459625],
                            [2.433851005477436, 48.75425799347498],
                            [2.433867417614227, 48.755292988377406],
                            [2.433871865888324, 48.75572840194772],
                            [2.433875961182599, 48.75598298628363],
                            [2.433876318366639, 48.756166194349106],
                            [2.433873216263952, 48.756420785841875],
                            [2.433817539681058, 48.75739635935004],
                            [2.433782745886303, 48.75800787740011],
                            [2.433713047511272, 48.759176187575164],
                            [2.433674716106457, 48.75982101953141],
                            [2.433619936619943, 48.76126056113242],
                            [2.433583295696, 48.76247957656717],
                            [2.433532294449451, 48.76407382361093],
                            [2.433527186465675, 48.764233480205604],
                            [2.433512045902057, 48.76470669175702],
                            [2.433457583756447, 48.76631516693117],
                            [2.433443893475024, 48.766679216121894],
                            [2.433437421055713, 48.76705277657283],
                            [2.43344875507995, 48.76732876915579],
                            [2.433470809000831, 48.76756430466045],
                            [2.433514528618688, 48.76783551112151],
                            [2.433547208387588, 48.76798300192939],
                            [2.433605313186639, 48.768247058669225],
                            [2.433692268519418, 48.768539642109744],
                            [2.433779131488626, 48.76878463877218],
                            [2.433880422467193, 48.769043900042725],
                            [2.433981629199955, 48.76926033248583],
                            [2.434100817640164, 48.76946723255786],
                            [2.434173058136915, 48.769595653939426],
                            [2.434266951982867, 48.76975261006521],
                            [2.434447454992141, 48.77002131901292],
                            [2.434761484095578, 48.77046360488249],
                            [2.435028593570148, 48.77083930919318],
                            [2.435158556251428, 48.77102954326885],
                            [2.435306339706323, 48.771266038121055],
                        ],
                    },
                },
                1216: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.86219530321953, 2.3413810722208965],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 1399.09860055,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.33418954196825,
                            48.85770881968848,
                            2.347944311105259,
                            48.86590673959416,
                        ),
                        "coordinates": [
                            [2.347944311105259, 48.85770881968848],
                            [2.347831876386782, 48.85782293353786],
                            [2.347726014118864, 48.857940038363814],
                            [2.347625155718968, 48.85806186227697],
                            [2.347531944702091, 48.85818443108332],
                            [2.347437848747705, 48.85831820268271],
                            [2.347346469314061, 48.858456606273926],
                            [2.347097285183795, 48.85884630863281],
                            [2.347014206381004, 48.85896857969926],
                            [2.346933978827634, 48.859079739503066],
                            [2.346833044719408, 48.85920956104746],
                            [2.346728262130653, 48.85933331246092],
                            [2.346617593252448, 48.85945339466409],
                            [2.346545687407072, 48.859525262064345],
                            [2.346499888633585, 48.85957103617144],
                            [2.346375497802309, 48.859695747691475],
                            [2.346049219702614, 48.86003596601749],
                            [2.345900452232309, 48.860187884897094],
                            [2.345763076772259, 48.86032151464481],
                            [2.345657235623554, 48.86041532441468],
                            [2.345495524421561, 48.86054495896539],
                            [2.345328818285076, 48.860672203373255],
                            [2.345157509427388, 48.86079675848282],
                            [2.34498200499546, 48.860918330618084],
                            [2.344802082381734, 48.861037062438555],
                            [2.344617538080548, 48.86115309490778],
                            [2.344428811665565, 48.861266157910705],
                            [2.34423633583737, 48.86137598669309],
                            [2.344039875932781, 48.86148270765898],
                            [2.343839224614094, 48.861586441964036],
                            [2.343634841488385, 48.861686953781565],
                            [2.343427190158573, 48.86178401540366],
                            [2.343290637083353, 48.86184226426355],
                            [2.343111000848176, 48.86191210111595],
                            [2.342935834470887, 48.86197668486619],
                            [2.34243180331855, 48.862158496776296],
                            [2.341513562991699, 48.86243177346527],
                            [2.339641041086562, 48.86299018323375],
                            [2.337930527531733, 48.863596078539935],
                            [2.336742144784989, 48.864118791867426],
                            [2.335776509165897, 48.86473980964383],
                            [2.334427485913044, 48.86576110282936],
                            [2.33418954196825, 48.86590673959416],
                        ],
                    },
                },
                1217: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.8953352880165, 2.8147646881016977],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2067.24866864,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.804054305016884,
                            48.890856796314026,
                            2.826405497304068,
                            48.89979105744454,
                        ),
                        "coordinates": [
                            [2.804079706711413, 48.89979105744454],
                            [2.804054305016884, 48.89956443924759],
                            [2.804062577592576, 48.89934450115387],
                            [2.804091549570532, 48.89912618142349],
                            [2.804169135495806, 48.89885311597776],
                            [2.804300915700609, 48.89856959751123],
                            [2.804471622737895, 48.898301263942464],
                            [2.804742259070606, 48.89793705696264],
                            [2.804949445258663, 48.89769925717761],
                            [2.805172480066623, 48.8974971908885],
                            [2.805385540496223, 48.89733437275999],
                            [2.805637363239929, 48.897169689065436],
                            [2.805850856197873, 48.897052894663474],
                            [2.80612883500719, 48.89692049187041],
                            [2.806322787328451, 48.89684220587551],
                            [2.806533411699653, 48.89676690426331],
                            [2.806756492796133, 48.896696984848674],
                            [2.807076608111277, 48.896613383977744],
                            [2.807361236362019, 48.89655573356456],
                            [2.807740812862895, 48.896504733214236],
                            [2.808094761984152, 48.896477703466275],
                            [2.808474793106409, 48.89647443228812],
                            [2.808849811812922, 48.89648822494376],
                            [2.80928444070577, 48.89651711243998],
                            [2.810171866160228, 48.89658162649932],
                            [2.810614236408484, 48.896608771414954],
                            [2.811033241448254, 48.89662578508918],
                            [2.811459956645007, 48.89663765020382],
                            [2.811917578789763, 48.89663745249066],
                            [2.812294943669697, 48.896625654113826],
                            [2.812723899330884, 48.896601707577425],
                            [2.813235357259316, 48.896553549787285],
                            [2.813671772070683, 48.89649888271962],
                            [2.814120950681514, 48.89642711407069],
                            [2.814600938125333, 48.896333055743234],
                            [2.815047217492239, 48.89622890644643],
                            [2.815472713445234, 48.89611461542557],
                            [2.815792356458137, 48.89601610904244],
                            [2.816137719844884, 48.895903854255025],
                            [2.816462334402258, 48.89578486964247],
                            [2.816781693607512, 48.89565738049281],
                            [2.817118952371249, 48.89550936000913],
                            [2.817489534621965, 48.895332219922324],
                            [2.81788311541216, 48.89512770412366],
                            [2.818477339341856, 48.894818356855936],
                            [2.819213049073952, 48.89443681191365],
                            [2.820383473888515, 48.89383010901804],
                            [2.822302390515508, 48.892834956838854],
                            [2.82441671260347, 48.89173835948076],
                            [2.824931151571501, 48.8914736409164],
                            [2.825242421599499, 48.891317183035234],
                            [2.825551271877132, 48.891177783122956],
                            [2.825844777912835, 48.891055492553235],
                            [2.826169337334402, 48.8909364802004],
                            [2.826405497304068, 48.890856796314026],
                        ],
                    },
                },
                1218: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [49.01330973476587, 2.1761501915558954],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3401.85573029,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.154663485640923,
                            49.00742329713069,
                            2.197619813968745,
                            49.01913673984224,
                        ),
                        "coordinates": [
                            [2.197619813968745, 49.00742329713069],
                            [2.197008091251297, 49.00762122621544],
                            [2.195541488379903, 49.008043884046316],
                            [2.193848750432538, 49.00850968595437],
                            [2.193439730674932, 49.00861862390083],
                            [2.191999067670692, 49.009011780942245],
                            [2.188342468293504, 49.0100239728252],
                            [2.187896449261309, 49.01014479582501],
                            [2.187193217458812, 49.01033362619896],
                            [2.184690434061876, 49.01100332858747],
                            [2.183093995563466, 49.01142947821652],
                            [2.182666827481433, 49.01154311184559],
                            [2.181816094022191, 49.01177275870757],
                            [2.180640878382492, 49.012089256590286],
                            [2.178049332489053, 49.01279432270234],
                            [2.178011018908898, 49.01280506074413],
                            [2.177708624539413, 49.01288647504226],
                            [2.177500636811216, 49.012943739858976],
                            [2.17674806297863, 49.01314682586018],
                            [2.175980425213717, 49.013356181143195],
                            [2.175078680235649, 49.013602211686965],
                            [2.174902164377811, 49.01364962398947],
                            [2.173447578949681, 49.01404773584815],
                            [2.173094537525855, 49.01414345457021],
                            [2.173043910225493, 49.01415597212351],
                            [2.172982332209368, 49.014172970655586],
                            [2.172861922373489, 49.01420337340517],
                            [2.172684032000837, 49.01425167940884],
                            [2.17239393191633, 49.014330399893325],
                            [2.172159933807473, 49.01439481122292],
                            [2.172124355370923, 49.01440465172236],
                            [2.169334150834148, 49.015161393541376],
                            [2.169280778493651, 49.015176602617416],
                            [2.168298240149801, 49.01544134684781],
                            [2.168121710485582, 49.015488749087595],
                            [2.16618532079457, 49.01601465458309],
                            [2.165480549707653, 49.01620514827598],
                            [2.163890874453162, 49.016629500666156],
                            [2.162296022835996, 49.01706274690875],
                            [2.161461213926096, 49.017287190064884],
                            [2.161117706484206, 49.01738018850346],
                            [2.157681202315227, 49.01830651546753],
                            [2.157593610267531, 49.018330658660545],
                            [2.156513748668304, 49.018628423148],
                            [2.154943888066075, 49.01906119071421],
                            [2.154663485640923, 49.01913673984224],
                        ],
                    },
                },
                1219: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [49.00300005384202, 2.074945885571376],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 2677.21544104,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.073186608046316,
                            48.99101254867934,
                            2.078757725897018,
                            49.014133684983044,
                        ),
                        "coordinates": [
                            [2.078306591409993, 49.014133684983044],
                            [2.078339757971262, 49.013905394065716],
                            [2.078470872757421, 49.013317515084445],
                            [2.078583574674959, 49.01293088722212],
                            [2.078663318480119, 49.01262127531286],
                            [2.078725692756072, 49.01231305239078],
                            [2.078757725897018, 49.01199619477375],
                            [2.078732025993187, 49.0115136049399],
                            [2.078666704338315, 49.01113799620632],
                            [2.078454918128412, 49.01054934200499],
                            [2.078209782345716, 49.01011479429198],
                            [2.077815372026369, 49.00959139744165],
                            [2.077402980702645, 49.009187877192076],
                            [2.076849673684159, 49.008758338824066],
                            [2.076222676868701, 49.00831292608526],
                            [2.075781639490159, 49.007996419607124],
                            [2.075451078094127, 49.007718707469216],
                            [2.075204955924964, 49.00747830678062],
                            [2.07499781579557, 49.00725369835747],
                            [2.074657427800449, 49.00678394888684],
                            [2.074485307217486, 49.006503742975994],
                            [2.074309604877165, 49.00608076712318],
                            [2.074162523075132, 49.00558076527068],
                            [2.074030747357509, 49.005059384276294],
                            [2.073716481743821, 49.00376096466016],
                            [2.073429580264889, 49.00241273144675],
                            [2.07325750151566, 49.00144869858747],
                            [2.073215749962943, 49.00113928519475],
                            [2.073192146383295, 49.000818019277744],
                            [2.073186608046316, 49.000499173307894],
                            [2.073199200594691, 49.000170851441],
                            [2.073237048850749, 48.999854485090616],
                            [2.073335872003388, 48.99895055781028],
                            [2.073460933092811, 48.99787299977956],
                            [2.073491870111239, 48.99749475389755],
                            [2.073490137244347, 48.99714022647409],
                            [2.07346699947166, 48.99673092480324],
                            [2.073422495840522, 48.996259710725255],
                            [2.073323246594915, 48.99520304972357],
                            [2.073289442036999, 48.99476041083592],
                            [2.073298849596716, 48.99435118328295],
                            [2.073329785666087, 48.993972937982306],
                            [2.073529193326251, 48.992510095715815],
                            [2.073694140143433, 48.99140645440052],
                            [2.073769886475506, 48.99101254867934],
                        ],
                    },
                },
                1220: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [49.05021880665001, 2.022354526331116],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1835.11393662,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.010999760003633,
                            49.047876203368986,
                            2.034294461852662,
                            49.05104855336923,
                        ),
                        "coordinates": [
                            [2.010999760003633, 49.047876203368986],
                            [2.012824844986796, 49.049102920262555],
                            [2.013873905514164, 49.049764963802374],
                            [2.014241856975978, 49.04996110765006],
                            [2.014736320939224, 49.05018615781923],
                            [2.015353789518761, 49.05042344822877],
                            [2.015816177845282, 49.05057226495576],
                            [2.016285947490587, 49.05069968562204],
                            [2.016810096450205, 49.05081536046382],
                            [2.017392288051122, 49.050912158187394],
                            [2.018101285744873, 49.050992651604204],
                            [2.018770695307558, 49.05103734023598],
                            [2.019382402802194, 49.05104855336923],
                            [2.020005166842821, 49.051028862615084],
                            [2.020533875061965, 49.05099939153168],
                            [2.021033680757431, 49.05096032163714],
                            [2.023460624314959, 49.0507147734925],
                            [2.032798582030029, 49.049788186849895],
                            [2.034294461852662, 49.049647005256354],
                        ],
                    },
                },
                1221: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.85271772860584, 2.3596112415142287],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2832.62444027,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347012687238757,
                            48.84413934985302,
                            2.373259976710645,
                            48.861822272798115,
                        ),
                        "coordinates": [
                            [2.373259976710645, 48.84413934985302],
                            [2.372461836166853, 48.8446213297083],
                            [2.371949288631041, 48.844943454292626],
                            [2.37148486699435, 48.84528015354964],
                            [2.370671617570643, 48.84585352628388],
                            [2.367969300349362, 48.84767451617495],
                            [2.366373660414324, 48.84879669155776],
                            [2.361663912287947, 48.85224582041532],
                            [2.361140847505953, 48.85262905923144],
                            [2.360841827743596, 48.852829662151564],
                            [2.360521344701473, 48.85303362739262],
                            [2.36002715159804, 48.85332578238206],
                            [2.358951186066298, 48.85385106726358],
                            [2.358347662850251, 48.85411428361651],
                            [2.357482039856472, 48.85447285471544],
                            [2.356656897995536, 48.85481173988781],
                            [2.355746527158751, 48.85513534994395],
                            [2.354787178237725, 48.855442261395396],
                            [2.353615835699875, 48.85578538552734],
                            [2.3525018319543, 48.85610920618555],
                            [2.351780423971029, 48.856343669006286],
                            [2.351165299418861, 48.85654974829082],
                            [2.35074298074319, 48.85672954658536],
                            [2.35041859858395, 48.85689721219578],
                            [2.350192508071292, 48.85702786190461],
                            [2.349484214156639, 48.857540921752864],
                            [2.349177502467835, 48.85784950927827],
                            [2.348890950526438, 48.85820535587663],
                            [2.34838853860216, 48.85901732244924],
                            [2.348387994662607, 48.85901820264864],
                            [2.347970423861637, 48.85971563273594],
                            [2.347663212781215, 48.86030109116217],
                            [2.347012687238757, 48.861822272798115],
                        ],
                    },
                },
                1222: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.86101518904687, 2.894403316424414],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 1713.82320342,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.883201728539714,
                            48.85955731687439,
                            2.905736964548534,
                            48.8632902390859,
                        ),
                        "coordinates": [
                            [2.883201728539714, 48.8632902390859],
                            [2.883533662603522, 48.863165911902094],
                            [2.883899275267243, 48.863049945032834],
                            [2.884326950384286, 48.86293879352313],
                            [2.884736763166585, 48.86284818345464],
                            [2.886693190199066, 48.86243135401624],
                            [2.895755649877526, 48.86049171630665],
                            [2.896356211756951, 48.860366035656874],
                            [2.896812579596415, 48.860283677421805],
                            [2.897184037706688, 48.86023241760761],
                            [2.897586594105394, 48.86018952803462],
                            [2.897953113485189, 48.86015874628669],
                            [2.898482273641998, 48.860116936450545],
                            [2.905736964548534, 48.85955731687439],
                        ],
                    },
                },
                1223: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.81107072470063, 1.6359811483903433],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 6438.15660307,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.602701692990599,
                            48.795680661252575,
                            1.669010161365564,
                            48.82942901532876,
                        ),
                        "coordinates": [
                            [1.602701692990599, 48.79602536780062],
                            [1.603236408008472, 48.79599968779957],
                            [1.603826127095842, 48.795978300038406],
                            [1.604511266455972, 48.795947630704326],
                            [1.605130979733526, 48.79592283220414],
                            [1.605746609968344, 48.7958980035499],
                            [1.606687775028809, 48.795859070009335],
                            [1.607003769575837, 48.795845805181926],
                            [1.60769429664843, 48.795818748794105],
                            [1.608691300917315, 48.795777457381384],
                            [1.609097244149182, 48.795756668166376],
                            [1.609398251726842, 48.79574420035714],
                            [1.609560324958897, 48.795738039162174],
                            [1.609787782080818, 48.79572869852583],
                            [1.610096968672011, 48.795715382320495],
                            [1.61053145302376, 48.795697466696495],
                            [1.610926361143088, 48.79568649244778],
                            [1.611281719315086, 48.795680661252575],
                            [1.611616568377337, 48.79568099343828],
                            [1.611917325860914, 48.795685604357196],
                            [1.612235699068487, 48.795695721685966],
                            [1.612596134830515, 48.795715099403985],
                            [1.612929282986005, 48.795738798980395],
                            [1.613107426670145, 48.79575072152044],
                            [1.613254292537207, 48.795760647344075],
                            [1.61355197547651, 48.79578951598316],
                            [1.613855011498673, 48.795824711940476],
                            [1.614171579974363, 48.795865390037804],
                            [1.614483988532269, 48.79591143589807],
                            [1.614785455417056, 48.79596100970799],
                            [1.61487913514537, 48.795977790136156],
                            [1.615092301769348, 48.79601511204463],
                            [1.615397646048974, 48.79607909796122],
                            [1.615735577351389, 48.79614868398936],
                            [1.616090968852056, 48.79623456702565],
                            [1.616383974679737, 48.79630476701647],
                            [1.616699831480257, 48.79639489490388],
                            [1.617022379307295, 48.79649315805075],
                            [1.617395053900527, 48.79660792420768],
                            [1.617778359092972, 48.79674074289106],
                            [1.618055954674448, 48.796841417441335],
                            [1.61835382603619, 48.796952111466],
                            [1.618630023766397, 48.79705547419264],
                            [1.618896475175063, 48.797174062904695],
                            [1.619184627333971, 48.797298182727786],
                            [1.619490112523963, 48.79744759286315],
                            [1.620027936925946, 48.79772166713097],
                            [1.620585601566154, 48.79803633403803],
                            [1.621049664254151, 48.798328825736746],
                            [1.621452778255632, 48.79860024950755],
                            [1.621862172992021, 48.79890858342306],
                            [1.622654067081801, 48.79959792059035],
                            [1.623977418153144, 48.80091559896419],
                            [1.624783673213797, 48.8017471032376],
                            [1.625785165228847, 48.80273180292078],
                            [1.626083123217934, 48.80303043347278],
                            [1.62688298894613, 48.80383760182552],
                            [1.627198388003273, 48.804155222753316],
                            [1.627312455759458, 48.804271044405496],
                            [1.62757819742035, 48.80453889308971],
                            [1.62814725603027, 48.80511349389317],
                            [1.628590295430443, 48.80555151245271],
                            [1.629217274900464, 48.80617143284072],
                            [1.630136364803175, 48.80702698059911],
                            [1.631334338473437, 48.808092887304],
                            [1.631510605067852, 48.80824056509661],
                            [1.631567121104171, 48.80828767909742],
                            [1.631786622225868, 48.80845900616437],
                            [1.631891626739228, 48.808543290706474],
                            [1.632020857289967, 48.8086475108403],
                            [1.632594533628995, 48.809095314216954],
                            [1.633037711829012, 48.80943259383599],
                            [1.633259983911212, 48.80960123672812],
                            [1.633425687366549, 48.809726363541785],
                            [1.633920155133423, 48.810096331501875],
                            [1.634414934951727, 48.810444715659074],
                            [1.634963495996341, 48.81084199105448],
                            [1.635355844643397, 48.81111689560507],
                            [1.635717035587376, 48.81138081658174],
                            [1.635849131873667, 48.81147605554681],
                            [1.635912476427781, 48.81152230972428],
                            [1.636555442014567, 48.81198580717627],
                            [1.637140444776068, 48.81240847692926],
                            [1.63761632275407, 48.81274863647501],
                            [1.637845521917745, 48.81291101834833],
                            [1.638553386474041, 48.8134099746252],
                            [1.639211341718301, 48.81387624739934],
                            [1.639836972328668, 48.81431803588154],
                            [1.641173002361624, 48.81527676435546],
                            [1.641361804220146, 48.81540831572849],
                            [1.641799940486337, 48.815724845709966],
                            [1.642471623554868, 48.81618758497156],
                            [1.642994780281967, 48.81656038494807],
                            [1.64358672481966, 48.816981264107845],
                            [1.64417460722227, 48.817401216108436],
                            [1.64473958865818, 48.81780393928613],
                            [1.645953204715318, 48.81866743972935],
                            [1.646535779913486, 48.81908015277366],
                            [1.647080634520988, 48.819463856636645],
                            [1.647482538831972, 48.81974687092492],
                            [1.648075946593855, 48.820165937140644],
                            [1.648665265711571, 48.82058587410759],
                            [1.650530477750688, 48.82190830519779],
                            [1.65057079768746, 48.82194721751852],
                            [1.65144638289829, 48.822548724212325],
                            [1.652009166739748, 48.8229217203294],
                            [1.652233483538641, 48.8230498692825],
                            [1.6527199658362, 48.82332707793472],
                            [1.653350806374975, 48.823627124538675],
                            [1.653952853301261, 48.823898331876386],
                            [1.654407855534273, 48.82408901072828],
                            [1.656463490380098, 48.82485401219692],
                            [1.657356654846587, 48.82517499412996],
                            [1.658970679761503, 48.82577004756353],
                            [1.660338379630538, 48.826253001490045],
                            [1.662297974402805, 48.82698225472081],
                            [1.664256278129541, 48.827710567158114],
                            [1.666215988004955, 48.82843975260579],
                            [1.667853355853103, 48.8290366146316],
                            [1.66810953854447, 48.82912984607092],
                            [1.668373919237159, 48.82922132701306],
                            [1.668707472003886, 48.82933479503642],
                            [1.669010161365564, 48.82942901532876],
                        ],
                    },
                },
                1224: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.51687499340416, 2.23513325840009],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 3074.56973634,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.21551781194949,
                            48.51424587530033,
                            2.254739702427517,
                            48.52040359106998,
                        ),
                        "coordinates": [
                            [2.254739702427517, 48.52040359106998],
                            [2.253948600552972, 48.520091843351565],
                            [2.252801841891321, 48.519662450163466],
                            [2.252051590599338, 48.519394522000965],
                            [2.251629374628166, 48.51925767636118],
                            [2.251267054343519, 48.51914931959484],
                            [2.250720970607259, 48.51900033982376],
                            [2.250060191933262, 48.51883931577484],
                            [2.249469553175208, 48.51871750271303],
                            [2.248887433793413, 48.518622240606],
                            [2.248436572884771, 48.51855172926467],
                            [2.248042776185105, 48.51849453535685],
                            [2.247320793480767, 48.518402947945546],
                            [2.246487484812948, 48.51831695583189],
                            [2.245639920529656, 48.5182233618472],
                            [2.24480665776147, 48.51811649960592],
                            [2.244198868564363, 48.518019296129],
                            [2.24365388402695, 48.51791834915383],
                            [2.242952019102254, 48.5177622802411],
                            [2.242387140999766, 48.51761769684068],
                            [2.241839410773581, 48.5174636445437],
                            [2.241271756019532, 48.517283024432956],
                            [2.240627126060506, 48.51705682706108],
                            [2.239891256754431, 48.516785039075856],
                            [2.239126856606684, 48.51651132480972],
                            [2.238579204233163, 48.51632881347305],
                            [2.238014399794335, 48.516161453483036],
                            [2.237446705383091, 48.51601494795487],
                            [2.236867566817216, 48.51588359860128],
                            [2.23627696803318, 48.51577499077615],
                            [2.235680630936562, 48.51568344041647],
                            [2.235104235707228, 48.51561086788457],
                            [2.234496406887427, 48.51555722596106],
                            [2.233885689634557, 48.51552064523988],
                            [2.233272076698193, 48.51550491664651],
                            [2.232652732490723, 48.515500556898886],
                            [2.232047595272153, 48.51552654634858],
                            [2.231433862998749, 48.51556769426499],
                            [2.230860042567898, 48.515629734673865],
                            [2.230343281037579, 48.515703204508405],
                            [2.229997802444797, 48.51576166248952],
                            [2.229678008559073, 48.51582014380694],
                            [2.229346777596866, 48.515888095107066],
                            [2.229015549287242, 48.515954148197906],
                            [2.228521553700985, 48.51605607435147],
                            [2.227973314486773, 48.516163634902945],
                            [2.227510748139381, 48.51624852154019],
                            [2.226956857686097, 48.516327626984484],
                            [2.226365899817577, 48.51638962873809],
                            [2.225780688243332, 48.51643267034802],
                            [2.225175533260959, 48.516460519372316],
                            [2.224570414594077, 48.516471299701806],
                            [2.223951072126575, 48.5164612036763],
                            [2.223343188676318, 48.51643215316723],
                            [2.222752483870909, 48.516380362349665],
                            [2.222190344503523, 48.51631911606749],
                            [2.221842244875324, 48.516269460548415],
                            [2.221428523742488, 48.51620836094774],
                            [2.220840792573186, 48.516107260885434],
                            [2.220261674222972, 48.515985308035205],
                            [2.219691143621475, 48.515853879896774],
                            [2.219117810661468, 48.51570158627572],
                            [2.218541681227835, 48.515526534347586],
                            [2.217811594096222, 48.51528305212368],
                            [2.21719851558085, 48.51504727308309],
                            [2.216679586698346, 48.51482865728964],
                            [2.216274748992143, 48.51464239723378],
                            [2.21598111969379, 48.514499867051285],
                            [2.215661879012976, 48.51432696845331],
                            [2.21551781194949, 48.51424587530033],
                        ],
                    },
                },
                1225: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.96175326093063, 2.9102059103633984],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 6094.34020908,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.873448188749959,
                            48.95726886600814,
                            2.950060382752808,
                            48.9644576375716,
                        ),
                        "coordinates": [
                            [2.873448188749959, 48.95726886600814],
                            [2.873685039539704, 48.95823220396531],
                            [2.873850690767723, 48.95875496514626],
                            [2.874021169950855, 48.95918245670696],
                            [2.874197809317763, 48.959577796696216],
                            [2.874383369342125, 48.95989600189286],
                            [2.874591905380254, 48.960233371886176],
                            [2.874855982129392, 48.96059403654777],
                            [2.875159087003569, 48.960954517230164],
                            [2.875386143116502, 48.96119971603272],
                            [2.875658941445611, 48.96146397162448],
                            [2.875967535429135, 48.961730199610315],
                            [2.876239944069584, 48.96195805140517],
                            [2.876643180738262, 48.96225381161295],
                            [2.877006883671701, 48.96250264554421],
                            [2.877350705972041, 48.96271730775391],
                            [2.877694321061737, 48.96291269813041],
                            [2.878080355737155, 48.96312073518226],
                            [2.878482465490084, 48.96331156331157],
                            [2.87886808531492, 48.96348105256796],
                            [2.879380868819429, 48.96367991879539],
                            [2.879792160668451, 48.963817162741236],
                            [2.880206566717466, 48.963941540338276],
                            [2.880653471478917, 48.96406362071875],
                            [2.8810447161623, 48.96415170086627],
                            [2.88153032251789, 48.964243613792966],
                            [2.882103714730816, 48.964332964634494],
                            [2.882722427633633, 48.96440282301731],
                            [2.883269240397062, 48.964440899488565],
                            [2.883799558745927, 48.9644576375716],
                            [2.884345946472418, 48.96445716490119],
                            [2.884905108818981, 48.96443521393392],
                            [2.885542037145706, 48.964387190309104],
                            [2.886214620869464, 48.96432828314591],
                            [2.89407699201699, 48.963589990487584],
                            [2.897848846566687, 48.96323105953925],
                            [2.902731745429968, 48.96277015624076],
                            [2.908306509712048, 48.96224349937728],
                            [2.912942305551196, 48.96180481702084],
                            [2.92248003116871, 48.960901968301194],
                            [2.928788459570303, 48.9602998856662],
                            [2.929883164349178, 48.960195711343765],
                            [2.930354198836383, 48.96015258242796],
                            [2.930818883122541, 48.96012233224885],
                            [2.931351805114436, 48.9600874433259],
                            [2.931842579293643, 48.96006347808079],
                            [2.932495946196341, 48.96003866456349],
                            [2.933064919267345, 48.96002713697594],
                            [2.933627464175898, 48.960022063241794],
                            [2.934212851520106, 48.96002329315496],
                            [2.934850319086824, 48.96002853033373],
                            [2.936587224937873, 48.960053705721165],
                            [2.941375029951941, 48.960116317983484],
                            [2.950060382752808, 48.960226490735955],
                        ],
                    },
                },
                1226: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.02829819019747, 2.098743182460937],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2638.64991952,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.090906063354292,
                            49.01834916361145,
                            2.10385269644926,
                            49.03998130935,
                        ),
                        "coordinates": [
                            [2.090906063354292, 49.01834916361145],
                            [2.091144308072323, 49.018564409763925],
                            [2.09122053522454, 49.0186329185302],
                            [2.091279070152425, 49.018685202224916],
                            [2.091615197276309, 49.01900696553482],
                            [2.092114719567505, 49.01946756597293],
                            [2.094352501318781, 49.02152538299336],
                            [2.09533537133959, 49.022421343284144],
                            [2.096228347382347, 49.02325145976882],
                            [2.0985454164078, 49.02538579820293],
                            [2.098719477388619, 49.02558849839749],
                            [2.099135570053817, 49.026079470408554],
                            [2.09915597037364, 49.026102893950906],
                            [2.099192680202592, 49.026147034200044],
                            [2.09921442601375, 49.02617495682095],
                            [2.099275578719204, 49.02625511954155],
                            [2.09934353862269, 49.026341591980604],
                            [2.09957568245288, 49.026696389079795],
                            [2.099878297436992, 49.027185324342724],
                            [2.100089530867916, 49.02762460939573],
                            [2.100270687800041, 49.02806293202759],
                            [2.100401544114964, 49.02843910073451],
                            [2.100596206114226, 49.029201191740526],
                            [2.101124406699995, 49.03143428909256],
                            [2.101608255889117, 49.03351261773517],
                            [2.101675269178231, 49.03380142337698],
                            [2.101694080434523, 49.03387250533291],
                            [2.101706082080894, 49.03393727769525],
                            [2.101714147456867, 49.03396697038454],
                            [2.101716860891602, 49.0339714724487],
                            [2.101726217570092, 49.03401735465715],
                            [2.101765167831181, 49.03416761432772],
                            [2.101785197638508, 49.03427017303603],
                            [2.101802559365983, 49.03435833847271],
                            [2.101826776225532, 49.034442920480515],
                            [2.101860385628148, 49.03456619017363],
                            [2.101902098215733, 49.03471105970538],
                            [2.101972101625191, 49.034946813731096],
                            [2.102034027434305, 49.03515557352568],
                            [2.102300012578942, 49.03588633279511],
                            [2.1024649416769, 49.03629584159403],
                            [2.102609366399447, 49.0367035107185],
                            [2.10320372786693, 49.03828565546363],
                            [2.103441514816164, 49.03891203731664],
                            [2.103611874653595, 49.03933414594337],
                            [2.10385269644926, 49.03998130935],
                        ],
                    },
                },
                1227: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.74892001950844, 2.299100045278641],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1345.50204169,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.296393158896152,
                            48.74337340202939,
                            2.300986855734952,
                            48.75494652553112,
                        ),
                        "coordinates": [
                            [2.296393158896152, 48.74337340202939],
                            [2.29649445505561, 48.743453726792715],
                            [2.296676536158772, 48.743607566928084],
                            [2.296898004846575, 48.743816276475634],
                            [2.297173841138499, 48.744067038114565],
                            [2.297307560522583, 48.744211272423556],
                            [2.297471356613433, 48.74439740702419],
                            [2.297641841733332, 48.74459683943821],
                            [2.297806889656583, 48.74481658414051],
                            [2.298089404115114, 48.74522405158383],
                            [2.298329772413089, 48.7456297054758],
                            [2.298530686604523, 48.74606502175447],
                            [2.298677258872666, 48.74644006769656],
                            [2.298742372466654, 48.74664602252095],
                            [2.298842709282879, 48.74702734803753],
                            [2.298902595338002, 48.74728400865554],
                            [2.298941642590665, 48.7474671261956],
                            [2.298997211111935, 48.747711746554664],
                            [2.299535296649005, 48.750086005914326],
                            [2.299870103396507, 48.75155912469546],
                            [2.299962292878813, 48.75194854060066],
                            [2.30012768977224, 48.75265452290687],
                            [2.300203662391967, 48.75290814218276],
                            [2.300544285889822, 48.75391723526393],
                            [2.300643397406436, 48.75415107773829],
                            [2.300703140849582, 48.75428508853481],
                            [2.300842991654108, 48.75460707222912],
                            [2.300986855734952, 48.75494652553112],
                        ],
                    },
                },
                1228: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.921614381160495, 2.374410385257585],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1880.72628955,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362665598830465,
                            48.9181138030661,
                            2.386388291064694,
                            48.92435387966092,
                        ),
                        "coordinates": [
                            [2.362665598830465, 48.9181138030661],
                            [2.363478143656108, 48.91855141330591],
                            [2.36405306968269, 48.918812641663706],
                            [2.36451170589102, 48.91899959963967],
                            [2.365139271643608, 48.9192362595873],
                            [2.365832607695872, 48.91949305336527],
                            [2.366612598408511, 48.91974506184772],
                            [2.36714514342469, 48.919891589139716],
                            [2.367702052962826, 48.92003153025176],
                            [2.369381165336558, 48.92044744485632],
                            [2.374833951750855, 48.921787697589636],
                            [2.379077229578892, 48.9228450042737],
                            [2.381294626002303, 48.92338188875586],
                            [2.381998846325951, 48.92353864835505],
                            [2.382645281011191, 48.923676390866945],
                            [2.383505430681238, 48.92384717430447],
                            [2.384730442788796, 48.92406508965816],
                            [2.386215731473625, 48.924325531484065],
                            [2.386388291064694, 48.92435387966092],
                        ],
                    },
                },
                1229: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [49.00058748839264, 2.2159551033513307],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3085.32946945,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.197619813968745,
                            48.99371348038584,
                            2.234276393996537,
                            49.00742329713069,
                        ),
                        "coordinates": [
                            [2.234276393996537, 48.99371348038584],
                            [2.232504861292808, 48.9943803276354],
                            [2.231359427180695, 48.994809666630914],
                            [2.230414903766395, 48.99517521281167],
                            [2.229683920708789, 48.995441016431265],
                            [2.228059050132284, 48.996046217987484],
                            [2.227121731667691, 48.99640222545707],
                            [2.226412418710857, 48.99666327110842],
                            [2.223423033436542, 48.997788159763694],
                            [2.222749859535978, 48.998042080573654],
                            [2.221005371270001, 48.99869702816867],
                            [2.219673320446388, 48.99919434307988],
                            [2.218975661356986, 48.99945531783884],
                            [2.217379205528473, 49.000060675939075],
                            [2.215785462942007, 49.00065882117623],
                            [2.214195783782723, 49.00125604913104],
                            [2.213191621323129, 49.00162906913297],
                            [2.210299417120758, 49.00271403690773],
                            [2.209001026064172, 49.003202701053084],
                            [2.208764333090145, 49.003290566148564],
                            [2.208537212324408, 49.00337664235786],
                            [2.208052885370861, 49.00355325664045],
                            [2.206133475048893, 49.00427013405321],
                            [2.203652642125176, 49.00519570211146],
                            [2.203086170973281, 49.005407272201836],
                            [2.200341329439513, 49.00642831184516],
                            [2.20001154742561, 49.00655471665025],
                            [2.199101295954952, 49.00689817438802],
                            [2.198359101214039, 49.00717090371677],
                            [2.197708619109245, 49.00739456289574],
                            [2.197619813968745, 49.00742329713069],
                        ],
                    },
                },
                1230: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.83270442467216, 1.9344990372911435],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 1464.5908263,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.924597779359982,
                            48.83191618431854,
                            1.944401758066846,
                            48.833512070590515,
                        ),
                        "coordinates": [
                            [1.924597779359982, 48.833512070590515],
                            [1.925238459634334, 48.833458627761495],
                            [1.925896862450586, 48.833403446487424],
                            [1.927956558438825, 48.833232787567816],
                            [1.93191636657706, 48.832911476124735],
                            [1.932407092523259, 48.83287005084331],
                            [1.932416627194093, 48.83287008468565],
                            [1.932592476169921, 48.832854520237966],
                            [1.933471677148463, 48.83278209207269],
                            [1.934503543595752, 48.83269670602836],
                            [1.936961186030132, 48.83249491362395],
                            [1.939469215665072, 48.83229234392198],
                            [1.940259684883654, 48.832241137452655],
                            [1.941362302020195, 48.83216312969583],
                            [1.941479517491518, 48.832154543372155],
                            [1.941636255472948, 48.8321433952598],
                            [1.94201242430609, 48.832116820436845],
                            [1.944401758066846, 48.83191618431854],
                        ],
                    },
                },
                1231: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.93251347378888, 2.4652205859443646],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1532.65028221,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.454766382765777,
                            48.93230541606912,
                            2.475674370833512,
                            48.93270621869947,
                        ),
                        "coordinates": [
                            [2.454766382765777, 48.93270621869947],
                            [2.45518364315076, 48.932700995781666],
                            [2.457598821452279, 48.93267475387125],
                            [2.459869971859382, 48.93263783496673],
                            [2.462118221556601, 48.93260520910067],
                            [2.463698639395359, 48.932580933909804],
                            [2.464275473393231, 48.93256638793979],
                            [2.466635518401334, 48.9324895754969],
                            [2.469417617732813, 48.932398319719525],
                            [2.471060166345491, 48.93235468930533],
                            [2.47238270795745, 48.932341542495124],
                            [2.475674370833512, 48.93230541606912],
                        ],
                    },
                },
                1232: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.02034400368261, 2.68985283486818],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3061.38658081,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.680252455973217,
                            49.00811401774285,
                            2.69945308646072,
                            49.0325740895669,
                        ),
                        "coordinates": [
                            [2.680252455973217, 49.00811401774285],
                            [2.680413408081984, 49.00831904007297],
                            [2.682980792887934, 49.01158912468828],
                            [2.69531301874826, 49.02730018886574],
                            [2.699074856685854, 49.03209228931005],
                            [2.69945308646072, 49.0325740895669],
                        ],
                    },
                },
                1233: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.11239507600253, 1.9608504878270299],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 3162.90993663,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.949332680280041,
                            49.099650121708414,
                            1.970535722321773,
                            49.12345185404933,
                        ),
                        "coordinates": [
                            [1.970535722321773, 49.099650121708414],
                            [1.970390535247909, 49.09995375145234],
                            [1.969858965222135, 49.10108694738046],
                            [1.969661412761697, 49.101500885080576],
                            [1.969281559520533, 49.10230272788293],
                            [1.968869878219135, 49.103146734184264],
                            [1.96839652011748, 49.10417849139565],
                            [1.967375339221423, 49.10630111277325],
                            [1.966935505568179, 49.10723764776223],
                            [1.966332856188451, 49.10851268478888],
                            [1.966071447897214, 49.10903162589225],
                            [1.965785432617782, 49.10954329242144],
                            [1.965461199360876, 49.11003594968727],
                            [1.965138741201041, 49.110473755700504],
                            [1.964705881556704, 49.1110191157457],
                            [1.96427902592455, 49.1114934516386],
                            [1.964013999370876, 49.111760576782125],
                            [1.963845619232703, 49.11192729590076],
                            [1.963643966339815, 49.11214065818842],
                            [1.963119947402951, 49.11260479189255],
                            [1.962636147718336, 49.11299710086697],
                            [1.962169039027187, 49.11335528942647],
                            [1.961406058772328, 49.113888767077846],
                            [1.96125464680586, 49.113983595496286],
                            [1.960980704767987, 49.11415805871265],
                            [1.960388938366326, 49.11451223462818],
                            [1.960002336804692, 49.114728592018835],
                            [1.957997082069814, 49.11573115850887],
                            [1.955729242071239, 49.11688667767492],
                            [1.954701574036264, 49.117406717971804],
                            [1.954053712273795, 49.11775753250874],
                            [1.953718710005357, 49.11793301524582],
                            [1.953400362455397, 49.11811050234628],
                            [1.95305075558635, 49.11831886586386],
                            [1.95281800842862, 49.11847456207997],
                            [1.95232606584323, 49.11883892353868],
                            [1.952080612599014, 49.11904223777728],
                            [1.951858483213578, 49.11924113384537],
                            [1.95141257556591, 49.11967398990842],
                            [1.951174830352074, 49.1199420768664],
                            [1.951123668121318, 49.12000215708756],
                            [1.951058643560165, 49.120082873909645],
                            [1.950853748851131, 49.120354667965465],
                            [1.950785912632721, 49.12044436805002],
                            [1.950754021583975, 49.12049282257167],
                            [1.950590338164125, 49.12075036572137],
                            [1.950520885542191, 49.120871535289616],
                            [1.950426433764886, 49.121035785627406],
                            [1.950263545596749, 49.12136617380972],
                            [1.950170168131946, 49.12156819773915],
                            [1.950078178849535, 49.12176752895752],
                            [1.949769923265884, 49.12246433371333],
                            [1.949332680280041, 49.12345185404933],
                        ],
                    },
                },
                1234: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.74657775229024, 2.2243940870104537],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1712.81148115,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.215860857351649,
                            48.74018152105127,
                            2.230961125063006,
                            48.751023275119756,
                        ),
                        "coordinates": [
                            [2.215860857351649, 48.751023275119756],
                            [2.216402248560275, 48.750780173208625],
                            [2.217980125073538, 48.75006061337667],
                            [2.218118985524632, 48.749997809315595],
                            [2.218995689410336, 48.74960843478377],
                            [2.219758055068794, 48.749258504004665],
                            [2.220043940273481, 48.74912660465951],
                            [2.220626584775005, 48.74886371316532],
                            [2.221063566104835, 48.748665418788136],
                            [2.223321959610476, 48.74762813211571],
                            [2.225376013529548, 48.74671200282293],
                            [2.226267659665766, 48.746277623305524],
                            [2.226881707520914, 48.74592660266426],
                            [2.227102294945866, 48.745790125055635],
                            [2.227343334682708, 48.74562848859509],
                            [2.227569399736954, 48.74547313097266],
                            [2.227745087109964, 48.74534740153055],
                            [2.227934420668569, 48.74519920270087],
                            [2.228396181947704, 48.74483363897137],
                            [2.228806262351471, 48.74446892324872],
                            [2.229040656326748, 48.744230838090324],
                            [2.229230612579832, 48.74401993036308],
                            [2.229362350347043, 48.74386333868691],
                            [2.229640486712221, 48.743514682361436],
                            [2.229779598120949, 48.74331967081882],
                            [2.229880556496796, 48.74316239332066],
                            [2.23004289796115, 48.7429125476522],
                            [2.230229415721035, 48.74259773622583],
                            [2.230408768999338, 48.74222584475121],
                            [2.230601520702954, 48.74174041653679],
                            [2.230741137079111, 48.74130439882057],
                            [2.230834485527692, 48.740885424204855],
                            [2.23090742321191, 48.74047362506254],
                            [2.230961125063006, 48.74018152105127],
                        ],
                    },
                },
                1235: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.79738009994493, 2.1538223326653543],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 2695.90231345,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.136050489663708,
                            48.79528024627206,
                            2.171389812756379,
                            48.80071846386355,
                        ),
                        "coordinates": [
                            [2.136050489663708, 48.79528024627206],
                            [2.136078615729023, 48.795284586940234],
                            [2.136184386259406, 48.79530090881185],
                            [2.136923051747886, 48.79540922138856],
                            [2.137193773686322, 48.79544566723029],
                            [2.137540717011488, 48.7954831446176],
                            [2.137935303232737, 48.79551980530034],
                            [2.138672898157999, 48.79555706102029],
                            [2.139428190102225, 48.79559434337222],
                            [2.141261337567381, 48.79567663989319],
                            [2.142141851963426, 48.795715917344765],
                            [2.142706607881934, 48.79574745613372],
                            [2.143856757254184, 48.79579486437915],
                            [2.147234244824272, 48.795959949065534],
                            [2.148995074205409, 48.79602948652837],
                            [2.150017745902113, 48.796064478878215],
                            [2.150442631394686, 48.79608658921006],
                            [2.150781082583517, 48.79610855609176],
                            [2.151285101512348, 48.7961569644232],
                            [2.151641490132594, 48.796197992654015],
                            [2.152030230622056, 48.79625572855427],
                            [2.152480159919246, 48.796323079295],
                            [2.152976821918897, 48.79641429648562],
                            [2.154495584415558, 48.796699879271635],
                            [2.155085753590148, 48.7968293061806],
                            [2.155636272857649, 48.79696818445126],
                            [2.155923219353944, 48.797048173958764],
                            [2.15683568548617, 48.797310081377546],
                            [2.157683680908086, 48.79753481665686],
                            [2.158322075302499, 48.79769604510322],
                            [2.15939704124788, 48.797973103336034],
                            [2.15992599538207, 48.79810716886839],
                            [2.160246219863137, 48.79819570134629],
                            [2.161170405599215, 48.7984774257692],
                            [2.161958736431169, 48.79873738058273],
                            [2.162850799732983, 48.799041995934324],
                            [2.163084630812713, 48.79912087097465],
                            [2.163649432820911, 48.79930969882626],
                            [2.164192683305267, 48.7994818365617],
                            [2.164692812178737, 48.79962773303816],
                            [2.165730297934967, 48.79991052985321],
                            [2.166345438479331, 48.80006859693602],
                            [2.167049172095505, 48.80023603764411],
                            [2.167687736234038, 48.80036640154266],
                            [2.168447606155488, 48.80048769712934],
                            [2.169202898781894, 48.8005843309325],
                            [2.169697168739786, 48.80062819510285],
                            [2.170326695902241, 48.80067533554842],
                            [2.170830357527754, 48.800700720559675],
                            [2.171389812756379, 48.80071846386355],
                        ],
                    },
                },
                1236: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [49.22851149897188, 2.4534808497047265],
                        "indice_lig": "D",
                        "idf": 0,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 9276.91081032,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.442510307190429,
                            49.1873335365493,
                            2.468914115351039,
                            49.26394414450533,
                        ),
                        "coordinates": [
                            [2.459520081112193, 49.1873335365493],
                            [2.457393035027741, 49.202123786737765],
                            [2.456554549866675, 49.20730086553362],
                            [2.455836361280597, 49.20931001739014],
                            [2.44903116013877, 49.22100249636138],
                            [2.44418514990101, 49.229339952598174],
                            [2.442510307190429, 49.233630459804836],
                            [2.442515288283561, 49.23595874790341],
                            [2.44364447306937, 49.23889870640681],
                            [2.450962253011323, 49.24710198287682],
                            [2.458843796152947, 49.25518165120713],
                            [2.468914115351039, 49.26394414450533],
                        ],
                    },
                },
                1237: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.986643147363, 1.7091422868963677],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1107.77054667,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.703016134167223,
                            48.983654507541004,
                            1.715210986447546,
                            48.989502508030505,
                        ),
                        "coordinates": [
                            [1.715210986447546, 48.983654507541004],
                            [1.714876713955381, 48.983788316553415],
                            [1.713600965108449, 48.98433101806053],
                            [1.712641222925728, 48.984754079445864],
                            [1.712284705578705, 48.98493058933371],
                            [1.711411070835274, 48.98540407886332],
                            [1.708445222531689, 48.9871303023471],
                            [1.707197842322636, 48.987799197118015],
                            [1.706378210456435, 48.98818807925704],
                            [1.705757817330407, 48.98845115279417],
                            [1.704968622676812, 48.98871963626297],
                            [1.70427599037051, 48.9889759579842],
                            [1.703016134167223, 48.989502508030505],
                        ],
                    },
                },
                1238: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.92879071327043, 2.1710667342244236],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 2834.83343407,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.157086496469818,
                            48.920379373924355,
                            2.185353376302864,
                            48.93773606341459,
                        ),
                        "coordinates": [
                            [2.157086496469818, 48.93773606341459],
                            [2.159197405123777, 48.93641370175961],
                            [2.161018108093818, 48.93526729322632],
                            [2.163222511688236, 48.93384305627839],
                            [2.165271328905886, 48.93246851051073],
                            [2.167844735351957, 48.93077825372754],
                            [2.168677232891343, 48.93021081769022],
                            [2.169625501214284, 48.929574546127455],
                            [2.172737711964865, 48.92756137399833],
                            [2.175144080165984, 48.926003956090945],
                            [2.177159517778266, 48.924700530967506],
                            [2.177716684610704, 48.92435392458564],
                            [2.178190624459705, 48.924061924895064],
                            [2.178769411868191, 48.9237248614286],
                            [2.179221561827801, 48.923468515339664],
                            [2.179691766691154, 48.92320981530839],
                            [2.180295726453799, 48.92289895093932],
                            [2.181319146329174, 48.92238403128845],
                            [2.182027886422397, 48.922042369149914],
                            [2.183726181297828, 48.92118856022069],
                            [2.184525333215453, 48.92078752097505],
                            [2.185353376302864, 48.920379373924355],
                        ],
                    },
                },
                1239: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.27029130734809, 1.8448977258575994],
                        "indice_lig": "J",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4855.39474203,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.81808238249243,
                            49.26132229816068,
                            1.872589469227938,
                            49.282589735816124,
                        ),
                        "coordinates": [
                            [1.872589469227938, 49.26132229816068],
                            [1.866591683846971, 49.261849809993684],
                            [1.859983755434342, 49.26264977743305],
                            [1.854355912639473, 49.26372920672908],
                            [1.85125017105705, 49.26537048341902],
                            [1.848977757729374, 49.26793429560031],
                            [1.847123713821226, 49.27077556950726],
                            [1.845004135512743, 49.272053241265894],
                            [1.841338501949477, 49.273416135304615],
                            [1.835990875334875, 49.27440397229955],
                            [1.832331404558238, 49.275123251309225],
                            [1.830217868878203, 49.27575732272755],
                            [1.826688213122693, 49.27748798496614],
                            [1.823295908810192, 49.279494877556864],
                            [1.81808238249243, 49.282589735816124],
                        ],
                    },
                },
                1240: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.245062282617575, 1.892803192248379],
                        "indice_lig": "J",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 5503.80014461,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.872589469227938,
                            49.22080705063383,
                            1.905299061887723,
                            49.26132229816068,
                        ),
                        "coordinates": [
                            [1.905299061887723, 49.22080705063383],
                            [1.902824430639971, 49.229732597387596],
                            [1.90093511435295, 49.23707808573898],
                            [1.899356973694322, 49.24093222356381],
                            [1.896946992124124, 49.243588355511136],
                            [1.891999131714059, 49.247429447140576],
                            [1.889290966470394, 49.25192242305406],
                            [1.887146460201944, 49.256141817862755],
                            [1.884877179450907, 49.25861443325063],
                            [1.88233784436496, 49.25989113652876],
                            [1.878537140933148, 49.260887040007006],
                            [1.872589469227938, 49.26132229816068],
                        ],
                    },
                },
                1241: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.283024055123256, 1.8012090159001461],
                        "indice_lig": "J",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2608.65752953,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.785066223503951,
                            49.28165768310037,
                            1.81808238249243,
                            49.28526352316656,
                        ),
                        "coordinates": [
                            [1.81808238249243, 49.282589735816124],
                            [1.814403196674858, 49.28349881772344],
                            [1.810184719046329, 49.283847225439146],
                            [1.806111616230063, 49.283736608109926],
                            [1.801062130533726, 49.28297794550104],
                            [1.79629878072309, 49.281760840628095],
                            [1.793911620722456, 49.28165768310037],
                            [1.790536015453303, 49.28200932318175],
                            [1.787713073511066, 49.283190683227424],
                            [1.785066223503951, 49.28526352316656],
                        ],
                    },
                },
                1242: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.963561910434706, 1.812005177604735],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 429.428439479,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.809094508773784,
                            48.96334411275807,
                            1.814911934161123,
                            48.963825577806084,
                        ),
                        "coordinates": [
                            [1.809094508773784, 48.96334411275807],
                            [1.809279551877828, 48.963355057024316],
                            [1.811029724209674, 48.96347807079743],
                            [1.812083086767916, 48.96355179040191],
                            [1.813387699003068, 48.963666453558346],
                            [1.814911934161123, 48.963825577806084],
                        ],
                    },
                },
                1243: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.848899282747254, 2.3565464425920335],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1938.42448243,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.346034985851638,
                            48.84252802768357,
                            2.36543338335276,
                            48.85333579289227,
                        ),
                        "coordinates": [
                            [2.36543338335276, 48.84252802768357],
                            [2.365257638312982, 48.84274779946375],
                            [2.365191085578711, 48.84291701365898],
                            [2.36516040949979, 48.84306929885185],
                            [2.365135320560115, 48.843207988351686],
                            [2.365128069572211, 48.84346430813881],
                            [2.365119077625744, 48.84363222139181],
                            [2.365101006061017, 48.8438091312994],
                            [2.365055681449269, 48.843992045460006],
                            [2.36501773798524, 48.844103029263515],
                            [2.364955870120526, 48.84422594646666],
                            [2.364869624166622, 48.844345903919084],
                            [2.364778135800636, 48.8444511082444],
                            [2.364519391182411, 48.84468228603924],
                            [2.364252447020815, 48.844873896412544],
                            [2.364146210881654, 48.84494676361882],
                            [2.363542832004758, 48.845338991767846],
                            [2.362916295125543, 48.84575999976151],
                            [2.361407116197089, 48.84677921723564],
                            [2.360976691386705, 48.84707337352038],
                            [2.360286088671625, 48.84753484784806],
                            [2.359359104998217, 48.84820066813228],
                            [2.358969535110866, 48.84845454124818],
                            [2.358718365985054, 48.84862717227726],
                            [2.358549210576133, 48.848742259156396],
                            [2.358339045702914, 48.84888104155426],
                            [2.358169880359749, 48.84897920732825],
                            [2.357985339457181, 48.8490909129088],
                            [2.357816170314294, 48.849182310492274],
                            [2.357657248981885, 48.849260170874665],
                            [2.357452188110405, 48.84935157579254],
                            [2.357026667173158, 48.849510698198664],
                            [2.356637942292148, 48.84962906205921],
                            [2.355019319437158, 48.850133829471524],
                            [2.353628202676638, 48.8505612022938],
                            [2.351824215406448, 48.851134297541606],
                            [2.351395015959603, 48.85128003706921],
                            [2.350799582054356, 48.85148065122805],
                            [2.3489928222575, 48.85212834138162],
                            [2.348618165855216, 48.85226643354489],
                            [2.348295139337003, 48.85238828909806],
                            [2.347961862261651, 48.85253044930869],
                            [2.347300436571243, 48.85284522096403],
                            [2.346828715662574, 48.85306183663058],
                            [2.34646978972057, 48.85320399472642],
                            [2.346168163020426, 48.853301271398095],
                            [2.346034985851638, 48.85333579289227],
                        ],
                    },
                },
                1244: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.74207585643256, 2.331916074868938],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3148.30843408,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.312711013515798,
                            48.738738654836844,
                            2.351633198171911,
                            48.74794571395915,
                        ),
                        "coordinates": [
                            [2.312711013515798, 48.747941901886946],
                            [2.312954547887192, 48.74794571395915],
                            [2.313294514565373, 48.74793589239383],
                            [2.313644005760375, 48.74791707803183],
                            [2.314200214846999, 48.74784974342829],
                            [2.314677554927342, 48.747774297536985],
                            [2.315022986980907, 48.747705119517796],
                            [2.315323428140145, 48.74762957351263],
                            [2.315681759063343, 48.747527892488726],
                            [2.315998109487221, 48.747429223182934],
                            [2.316222519001663, 48.747342034088646],
                            [2.316755662215582, 48.747121806058445],
                            [2.318526226281677, 48.746315382799565],
                            [2.319932703806598, 48.745695168838616],
                            [2.321232167678898, 48.7451102517737],
                            [2.322407582797582, 48.744577435373934],
                            [2.323420980982226, 48.744139884726955],
                            [2.324007099304466, 48.74387646405618],
                            [2.325309863984821, 48.74329477148518],
                            [2.325770855123277, 48.7430888828714],
                            [2.327099412766535, 48.74251076922499],
                            [2.327969684712783, 48.74215832374952],
                            [2.328819541864001, 48.74184363902379],
                            [2.329364803418165, 48.74165752572969],
                            [2.329891023066446, 48.741484898162824],
                            [2.331287456413227, 48.74105242209054],
                            [2.333128480757714, 48.740493145702104],
                            [2.334744798588848, 48.73999948246041],
                            [2.335783523924499, 48.73968020127323],
                            [2.336798169287619, 48.73936371305131],
                            [2.337148530683693, 48.739251792698546],
                            [2.33758020725802, 48.73911537462024],
                            [2.337992694666737, 48.73899799057319],
                            [2.338385997901208, 48.7389155016141],
                            [2.338894412684503, 48.738836181725766],
                            [2.339426807638118, 48.73877906566978],
                            [2.339986430072071, 48.73874226605257],
                            [2.340420142293865, 48.738738654836844],
                            [2.340845698587959, 48.738752129655026],
                            [2.341377306552279, 48.73879707146058],
                            [2.341900758980999, 48.73885550168947],
                            [2.34291231973197, 48.73898224707868],
                            [2.342924556277525, 48.738984044962976],
                            [2.343560862731155, 48.73906134592529],
                            [2.345544166923985, 48.739308462626816],
                            [2.346450102220287, 48.73942353922805],
                            [2.347853266372745, 48.73959517052126],
                            [2.348251647444905, 48.73964459031302],
                            [2.349091922822984, 48.73975421272648],
                            [2.349949881828628, 48.739882711273985],
                            [2.350689557679258, 48.74001121783873],
                            [2.350941103460682, 48.740060646587224],
                            [2.351203528283975, 48.74011187164995],
                            [2.351633198171911, 48.74019544820276],
                        ],
                    },
                },
                1245: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.749454187881554, 2.3888211902596206],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2931.84432367,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.373111940704935,
                            48.74187870567889,
                            2.40290860736794,
                            48.753024053396466,
                        ),
                        "coordinates": [
                            [2.373111940704935, 48.74834968236464],
                            [2.375038314740253, 48.7491591776172],
                            [2.376449188498006, 48.74971704252789],
                            [2.377442593546729, 48.75012910826065],
                            [2.379664684921162, 48.75100384351047],
                            [2.381019671355158, 48.75155637531202],
                            [2.381993755078001, 48.75195346947338],
                            [2.382601886806677, 48.75220142434109],
                            [2.383398470065671, 48.752490282214346],
                            [2.384090155503829, 48.75269091714027],
                            [2.384649229971608, 48.75281748016059],
                            [2.385345647521766, 48.75292599532882],
                            [2.385964506247302, 48.75299047714941],
                            [2.386471808951518, 48.75301723437296],
                            [2.386901468057297, 48.753024053396466],
                            [2.387285085274832, 48.753016134923854],
                            [2.387702427305103, 48.752995492117215],
                            [2.388215469965258, 48.75295465938656],
                            [2.388759177761242, 48.75288851315514],
                            [2.389254438995922, 48.75280315129084],
                            [2.389771510923235, 48.752688349848135],
                            [2.390208585449726, 48.752573993937595],
                            [2.390706165210284, 48.75241548721488],
                            [2.391092238848415, 48.75226962070701],
                            [2.391623041594178, 48.75203544046033],
                            [2.391971692368281, 48.751866323511074],
                            [2.392297353788927, 48.751680020034726],
                            [2.392613732305581, 48.75148997896813],
                            [2.392914004950804, 48.75127587542633],
                            [2.393148386563563, 48.751098214001836],
                            [2.3933973598713, 48.75088870180531],
                            [2.393655008221016, 48.75066297588677],
                            [2.39390846286162, 48.75041728499207],
                            [2.394147003440079, 48.750145837266736],
                            [2.395544409175165, 48.74849945567564],
                            [2.396183265847584, 48.74773766689982],
                            [2.396737943950552, 48.74706668852121],
                            [2.397305625310963, 48.74642158935819],
                            [2.39765739209652, 48.74607120880517],
                            [2.397850268442019, 48.74589574763405],
                            [2.398208872973871, 48.74558620449429],
                            [2.399210014732709, 48.74477091897648],
                            [2.400217958361645, 48.74398529614095],
                            [2.400821071882167, 48.74351193975223],
                            [2.400952830283561, 48.743406650891515],
                            [2.401452686788605, 48.743005291899664],
                            [2.401680893640317, 48.742833400289314],
                            [2.401933544699539, 48.74263901253194],
                            [2.40290860736794, 48.74187870567889],
                        ],
                    },
                },
                1246: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.81221533380615, 2.4285449456670642],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 1096.90712971,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.422376142845623,
                            48.80914436183541,
                            2.434509895923941,
                            48.814803007000464,
                        ),
                        "coordinates": [
                            [2.434509895923941, 48.80914436183541],
                            [2.433827885265386, 48.809508195907384],
                            [2.432189821885798, 48.810382017970944],
                            [2.42664390777217, 48.81336752861133],
                            [2.426529517269106, 48.81342721951382],
                            [2.426335872904105, 48.813520818892385],
                            [2.426135933851744, 48.81360845633376],
                            [2.425930122991848, 48.81368994586777],
                            [2.425718869824613, 48.8137651195456],
                            [2.425513138070821, 48.81383065914801],
                            [2.424980141061789, 48.81398200943657],
                            [2.424409090399511, 48.814158542932134],
                            [2.422376142845623, 48.814803007000464],
                        ],
                    },
                },
                1247: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.92688448806625, 2.310889021082025],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1405.03200914,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307943234074898,
                            48.92087280435657,
                            2.313835382457718,
                            48.93289616644866,
                        ),
                        "coordinates": [
                            [2.313835382457718, 48.92087280435657],
                            [2.312920716694121, 48.922753897165464],
                            [2.312118859006341, 48.92438591480862],
                            [2.311338806360375, 48.92597656560873],
                            [2.31055733947707, 48.92756631083003],
                            [2.310135172037232, 48.928405238887535],
                            [2.30957499500258, 48.92951751200181],
                            [2.309211532629846, 48.93027012032423],
                            [2.308884935299763, 48.930976872436],
                            [2.308710017569288, 48.931354525770544],
                            [2.308588406511641, 48.93159640155675],
                            [2.307943234074898, 48.93289616644866],
                        ],
                    },
                },
                1248: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.85059606931942, 2.380086287321508],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 600.784020846,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.376118773328578,
                            48.85017786279967,
                            2.384092210055667,
                            48.85127112726454,
                        ),
                        "coordinates": [
                            [2.384092210055667, 48.85017786279967],
                            [2.383186318613051, 48.850263649469504],
                            [2.382606997308234, 48.850311088250635],
                            [2.38215388037331, 48.85034819130073],
                            [2.381913484029662, 48.850378472015116],
                            [2.381643177183887, 48.85040555785355],
                            [2.381371443770908, 48.8504254813491],
                            [2.381098720301239, 48.850438215970456],
                            [2.38099397553596, 48.850441185185765],
                            [2.380960212262458, 48.85044090348054],
                            [2.380700943809702, 48.850442807544226],
                            [2.380442028413532, 48.85045192209259],
                            [2.380183926746136, 48.85046823332632],
                            [2.379927096980201, 48.850491708550685],
                            [2.37967199056322, 48.850522307844855],
                            [2.379419068666743, 48.85055997605323],
                            [2.379184021099011, 48.8506017116162],
                            [2.378291870802432, 48.85078711439231],
                            [2.376118773328578, 48.85127112726454],
                        ],
                    },
                },
                1249: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.86280236752063, 2.3074496200397405],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 948.564860772,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.300989969386769,
                            48.86266245169434,
                            2.313911078550822,
                            48.8629018908629,
                        ),
                        "coordinates": [
                            [2.313911078550822, 48.8629018908629],
                            [2.313908906380806, 48.86290184423484],
                            [2.313451252950004, 48.86289193046037],
                            [2.310728004457645, 48.86286527076938],
                            [2.310426784793952, 48.862862504872936],
                            [2.309152400773083, 48.86283702781332],
                            [2.306866373246121, 48.862788646784374],
                            [2.305428753405039, 48.86275873910871],
                            [2.303633707360317, 48.862740251256064],
                            [2.302454726223663, 48.862732712531155],
                            [2.302041747129463, 48.86272179776361],
                            [2.301770518482009, 48.862714520943285],
                            [2.301616503103, 48.862710877448414],
                            [2.301474759354554, 48.862700043122395],
                            [2.301309846776587, 48.86268740237203],
                            [2.301180370036378, 48.86267836966447],
                            [2.300989969386769, 48.86266245169434],
                        ],
                    },
                },
                1250: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.85503716906271, 2.2772881755497036],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 451.794529677,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.27516715468514,
                            48.85364805716894,
                            2.279487064962566,
                            48.8565315515406,
                        ),
                        "coordinates": [
                            [2.279487064962566, 48.85364805716894],
                            [2.278645134797464, 48.85415838819558],
                            [2.278597403766687, 48.85418804014216],
                            [2.278437847581405, 48.85428418111049],
                            [2.278358749742464, 48.85433360060904],
                            [2.278279650199504, 48.85438391940398],
                            [2.277717754978346, 48.854750534707186],
                            [2.276984019153974, 48.85521687696223],
                            [2.276653971583136, 48.855426235360966],
                            [2.276383924800431, 48.85560235021971],
                            [2.275899743151141, 48.85591863805947],
                            [2.275633768115702, 48.856103746925],
                            [2.275591482314248, 48.856134299385424],
                            [2.275307697992698, 48.8563922394989],
                            [2.275198539468295, 48.85649919474854],
                            [2.27516715468514, 48.8565315515406],
                        ],
                    },
                },
                1251: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.84879343699644, 2.3856508893384962],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 411.629036136,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.384092210055667,
                            48.84712872224062,
                            2.387025242098631,
                            48.85017786279967,
                        ),
                        "coordinates": [
                            [2.387025242098631, 48.84712872224062],
                            [2.386808445777995, 48.84735451689955],
                            [2.386714451273586, 48.847452412907835],
                            [2.384947707190126, 48.849771610681465],
                            [2.384934942564869, 48.84978787013121],
                            [2.384877562585458, 48.84985114236024],
                            [2.384811059927801, 48.84991039790595],
                            [2.38473607771743, 48.84996506627346],
                            [2.384653336253008, 48.85001462053349],
                            [2.384563631558606, 48.85005858451039],
                            [2.384467829933028, 48.850096532754904],
                            [2.384366855525492, 48.85012810397125],
                            [2.38426167820912, 48.85015298926354],
                            [2.384153310641365, 48.8501709501086],
                            [2.384092210055667, 48.85017786279967],
                        ],
                    },
                },
                1252: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.82383704431745, 2.4102472270235564],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 713.906852726,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.406742224555687,
                            48.82159576732173,
                            2.413737517516731,
                            48.82605499744055,
                        ),
                        "coordinates": [
                            [2.413737517516731, 48.82159576732173],
                            [2.41359286703893, 48.821688876231036],
                            [2.408427524773798, 48.825013377854866],
                            [2.406897858736302, 48.82595880913181],
                            [2.406742224555687, 48.82605499744055],
                        ],
                    },
                },
                1253: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.79486075047856, 2.1040231487081065],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 5003.12924709,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.071847005929401,
                            48.79197130289541,
                            2.136050489663708,
                            48.798774681352754,
                        ),
                        "coordinates": [
                            [2.071847005929401, 48.79870763528835],
                            [2.071930959217986, 48.79871552851866],
                            [2.072216710538763, 48.7987359766609],
                            [2.072579474675331, 48.79875781412333],
                            [2.072862898980037, 48.79877217510979],
                            [2.07339670251307, 48.798774681352754],
                            [2.073713874486058, 48.798774514434655],
                            [2.074120918822997, 48.79876825942257],
                            [2.074570257201611, 48.79874411437348],
                            [2.075095898700846, 48.79870575443047],
                            [2.075455455431691, 48.79866970976342],
                            [2.075887224661105, 48.79862123822052],
                            [2.076227752121453, 48.79857975186269],
                            [2.076626900075734, 48.798521310787564],
                            [2.07716506105974, 48.79843081224707],
                            [2.07764852043101, 48.798316933934665],
                            [2.078167738891175, 48.798203905116274],
                            [2.078658217708944, 48.798076532368164],
                            [2.079083828515797, 48.79795614915085],
                            [2.07970072398773, 48.79775767757964],
                            [2.08020225629617, 48.79758035736656],
                            [2.080682237327531, 48.79739108945262],
                            [2.082831239058495, 48.79647994934646],
                            [2.08407821011798, 48.79595569704254],
                            [2.084495051075953, 48.79578292818973],
                            [2.084798183357852, 48.795662251920504],
                            [2.085068779097173, 48.79556529741404],
                            [2.085472803759792, 48.795432945457634],
                            [2.085851533812421, 48.795317192821884],
                            [2.086342037093098, 48.795175510300744],
                            [2.086926168987106, 48.795034032056186],
                            [2.087503001665491, 48.794911569452395],
                            [2.088104956144356, 48.79480581469834],
                            [2.088696007853362, 48.794719067792464],
                            [2.089301405013185, 48.794644244904084],
                            [2.089913909264423, 48.794588469047525],
                            [2.09054429876811, 48.794556522554586],
                            [2.091113408132319, 48.79453633626861],
                            [2.09172199049859, 48.79454478562203],
                            [2.092341270622694, 48.79457466828989],
                            [2.093068461780212, 48.79463095098126],
                            [2.093925150711385, 48.79471843643121],
                            [2.094774639817521, 48.794805900752586],
                            [2.098176203113287, 48.7951604600855],
                            [2.101567045015145, 48.79550775765459],
                            [2.10300329181604, 48.795658232499086],
                            [2.103510872100985, 48.79570448052273],
                            [2.103986129960595, 48.795731624861844],
                            [2.104472236811199, 48.795749272395476],
                            [2.104962034435666, 48.79574789032003],
                            [2.105455511439231, 48.79572985839365],
                            [2.105949086909674, 48.79569041070288],
                            [2.106424732283703, 48.79563426936188],
                            [2.106914848316776, 48.7955638785091],
                            [2.107390620647533, 48.795479181062994],
                            [2.107816052636528, 48.795377724667944],
                            [2.108270390515862, 48.79525491057731],
                            [2.108728360406763, 48.79512496420476],
                            [2.109154025991882, 48.79497115721885],
                            [2.109680764025691, 48.79476520547845],
                            [2.110294111936995, 48.794518974053865],
                            [2.110961593718655, 48.79424667472427],
                            [2.111369258162332, 48.794088065982855],
                            [2.111697533309683, 48.79396498860572],
                            [2.112061828922531, 48.79383960199691],
                            [2.112483806336287, 48.79370005213547],
                            [2.112801132518071, 48.793607882006135],
                            [2.113176151228948, 48.79349916875279],
                            [2.11369172125704, 48.793366936094806],
                            [2.114286612721081, 48.79321344201142],
                            [2.114690340145993, 48.79312619386876],
                            [2.115083250085545, 48.79304130261554],
                            [2.115443696458172, 48.792968243717226],
                            [2.11591216526011, 48.79289777277563],
                            [2.116330153700183, 48.792841477695944],
                            [2.11687422424131, 48.79277590713132],
                            [2.117843448911033, 48.79266118584478],
                            [2.120895214199257, 48.79230058968553],
                            [2.12276515961669, 48.79208045968901],
                            [2.123371895057395, 48.792006960314865],
                            [2.123854964587829, 48.79198209806883],
                            [2.124117106316824, 48.79197237837199],
                            [2.124505010430262, 48.79197130289541],
                            [2.124978607028827, 48.791982975227185],
                            [2.125773213019912, 48.79204200359494],
                            [2.126103812899514, 48.792074090135145],
                            [2.126404451834651, 48.79211061667671],
                            [2.126827479735518, 48.79217254796331],
                            [2.127227320272672, 48.79224612597793],
                            [2.12760129539878, 48.792321452990265],
                            [2.127994261423026, 48.792412101522544],
                            [2.128362701359944, 48.79250989839397],
                            [2.128830302441107, 48.79265463765974],
                            [2.129149705918469, 48.79276223361234],
                            [2.129462265955019, 48.792878809983584],
                            [2.130050581171206, 48.79312718041466],
                            [2.130828967598358, 48.7934927980301],
                            [2.13206509185052, 48.79409304530295],
                            [2.132487588843224, 48.794289846410095],
                            [2.133002509056168, 48.794520084339],
                            [2.13335716335117, 48.7946664018369],
                            [2.13369969439922, 48.79478212009287],
                            [2.13399604854809, 48.79487347462278],
                            [2.134304686413588, 48.794956757804414],
                            [2.134637837020887, 48.79503738448375],
                            [2.135009117560278, 48.7951135822115],
                            [2.1359721799146, 48.79526816122795],
                            [2.136050489663708, 48.79528024627206],
                        ],
                    },
                },
                1254: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.89475153867208, 2.355271109976486],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 3147.39469752,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352273798625216,
                            48.880922006671476,
                            2.35776859674016,
                            48.90875602475913,
                        ),
                        "coordinates": [
                            [2.356328543670162, 48.880922006671476],
                            [2.356628054656908, 48.88155417154206],
                            [2.356799333165851, 48.881982196383895],
                            [2.356994235882585, 48.88246469507391],
                            [2.357153723092858, 48.882900503241956],
                            [2.357301391124828, 48.88328961735871],
                            [2.357460898560597, 48.88376044832461],
                            [2.357638214045052, 48.88448421689481],
                            [2.357732877413799, 48.885091258325765],
                            [2.35776859674016, 48.88584618505727],
                            [2.357768158187986, 48.885851004895414],
                            [2.35771581244326, 48.886426164530604],
                            [2.357672776648871, 48.88704955877387],
                            [2.357622547948076, 48.88773481642559],
                            [2.357514564652608, 48.88836298218558],
                            [2.357406615422702, 48.88907680292586],
                            [2.35732021320441, 48.88955268597487],
                            [2.357212161668813, 48.89002857305947],
                            [2.35702476399322, 48.890604406366215],
                            [2.356866168146696, 48.89102319759584],
                            [2.356671515411152, 48.89151813463572],
                            [2.356188407767444, 48.89257940363092],
                            [2.355726862337239, 48.893459837040616],
                            [2.355279785936971, 48.894483026670464],
                            [2.354955332043211, 48.89535391720402],
                            [2.354760668682024, 48.89592023004912],
                            [2.354573252941464, 48.89658647405615],
                            [2.354400303679799, 48.89735264752717],
                            [2.354321102683396, 48.89790466678896],
                            [2.354243027550289, 48.89844847923835],
                            [2.354148424680226, 48.89948338357097],
                            [2.353906105047874, 48.90043998621057],
                            [2.353278831413479, 48.90253866092549],
                            [2.352860729356008, 48.90428515788201],
                            [2.352396188268603, 48.90767816593894],
                            [2.352342196388262, 48.90815880031198],
                            [2.352273798625216, 48.90875602475913],
                        ],
                    },
                },
                1255: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.94009088399499, 2.550616210006712],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2485.82994821,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.534714974742524,
                            48.93628018565177,
                            2.566448016963,
                            48.94418106597472,
                        ),
                        "coordinates": [
                            [2.534714974742524, 48.93628018565177],
                            [2.535340370734915, 48.93642662289816],
                            [2.535962129245601, 48.93656592503689],
                            [2.537332129872436, 48.93686095462459],
                            [2.537917744457916, 48.93699079325262],
                            [2.538601003272541, 48.93715138676137],
                            [2.540918322655967, 48.93769453308393],
                            [2.543683993892404, 48.938343894483246],
                            [2.544656530410048, 48.93857531034312],
                            [2.545538668164763, 48.93878071039493],
                            [2.54620751804285, 48.93893890513631],
                            [2.548626257665795, 48.93951026287049],
                            [2.549765126932029, 48.93977463943],
                            [2.550694334226996, 48.93999656709117],
                            [2.5514427700577, 48.940175997923625],
                            [2.551959857044305, 48.94031065011705],
                            [2.552824110079801, 48.94054220031732],
                            [2.554205472265827, 48.9409083884766],
                            [2.556928501227496, 48.94163602933851],
                            [2.559405672499717, 48.94229270450478],
                            [2.560599066535213, 48.94260683298388],
                            [2.561441695287231, 48.942831221353366],
                            [2.562157770590603, 48.943024923588446],
                            [2.563249943759487, 48.94331305085653],
                            [2.564117913392034, 48.94354450877578],
                            [2.564797843137347, 48.94372874544],
                            [2.566448016963, 48.94418106597472],
                        ],
                    },
                },
                1256: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.245062282617575, 1.892803192248379],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 5503.80014461,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.872589469227938,
                            49.22080705063383,
                            1.905299061887723,
                            49.26132229816068,
                        ),
                        "coordinates": [
                            [1.905299061887723, 49.22080705063383],
                            [1.902824430639971, 49.229732597387596],
                            [1.90093511435295, 49.23707808573898],
                            [1.899356973694322, 49.24093222356381],
                            [1.896946992124124, 49.243588355511136],
                            [1.891999131714059, 49.247429447140576],
                            [1.889290966470394, 49.25192242305406],
                            [1.887146460201944, 49.256141817862755],
                            [1.884877179450907, 49.25861443325063],
                            [1.88233784436496, 49.25989113652876],
                            [1.878537140933148, 49.260887040007006],
                            [1.872589469227938, 49.26132229816068],
                        ],
                    },
                },
                1257: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.91082684540067, 2.352344601943885],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 455.286704745,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352105705816552,
                            48.90875602475913,
                            2.35307378633796,
                            48.912728022078205,
                        ),
                        "coordinates": [
                            [2.352273798625216, 48.90875602475913],
                            [2.352210056592285, 48.90957789507191],
                            [2.352177649040248, 48.909832489206664],
                            [2.352152445463866, 48.91004187447977],
                            [2.352130844433447, 48.910232225568045],
                            [2.352109255641117, 48.91045588612407],
                            [2.352105705816552, 48.91065337184244],
                            [2.352123814122804, 48.91085323371987],
                            [2.352174431988979, 48.91111495570954],
                            [2.352253936570604, 48.91140760357833],
                            [2.352383984953965, 48.91172165915649],
                            [2.352510404644672, 48.911959574937896],
                            [2.352672926938664, 48.91221890023702],
                            [2.352806550119313, 48.91240209040332],
                            [2.352958591601471, 48.91258752650817],
                            [2.35307378633796, 48.912728022078205],
                        ],
                    },
                },
                1258: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.283024055123256, 1.8012090159001461],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 2608.65752953,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.785066223503951,
                            49.28165768310037,
                            1.81808238249243,
                            49.28526352316656,
                        ),
                        "coordinates": [
                            [1.81808238249243, 49.282589735816124],
                            [1.814403196674858, 49.28349881772344],
                            [1.810184719046329, 49.283847225439146],
                            [1.806111616230063, 49.283736608109926],
                            [1.801062130533726, 49.28297794550104],
                            [1.79629878072309, 49.281760840628095],
                            [1.793911620722456, 49.28165768310037],
                            [1.790536015453303, 49.28200932318175],
                            [1.787713073511066, 49.283190683227424],
                            [1.785066223503951, 49.28526352316656],
                        ],
                    },
                },
                1259: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.85464401895172, 2.416803255001913],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 938.622978733,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.410626429815428,
                            48.85354391700303,
                            2.422983216145875,
                            48.855726428633155,
                        ),
                        "coordinates": [
                            [2.410626429815428, 48.85354391700303],
                            [2.412247099153639, 48.853836129599316],
                            [2.415759467029117, 48.85446933539069],
                            [2.417160276310339, 48.854712143776716],
                            [2.422983216145875, 48.855726428633155],
                        ],
                    },
                },
                1260: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.86286428901469, 2.3716095014118332],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 615.98115132,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368496387112846,
                            48.86101925991959,
                            2.37473343128132,
                            48.86472762072593,
                        ),
                        "coordinates": [
                            [2.368496387112846, 48.86472762072593],
                            [2.371346946351094, 48.86301478393277],
                            [2.373545285700105, 48.86170694688268],
                            [2.374082680311722, 48.86139591248359],
                            [2.37473343128132, 48.86101925991959],
                        ],
                    },
                },
                1261: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.830892701974484, 2.2347194699463113],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 636.057762613,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.230799591317221,
                            48.82967484383875,
                            2.238639348575401,
                            48.832110560110216,
                        ),
                        "coordinates": [
                            [2.230799591317221, 48.82967484383875],
                            [2.238639348575401, 48.832110560110216],
                        ],
                    },
                },
                1262: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.852268628865545, 2.4035557157822165],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 385.418096514,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.401022270517142,
                            48.851812133001964,
                            2.406089161868773,
                            48.85272512017011,
                        ),
                        "coordinates": [
                            [2.401022270517142, 48.851812133001964],
                            [2.401927284511546, 48.8519752093256],
                            [2.406089161868773, 48.85272512017011],
                        ],
                    },
                },
                1263: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.82567040814424, 2.4026013366110286],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 6261.63580934,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.373916469806499,
                            48.80204938032392,
                            2.426482408484048,
                            48.84377257685145,
                        ),
                        "coordinates": [
                            [2.426482408484048, 48.80204938032392],
                            [2.426213233389943, 48.80270366871429],
                            [2.426059067224202, 48.803103518578126],
                            [2.425865562558176, 48.803662814109195],
                            [2.425636975576803, 48.80424292499913],
                            [2.425500067919798, 48.804575763236556],
                            [2.425308930865491, 48.80503813993732],
                            [2.425131451195494, 48.805526583980225],
                            [2.424802040965552, 48.80632899240994],
                            [2.424661066987416, 48.806678919456175],
                            [2.424301888093021, 48.807594657790766],
                            [2.423945340007631, 48.808306202909264],
                            [2.4238066071551, 48.808545570792425],
                            [2.423630072802756, 48.80881009275069],
                            [2.423363810386366, 48.80915291901504],
                            [2.423071675265067, 48.809494865161774],
                            [2.422746842177166, 48.80982694379628],
                            [2.422361495815938, 48.81015720195034],
                            [2.422000423766193, 48.81045160176861],
                            [2.421588397441904, 48.810760360786645],
                            [2.420092448473936, 48.81182171041226],
                            [2.419617867358986, 48.812192557978705],
                            [2.419166456889185, 48.812581372445564],
                            [2.418674308593593, 48.81304215600817],
                            [2.418183542880156, 48.813520922732344],
                            [2.417734967710867, 48.81399336146604],
                            [2.417430592583147, 48.814349552081005],
                            [2.417261333276494, 48.81455065586815],
                            [2.417069037353589, 48.814788792325686],
                            [2.416913692091962, 48.8149964479154],
                            [2.416488893695249, 48.815597648120736],
                            [2.416210377872471, 48.815994422632],
                            [2.415946794225707, 48.81636510731462],
                            [2.415627652920495, 48.81683921532513],
                            [2.415503595505816, 48.817020435180275],
                            [2.415415890548352, 48.81714513857545],
                            [2.415322964685196, 48.81727594562042],
                            [2.415219942191224, 48.81742585543538],
                            [2.415157444171279, 48.817516725902586],
                            [2.415055535950904, 48.817658881174786],
                            [2.414972657548998, 48.81777854160697],
                            [2.414770182636784, 48.818052060328704],
                            [2.414647887813147, 48.818221207331455],
                            [2.414471216694762, 48.818451542308544],
                            [2.414260533010118, 48.818704381847574],
                            [2.414051194292975, 48.81894642965178],
                            [2.413811905866178, 48.819196590093426],
                            [2.413563072631133, 48.819441360909316],
                            [2.413301987130172, 48.81968883662897],
                            [2.413047690982288, 48.81992641596042],
                            [2.412797443495975, 48.820140611055436],
                            [2.412571657662627, 48.820322415163034],
                            [2.412408434024621, 48.82045201896428],
                            [2.412256093224649, 48.82057352229208],
                            [2.412062951465379, 48.82073192221927],
                            [2.411867079403589, 48.820885827704885],
                            [2.411616784560575, 48.821075739547794],
                            [2.411408651811768, 48.82122965227109],
                            [2.411192349967435, 48.821385368109524],
                            [2.410966520478706, 48.82154558654308],
                            [2.410733875941399, 48.821703110602364],
                            [2.410510741612263, 48.8218462398296],
                            [2.41029985096752, 48.821981268089914],
                            [2.41025903292298, 48.82200737347515],
                            [2.410216854174392, 48.82203347932984],
                            [2.410004588052336, 48.82216041400117],
                            [2.409652173980301, 48.822374667383436],
                            [2.409324239749755, 48.82256642227976],
                            [2.409031663100444, 48.82272488081891],
                            [2.408762210604572, 48.82286533778582],
                            [2.408490031842356, 48.82300489746526],
                            [2.40826410815419, 48.8231102547108],
                            [2.407759182536653, 48.82334977727461],
                            [2.407214732646087, 48.823572236719585],
                            [2.406283665804337, 48.82391902962454],
                            [2.405445158717418, 48.82423788137506],
                            [2.405170194371788, 48.82434416166671],
                            [2.404959205661507, 48.82442612226807],
                            [2.404618913210112, 48.82456751146986],
                            [2.404335797561936, 48.82469177985944],
                            [2.403960143470646, 48.8248718564924],
                            [2.40354230146633, 48.825078935613554],
                            [2.403144882580885, 48.825284202222214],
                            [2.402831854855952, 48.82545254881691],
                            [2.402535171598737, 48.82562448198626],
                            [2.402282053415619, 48.82578290055115],
                            [2.402033024959504, 48.82594671096045],
                            [2.401808498266836, 48.82609971603596],
                            [2.401569009892957, 48.82626981570265],
                            [2.401195832664583, 48.82655819275876],
                            [2.400834284691245, 48.82685386050075],
                            [2.400681893009959, 48.8269735496221],
                            [2.400393433755833, 48.82719853013525],
                            [2.40008456050687, 48.827437908965805],
                            [2.399740320857572, 48.827717774478614],
                            [2.399426035559518, 48.82799222677444],
                            [2.39920974592434, 48.82821176934364],
                            [2.399007073190293, 48.82843040410095],
                            [2.398865662351821, 48.8286256237548],
                            [2.398755540165808, 48.82879025107601],
                            [2.398610096929417, 48.8290304365512],
                            [2.398516340179615, 48.82921394000908],
                            [2.398428028740589, 48.82939474207146],
                            [2.398315283707336, 48.82964390175761],
                            [2.398171359476316, 48.83001538039786],
                            [2.398050486906158, 48.83030411238482],
                            [2.397982572837722, 48.83046062305791],
                            [2.397895604868111, 48.83062973322914],
                            [2.3977882157148, 48.83080784749022],
                            [2.397679433512619, 48.83096168157907],
                            [2.39758152642139, 48.83109752451698],
                            [2.39748769902434, 48.831228868591225],
                            [2.397406686186359, 48.83132460463281],
                            [2.397206507880598, 48.83153198292341],
                            [2.397008812813349, 48.831712034404575],
                            [2.396902670816615, 48.8317993206339],
                            [2.396687665879538, 48.83197749002836],
                            [2.396521636604763, 48.832105274481506],
                            [2.396312047021417, 48.83225826123725],
                            [2.396079307259286, 48.83241755489672],
                            [2.395794823378921, 48.83259306130089],
                            [2.395480393429601, 48.832788367203605],
                            [2.395118318527763, 48.83301337211617],
                            [2.394700414833012, 48.83325908818281],
                            [2.394240295775539, 48.83351921264995],
                            [2.393707998818727, 48.833800054192515],
                            [2.393257381108426, 48.83403858692467],
                            [2.392719658517632, 48.834349102510636],
                            [2.392361129475945, 48.83457498027207],
                            [2.39205402873903, 48.83479457005944],
                            [2.391799493674758, 48.834977246579015],
                            [2.391557244840326, 48.83518599466781],
                            [2.391221095491382, 48.83548291743034],
                            [2.390852317628658, 48.835843702378234],
                            [2.390569255563208, 48.83610912347908],
                            [2.390322929581464, 48.83633675636582],
                            [2.390158249950645, 48.836481616539544],
                            [2.389728192331321, 48.83687839803796],
                            [2.389559430812823, 48.83703135416416],
                            [2.389201465208559, 48.83733277687348],
                            [2.388881582141247, 48.83757842565034],
                            [2.388281229299247, 48.83798786961311],
                            [2.387935402598586, 48.83818406832291],
                            [2.386841850262587, 48.83882705395043],
                            [2.386514484093897, 48.8390122044851],
                            [2.385941336398595, 48.83934528783985],
                            [2.385664407602353, 48.83950159154659],
                            [2.385376154010946, 48.83965646848244],
                            [2.385084960968584, 48.83979923678294],
                            [2.384800338585216, 48.83992541615458],
                            [2.384555820141204, 48.84001845285108],
                            [2.384259637093709, 48.840114886218764],
                            [2.383909724229494, 48.840202786000205],
                            [2.383466349263064, 48.840292545029556],
                            [2.382961084593842, 48.84037671113637],
                            [2.382503931468573, 48.840444970941384],
                            [2.382094906542723, 48.84051321050309],
                            [2.381679002257174, 48.84057918089413],
                            [2.381338525659911, 48.840645019225875],
                            [2.380925998582088, 48.84075398764486],
                            [2.380444181787893, 48.840902726195225],
                            [2.380043983149386, 48.84104684219658],
                            [2.379620063352382, 48.84120458866421],
                            [2.378015965569879, 48.841800908392386],
                            [2.377147174382835, 48.84215570513919],
                            [2.376710140932717, 48.84231893999389],
                            [2.376296123283737, 48.842494627969224],
                            [2.375927311253918, 48.84268135974448],
                            [2.374760736599005, 48.84330142800346],
                            [2.374756134440075, 48.84330387359257],
                            [2.374231143268418, 48.843596873153125],
                            [2.373916469806499, 48.84377257685145],
                        ],
                    },
                },
                1264: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.849636359562275, 2.2815728096200534],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1039.89446243,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.276760967379574,
                            48.84619214048855,
                            2.286419448213008,
                            48.853033488503854,
                        ),
                        "coordinates": [
                            [2.286419448213008, 48.853033488503854],
                            [2.285753551167312, 48.852571864876346],
                            [2.285019573521851, 48.85206883938463],
                            [2.283258945014557, 48.85082522891038],
                            [2.281639998854621, 48.849689573608785],
                            [2.281155290820172, 48.849342217700965],
                            [2.280386028662221, 48.848795080578896],
                            [2.27845814980847, 48.84745419220451],
                            [2.277513320159236, 48.846787341834066],
                            [2.276966092069675, 48.84635720274608],
                            [2.276847666762353, 48.846260918444166],
                            [2.276760967379574, 48.84619214048855],
                        ],
                    },
                },
                1265: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98075859926737, 2.2709659827582835],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 166.303618961,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.269851993930268,
                            48.980646100425986,
                            2.272084772747633,
                            48.98091190326584,
                        ),
                        "coordinates": [
                            [2.272084772747633, 48.980646100425986],
                            [2.271950869618948, 48.98065591704335],
                            [2.271823795701041, 48.98066663645357],
                            [2.271758211804184, 48.98067109521663],
                            [2.271662563736779, 48.98067913480196],
                            [2.271161102964788, 48.98072021476257],
                            [2.270614515042522, 48.98079094371412],
                            [2.270471029382747, 48.98081424142235],
                            [2.270322078497261, 48.98083843554761],
                            [2.269851993930268, 48.98091190326584],
                        ],
                    },
                },
                1266: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.962725182457326, 3.270002332595575],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 9880.37545358,
                    },
                    "geometry": {
                        "type": "LineString",
                        "coordinates": [
                            [3.298782001341376, 48.9669272009919],
                            [3.312418595811659, 48.968202831680195],
                            [3.32188681725306, 48.969278782071456],
                        ],
                        "bbox": (
                            3.298782001341376,
                            48.9669272009919,
                            3.32188681725306,
                            48.969278782071456,
                        ),
                    },
                },
                1267: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.868157207747004, 2.3395392312803334],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1833.05352176,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.329927170608276,
                            48.861822272798115,
                            2.347012687238757,
                            48.87215749487708,
                        ),
                        "coordinates": [
                            [2.347012687238757, 48.861822272798115],
                            [2.346139950534157, 48.86386291966857],
                            [2.345636988821748, 48.86531838987238],
                            [2.345417927355666, 48.86573727310478],
                            [2.345160478893447, 48.86612636184987],
                            [2.344819775242238, 48.8665548917898],
                            [2.34475844522104, 48.86661514753044],
                            [2.344665769071722, 48.86670688041095],
                            [2.344536294336762, 48.86683458688842],
                            [2.344451793926929, 48.86691732596113],
                            [2.344355026293322, 48.867001864807165],
                            [2.344171028612736, 48.8671529554832],
                            [2.344009241484839, 48.86727313036127],
                            [2.343843353098865, 48.86738734956059],
                            [2.343665360130306, 48.867498310376],
                            [2.343531785407692, 48.86758105124546],
                            [2.343426831709067, 48.86763681309438],
                            [2.343188300831486, 48.8677636247545],
                            [2.342985042795352, 48.86786326885299],
                            [2.342594006842083, 48.86802894445205],
                            [2.342386819803436, 48.868108990848015],
                            [2.342009244406632, 48.86823940510147],
                            [2.341642570351269, 48.8683671189393],
                            [2.341326330309344, 48.868468751274044],
                            [2.34109051191617, 48.8685451996623],
                            [2.340278090764377, 48.868776343177274],
                            [2.340030000170044, 48.86884019938441],
                            [2.33961131398571, 48.868948034300686],
                            [2.339208025152501, 48.86905245161841],
                            [2.338692754287797, 48.86916487181267],
                            [2.337878946646969, 48.86934024384334],
                            [2.336784319108757, 48.86958035865164],
                            [2.336387634231484, 48.86966668940923],
                            [2.335952777688218, 48.86976830634638],
                            [2.33555881533213, 48.869860929567324],
                            [2.334893574433088, 48.87001559727425],
                            [2.334788607733597, 48.87003987626432],
                            [2.334769522943032, 48.87004437212967],
                            [2.334709541386526, 48.87005876007921],
                            [2.334578673458517, 48.87008933330528],
                            [2.334387824231294, 48.870139689329875],
                            [2.334222875600922, 48.87018195204797],
                            [2.334077011439678, 48.870217920101304],
                            [2.334029298928471, 48.870230508934746],
                            [2.333891614658895, 48.87026377928153],
                            [2.333877981503131, 48.87026827566506],
                            [2.33379346244092, 48.87029165401718],
                            [2.333414486751867, 48.87039506205515],
                            [2.332858283700289, 48.870594684761826],
                            [2.332591086358716, 48.870704387094804],
                            [2.332261334413238, 48.870870205029945],
                            [2.331899902590971, 48.871064071950485],
                            [2.330581576594389, 48.87179602140402],
                            [2.329927170608276, 48.87215749487708],
                        ],
                    },
                },
                1268: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.896803342918396, 2.812983771854086],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2683.73599938,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.804054305016884,
                            48.890856796314026,
                            2.826405497304068,
                            48.90307291600507,
                        ),
                        "coordinates": [
                            [2.810248219362661, 48.90307291600507],
                            [2.80700011758749, 48.90218589628686],
                            [2.806685256018316, 48.90209439511844],
                            [2.806337598314561, 48.90196971756673],
                            [2.805949929325692, 48.901811891212596],
                            [2.80563807401666, 48.901656130886366],
                            [2.805340409447035, 48.90147413990198],
                            [2.805076227268223, 48.90127516834251],
                            [2.804841725161372, 48.90108520412572],
                            [2.804625020575563, 48.900862778988035],
                            [2.804452413589881, 48.900655512765645],
                            [2.804318561411674, 48.90044468005146],
                            [2.804197253894176, 48.900192882600365],
                            [2.804128216979653, 48.90000053427984],
                            [2.804079706711413, 48.89979105744454],
                            [2.804054305016884, 48.89956443924759],
                            [2.804062577592576, 48.89934450115387],
                            [2.804091549570532, 48.89912618142349],
                            [2.804169135495806, 48.89885311597776],
                            [2.804300915700609, 48.89856959751123],
                            [2.804471622737895, 48.898301263942464],
                            [2.804742259070606, 48.89793705696264],
                            [2.804949445258663, 48.89769925717761],
                            [2.805172480066623, 48.8974971908885],
                            [2.805385540496223, 48.89733437275999],
                            [2.805637363239929, 48.897169689065436],
                            [2.805850856197873, 48.897052894663474],
                            [2.80612883500719, 48.89692049187041],
                            [2.806322787328451, 48.89684220587551],
                            [2.806533411699653, 48.89676690426331],
                            [2.806756492796133, 48.896696984848674],
                            [2.807076608111277, 48.896613383977744],
                            [2.807361236362019, 48.89655573356456],
                            [2.807740812862895, 48.896504733214236],
                            [2.808094761984152, 48.896477703466275],
                            [2.808474793106409, 48.89647443228812],
                            [2.808849811812922, 48.89648822494376],
                            [2.80928444070577, 48.89651711243998],
                            [2.810171866160228, 48.89658162649932],
                            [2.810614236408484, 48.896608771414954],
                            [2.811033241448254, 48.89662578508918],
                            [2.811459956645007, 48.89663765020382],
                            [2.811917578789763, 48.89663745249066],
                            [2.812294943669697, 48.896625654113826],
                            [2.812723899330884, 48.896601707577425],
                            [2.813235357259316, 48.896553549787285],
                            [2.813671772070683, 48.89649888271962],
                            [2.814120950681514, 48.89642711407069],
                            [2.814600938125333, 48.896333055743234],
                            [2.815047217492239, 48.89622890644643],
                            [2.815472713445234, 48.89611461542557],
                            [2.815792356458137, 48.89601610904244],
                            [2.816137719844884, 48.895903854255025],
                            [2.816462334402258, 48.89578486964247],
                            [2.816781693607512, 48.89565738049281],
                            [2.817118952371249, 48.89550936000913],
                            [2.817489534621965, 48.895332219922324],
                            [2.81788311541216, 48.89512770412366],
                            [2.818477339341856, 48.894818356855936],
                            [2.819213049073952, 48.89443681191365],
                            [2.820383473888515, 48.89383010901804],
                            [2.822302390515508, 48.892834956838854],
                            [2.82441671260347, 48.89173835948076],
                            [2.824931151571501, 48.8914736409164],
                            [2.825242421599499, 48.891317183035234],
                            [2.825551271877132, 48.891177783122956],
                            [2.825844777912835, 48.891055492553235],
                            [2.826169337334402, 48.8909364802004],
                            [2.826405497304068, 48.890856796314026],
                        ],
                    },
                },
                1269: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.89344778185938, 2.2299135312056424],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1135.17769977,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.223212968406662,
                            48.89218701384532,
                            2.237018252347291,
                            48.89574531120744,
                        ),
                        "coordinates": [
                            [2.237018252347291, 48.89218701384532],
                            [2.236889972111692, 48.89222826815874],
                            [2.236562441273872, 48.892335894685075],
                            [2.236385028677886, 48.89239419234888],
                            [2.236053404582021, 48.89250271319473],
                            [2.235649451065534, 48.89263275207622],
                            [2.235233967050919, 48.89275838925989],
                            [2.234854900926522, 48.892846087288035],
                            [2.234659961595227, 48.89288636197261],
                            [2.234486692126743, 48.89291713941127],
                            [2.234288154742628, 48.89295265190175],
                            [2.233974121564934, 48.892999957509865],
                            [2.233688994579055, 48.893028252804115],
                            [2.233335326235989, 48.89304696779208],
                            [2.232902282753761, 48.89306085109608],
                            [2.232133662271731, 48.89306966853521],
                            [2.231461625233044, 48.8930669212707],
                            [2.231314326637488, 48.893069483228665],
                            [2.231041551576202, 48.89307462712151],
                            [2.230562832052212, 48.893082276649736],
                            [2.230008222435449, 48.8930962559594],
                            [2.229373093736391, 48.893114695969764],
                            [2.228986926801153, 48.89314288560191],
                            [2.228611779233112, 48.89318915683629],
                            [2.22817320780554, 48.89326569890286],
                            [2.227825081123822, 48.8933350964347],
                            [2.227700909628444, 48.893363755161204],
                            [2.22750168502265, 48.89341122662585],
                            [2.227377510733342, 48.89344078433325],
                            [2.227160546784202, 48.893492734573016],
                            [2.226850351153578, 48.89358229341453],
                            [2.226611914182309, 48.89365947332927],
                            [2.226216061131326, 48.8938119684561],
                            [2.225994411857472, 48.893906962594166],
                            [2.225760086735957, 48.894012964947265],
                            [2.225362762980957, 48.894210419801766],
                            [2.225334086962441, 48.89422567945487],
                            [2.225252155743349, 48.89427056395999],
                            [2.225171584474072, 48.89431634844688],
                            [2.224994059012033, 48.894415994264065],
                            [2.224933973965228, 48.894449208983886],
                            [2.224826060753511, 48.89452374332353],
                            [2.22476458973515, 48.894566848845905],
                            [2.22438893801474, 48.89482637149489],
                            [2.224274192730952, 48.89490629484218],
                            [2.224145757547004, 48.895007786221],
                            [2.224056946910932, 48.89507784261679],
                            [2.223888884519255, 48.89521166966118],
                            [2.22379460879775, 48.89528531744434],
                            [2.223642943095288, 48.89540567047953],
                            [2.223468050419309, 48.89554398616258],
                            [2.223253530831047, 48.895713737037774],
                            [2.223212968406662, 48.89574531120744],
                        ],
                    },
                },
                1270: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.98106315549728, 2.0768962508253357],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2305.58842662,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.073769886475506,
                            48.970665048322616,
                            2.07803798220009,
                            48.99101254867934,
                        ),
                        "coordinates": [
                            [2.073769886475506, 48.99101254867934],
                            [2.073779661264222, 48.99096171188935],
                            [2.073879411496579, 48.99055983125146],
                            [2.074019020488473, 48.99014138587337],
                            [2.0741983857691, 48.98972541061173],
                            [2.074432381748382, 48.989233421812195],
                            [2.074808983748562, 48.988437201885674],
                            [2.076362176250532, 48.985269071863705],
                            [2.076742329616248, 48.984472853600245],
                            [2.076939740037784, 48.984054535501954],
                            [2.077115342777914, 48.983657581467504],
                            [2.07729858464019, 48.98318212852255],
                            [2.077412377923963, 48.98285165677231],
                            [2.077537304439022, 48.98246648461567],
                            [2.077658884537246, 48.98202895926283],
                            [2.077754922611568, 48.98163658249293],
                            [2.077843965823255, 48.981198983651325],
                            [2.077899965343129, 48.98085886246776],
                            [2.077963815271243, 48.98039979261784],
                            [2.07800954927886, 48.97994781801503],
                            [2.07803798220009, 48.979348284876586],
                            [2.078028030755505, 48.97848455869799],
                            [2.078002901077792, 48.97775879810884],
                            [2.077873249960118, 48.974206130751305],
                            [2.077731764565598, 48.970665048322616],
                        ],
                    },
                },
                1271: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.891363113248495, 2.183967255872026],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1869.94003094,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.172579447718415,
                            48.88757361863876,
                            2.195363986912902,
                            48.89512589133458,
                        ),
                        "coordinates": [
                            [2.195363986912902, 48.89512589133458],
                            [2.193458595624521, 48.89450310661282],
                            [2.192525280289681, 48.89418268660796],
                            [2.189088993223235, 48.89305509008498],
                            [2.187187050039408, 48.89243180853922],
                            [2.186361570097372, 48.89215234013162],
                            [2.1851431455468, 48.891755754259144],
                            [2.18373372545416, 48.89128514130804],
                            [2.182381975992643, 48.89084314090626],
                            [2.181026163460403, 48.890415775277674],
                            [2.180354528025983, 48.890195432112435],
                            [2.179631139981862, 48.889955230101336],
                            [2.178546792073141, 48.88958232934799],
                            [2.177910629763803, 48.88936381994337],
                            [2.176827634118682, 48.889002595006886],
                            [2.176562004691086, 48.88891139451675],
                            [2.176108394074554, 48.88875518161231],
                            [2.175133036249012, 48.88843096290687],
                            [2.174242171687749, 48.88812753967366],
                            [2.173220526443042, 48.88778705122049],
                            [2.173078858599261, 48.88774008491229],
                            [2.172939918488416, 48.887693122884805],
                            [2.172579447718415, 48.88757361863876],
                        ],
                    },
                },
                1272: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.88711344166894, 2.1451471150080663],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1668.98322873,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.134600875228717,
                            48.88521121820845,
                            2.155903471896523,
                            48.89008623555385,
                        ),
                        "coordinates": [
                            [2.155903471896523, 48.88521121820845],
                            [2.155797982492893, 48.88521488576106],
                            [2.154850118589494, 48.88525744342524],
                            [2.154709641139282, 48.88526441366933],
                            [2.15457734067213, 48.88527229586955],
                            [2.154200917763845, 48.885290578647904],
                            [2.153517186451573, 48.88532650243316],
                            [2.15278096800325, 48.88538242208498],
                            [2.151942904156351, 48.88546529605056],
                            [2.151436864315177, 48.88552205608111],
                            [2.150945951226104, 48.885585499989176],
                            [2.150317855050772, 48.88567013199003],
                            [2.149393701567056, 48.88580899930708],
                            [2.148617468689247, 48.88594810472129],
                            [2.148014475859808, 48.88607083412691],
                            [2.147313937283235, 48.886226711062385],
                            [2.146866161031904, 48.886328278406936],
                            [2.146400297525605, 48.886441710651475],
                            [2.145851328689233, 48.88658593374018],
                            [2.145187151305534, 48.88677939681714],
                            [2.143571947661347, 48.88729375953591],
                            [2.142587529316887, 48.887604138426205],
                            [2.139952423498739, 48.888414372483126],
                            [2.137485118219788, 48.8891870683311],
                            [2.134990432871523, 48.889966856906675],
                            [2.134600875228717, 48.89008623555385],
                        ],
                    },
                },
                1273: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.86101518904687, 2.894403316424414],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 1713.82320342,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.883201728539714,
                            48.85955731687439,
                            2.905736964548534,
                            48.8632902390859,
                        ),
                        "coordinates": [
                            [2.883201728539714, 48.8632902390859],
                            [2.883533662603522, 48.863165911902094],
                            [2.883899275267243, 48.863049945032834],
                            [2.884326950384286, 48.86293879352313],
                            [2.884736763166585, 48.86284818345464],
                            [2.886693190199066, 48.86243135401624],
                            [2.895755649877526, 48.86049171630665],
                            [2.896356211756951, 48.860366035656874],
                            [2.896812579596415, 48.860283677421805],
                            [2.897184037706688, 48.86023241760761],
                            [2.897586594105394, 48.86018952803462],
                            [2.897953113485189, 48.86015874628669],
                            [2.898482273641998, 48.860116936450545],
                            [2.905736964548534, 48.85955731687439],
                        ],
                    },
                },
                1274: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84403210476037, 2.4627083183538687],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 161.495650243,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461697053166161,
                            48.84372026160052,
                            2.463708038038903,
                            48.844305524221596,
                        ),
                        "coordinates": [
                            [2.461697053166161, 48.844305524221596],
                            [2.462504442595751, 48.84410009382778],
                            [2.462791718074214, 48.84401794321317],
                            [2.462838010116912, 48.84400530203782],
                            [2.463017730652056, 48.84395564263458],
                            [2.46331859202052, 48.84385908655539],
                            [2.463708038038903, 48.84372026160052],
                        ],
                    },
                },
                1275: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.8921550401151, 2.2371158460671285],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 15.972853041,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.237018252347291,
                            48.89212336383249,
                            2.237213536457713,
                            48.89218701384532,
                        ),
                        "coordinates": [
                            [2.237213536457713, 48.89212336383249],
                            [2.237141074683929, 48.892146652736706],
                            [2.237018252347291, 48.89218701384532],
                        ],
                    },
                },
                1276: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.971398626344104, 3.000666216545214],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 4989.5011259,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.973519215077535,
                            48.959160968311494,
                            3.026111294286066,
                            48.97846727884664,
                        ),
                        "coordinates": [
                            [2.973519215077535, 48.97436062282584],
                            [2.973772895317904, 48.9746097652687],
                            [2.974039591773709, 48.97485883529857],
                            [2.97436853189884, 48.975141821396356],
                            [2.974700483365715, 48.97540551702581],
                            [2.975005891586773, 48.9756286700914],
                            [2.97538647611226, 48.97587924248098],
                            [2.975753777429205, 48.976108474176925],
                            [2.97610776720775, 48.97631422246366],
                            [2.976445220003553, 48.97649864677014],
                            [2.976838166508574, 48.976697750724576],
                            [2.977325811626418, 48.976924161762916],
                            [2.977767396085792, 48.97711014134753],
                            [2.97820881560314, 48.97728327117223],
                            [2.978666392472243, 48.9774477427205],
                            [2.979228290126303, 48.97762875918514],
                            [2.979776874881422, 48.97778629119148],
                            [2.980308921137792, 48.9779225001296],
                            [2.980879948547887, 48.978054202419784],
                            [2.981506143445581, 48.97817488515208],
                            [2.982083127039654, 48.97826371767019],
                            [2.982676184071168, 48.978337468905565],
                            [2.983392828782192, 48.978408376655196],
                            [2.984027702664223, 48.97844547746635],
                            [2.984620037854598, 48.97846354287163],
                            [2.985095066719508, 48.97846727884664],
                            [2.985745563550632, 48.9784550287008],
                            [2.986285287869332, 48.9784305537024],
                            [2.986850786308361, 48.978386655947766],
                            [2.987451811970465, 48.97832328123823],
                            [2.987909702713267, 48.978260717354765],
                            [2.988497291922027, 48.97816529052971],
                            [2.989091159669055, 48.97805269347273],
                            [2.989610148759171, 48.977936237438776],
                            [2.990158271622399, 48.97780890456781],
                            [2.990696464199218, 48.97766877789147],
                            [2.999917254677413, 48.97531793183979],
                            [3.002131596220587, 48.97475686073431],
                            [3.002731354481651, 48.97460346896076],
                            [3.003314729255557, 48.974441603035615],
                            [3.003839607144153, 48.974284358144736],
                            [3.00436099993864, 48.97410999973166],
                            [3.004836850832929, 48.97393590344203],
                            [3.005302765361638, 48.97374901511267],
                            [3.005739316082717, 48.973555872244766],
                            [3.006233863558562, 48.97332169943727],
                            [3.006634365827703, 48.973109489742136],
                            [3.007060453954556, 48.97286500668348],
                            [3.007437893521372, 48.9726315154097],
                            [3.007795810700965, 48.972398135671284],
                            [3.008143853232041, 48.97215624881205],
                            [3.008485125405614, 48.971895125132356],
                            [3.008819568851032, 48.97161048526421],
                            [3.009182673486361, 48.97128070464139],
                            [3.009461902708602, 48.971002811230136],
                            [3.009734333801408, 48.97070354213192],
                            [3.00998730443577, 48.97040867027304],
                            [3.010207863399986, 48.97012255363876],
                            [3.010405739879971, 48.96984299565804],
                            [3.010609506870402, 48.96951843131334],
                            [3.010768437491048, 48.96924552580462],
                            [3.010923879978115, 48.96895550892149],
                            [3.011088291405763, 48.96860761838882],
                            [3.011960218556504, 48.96647169234861],
                            [3.01229074511897, 48.965664540165804],
                            [3.01243008175896, 48.96538746553912],
                            [3.012563174732215, 48.96512970052752],
                            [3.012734650739944, 48.96482459658548],
                            [3.013021451530569, 48.964390319569105],
                            [3.013184362612078, 48.9641730670892],
                            [3.013536049563837, 48.96372769838496],
                            [3.013843691822617, 48.96339180526326],
                            [3.014106766867075, 48.963126845302845],
                            [3.014357210387531, 48.96288979841196],
                            [3.014765419763678, 48.962536175678885],
                            [3.01508075155229, 48.96228803518338],
                            [3.015476764371755, 48.96199444332488],
                            [3.015792557376289, 48.96178056249288],
                            [3.016121443474653, 48.96157302672188],
                            [3.016547296176869, 48.96132208500435],
                            [3.016928206566057, 48.96111423759807],
                            [3.017273871957416, 48.960945145651145],
                            [3.017622814663952, 48.960778176192306],
                            [3.018026891966558, 48.9606001682969],
                            [3.018634920201428, 48.960354558046866],
                            [3.019117123019213, 48.96018250516372],
                            [3.019550955065364, 48.96004072018662],
                            [3.019968763398198, 48.95991616115088],
                            [3.020493642737157, 48.95977382878023],
                            [3.020898792578962, 48.95967504073729],
                            [3.021372169011701, 48.959571559551165],
                            [3.021784056451335, 48.95948985817831],
                            [3.022296717126513, 48.959405412003036],
                            [3.022736234303315, 48.95933941366113],
                            [3.02320559212246, 48.95928218088204],
                            [3.023624510936894, 48.95923897890156],
                            [3.024082567545182, 48.95920410622047],
                            [3.024589490762557, 48.959175361763535],
                            [3.02507060456231, 48.95916176190395],
                            [3.025558403424575, 48.959160968311494],
                            [3.026111294286066, 48.959164063062694],
                        ],
                    },
                },
                1277: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.06838299808802, 2.0409335435768825],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2911.20726257,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.024952931375388,
                            49.062969678597184,
                            2.057902989161614,
                            49.07584288482138,
                        ),
                        "coordinates": [
                            [2.057902989161614, 49.062969678597184],
                            [2.057205435039614, 49.06310748599954],
                            [2.057120496395169, 49.063123465723514],
                            [2.054783068771868, 49.063605147499324],
                            [2.053849921717859, 49.06381148035727],
                            [2.052556455010289, 49.06408525862717],
                            [2.051172463791482, 49.064391169915474],
                            [2.050921685924129, 49.064448997786755],
                            [2.050181820299791, 49.0645955312425],
                            [2.049347347863518, 49.06477149914066],
                            [2.047586600542613, 49.06513937127203],
                            [2.047422174471494, 49.06517312906096],
                            [2.046887764902816, 49.06528688680347],
                            [2.045944995656484, 49.06548953381973],
                            [2.045876477505629, 49.06550464775561],
                            [2.045814819491, 49.06551708162601],
                            [2.045757270916986, 49.06552862550805],
                            [2.045661343940765, 49.065549965407136],
                            [2.044519884216904, 49.06579256307055],
                            [2.043267450714418, 49.066052852210504],
                            [2.042971502471737, 49.06610874825014],
                            [2.04215742272278, 49.06629910463407],
                            [2.041458336049697, 49.06648345701655],
                            [2.040882491563617, 49.06665553290175],
                            [2.040307862077174, 49.06685278823817],
                            [2.039860653122866, 49.06702609150031],
                            [2.039332379916411, 49.06725134078556],
                            [2.038797112445411, 49.06750084913709],
                            [2.038394888580283, 49.06770214126712],
                            [2.038217756515477, 49.067797903156674],
                            [2.038037875414937, 49.06789545558304],
                            [2.037792011430823, 49.06804049814144],
                            [2.037231504589459, 49.068387055897055],
                            [2.0371971416056, 49.06841124718697],
                            [2.036817822889324, 49.068670147302484],
                            [2.036234792039568, 49.06911736070743],
                            [2.036071074783365, 49.06925631976059],
                            [2.035720173531614, 49.06956654987718],
                            [2.035359445375408, 49.069916321865136],
                            [2.035242341170245, 49.070041913066525],
                            [2.035121113477004, 49.070170191141756],
                            [2.034791912703301, 49.07051105058178],
                            [2.034705042639174, 49.07061603768989],
                            [2.034656803103365, 49.07067076717141],
                            [2.034640322742302, 49.0706797158915],
                            [2.034349648213344, 49.07098650405376],
                            [2.033814828718146, 49.071599300280944],
                            [2.03368526026093, 49.07174733903692],
                            [2.033557075674022, 49.07189268395114],
                            [2.033500604872891, 49.0719500884096],
                            [2.033305031494602, 49.072147412855344],
                            [2.033263682905267, 49.072194065619136],
                            [2.033074829628442, 49.07241119119755],
                            [2.03275657185958, 49.07274847731178],
                            [2.032493557737728, 49.07300497384018],
                            [2.032354537774643, 49.07313050422791],
                            [2.032336637923809, 49.07314754304051],
                            [2.032274700259945, 49.07320313321975],
                            [2.032027114927031, 49.07339851874485],
                            [2.031490890576868, 49.073786480959185],
                            [2.031389205735461, 49.07385005901195],
                            [2.031198205586153, 49.0739691542722],
                            [2.031031998230004, 49.07406313557223],
                            [2.030839677767924, 49.07417413304975],
                            [2.030806726548958, 49.07419023197307],
                            [2.030500516593177, 49.07434588935578],
                            [2.030151859623305, 49.074503231135495],
                            [2.029563235218527, 49.0747282734898],
                            [2.02931356936107, 49.07481483443857],
                            [2.028164438152646, 49.0751426825309],
                            [2.027561250076705, 49.075285841577525],
                            [2.026405956171413, 49.075527601465666],
                            [2.024962411214713, 49.07584085219244],
                            [2.024952931375388, 49.07584288482138],
                        ],
                    },
                },
                1278: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.848899282747254, 2.3565464425920335],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1938.42448243,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.346034985851638,
                            48.84252802768357,
                            2.36543338335276,
                            48.85333579289227,
                        ),
                        "coordinates": [
                            [2.36543338335276, 48.84252802768357],
                            [2.365257638312982, 48.84274779946375],
                            [2.365191085578711, 48.84291701365898],
                            [2.36516040949979, 48.84306929885185],
                            [2.365135320560115, 48.843207988351686],
                            [2.365128069572211, 48.84346430813881],
                            [2.365119077625744, 48.84363222139181],
                            [2.365101006061017, 48.8438091312994],
                            [2.365055681449269, 48.843992045460006],
                            [2.36501773798524, 48.844103029263515],
                            [2.364955870120526, 48.84422594646666],
                            [2.364869624166622, 48.844345903919084],
                            [2.364778135800636, 48.8444511082444],
                            [2.364519391182411, 48.84468228603924],
                            [2.364252447020815, 48.844873896412544],
                            [2.364146210881654, 48.84494676361882],
                            [2.363542832004758, 48.845338991767846],
                            [2.362916295125543, 48.84575999976151],
                            [2.361407116197089, 48.84677921723564],
                            [2.360976691386705, 48.84707337352038],
                            [2.360286088671625, 48.84753484784806],
                            [2.359359104998217, 48.84820066813228],
                            [2.358969535110866, 48.84845454124818],
                            [2.358718365985054, 48.84862717227726],
                            [2.358549210576133, 48.848742259156396],
                            [2.358339045702914, 48.84888104155426],
                            [2.358169880359749, 48.84897920732825],
                            [2.357985339457181, 48.8490909129088],
                            [2.357816170314294, 48.849182310492274],
                            [2.357657248981885, 48.849260170874665],
                            [2.357452188110405, 48.84935157579254],
                            [2.357026667173158, 48.849510698198664],
                            [2.356637942292148, 48.84962906205921],
                            [2.355019319437158, 48.850133829471524],
                            [2.353628202676638, 48.8505612022938],
                            [2.351824215406448, 48.851134297541606],
                            [2.351395015959603, 48.85128003706921],
                            [2.350799582054356, 48.85148065122805],
                            [2.3489928222575, 48.85212834138162],
                            [2.348618165855216, 48.85226643354489],
                            [2.348295139337003, 48.85238828909806],
                            [2.347961862261651, 48.85253044930869],
                            [2.347300436571243, 48.85284522096403],
                            [2.346828715662574, 48.85306183663058],
                            [2.34646978972057, 48.85320399472642],
                            [2.346168163020426, 48.853301271398095],
                            [2.346034985851638, 48.85333579289227],
                        ],
                    },
                },
                1279: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.95981676573135, 2.2954343956420593],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1782.32127973,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.285930718208942,
                            48.95339646167632,
                            2.302347871689533,
                            48.96358968487314,
                        ),
                        "coordinates": [
                            [2.30234042019572, 48.95339646167632],
                            [2.302347871689533, 48.953587394392805],
                            [2.302335399445179, 48.95384997875558],
                            [2.302325714332493, 48.9540316291705],
                            [2.302311941596061, 48.954199790015444],
                            [2.302309173530747, 48.954253745730234],
                            [2.302300896093228, 48.95437514561916],
                            [2.302295357408279, 48.95448395628861],
                            [2.302285703186266, 48.95462064301265],
                            [2.302210146365722, 48.955268997834544],
                            [2.30214986257661, 48.95555674848297],
                            [2.302060886266997, 48.95586427341901],
                            [2.301955563060278, 48.95611424032951],
                            [2.301873510143942, 48.95628327934421],
                            [2.301691666802028, 48.9565979707393],
                            [2.301571368460207, 48.956778687720664],
                            [2.301452455235365, 48.956929730308644],
                            [2.301341746444026, 48.95706638543275],
                            [2.301112151930768, 48.95731181696755],
                            [2.300709041023123, 48.957671401572156],
                            [2.300346958340289, 48.957942867907676],
                            [2.299999922192097, 48.95817477112097],
                            [2.299070848881404, 48.958773386723855],
                            [2.298872729195725, 48.958910011304766],
                            [2.298722435736681, 48.95900438509954],
                            [2.298660951962535, 48.95904483266034],
                            [2.298144475413129, 48.95938548540862],
                            [2.297925868499213, 48.95951760450818],
                            [2.297554240696941, 48.95973330444529],
                            [2.297179891122347, 48.959932814757366],
                            [2.29689708699247, 48.96007210413513],
                            [2.296641611901363, 48.960190719728224],
                            [2.296405023996748, 48.960297733488574],
                            [2.29612657882905, 48.96040546510364],
                            [2.295805020759344, 48.96052593735619],
                            [2.295476327784761, 48.96063364843375],
                            [2.295125254956447, 48.96074503187028],
                            [2.294588394798257, 48.9609174961694],
                            [2.294000996068092, 48.96109353727476],
                            [2.291081678522152, 48.961997081668244],
                            [2.290912280567436, 48.96204917211165],
                            [2.29027567125032, 48.96224585692243],
                            [2.288450512538769, 48.96281164555615],
                            [2.28684117432929, 48.96330375839909],
                            [2.286281035766312, 48.963479770849645],
                            [2.285930718208942, 48.96358968487314],
                        ],
                    },
                },
                1280: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.88295715568775, 2.3196820795515647],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1516.1561858,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313732451520271,
                            48.87683695396951,
                            2.324738046836634,
                            48.88822016276462,
                        ),
                        "coordinates": [
                            [2.324738046836634, 48.87683695396951],
                            [2.32420142057937, 48.87748880417361],
                            [2.323956605544434, 48.877847241123426],
                            [2.32373720863479, 48.878224548844315],
                            [2.32352415360155, 48.87863539844985],
                            [2.323339714766086, 48.87900013217418],
                            [2.323107564883391, 48.87948434675638],
                            [2.322872780798152, 48.87990183133246],
                            [2.322699857158072, 48.880154733598346],
                            [2.322475211042448, 48.88042595099708],
                            [2.322188319175849, 48.88072928059579],
                            [2.321847299445921, 48.88108256843456],
                            [2.321165706465782, 48.88174482790253],
                            [2.320547906039082, 48.88237470681367],
                            [2.319826119003644, 48.88310506035692],
                            [2.319162051301495, 48.883785452158705],
                            [2.318772266168705, 48.88418512040464],
                            [2.317981852446237, 48.884977315949094],
                            [2.317371900145514, 48.88554825533218],
                            [2.316909910839129, 48.88598121765758],
                            [2.316419050997167, 48.88641655115975],
                            [2.316011197598551, 48.88677813862067],
                            [2.315596526577928, 48.88708453333479],
                            [2.314979371694457, 48.88749604387476],
                            [2.314105991626147, 48.8880026761262],
                            [2.313732451520271, 48.88822016276462],
                        ],
                    },
                },
                1281: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [49.00300005384484, 2.07494588559034],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2677.21544104,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.073186608046316,
                            48.99101254867934,
                            2.078757725897018,
                            49.014133684983044,
                        ),
                        "coordinates": [
                            [2.078306591409993, 49.014133684983044],
                            [2.078339757971262, 49.013905394065716],
                            [2.078470872757421, 49.013317515084445],
                            [2.078583574674959, 49.01293088722212],
                            [2.078663318480119, 49.01262127531286],
                            [2.078725692756072, 49.01231305239078],
                            [2.078757725897018, 49.01199619477375],
                            [2.078732025993187, 49.0115136049399],
                            [2.078666704338315, 49.01113799620632],
                            [2.078454918128412, 49.01054934200499],
                            [2.078209782345716, 49.01011479429198],
                            [2.077815372026369, 49.00959139744165],
                            [2.077402980702645, 49.009187877192076],
                            [2.076849673684159, 49.008758338824066],
                            [2.076222676868701, 49.00831292608526],
                            [2.075781639490159, 49.007996419607124],
                            [2.075451078094127, 49.007718707469216],
                            [2.075204955924964, 49.00747830678062],
                            [2.07499781579557, 49.00725369835747],
                            [2.074657427800449, 49.00678394888684],
                            [2.074485307217486, 49.006503742975994],
                            [2.074309604877165, 49.00608076712318],
                            [2.074162523075132, 49.00558076527068],
                            [2.074030747357509, 49.005059384276294],
                            [2.073716481743821, 49.00376096466016],
                            [2.073429580264889, 49.00241273144675],
                            [2.07325750151566, 49.00144869858747],
                            [2.073215749962943, 49.00113928519475],
                            [2.073192146383295, 49.000818019277744],
                            [2.073186608046316, 49.000499173307894],
                            [2.073199200594691, 49.000170851441],
                            [2.073237048850749, 48.999854485090616],
                            [2.073335872003388, 48.99895055781028],
                            [2.073460933092811, 48.99787299977956],
                            [2.073491870111239, 48.99749475389755],
                            [2.073490137244347, 48.99714022647409],
                            [2.07346699947166, 48.99673092480324],
                            [2.073422495840522, 48.996259710725255],
                            [2.073323246594915, 48.99520304972357],
                            [2.073289442036999, 48.99476041083592],
                            [2.073298849596716, 48.99435118328295],
                            [2.073329785666087, 48.993972937982306],
                            [2.073529193326251, 48.992510095715815],
                            [2.073620620466596, 48.99189837244827],
                            [2.073694140143433, 48.99140645440052],
                            [2.073769886475506, 48.99101254867934],
                        ],
                    },
                },
                1282: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.982797574591515, 2.2636157549922533],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1016.7562533,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25747415725031,
                            48.98091190326584,
                            2.269851993930268,
                            48.98500470125915,
                        ),
                        "coordinates": [
                            [2.269851993930268, 48.98091190326584],
                            [2.26954526509951, 48.98096437982222],
                            [2.269004726617549, 48.98105798659492],
                            [2.268027562605059, 48.981275029387575],
                            [2.267747367056282, 48.98135669483977],
                            [2.266934115114945, 48.98159361082247],
                            [2.266826128905727, 48.98163041570474],
                            [2.266060654556562, 48.981888936410705],
                            [2.26429179731313, 48.98251102926852],
                            [2.263314407492389, 48.982847635066406],
                            [2.261622025452842, 48.983449052471265],
                            [2.261108001244041, 48.9836411590941],
                            [2.260894732323527, 48.983721952743366],
                            [2.258429804144584, 48.984645647981104],
                            [2.257613609603145, 48.984951740311374],
                            [2.25747415725031, 48.98500470125915],
                        ],
                    },
                },
                1283: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.043392756550006, 2.103670178900755],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 764.663069972,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.101108482966614,
                            49.03998130935,
                            2.104731441997329,
                            49.04564873988319,
                        ),
                        "coordinates": [
                            [2.10385269644926, 49.03998130935],
                            [2.103894189299988, 49.04009281176542],
                            [2.104617380681375, 49.042108982759835],
                            [2.104712051825991, 49.042455076590976],
                            [2.104731441997329, 49.04269636039878],
                            [2.104715623143703, 49.04286065821373],
                            [2.104663251189402, 49.04323555124596],
                            [2.104510836788841, 49.04364891068721],
                            [2.104470811492738, 49.04372436904673],
                            [2.104425213185352, 49.043821398638705],
                            [2.104288923849149, 49.04400457451242],
                            [2.103932572712254, 49.04443910203954],
                            [2.103419400678432, 49.0448144563268],
                            [2.103049885721393, 49.04501560498302],
                            [2.102701012760657, 49.045180900076154],
                            [2.102311313653998, 49.04531919116353],
                            [2.101607349709782, 49.04551964999514],
                            [2.101108482966614, 49.04564873988319],
                        ],
                    },
                },
                1284: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.862201073048624, 2.319827743022051],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 908.172241182,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313911078550822,
                            48.86070823076494,
                            2.325620298740735,
                            48.86292653482459,
                        ),
                        "coordinates": [
                            [2.325620298740735, 48.86070823076494],
                            [2.323709575459263, 48.861292826998735],
                            [2.321967566504392, 48.86181419893328],
                            [2.319849294634563, 48.86246678387875],
                            [2.319483982102736, 48.86256115428689],
                            [2.319069606109598, 48.862642926040046],
                            [2.318773818382617, 48.862694138845036],
                            [2.318452467654884, 48.86274912201002],
                            [2.318067779408485, 48.86280320291549],
                            [2.317708743931849, 48.862836984827986],
                            [2.317262195350424, 48.862867455080995],
                            [2.316635205737553, 48.86289792322617],
                            [2.316226650592367, 48.86291046218402],
                            [2.315702904868771, 48.86292653482459],
                            [2.314750174799847, 48.86292006267417],
                            [2.313911078550822, 48.8629018908629],
                        ],
                    },
                },
                1285: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.90712643463097, 2.281447637918914],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 450.365738606,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.279278948726629,
                            48.90570604953261,
                            2.283628702682815,
                            48.908565915509755,
                        ),
                        "coordinates": [
                            [2.283628702682815, 48.90570604953261],
                            [2.283600782032804, 48.905721936264776],
                            [2.282318556436694, 48.9065398258799],
                            [2.28164308646769, 48.90699395643027],
                            [2.281184347458327, 48.907293531361624],
                            [2.280819511455299, 48.907539614892606],
                            [2.280186463797945, 48.90796168102705],
                            [2.279278948726629, 48.908565915509755],
                        ],
                    },
                },
                1286: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.956004681840064, 1.8279231039297072],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 4206.13014073,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.809094508773784,
                            48.93871923993318,
                            1.840517029657971,
                            48.96402029406584,
                        ),
                        "coordinates": [
                            [1.840517029657971, 48.93871923993318],
                            [1.839259456119651, 48.94106112942705],
                            [1.839107683302341, 48.94135723598351],
                            [1.838520471447111, 48.94246350831057],
                            [1.838257589751843, 48.94294708135568],
                            [1.837917818636616, 48.943473485196535],
                            [1.837643696575598, 48.94385179147729],
                            [1.837324203219214, 48.94426137330424],
                            [1.837253646103172, 48.944353692996536],
                            [1.836736138239635, 48.9450384910066],
                            [1.836364629118505, 48.94559532762359],
                            [1.836343805211657, 48.94562941031768],
                            [1.836327122982816, 48.94565901400366],
                            [1.836197924442457, 48.94587967404183],
                            [1.835901999807183, 48.94638648009117],
                            [1.835687619467646, 48.94679471950965],
                            [1.835485103516853, 48.94724437875692],
                            [1.835377351175946, 48.947503801768036],
                            [1.835280583184135, 48.947756979290695],
                            [1.835080565590898, 48.94836402439362],
                            [1.834803321403501, 48.94931606064913],
                            [1.834378140809992, 48.950717991784316],
                            [1.834202786215099, 48.95131435306057],
                            [1.834051651156718, 48.95181099933344],
                            [1.833986956337929, 48.951996869056266],
                            [1.833690264508096, 48.952842699291516],
                            [1.833037119046262, 48.95476881174423],
                            [1.833028624850475, 48.954798450395934],
                            [1.832719100073569, 48.95569458267156],
                            [1.832702220751264, 48.95574307069489],
                            [1.832681079540156, 48.95580772687732],
                            [1.832582642236807, 48.956087872501264],
                            [1.832289121744022, 48.957020045691515],
                            [1.832227033941579, 48.957216717623034],
                            [1.831973144805372, 48.95780227457157],
                            [1.831814951212435, 48.95812318663324],
                            [1.831566309802636, 48.95853486470205],
                            [1.831366522005625, 48.95884244002127],
                            [1.830930875208208, 48.95937829147739],
                            [1.830513697545098, 48.959843179464144],
                            [1.83041992769994, 48.95993179448333],
                            [1.829977234340759, 48.96035340112891],
                            [1.829453775254138, 48.960792634183875],
                            [1.8293779933736, 48.960857945936716],
                            [1.828791907114133, 48.96127711378623],
                            [1.827900609028269, 48.96182441486179],
                            [1.827302515207834, 48.96214819875789],
                            [1.826443219507783, 48.96256973336008],
                            [1.826328009966394, 48.96261688194734],
                            [1.825942562321888, 48.962778832278936],
                            [1.825778066660629, 48.96283745079758],
                            [1.825222869250805, 48.96303730978066],
                            [1.824389860641312, 48.96329077888374],
                            [1.823769628122923, 48.96343907963246],
                            [1.82317407843752, 48.96357759546599],
                            [1.822212088636071, 48.96375492857831],
                            [1.821887795089493, 48.96381282201855],
                            [1.821162938189798, 48.963907579271016],
                            [1.820826650049974, 48.96393663804808],
                            [1.820572389508032, 48.96395797343079],
                            [1.819983363908843, 48.96399308292943],
                            [1.819040677367278, 48.96402029406584],
                            [1.818453476307409, 48.96401133862653],
                            [1.817768008052001, 48.96399563961877],
                            [1.81649320302604, 48.9639143051651],
                            [1.815836663654982, 48.963875344154495],
                            [1.814911934161123, 48.963825577806084],
                            [1.813387699003068, 48.963666453558346],
                            [1.812083086767916, 48.96355179040191],
                            [1.811029724209674, 48.96347807079743],
                            [1.809279551877828, 48.963355057024316],
                            [1.809094508773784, 48.96334411275807],
                        ],
                    },
                },
                1287: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.06838299808802, 2.0409335435768825],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 2911.20726257,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.024952931375388,
                            49.062969678597184,
                            2.057902989161614,
                            49.07584288482138,
                        ),
                        "coordinates": [
                            [2.057902989161614, 49.062969678597184],
                            [2.057205435039614, 49.06310748599954],
                            [2.057120496395169, 49.063123465723514],
                            [2.054783068771868, 49.063605147499324],
                            [2.053849921717859, 49.06381148035727],
                            [2.052556455010289, 49.06408525862717],
                            [2.051172463791482, 49.064391169915474],
                            [2.050921685924129, 49.064448997786755],
                            [2.050181820299791, 49.0645955312425],
                            [2.049347347863518, 49.06477149914066],
                            [2.047586600542613, 49.06513937127203],
                            [2.047422174471494, 49.06517312906096],
                            [2.046887764902816, 49.06528688680347],
                            [2.045944995656484, 49.06548953381973],
                            [2.045876477505629, 49.06550464775561],
                            [2.045814819491, 49.06551708162601],
                            [2.045757270916986, 49.06552862550805],
                            [2.045661343940765, 49.065549965407136],
                            [2.044519884216904, 49.06579256307055],
                            [2.043267450714418, 49.066052852210504],
                            [2.042971502471737, 49.06610874825014],
                            [2.04215742272278, 49.06629910463407],
                            [2.041458336049697, 49.06648345701655],
                            [2.040882491563617, 49.06665553290175],
                            [2.040307862077174, 49.06685278823817],
                            [2.039860653122866, 49.06702609150031],
                            [2.039332379916411, 49.06725134078556],
                            [2.038797112445411, 49.06750084913709],
                            [2.038394888580283, 49.06770214126712],
                            [2.038217756515477, 49.067797903156674],
                            [2.038037875414937, 49.06789545558304],
                            [2.037792011430823, 49.06804049814144],
                            [2.037231504589459, 49.068387055897055],
                            [2.0371971416056, 49.06841124718697],
                            [2.036817822889324, 49.068670147302484],
                            [2.036234792039568, 49.06911736070743],
                            [2.036071074783365, 49.06925631976059],
                            [2.035720173531614, 49.06956654987718],
                            [2.035359445375408, 49.069916321865136],
                            [2.035242341170245, 49.070041913066525],
                            [2.035121113477004, 49.070170191141756],
                            [2.034791912703301, 49.07051105058178],
                            [2.034705042639174, 49.07061603768989],
                            [2.034656803103365, 49.07067076717141],
                            [2.034640322742302, 49.0706797158915],
                            [2.034349648213344, 49.07098650405376],
                            [2.033814828718146, 49.071599300280944],
                            [2.03368526026093, 49.07174733903692],
                            [2.033557075674022, 49.07189268395114],
                            [2.033500604872891, 49.0719500884096],
                            [2.033305031494602, 49.072147412855344],
                            [2.033263682905267, 49.072194065619136],
                            [2.033074829628442, 49.07241119119755],
                            [2.03275657185958, 49.07274847731178],
                            [2.032493557737728, 49.07300497384018],
                            [2.032354537774643, 49.07313050422791],
                            [2.032336637923809, 49.07314754304051],
                            [2.032274700259945, 49.07320313321975],
                            [2.032027114927031, 49.07339851874485],
                            [2.031490890576868, 49.073786480959185],
                            [2.031389205735461, 49.07385005901195],
                            [2.031198205586153, 49.0739691542722],
                            [2.031031998230004, 49.07406313557223],
                            [2.030839677767924, 49.07417413304975],
                            [2.030806726548958, 49.07419023197307],
                            [2.030500516593177, 49.07434588935578],
                            [2.030151859623305, 49.074503231135495],
                            [2.029563235218527, 49.0747282734898],
                            [2.02931356936107, 49.07481483443857],
                            [2.028164438152646, 49.0751426825309],
                            [2.027561250076705, 49.075285841577525],
                            [2.026405956171413, 49.075527601465666],
                            [2.024962411214713, 49.07584085219244],
                            [2.024952931375388, 49.07584288482138],
                        ],
                    },
                },
                1288: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.757009712671305, 2.7075015080368647],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 3959.72058976,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.690252782195758,
                            48.746452320704556,
                            2.727229371429766,
                            48.7707789170597,
                        ),
                        "coordinates": [
                            [2.690252782195758, 48.7707789170597],
                            [2.690615889290086, 48.769940835223],
                            [2.690729793084868, 48.76969677569629],
                            [2.690987161491167, 48.76915730509382],
                            [2.691269192052953, 48.76864293667765],
                            [2.691314920614938, 48.76856905329303],
                            [2.691530277414749, 48.76824464089754],
                            [2.69157602332934, 48.768173455628805],
                            [2.691873815347791, 48.767772346862145],
                            [2.692236551196859, 48.76732247367335],
                            [2.69229198639094, 48.76727463895363],
                            [2.692705248860715, 48.7668524842858],
                            [2.692898498261289, 48.7666729233405],
                            [2.693993282060074, 48.76568028549119],
                            [2.695088021496021, 48.764687637641586],
                            [2.69618272358617, 48.76369587831255],
                            [2.69649084331991, 48.76341522988909],
                            [2.696942132116895, 48.76299383857648],
                            [2.697536815646411, 48.762464078978034],
                            [2.698996254566406, 48.76113840251165],
                            [2.700456974319795, 48.759812701986746],
                            [2.701917625946819, 48.758488779995126],
                            [2.702451266301405, 48.7579960591422],
                            [2.703093193347397, 48.75743374270838],
                            [2.703319830647944, 48.75724425780272],
                            [2.703527153059137, 48.757075330793334],
                            [2.703744879687559, 48.75690556398346],
                            [2.703986718807794, 48.756724265870304],
                            [2.704204698832289, 48.7565747966186],
                            [2.704751744428931, 48.756221558238586],
                            [2.705086281766097, 48.75603162778799],
                            [2.705404615425643, 48.755857935676644],
                            [2.705800548050763, 48.755652209918416],
                            [2.706191859543786, 48.755458801428034],
                            [2.706576874852881, 48.75529118466451],
                            [2.70705152784528, 48.755107088157935],
                            [2.707453031954326, 48.75496279644915],
                            [2.708363377923608, 48.75466126871188],
                            [2.709056379573694, 48.754449502551324],
                            [2.709725747885977, 48.754244944818076],
                            [2.710680741315084, 48.75395035050859],
                            [2.711716287896599, 48.75362959572182],
                            [2.713496581181229, 48.75309404421522],
                            [2.715565775504662, 48.75246128074907],
                            [2.716406965317591, 48.752198587876734],
                            [2.717297001441261, 48.751922235623766],
                            [2.718108350606253, 48.751672219965215],
                            [2.71881928607652, 48.75145221041933],
                            [2.719348398848898, 48.7512867656579],
                            [2.719609977247488, 48.75120582612548],
                            [2.719857075515036, 48.751116889565886],
                            [2.72018120294589, 48.75099979169586],
                            [2.720501551324978, 48.75087948398938],
                            [2.720804721319064, 48.75075863158059],
                            [2.721076045181154, 48.750646954448484],
                            [2.72135792661464, 48.750519204572996],
                            [2.721623528244793, 48.75039690337546],
                            [2.721928336372062, 48.75024479376514],
                            [2.722214041839074, 48.750084653951056],
                            [2.722469946732394, 48.74993990235693],
                            [2.722935606420231, 48.74966224448177],
                            [2.723204908727744, 48.749492265079994],
                            [2.724063811154212, 48.74889582039618],
                            [2.724361236708088, 48.74867088623932],
                            [2.725539857056865, 48.747748700286664],
                            [2.725819641427011, 48.747530117477375],
                            [2.726244071081227, 48.74720222723106],
                            [2.727229371429766, 48.746452320704556],
                        ],
                    },
                },
                1289: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.87654430546382, 1.8746361954415827],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 3763.39871863,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.871738475714576,
                            48.85999873043875,
                            1.876621027777829,
                            48.893238595694605,
                        ),
                        "coordinates": [
                            [1.875595590302068, 48.85999873043875],
                            [1.874880820213616, 48.86244429064873],
                            [1.874580974869085, 48.863468270304544],
                            [1.874283843954937, 48.864492259515984],
                            [1.874183412365938, 48.8648848434657],
                            [1.874111886872333, 48.865246968269304],
                            [1.874074818909281, 48.86571445051405],
                            [1.874086586387671, 48.866207310000384],
                            [1.874135124085862, 48.86655733182802],
                            [1.874217791610205, 48.866902095563844],
                            [1.874323731208806, 48.8672361619518],
                            [1.874414178336782, 48.867477538316244],
                            [1.874535725449866, 48.86774602001969],
                            [1.874688400167162, 48.86803890809279],
                            [1.874868079522875, 48.868359782827206],
                            [1.875343338755898, 48.86914588782847],
                            [1.875661292764052, 48.869697538916235],
                            [1.875882416828523, 48.870107610418955],
                            [1.875976285955063, 48.87027525713336],
                            [1.876093784683952, 48.870541022702206],
                            [1.876176600246217, 48.870724812156496],
                            [1.876309517011832, 48.87109225994167],
                            [1.876376764341849, 48.87133803804185],
                            [1.876425577564684, 48.87151359684397],
                            [1.876466395389776, 48.87166933872067],
                            [1.876545859990483, 48.872068045523136],
                            [1.876567410917636, 48.87224349395396],
                            [1.876586392538174, 48.87240184584358],
                            [1.876598700597584, 48.872544883063846],
                            [1.876619542662846, 48.87279676915366],
                            [1.876621027777829, 48.87293076921606],
                            [1.876620028281249, 48.8730386804738],
                            [1.876585927458329, 48.87362937845243],
                            [1.876525525666442, 48.874115652027186],
                            [1.876203590550863, 48.87545969493346],
                            [1.87609168511961, 48.87591248694666],
                            [1.875933096011904, 48.8765476461318],
                            [1.875875028707326, 48.8767812279449],
                            [1.875735953892318, 48.87736970308648],
                            [1.875718884625771, 48.8774460741056],
                            [1.875461207272405, 48.878472923773025],
                            [1.875321001136322, 48.87903531445905],
                            [1.874990452540816, 48.88041888871282],
                            [1.874777696210153, 48.88130383044288],
                            [1.874692985675026, 48.881615542353664],
                            [1.874412000536258, 48.88279787424524],
                            [1.873883280038885, 48.88495583203371],
                            [1.873516619753718, 48.88640130698061],
                            [1.873086913904117, 48.88817026990819],
                            [1.872724878826941, 48.889661283870936],
                            [1.872657170238704, 48.8899401304465],
                            [1.87222602216343, 48.89171088381271],
                            [1.872009582966879, 48.8925418488953],
                            [1.8718654852751, 48.89292885676782],
                            [1.871738475714576, 48.893238595694605],
                        ],
                    },
                },
                1290: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.70857323368284, 1.8721225754551571],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 4084.99966675,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.85659206528713,
                            48.69309659121679,
                            1.890004563697985,
                            48.72191596105865,
                        ),
                        "coordinates": [
                            [1.85659206528713, 48.69309659121679],
                            [1.856715398503036, 48.69345196258986],
                            [1.856799946512059, 48.69369962214961],
                            [1.857277685985409, 48.69501099590093],
                            [1.857507784225903, 48.69551830749273],
                            [1.857753066602306, 48.69603948180251],
                            [1.858030526563277, 48.69653575647938],
                            [1.858262072372782, 48.696896444672134],
                            [1.858442917149364, 48.697161594401486],
                            [1.858730317708505, 48.69757590145742],
                            [1.859003393662899, 48.69796012582615],
                            [1.859244743253453, 48.69827997358976],
                            [1.859440144657987, 48.69851872870949],
                            [1.859750937344423, 48.69888292086132],
                            [1.860112396605303, 48.699299005778514],
                            [1.860648986307845, 48.69987049879539],
                            [1.861172491947406, 48.70039157634829],
                            [1.861697736142728, 48.70087398867113],
                            [1.862232750374959, 48.70133036004215],
                            [1.862781478892719, 48.701774196723605],
                            [1.864799002836341, 48.70335363345357],
                            [1.865029637383951, 48.70353264863516],
                            [1.865365446260445, 48.703796631668055],
                            [1.866569838035721, 48.70473956896716],
                            [1.867022941689387, 48.7051020537334],
                            [1.869610704020809, 48.70713140426907],
                            [1.87068369324005, 48.7079633431826],
                            [1.871297369540176, 48.70845236829666],
                            [1.872929590574994, 48.709732420126194],
                            [1.873113045264286, 48.70987705304943],
                            [1.875622239556932, 48.711846790073906],
                            [1.876220046429648, 48.71229885351404],
                            [1.876464352393001, 48.712477900387846],
                            [1.876649335188688, 48.71260634668252],
                            [1.879687442676669, 48.71472381395895],
                            [1.879841369904282, 48.71483234560751],
                            [1.881241773766145, 48.7157992943732],
                            [1.882713742400859, 48.71682316600738],
                            [1.883287686057122, 48.717222938365225],
                            [1.883992701473626, 48.71770686229569],
                            [1.884310062671973, 48.71792844860221],
                            [1.885294539118915, 48.71862031034604],
                            [1.885965690491573, 48.7190959940718],
                            [1.888508517925195, 48.720867321760046],
                            [1.890004563697985, 48.72191596105865],
                        ],
                    },
                },
                1291: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.85930191161588, 2.3136515167449905],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 754.010440212,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.310565960946846,
                            48.85772541289345,
                            2.315138432191171,
                            48.86232532909372,
                        ),
                        "coordinates": [
                            [2.315138432191171, 48.86232532909372],
                            [2.315138194839405, 48.862323475973604],
                            [2.314898977048293, 48.860457313532464],
                            [2.314679029222253, 48.85874135077287],
                            [2.314675932676777, 48.85872216782571],
                            [2.314659513642972, 48.8586664542018],
                            [2.314632433633713, 48.85861258344489],
                            [2.314595134914216, 48.858561440346456],
                            [2.314548232081611, 48.858513863916784],
                            [2.314492491772773, 48.85847063557789],
                            [2.314428832841195, 48.858432465674994],
                            [2.31435830063897, 48.858399979839994],
                            [2.314282049370406, 48.858373713494935],
                            [2.314201335492125, 48.8583540956269],
                            [2.314117482267401, 48.85834144948495],
                            [2.314031864895724, 48.85833598350183],
                            [2.313968476665885, 48.85833660581149],
                            [2.312200603210059, 48.8584091478726],
                            [2.312119519254238, 48.85841080067852],
                            [2.311999584372278, 48.85840711724327],
                            [2.311880676678383, 48.858396145836764],
                            [2.311763810367809, 48.858377983129266],
                            [2.31164998254076, 48.858352781456304],
                            [2.311540164904576, 48.858320757764425],
                            [2.311435294350794, 48.858282184562874],
                            [2.311336264764424, 48.85823739077541],
                            [2.311243921606659, 48.8581867590105],
                            [2.311184306458484, 48.858148497312335],
                            [2.310565960946846, 48.85772541289345],
                        ],
                    },
                },
                1292: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.587632417399725, 2.2541755974922735],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2059.41739555,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.241070080902974,
                            48.58564905652479,
                            2.266937972614161,
                            48.591460820223375,
                        ),
                        "coordinates": [
                            [2.241070080902974, 48.58600789080001],
                            [2.242084455186498, 48.58594756803607],
                            [2.243244380386634, 48.58588191019452],
                            [2.24518763061134, 48.585766910831964],
                            [2.245980996473156, 48.58571924839891],
                            [2.246327467778501, 48.58569787421666],
                            [2.246809508060314, 48.585671609704285],
                            [2.247271452883254, 48.585651989014636],
                            [2.247778554485241, 48.58564905652479],
                            [2.248285616521396, 48.58566777339114],
                            [2.248692252093051, 48.5856930732241],
                            [2.248985920442405, 48.585719948270935],
                            [2.249246943696469, 48.58575179549462],
                            [2.249723790058498, 48.58582377888461],
                            [2.25020812668337, 48.58592074902591],
                            [2.250679882833715, 48.5860343627792],
                            [2.251118994081004, 48.58615627646565],
                            [2.251545529507748, 48.586291504017275],
                            [2.25192438989098, 48.586416700613796],
                            [2.253239129963109, 48.58684404584783],
                            [2.255933926869488, 48.58771539233423],
                            [2.26102017922893, 48.58935443041366],
                            [2.263203327353522, 48.59006037622496],
                            [2.264305584422156, 48.590417635461435],
                            [2.264839473848621, 48.59058772532614],
                            [2.265346363454804, 48.59076792003928],
                            [2.265707891162466, 48.59090682001625],
                            [2.266204508183534, 48.5911148827013],
                            [2.266704982341543, 48.59134178320871],
                            [2.266937972614161, 48.591460820223375],
                        ],
                    },
                },
                1293: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.862201073048624, 2.319827743022051],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 908.172241182,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313911078550822,
                            48.86070823076494,
                            2.325620298740735,
                            48.86292653482459,
                        ),
                        "coordinates": [
                            [2.325620298740735, 48.86070823076494],
                            [2.323709575459263, 48.861292826998735],
                            [2.321967566504392, 48.86181419893328],
                            [2.319849294634563, 48.86246678387875],
                            [2.319483982102736, 48.86256115428689],
                            [2.319069606109598, 48.862642926040046],
                            [2.318773818382617, 48.862694138845036],
                            [2.318452467654884, 48.86274912201002],
                            [2.318067779408485, 48.86280320291549],
                            [2.317708743931849, 48.862836984827986],
                            [2.317262195350424, 48.862867455080995],
                            [2.316635205737553, 48.86289792322617],
                            [2.316226650592367, 48.86291046218402],
                            [2.315702904868771, 48.86292653482459],
                            [2.314750174799847, 48.86292006267417],
                            [2.313911078550822, 48.8629018908629],
                        ],
                    },
                },
                1294: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.9429407406498, 2.3037045736209234],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2358.83064982,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.301294975906111,
                            48.93289616644866,
                            2.307943234074898,
                            48.95339646167632,
                        ),
                        "coordinates": [
                            [2.307943234074898, 48.93289616644866],
                            [2.307790373610745, 48.93320410885454],
                            [2.307700179597064, 48.93338933674383],
                            [2.307592219082522, 48.933610531607584],
                            [2.307231435003357, 48.9343478463323],
                            [2.306959967215049, 48.934914773842294],
                            [2.306942389887075, 48.934951480188985],
                            [2.306791361624463, 48.935266792095796],
                            [2.306211875969694, 48.936451885601386],
                            [2.305632363899749, 48.93763697590386],
                            [2.305054188036975, 48.93882296299697],
                            [2.304996778965808, 48.93893985323258],
                            [2.304909298806844, 48.93911878538438],
                            [2.304789010420524, 48.939366052886314],
                            [2.304164316422684, 48.940649143463794],
                            [2.303885466982651, 48.94119582386023],
                            [2.303633933861768, 48.94171193616121],
                            [2.303159550238386, 48.94270280078087],
                            [2.303096664922068, 48.94282957971184],
                            [2.303035148519818, 48.942950964551486],
                            [2.302854685341371, 48.943326808992296],
                            [2.302061722366169, 48.944958757593575],
                            [2.302058987723681, 48.94496415265967],
                            [2.302045313819851, 48.944993824036494],
                            [2.301755434922947, 48.94562502796113],
                            [2.301543394204471, 48.94621938486529],
                            [2.301418786496034, 48.9467319330652],
                            [2.301355724831788, 48.94709252378621],
                            [2.301322748803998, 48.94738387867186],
                            [2.301295098929685, 48.947861386022794],
                            [2.301294975906111, 48.948033147065296],
                            [2.301313813540341, 48.94841984144111],
                            [2.301364024439001, 48.94884791273588],
                            [2.30146468453999, 48.949374019617075],
                            [2.301580375162466, 48.949887541064854],
                            [2.301658725763627, 48.950268171329256],
                            [2.301768236604624, 48.950678961235134],
                            [2.301791371778074, 48.950786881701916],
                            [2.301894825858126, 48.95123565119294],
                            [2.301917970788922, 48.9513309817407],
                            [2.302083730736812, 48.95209563320852],
                            [2.302144981440925, 48.952331205612126],
                            [2.302191588827377, 48.952519007640106],
                            [2.302275983078653, 48.95289852691586],
                            [2.302335798780749, 48.95327803966121],
                            [2.30234042019572, 48.95339646167632],
                        ],
                    },
                },
                1295: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.90147276575291, 2.355625617093602],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 4528.30879744,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352105705816552,
                            48.880922006671476,
                            2.362665598830465,
                            48.9181138030661,
                        ),
                        "coordinates": [
                            [2.356328543670162, 48.880922006671476],
                            [2.356628054656908, 48.88155417154206],
                            [2.356799333165851, 48.881982196383895],
                            [2.356994235882585, 48.88246469507391],
                            [2.357153723092858, 48.882900503241956],
                            [2.357301391124828, 48.88328961735871],
                            [2.357460898560597, 48.88376044832461],
                            [2.357638214045052, 48.88448421689481],
                            [2.357732877413799, 48.885091258325765],
                            [2.35776859674016, 48.88584618505727],
                            [2.357768158187986, 48.885851004895414],
                            [2.35771581244326, 48.886426164530604],
                            [2.357672776648871, 48.88704955877387],
                            [2.357622547948076, 48.88773481642559],
                            [2.357514564652608, 48.88836298218558],
                            [2.357406615422702, 48.88907680292586],
                            [2.35732021320441, 48.88955268597487],
                            [2.357212161668813, 48.89002857305947],
                            [2.35702476399322, 48.890604406366215],
                            [2.356866168146696, 48.89102319759584],
                            [2.356671515411152, 48.89151813463572],
                            [2.356188407767444, 48.89257940363092],
                            [2.355726862337239, 48.893459837040616],
                            [2.355279785936971, 48.894483026670464],
                            [2.354955332043211, 48.89535391720402],
                            [2.354760668682024, 48.89592023004912],
                            [2.354573252941464, 48.89658647405615],
                            [2.354400303679799, 48.89735264752717],
                            [2.354321102683396, 48.89790466678896],
                            [2.354243027550289, 48.89844847923835],
                            [2.354148424680226, 48.89948338357097],
                            [2.353906105047874, 48.90043998621057],
                            [2.353278831413479, 48.90253866092549],
                            [2.352860729356008, 48.90428515788201],
                            [2.352396188268603, 48.90767816593894],
                            [2.352342196388262, 48.90815880031198],
                            [2.352273798625216, 48.90875602475913],
                            [2.352210056592285, 48.90957789507191],
                            [2.352177649040248, 48.909832489206664],
                            [2.352152445463866, 48.91004187447977],
                            [2.352130844433447, 48.910232225568045],
                            [2.352109255641117, 48.91045588612407],
                            [2.352105705816552, 48.91065337184244],
                            [2.352123814122804, 48.91085323371987],
                            [2.352174431988979, 48.91111495570954],
                            [2.352253936570604, 48.91140760357833],
                            [2.352383984953965, 48.91172165915649],
                            [2.352510404644672, 48.911959574937896],
                            [2.352672926938664, 48.91221890023702],
                            [2.352806550119313, 48.91240209040332],
                            [2.352958591601471, 48.91258752650817],
                            [2.35307378633796, 48.912728022078205],
                            [2.353250726293694, 48.91290168899872],
                            [2.353413217384326, 48.913042045626646],
                            [2.353608203857694, 48.913194294391865],
                            [2.353886235519248, 48.91339411698931],
                            [2.354084823170449, 48.91351543297699],
                            [2.354352010214886, 48.913665290853174],
                            [2.354843052535474, 48.91391266391197],
                            [2.355391879240095, 48.91421237233093],
                            [2.356077914021508, 48.91457153659441],
                            [2.357258650022995, 48.915211372236534],
                            [2.359176046589199, 48.916226987040226],
                            [2.361057416606341, 48.91723781822859],
                            [2.362665598830465, 48.9181138030661],
                        ],
                    },
                },
                1296: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.85625666969062, 2.5010905221864506],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2153.62375534,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.488187573818578,
                            48.853485712976834,
                            2.513825291026663,
                            48.85748217116617,
                        ),
                        "coordinates": [
                            [2.513825291026663, 48.853485712976834],
                            [2.513573333400054, 48.853790580716385],
                            [2.513469923351217, 48.853912087437266],
                            [2.513129442358261, 48.854288074605044],
                            [2.512868560922781, 48.85453973540208],
                            [2.512702519959024, 48.85469274568056],
                            [2.512465186832828, 48.85487441769676],
                            [2.512158707539135, 48.855080464521635],
                            [2.511849982529234, 48.85526367074792],
                            [2.511551960960545, 48.85541545377298],
                            [2.511329507568344, 48.85552429276243],
                            [2.511135098106737, 48.85561024531305],
                            [2.51089098958607, 48.855713405611844],
                            [2.51071814929127, 48.85578076636994],
                            [2.510435081022387, 48.8558797014097],
                            [2.510115243370091, 48.85598154749842],
                            [2.50983642062207, 48.85605763280859],
                            [2.509680320999127, 48.85609501642379],
                            [2.509503519546586, 48.85613665428845],
                            [2.509326262758616, 48.85617378883469],
                            [2.509188705927963, 48.856199176918174],
                            [2.508883620329728, 48.85625269399726],
                            [2.508551267012747, 48.8563035531859],
                            [2.50800775544986, 48.85637721045348],
                            [2.50728088675139, 48.85647588994729],
                            [2.506430327369622, 48.85658819520841],
                            [2.505824143476159, 48.856669128595655],
                            [2.505117173264605, 48.85676909303348],
                            [2.504143173348377, 48.85689552260271],
                            [2.503565583264654, 48.85697100692557],
                            [2.50236408968383, 48.85713012767741],
                            [2.501572636799188, 48.857238286024796],
                            [2.500914679499759, 48.85732826097013],
                            [2.500263601695035, 48.857400721235884],
                            [2.499665348664538, 48.857450552051745],
                            [2.498932240770595, 48.85748217116617],
                            [2.498389827605251, 48.85748204093932],
                            [2.497993199660516, 48.85747001192838],
                            [2.497404353551471, 48.85744026597355],
                            [2.496863129714263, 48.85738617081192],
                            [2.496350500902195, 48.8573239385214],
                            [2.495858270035858, 48.85724728812711],
                            [2.49527003265719, 48.857137491260204],
                            [2.494884563600606, 48.85704630231072],
                            [2.494394895440402, 48.856916583979135],
                            [2.493821966377656, 48.856745611301974],
                            [2.493314454144088, 48.85657364747983],
                            [2.492917590651718, 48.856423906325944],
                            [2.492583228547638, 48.85628490168527],
                            [2.492218680103453, 48.85611651246806],
                            [2.491854246271819, 48.85593535376134],
                            [2.491413313602603, 48.85569494491585],
                            [2.490980521851251, 48.85544193417205],
                            [2.490585951959958, 48.855207754825614],
                            [2.49016134351068, 48.85495382970485],
                            [2.489269851012548, 48.854431644041746],
                            [2.48925210176109, 48.8544208769105],
                            [2.489183839586367, 48.85438050007056],
                            [2.489144248374941, 48.85435717210593],
                            [2.489093735538042, 48.85432756325982],
                            [2.489021377377017, 48.854284494191916],
                            [2.488988613808476, 48.85426565336587],
                            [2.488842538522023, 48.85418041668119],
                            [2.488696465799935, 48.85409607826304],
                            [2.488517622728362, 48.853990201541755],
                            [2.488187573818578, 48.85379557653064],
                        ],
                    },
                },
                1297: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84903835650511, 2.5197404801523375],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1319.17687818,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.513825291026663,
                            48.844901139612055,
                            2.525922546560017,
                            48.853485712976834,
                        ),
                        "coordinates": [
                            [2.525922546560017, 48.844901139612055],
                            [2.524740876082093, 48.84601819039543],
                            [2.524451629186985, 48.84627675945228],
                            [2.524228858677104, 48.84645877904797],
                            [2.523874221501914, 48.84672195022929],
                            [2.523781808928433, 48.84678595035746],
                            [2.523600687496387, 48.84690925347037],
                            [2.523403939932178, 48.84703207135975],
                            [2.523065386736493, 48.84722596911878],
                            [2.522892694440555, 48.84732067498281],
                            [2.522495573865072, 48.84752186054224],
                            [2.521687709791768, 48.847927846994665],
                            [2.520828150866766, 48.84835998963751],
                            [2.519138923006767, 48.84921251745475],
                            [2.518694158912997, 48.84943534822823],
                            [2.518039043943425, 48.84977342997996],
                            [2.517445714247184, 48.85011088941467],
                            [2.517039219949522, 48.85036962432718],
                            [2.516668113317061, 48.85061841014801],
                            [2.516426212863923, 48.85079954598965],
                            [2.516128638587414, 48.85103562453894],
                            [2.515962862848575, 48.85116628046753],
                            [2.515744138977678, 48.85135187492388],
                            [2.515483368115688, 48.85159239058377],
                            [2.515382891147006, 48.851693266648425],
                            [2.515237572651516, 48.85183018464216],
                            [2.51509505755124, 48.85198868001838],
                            [2.51481631041066, 48.85231250279663],
                            [2.514432830651162, 48.852764890564366],
                            [2.514206199220612, 48.85302963056807],
                            [2.514070494422291, 48.853189013796815],
                            [2.513825291026663, 48.853485712976834],
                        ],
                    },
                },
                1298: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.86045276179413, 2.2736420038232623],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 932.361874381,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272120621598503,
                            48.8565315515406,
                            2.27516715468514,
                            48.86446175107751,
                        ),
                        "coordinates": [
                            [2.27516715468514, 48.8565315515406],
                            [2.275127581654939, 48.85657289637881],
                            [2.274911974657924, 48.856797598953634],
                            [2.274714017434229, 48.857075367707694],
                            [2.274571983031301, 48.8573135984634],
                            [2.274505045217647, 48.85744036010534],
                            [2.27445857531699, 48.857545549685206],
                            [2.274436700562293, 48.857600393912705],
                            [2.274410722392584, 48.857667824949914],
                            [2.274377906466341, 48.85775323854759],
                            [2.274331269945568, 48.857990621846746],
                            [2.274312071537305, 48.85808413575567],
                            [2.274330895518769, 48.85828828177093],
                            [2.274406751583312, 48.85865702678876],
                            [2.2745030713875, 48.85901139356529],
                            [2.274541010887684, 48.85918767267281],
                            [2.274565205829267, 48.85945656869903],
                            [2.274540482814241, 48.85960853328147],
                            [2.274498071642023, 48.8597371062693],
                            [2.274428352062174, 48.85990433346786],
                            [2.274321813228827, 48.860088626557165],
                            [2.274239895461006, 48.86020189111965],
                            [2.274119765810449, 48.86035380299627],
                            [2.274046047027673, 48.8604490850527],
                            [2.273893151057292, 48.86064414414644],
                            [2.273796225290937, 48.86076819050592],
                            [2.273704758567289, 48.860885945639666],
                            [2.273646056813958, 48.86096145179053],
                            [2.273273355228753, 48.861443257152736],
                            [2.273090454216617, 48.86164998906515],
                            [2.272692143198706, 48.8621917838564],
                            [2.272603290629512, 48.86238173519964],
                            [2.272455219402724, 48.86268370435763],
                            [2.272351534370337, 48.86292236511484],
                            [2.272269898210913, 48.86323898808757],
                            [2.272120938930815, 48.86421815969464],
                            [2.272120621598503, 48.86446175107751],
                        ],
                    },
                },
                1299: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.84180148400694, 2.6246544426011207],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 1380.1518069,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.615952488508274,
                            48.83921929995164,
                            2.633210913417633,
                            48.84352915249055,
                        ),
                        "coordinates": [
                            [2.633210913417633, 48.83921929995164],
                            [2.632776394167405, 48.83930998416797],
                            [2.631473748775691, 48.83958909898851],
                            [2.631018707055509, 48.83968734991612],
                            [2.630485995975711, 48.83981815920189],
                            [2.629994229207965, 48.83996554716127],
                            [2.629053373276544, 48.84029080309017],
                            [2.627615378873879, 48.84087451339819],
                            [2.62706084907302, 48.84110254390364],
                            [2.626522557892547, 48.841312545705115],
                            [2.625174209320764, 48.84185912675991],
                            [2.624293384380304, 48.84221027036676],
                            [2.623789098487805, 48.84241477800784],
                            [2.62291630295088, 48.84274430832581],
                            [2.622413100152527, 48.84290204322312],
                            [2.621919697938824, 48.843041542225194],
                            [2.621464682977642, 48.84315308049558],
                            [2.621087960445371, 48.84323358951462],
                            [2.620640781206775, 48.843309315178814],
                            [2.620127875273939, 48.84338482508764],
                            [2.61968308882556, 48.843443914243935],
                            [2.619384345889872, 48.84347613098236],
                            [2.619068917627176, 48.84349759257705],
                            [2.618639846172767, 48.843516638827346],
                            [2.618197092952864, 48.84352582445688],
                            [2.617575823186513, 48.84352915249055],
                            [2.616523858903287, 48.84350565511179],
                            [2.616105523028687, 48.843495888383586],
                            [2.615952488508274, 48.843491647846726],
                        ],
                    },
                },
                1300: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.85058881153491, 2.3461638208186684],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 295.82650798,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344273345421351,
                            48.850127322904584,
                            2.348054291858487,
                            48.851050282314304,
                        ),
                        "coordinates": [
                            [2.348054291858487, 48.850127322904584],
                            [2.345608321857364, 48.850724422752776],
                            [2.344273345421351, 48.851050282314304],
                        ],
                    },
                },
                1301: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.645351614736484, 2.307411639049155],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2066.85597679,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.305618513847831,
                            48.63587586133943,
                            2.312736251060262,
                            48.65281140144265,
                        ),
                        "coordinates": [
                            [2.312736251060262, 48.65281140144265],
                            [2.311434035743083, 48.652161697821754],
                            [2.311161595518889, 48.6520157161731],
                            [2.310773880653907, 48.65179435262542],
                            [2.310282075275412, 48.65148968842449],
                            [2.309905157465262, 48.65123739338836],
                            [2.309513900617501, 48.65094702475268],
                            [2.308695550578756, 48.65026396415496],
                            [2.308354595249252, 48.649947432901875],
                            [2.308045958245556, 48.64963804509417],
                            [2.307805508604246, 48.6494024323972],
                            [2.307547136214757, 48.64911922858859],
                            [2.307335429984876, 48.64885982948018],
                            [2.307188323680806, 48.64866468837927],
                            [2.307005358878571, 48.64838864007318],
                            [2.306614328612295, 48.64779133136349],
                            [2.3063561210502, 48.6472582976048],
                            [2.305983255727477, 48.646346922119776],
                            [2.305882926907937, 48.64601141233609],
                            [2.305761120993855, 48.645571207113846],
                            [2.305699667711305, 48.64525269049801],
                            [2.305650202835725, 48.64494898766603],
                            [2.305621792958605, 48.644445756042174],
                            [2.305618513847831, 48.643950858997094],
                            [2.3056367819289, 48.643446449839544],
                            [2.305741434903754, 48.64259230671794],
                            [2.305820799508666, 48.64195418536201],
                            [2.306083837795694, 48.640419602194584],
                            [2.306278577144555, 48.639001587767794],
                            [2.306502055920804, 48.63753361350995],
                            [2.30680878358536, 48.63603047056848],
                            [2.306833164014825, 48.63587586133943],
                        ],
                    },
                },
                1302: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.6803769899765, 2.325009400834563],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1574.54069322,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.31762640494754,
                            48.676381326172205,
                            2.333249457132578,
                            48.68571362817925,
                        ),
                        "coordinates": [
                            [2.31762640494754, 48.68571362817925],
                            [2.317792142143091, 48.68549491226578],
                            [2.317917195368779, 48.685330588465135],
                            [2.317955242307923, 48.68527933641483],
                            [2.318025900408485, 48.68518852152944],
                            [2.318202543452599, 48.684961935639386],
                            [2.318660418908339, 48.68445392235206],
                            [2.319028598491382, 48.68409247505133],
                            [2.319218800299125, 48.683906355616585],
                            [2.319786653577804, 48.68341993798818],
                            [2.320000218683265, 48.68323593657322],
                            [2.320427837264242, 48.682920937802926],
                            [2.32072396200351, 48.68272583896088],
                            [2.321189876027194, 48.682420152964944],
                            [2.322424582935043, 48.681636152897084],
                            [2.324087091277706, 48.68060758749037],
                            [2.325464316937487, 48.67973724088596],
                            [2.326655424701757, 48.679003550279134],
                            [2.327511031896385, 48.67854499609301],
                            [2.328166978540254, 48.678237497939705],
                            [2.328765875419987, 48.6779875448077],
                            [2.329413650235648, 48.677749282625044],
                            [2.330987559851962, 48.677221502370834],
                            [2.332160841780996, 48.67682317987782],
                            [2.332783482129072, 48.676590236454736],
                            [2.333083131159542, 48.676461763296835],
                            [2.333249457132578, 48.676381326172205],
                        ],
                    },
                },
                1303: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.84770558657781, 2.402790002828695],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 1101.48299925,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.395554512170688,
                            48.84715847940882,
                            2.41014036933673,
                            48.8481949975967,
                        ),
                        "coordinates": [
                            [2.41014036933673, 48.84715847940882],
                            [2.406322806489701, 48.84748774021236],
                            [2.405282347613104, 48.84757855087354],
                            [2.397972171083479, 48.848190251218085],
                            [2.397892382321705, 48.84819493914492],
                            [2.397783558736279, 48.8481949975967],
                            [2.397675285185727, 48.84818778924133],
                            [2.397568672806526, 48.84817338982437],
                            [2.397464815580022, 48.84815194425909],
                            [2.397364776600262, 48.848123675550575],
                            [2.397269585502539, 48.848088871291864],
                            [2.397180217949895, 48.848047889855955],
                            [2.397097591627042, 48.848001153179766],
                            [2.397022554090487, 48.84794913680968],
                            [2.396966425436333, 48.847902189126735],
                            [2.396949573949514, 48.84788714792833],
                            [2.396872706961453, 48.84782615387566],
                            [2.396787639500093, 48.84777010084677],
                            [2.396695099156426, 48.84771946735299],
                            [2.396595875380204, 48.847674684552636],
                            [2.396490814029592, 48.84763613622427],
                            [2.396380810673506, 48.84760414884054],
                            [2.396266805079931, 48.84757899693717],
                            [2.396149769057612, 48.84756089405859],
                            [2.396030702328815, 48.84754999633484],
                            [2.395910618998508, 48.847546394319366],
                            [2.39581854989216, 48.84754925162354],
                            [2.395790544737777, 48.84755012106935],
                            [2.395671504626308, 48.84756114309063],
                            [2.395554512170688, 48.84757936747707],
                        ],
                    },
                },
                1304: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.75023507331923, 1.9320404020357282],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 2159.61345089,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.921036600039739,
                            48.74348398592533,
                            1.943835201056777,
                            48.75538926869322,
                        ),
                        "coordinates": [
                            [1.921036600039739, 48.74348398592533],
                            [1.921104399376312, 48.74353070764457],
                            [1.922480849069239, 48.74449205095635],
                            [1.925482786858743, 48.74657553602807],
                            [1.926341367775977, 48.74717109459183],
                            [1.927094073911974, 48.74768951280347],
                            [1.927227903971078, 48.747786217832804],
                            [1.928782911692224, 48.74886374680436],
                            [1.929289397065046, 48.74920652016492],
                            [1.929740368712389, 48.74949841506701],
                            [1.930277289391478, 48.74984058153969],
                            [1.931004135825545, 48.7502785971665],
                            [1.931555755456535, 48.7505851200898],
                            [1.932336468804178, 48.751003296015405],
                            [1.932984983605017, 48.75134346644805],
                            [1.933665968600685, 48.751674230292544],
                            [1.934368572357154, 48.75200268784397],
                            [1.935666393459057, 48.7525925899884],
                            [1.936534101462431, 48.7529763409054],
                            [1.936953682370978, 48.7531538871283],
                            [1.937534710307975, 48.75339148243475],
                            [1.938072775914866, 48.75360275073602],
                            [1.938711425237457, 48.75383578305956],
                            [1.939251441959425, 48.75402920757684],
                            [1.939795156534861, 48.754210746059584],
                            [1.940624174605661, 48.75448963784716],
                            [1.941044181533461, 48.75461720403976],
                            [1.94161861687091, 48.75478337433597],
                            [1.942189438321365, 48.75495190961877],
                            [1.942749601657392, 48.75510374870748],
                            [1.943835201056777, 48.75538926869322],
                        ],
                    },
                },
                1305: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.80216172374766, 2.1835852912178235],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 912.986340232,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.178130972336866,
                            48.80066322078583,
                            2.188630276475413,
                            48.80468335617195,
                        ),
                        "coordinates": [
                            [2.178130972336866, 48.80066322078583],
                            [2.178829444870606, 48.80074746856324],
                            [2.179484646053586, 48.800848307096956],
                            [2.180395418194379, 48.8009994604146],
                            [2.180870559494049, 48.80109290627654],
                            [2.181241265784936, 48.80118144902706],
                            [2.181593965000977, 48.80126996535506],
                            [2.182000649095227, 48.80137283057331],
                            [2.182619617426564, 48.801547361657526],
                            [2.183263715791572, 48.80175047635265],
                            [2.18369906739649, 48.80190334016584],
                            [2.184022859062761, 48.802025121632084],
                            [2.184346637733814, 48.80215166090101],
                            [2.184663193889977, 48.80228532641381],
                            [2.18528884657049, 48.802585985680665],
                            [2.18617119065725, 48.803021992614916],
                            [2.186618693408936, 48.803266228377815],
                            [2.187022675207288, 48.80350363756777],
                            [2.187439361841892, 48.80377659275736],
                            [2.18767194257462, 48.80394609535828],
                            [2.188295526284685, 48.804415587530144],
                            [2.188630276475413, 48.80468335617195],
                        ],
                    },
                },
                1306: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.84143606879085, 2.2337041014010763],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 776.836466558,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.228536981491631,
                            48.84074501612617,
                            2.238887327153073,
                            48.84200534728956,
                        ),
                        "coordinates": [
                            [2.228536981491631, 48.84074501612617],
                            [2.231039802599657, 48.84127419718994],
                            [2.231269710056974, 48.84131453688036],
                            [2.231496356699666, 48.841339483944616],
                            [2.234632443658442, 48.84155124336475],
                            [2.236845107426112, 48.84163684853115],
                            [2.237065168934966, 48.84166084542485],
                            [2.237281264766935, 48.841687133416926],
                            [2.238585162868251, 48.841944727623385],
                            [2.238887327153073, 48.84200534728956],
                        ],
                    },
                },
                1307: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.868038370123635, 2.3244835887589343],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 474.303477125,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.323175680856619,
                            48.866167114949185,
                            2.325269410336215,
                            48.87009973284847,
                        ),
                        "coordinates": [
                            [2.323175680856619, 48.866167114949185],
                            [2.325156166494656, 48.868709707946266],
                            [2.325182888671519, 48.868748350528],
                            [2.325220471392366, 48.86881650154623],
                            [2.325247581326141, 48.868886784310014],
                            [2.325263946685696, 48.868958497604716],
                            [2.325269410336215, 48.86903092916808],
                            [2.32526391338146, 48.86910336009417],
                            [2.325253863010758, 48.86915253979929],
                            [2.325171664089637, 48.869450520806886],
                            [2.325164109535879, 48.87009973284847],
                        ],
                    },
                },
                1308: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.84591281792248, 2.4243424394918667],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 720.49723275,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.41947990037451,
                            48.84547070758355,
                            2.429205166348,
                            48.84635698889295,
                        ),
                        "coordinates": [
                            [2.429205166348, 48.84547070758355],
                            [2.42461951762163, 48.845886528414525],
                            [2.41947990037451, 48.84635698889295],
                        ],
                    },
                },
                1309: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M9",
                        "rer": 0,
                        "extcode": "100110009:9",
                        "geo_point_2d": [48.869691230528964, 2.3525502162253717],
                        "indice_lig": "9",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01379",
                        "navette": 0,
                        "idrefliga": "A01542",
                        "shape_leng": 318.811426167,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350497971851879,
                            48.8692241707531,
                            2.354603790708304,
                            48.870164201799824,
                        ),
                        "coordinates": [
                            [2.350497971851879, 48.870164201799824],
                            [2.353702953721122, 48.86942464649979],
                            [2.354280879075376, 48.86929400766136],
                            [2.354603790708304, 48.8692241707531],
                        ],
                    },
                },
                1310: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.757009712671305, 2.7075015080368647],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 3959.72058976,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.690252782195758,
                            48.746452320704556,
                            2.727229371429766,
                            48.7707789170597,
                        ),
                        "coordinates": [
                            [2.690252782195758, 48.7707789170597],
                            [2.690615889290086, 48.769940835223],
                            [2.690729793084868, 48.76969677569629],
                            [2.690987161491167, 48.76915730509382],
                            [2.691269192052953, 48.76864293667765],
                            [2.691314920614938, 48.76856905329303],
                            [2.691530277414749, 48.76824464089754],
                            [2.69157602332934, 48.768173455628805],
                            [2.691873815347791, 48.767772346862145],
                            [2.692236551196859, 48.76732247367335],
                            [2.69229198639094, 48.76727463895363],
                            [2.692705248860715, 48.7668524842858],
                            [2.692898498261289, 48.7666729233405],
                            [2.693993282060074, 48.76568028549119],
                            [2.695088021496021, 48.764687637641586],
                            [2.69618272358617, 48.76369587831255],
                            [2.69649084331991, 48.76341522988909],
                            [2.696942132116895, 48.76299383857648],
                            [2.697536815646411, 48.762464078978034],
                            [2.698996254566406, 48.76113840251165],
                            [2.700456974319795, 48.759812701986746],
                            [2.701917625946819, 48.758488779995126],
                            [2.702451266301405, 48.7579960591422],
                            [2.703093193347397, 48.75743374270838],
                            [2.703319830647944, 48.75724425780272],
                            [2.703527153059137, 48.757075330793334],
                            [2.703744879687559, 48.75690556398346],
                            [2.703986718807794, 48.756724265870304],
                            [2.704204698832289, 48.7565747966186],
                            [2.704751744428931, 48.756221558238586],
                            [2.705086281766097, 48.75603162778799],
                            [2.705404615425643, 48.755857935676644],
                            [2.705800548050763, 48.755652209918416],
                            [2.706191859543786, 48.755458801428034],
                            [2.706576874852881, 48.75529118466451],
                            [2.70705152784528, 48.755107088157935],
                            [2.707453031954326, 48.75496279644915],
                            [2.708363377923608, 48.75466126871188],
                            [2.709056379573694, 48.754449502551324],
                            [2.709725747885977, 48.754244944818076],
                            [2.710680741315084, 48.75395035050859],
                            [2.711716287896599, 48.75362959572182],
                            [2.713496581181229, 48.75309404421522],
                            [2.715565775504662, 48.75246128074907],
                            [2.716406965317591, 48.752198587876734],
                            [2.717297001441261, 48.751922235623766],
                            [2.718108350606253, 48.751672219965215],
                            [2.71881928607652, 48.75145221041933],
                            [2.719348398848898, 48.7512867656579],
                            [2.719609977247488, 48.75120582612548],
                            [2.719857075515036, 48.751116889565886],
                            [2.72018120294589, 48.75099979169586],
                            [2.720501551324978, 48.75087948398938],
                            [2.720804721319064, 48.75075863158059],
                            [2.721076045181154, 48.750646954448484],
                            [2.72135792661464, 48.750519204572996],
                            [2.721623528244793, 48.75039690337546],
                            [2.721928336372062, 48.75024479376514],
                            [2.722214041839074, 48.750084653951056],
                            [2.722469946732394, 48.74993990235693],
                            [2.722935606420231, 48.74966224448177],
                            [2.723204908727744, 48.749492265079994],
                            [2.724063811154212, 48.74889582039618],
                            [2.724361236708088, 48.74867088623932],
                            [2.725539857056865, 48.747748700286664],
                            [2.725819641427011, 48.747530117477375],
                            [2.726244071081227, 48.74720222723106],
                            [2.727229371429766, 48.746452320704556],
                        ],
                    },
                },
                1311: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.78640256771013, 2.6730783577754096],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 4320.77534872,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.65038766844115,
                            48.7707789170597,
                            2.690252782195758,
                            48.795654821412064,
                        ),
                        "coordinates": [
                            [2.65038766844115, 48.795654821412064],
                            [2.653738082681988, 48.79456375969959],
                            [2.654293578544201, 48.794374264997444],
                            [2.655001273111905, 48.79414657249452],
                            [2.658862788945834, 48.79288483318345],
                            [2.66130748957195, 48.79207754218481],
                            [2.664499211726753, 48.79104593321487],
                            [2.666678938297153, 48.79033011518671],
                            [2.66885860370027, 48.78961425604855],
                            [2.671039561150659, 48.78889745204991],
                            [2.673504313525253, 48.78809433686021],
                            [2.675968967318145, 48.78728847025629],
                            [2.678434915405753, 48.786484345712665],
                            [2.679329631706581, 48.78617500629736],
                            [2.67981579165295, 48.78598582565908],
                            [2.680244371035857, 48.78581074330536],
                            [2.680636457320475, 48.78563510048336],
                            [2.681036778289391, 48.7854373615558],
                            [2.681452903633455, 48.78522885817877],
                            [2.681987531079078, 48.78491838524668],
                            [2.682455316941921, 48.784623086557026],
                            [2.682716109257094, 48.784450545926546],
                            [2.683063902704594, 48.784209585365055],
                            [2.683291287444024, 48.784031735674226],
                            [2.683610598937456, 48.78376637584698],
                            [2.683786439475538, 48.78361296259848],
                            [2.68398524881878, 48.78343609805765],
                            [2.68420824317259, 48.78321509402277],
                            [2.684478486418863, 48.78293998847224],
                            [2.684633707729437, 48.78275785956092],
                            [2.684821297129882, 48.782534265014235],
                            [2.685072111464724, 48.78220615978139],
                            [2.68538060446695, 48.7817591718489],
                            [2.685609637853775, 48.781376197417686],
                            [2.685838907521479, 48.78094301828567],
                            [2.686183085204097, 48.780154190155315],
                            [2.686498103258331, 48.779430693919146],
                            [2.686821822981746, 48.778684598663126],
                            [2.68800829622975, 48.775976801836975],
                            [2.688231903163656, 48.775464419760496],
                            [2.688709847845154, 48.77436222134508],
                            [2.689292442230653, 48.77305466097908],
                            [2.689696578735758, 48.77205903973373],
                            [2.689989370966271, 48.77137533830717],
                            [2.690252782195758, 48.7707789170597],
                        ],
                    },
                },
                1312: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.846836692583395, 2.4917993337281956],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 1701.44033125,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.489167460948015,
                            48.839341939180265,
                            2.494188055346116,
                            48.85426899363537,
                        ),
                        "coordinates": [
                            [2.489167460948015, 48.85426899363537],
                            [2.489441244458785, 48.85350539416663],
                            [2.490005965305802, 48.85189382114354],
                            [2.490577868338836, 48.85028461304433],
                            [2.491113984856464, 48.84877300403469],
                            [2.491678865449789, 48.84724707839666],
                            [2.492243249362621, 48.84557362952163],
                            [2.492675472029595, 48.84437157499402],
                            [2.492897141309431, 48.84378595362841],
                            [2.493075866128748, 48.8433027016065],
                            [2.493186673629519, 48.84300275211929],
                            [2.493301182367373, 48.84273372791304],
                            [2.493419234998187, 48.84244566579689],
                            [2.493522978770402, 48.84219331280554],
                            [2.493633737464267, 48.84187908611802],
                            [2.493708573693987, 48.841605358805346],
                            [2.493812044012337, 48.841267349070705],
                            [2.493893947463762, 48.84094840320628],
                            [2.493972167761648, 48.840605670838706],
                            [2.494064475159349, 48.8401582260201],
                            [2.494120997567285, 48.83979410847092],
                            [2.494188055346116, 48.839341939180265],
                        ],
                    },
                },
                1313: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.81379763817774, 2.599340702456658],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 3501.36963764,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.579837253911679,
                            48.80577037511879,
                            2.619395781719303,
                            48.823151855834304,
                        ),
                        "coordinates": [
                            [2.579837253911679, 48.823151855834304],
                            [2.581155115207787, 48.822485147533854],
                            [2.581903655396125, 48.82210674278792],
                            [2.583772966236383, 48.82117105773609],
                            [2.584755116675035, 48.820674323635544],
                            [2.585718270738693, 48.8201956079777],
                            [2.587732764523767, 48.81918310213227],
                            [2.588892832544682, 48.81860770290041],
                            [2.58997945661268, 48.8180558366566],
                            [2.591739847255778, 48.817183211036536],
                            [2.593047809445939, 48.816522007670784],
                            [2.596057164017709, 48.81501142567895],
                            [2.597463202560697, 48.81430696788385],
                            [2.601688035105247, 48.81217763115321],
                            [2.602899419478348, 48.81158308451889],
                            [2.603615272568844, 48.81125336823382],
                            [2.60426040544961, 48.81096209537898],
                            [2.604814585533072, 48.81072440047871],
                            [2.605364211069727, 48.810498588395],
                            [2.606162384032739, 48.81017884333655],
                            [2.606962718033112, 48.80987928904391],
                            [2.607975113109869, 48.8095189727751],
                            [2.608923743215775, 48.8092028645714],
                            [2.610235267042617, 48.808773469632065],
                            [2.611328027659545, 48.80842821916969],
                            [2.612176119719753, 48.8081581898816],
                            [2.614861444541515, 48.807260487950884],
                            [2.616367137447408, 48.80676303587094],
                            [2.617409824810454, 48.80641546873197],
                            [2.618337498783522, 48.80611576400223],
                            [2.618952317516781, 48.80591200030611],
                            [2.619395781719303, 48.80577037511879],
                        ],
                    },
                },
                1314: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.83989927525522, 2.3986764261194753],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 509.404216673,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.395703289436394,
                            48.839549645568674,
                            2.400918536779803,
                            48.84133824913212,
                        ),
                        "coordinates": [
                            [2.395703289436394, 48.839549645568674],
                            [2.395952926588724, 48.839567198337505],
                            [2.396609864541429, 48.83961328205739],
                            [2.3971986202634, 48.83964057360401],
                            [2.399360932680366, 48.83967676747653],
                            [2.399471959853255, 48.83968210141441],
                            [2.399574847111077, 48.839687357518365],
                            [2.399704357663598, 48.83969932506303],
                            [2.399847566753859, 48.8397251304041],
                            [2.399940619428081, 48.839753371272],
                            [2.400061968720123, 48.83980146077119],
                            [2.400148656261709, 48.839842947707716],
                            [2.400246298170518, 48.8398928562513],
                            [2.400320238262047, 48.83995000086282],
                            [2.400371378659755, 48.84000595550462],
                            [2.400432584486143, 48.84008839006866],
                            [2.400461836761041, 48.84014315212532],
                            [2.400492019737688, 48.840212360760106],
                            [2.400511236377036, 48.84026471977666],
                            [2.400918536779803, 48.84133824913212],
                        ],
                    },
                },
                1315: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.890018059748364, 2.326488520485995],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 641.770153202,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325712043506408,
                            48.88718394686578,
                            2.327428458503176,
                            48.89282885338917,
                        ),
                        "coordinates": [
                            [2.325779674806892, 48.88718394686578],
                            [2.325761631670082, 48.88726048066515],
                            [2.32573414064636, 48.88736786038705],
                            [2.325717586408595, 48.88747621270265],
                            [2.325712043506408, 48.88758505149895],
                            [2.325717536024254, 48.88769389127532],
                            [2.325734043046418, 48.887802246274724],
                            [2.325761485007195, 48.887909631306464],
                            [2.325771697369423, 48.88794118418385],
                            [2.327249535140882, 48.89229525143094],
                            [2.327304993218849, 48.8924586284821],
                            [2.327428458503176, 48.89282885338917],
                        ],
                    },
                },
                1316: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.836554021403884, 2.331686576857459],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 545.1623044,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.330754192086216,
                            48.8342929804732,
                            2.332852309960891,
                            48.838964280710556,
                        ),
                        "coordinates": [
                            [2.330754192086216, 48.838964280710556],
                            [2.330928467459536, 48.83850203992784],
                            [2.332217155067424, 48.835083732391226],
                            [2.332243507505043, 48.83501885323196],
                            [2.332297168257836, 48.83490868851278],
                            [2.332361098703819, 48.83480093743519],
                            [2.332392858918918, 48.834755880864186],
                            [2.332435053604957, 48.83469602221858],
                            [2.332518743064439, 48.834594342347025],
                            [2.332611848631929, 48.83449629354624],
                            [2.332714007096237, 48.83440225690105],
                            [2.332824822814759, 48.83431259352841],
                            [2.332852309960891, 48.8342929804732],
                        ],
                    },
                },
                1317: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.87657225603614, 2.286242290394461],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 501.517147243,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.283162242230229,
                            48.87559404986667,
                            2.289322589613774,
                            48.87755125180425,
                        ),
                        "coordinates": [
                            [2.289322589613774, 48.87559404986667],
                            [2.284474902235015, 48.877133342463765],
                            [2.283795558364668, 48.87734960150105],
                            [2.283162242230229, 48.87755125180425],
                        ],
                    },
                },
                1318: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.89215523595606, 2.23711580846958],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 15.9886988974,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.237018056395014,
                            48.89212339546262,
                            2.237213560544146,
                            48.8921870764495,
                        ),
                        "coordinates": [
                            [2.237213560544146, 48.89212339546262],
                            [2.237018056395014, 48.8921870764495],
                        ],
                    },
                },
                1319: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.8481188517871, 2.300947959202468],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 326.564983958,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.298930911748061,
                            48.84750708199681,
                            2.302968297817314,
                            48.84874166571782,
                        ),
                        "coordinates": [
                            [2.298930911748061, 48.84874166571782],
                            [2.301099109279391, 48.84807195687143],
                            [2.301972124704083, 48.84779657278517],
                            [2.302968297817314, 48.84750708199681],
                        ],
                    },
                },
                1320: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.694412290415755, 2.314205660283161],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1937.89988409,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.307841188697314,
                            48.68571362817925,
                            2.31762640494754,
                            48.700680803710014,
                        ),
                        "coordinates": [
                            [2.307841188697314, 48.700680803710014],
                            [2.308060492335775, 48.700621314441115],
                            [2.308496658628785, 48.700500920955015],
                            [2.309046973424329, 48.700322101277074],
                            [2.309257589823621, 48.700248411589364],
                            [2.30954701978214, 48.700141467984565],
                            [2.309901672201181, 48.70000756046726],
                            [2.310101843355535, 48.69992686847791],
                            [2.310295737363296, 48.69984308702621],
                            [2.310574266227183, 48.69971997721804],
                            [2.310846076597988, 48.69959411601077],
                            [2.311024088223121, 48.699508725084954],
                            [2.311270048560566, 48.69938018515689],
                            [2.311507855093035, 48.699252542105484],
                            [2.311797305550721, 48.6990844429409],
                            [2.31201473312595, 48.698954995661104],
                            [2.312211625356501, 48.69883523479572],
                            [2.312400667760392, 48.698717671650385],
                            [2.312592280311594, 48.69858821750055],
                            [2.312797479879726, 48.69845247119749],
                            [2.312991815656252, 48.698306830650594],
                            [2.313133152358122, 48.69819535086259],
                            [2.313328845049483, 48.69804970946394],
                            [2.313481054366961, 48.69792564155337],
                            [2.313774603832589, 48.69767300725701],
                            [2.313906431843856, 48.697551632395616],
                            [2.314168395365838, 48.69730383358898],
                            [2.314334529342819, 48.69713398279375],
                            [2.314541662691648, 48.69690418132748],
                            [2.314673282649053, 48.696745743965415],
                            [2.314880728304293, 48.696493853297916],
                            [2.314968896717843, 48.69636748972243],
                            [2.315070322157489, 48.696213329980544],
                            [2.315204122840613, 48.695990650048095],
                            [2.315368144891214, 48.695696597757],
                            [2.315465274335875, 48.695495325991445],
                            [2.315549467333629, 48.6952854860777],
                            [2.315637994271597, 48.69502425295953],
                            [2.31570062234614, 48.69481155380333],
                            [2.315752506223614, 48.69451034146246],
                            [2.315793586028409, 48.69425338274853],
                            [2.315826066371573, 48.693939318656874],
                            [2.315854188550386, 48.6937266119863],
                            [2.315882410206213, 48.693281209577364],
                            [2.315917132941752, 48.69275729059034],
                            [2.315936684692231, 48.69241181750756],
                            [2.315954057640198, 48.692120591401256],
                            [2.316024213501852, 48.691183592517824],
                            [2.316053829381143, 48.690728709350765],
                            [2.316069342227258, 48.690453395739624],
                            [2.316082057816258, 48.690257610219724],
                            [2.316097246868391, 48.69003205328465],
                            [2.316117186824867, 48.68972050122383],
                            [2.316164396581444, 48.689292573421255],
                            [2.316192503817615, 48.689112702416004],
                            [2.316234346087684, 48.68887880781639],
                            [2.316285414633234, 48.68864018618043],
                            [2.316358853446466, 48.68832898539418],
                            [2.316414987576488, 48.68814911834479],
                            [2.316471128984852, 48.687956403910746],
                            [2.316544523127048, 48.687746561315954],
                            [2.316758194109892, 48.68722695632568],
                            [2.316982614302826, 48.68676873940675],
                            [2.317304105815702, 48.68618205504511],
                            [2.31762640494754, 48.68571362817925],
                        ],
                    },
                },
                1321: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.672219398407286, 2.3382785118461307],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1207.65650753,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.333249457132578,
                            48.67035068664662,
                            2.344492790482471,
                            48.676381326172205,
                        ),
                        "coordinates": [
                            [2.333249457132578, 48.676381326172205],
                            [2.33327499324832, 48.67636897589384],
                            [2.33349078609946, 48.676261319289814],
                            [2.333667336763631, 48.676163413882506],
                            [2.333887224359005, 48.67602494296488],
                            [2.334113570669939, 48.67586821917927],
                            [2.334316525951001, 48.67572353451888],
                            [2.334467114848041, 48.67559810772385],
                            [2.334680532026273, 48.675385400749484],
                            [2.334852988773019, 48.67520552760157],
                            [2.33501466729806, 48.67501185338067],
                            [2.335226644484929, 48.67472871852567],
                            [2.335377545418504, 48.674457477725035],
                            [2.33546017913758, 48.674309961413655],
                            [2.335600301503366, 48.67396734094049],
                            [2.33575479324149, 48.673498618044995],
                            [2.335862575997938, 48.673227376311274],
                            [2.335952393178484, 48.67299658366883],
                            [2.336031430936267, 48.67282765224317],
                            [2.336142802653101, 48.67258972228607],
                            [2.336239803436913, 48.67244934268321],
                            [2.336448169287977, 48.672192378391884],
                            [2.336606239593984, 48.67200679139096],
                            [2.336775085197726, 48.671844997341154],
                            [2.33697267072562, 48.67167844532092],
                            [2.337163068378227, 48.67153092684074],
                            [2.337364243424585, 48.67139054699397],
                            [2.337590563512263, 48.67125492453411],
                            [2.337870769217268, 48.67110502456225],
                            [2.338125826713462, 48.67098367739124],
                            [2.338416805485883, 48.67085280993921],
                            [2.33874011669034, 48.670731460601395],
                            [2.339160419186143, 48.670614865808496],
                            [2.339616779537449, 48.67050408394311],
                            [2.340030885225712, 48.67043033263106],
                            [2.340270444287606, 48.670400696937406],
                            [2.340550302803886, 48.67038053232821],
                            [2.340897115540767, 48.67036555675809],
                            [2.341220255844797, 48.67035205497441],
                            [2.341473877979316, 48.67035068664662],
                            [2.341775570891128, 48.67036462100919],
                            [2.342188326473588, 48.67040596802333],
                            [2.342603161083047, 48.67044619259999],
                            [2.34312046918891, 48.67052230187858],
                            [2.343630595927048, 48.670607928323335],
                            [2.344492790482471, 48.670783940999655],
                        ],
                    },
                },
                1322: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.05603243333109, 2.3210322350458443],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2424.47927487,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.320418181969663,
                            49.045169460276206,
                            2.322920457193825,
                            49.06628869769713,
                        ),
                        "coordinates": [
                            [2.322917846227109, 49.045169460276206],
                            [2.320958012205755, 49.0503632922462],
                            [2.320831206037497, 49.05069875981011],
                            [2.320718886612013, 49.051010437325786],
                            [2.320646403158674, 49.051269774119554],
                            [2.320602880734363, 49.051519597505795],
                            [2.320562950823169, 49.051855079155295],
                            [2.320544741683039, 49.05218342347354],
                            [2.320451368667623, 49.06084656261316],
                            [2.320429271828573, 49.06196960451012],
                            [2.320418181969663, 49.06265722955245],
                            [2.320439792809436, 49.062997477819486],
                            [2.320493957369586, 49.06344242092699],
                            [2.320562659883669, 49.063727949424035],
                            [2.32067118654574, 49.064039657778835],
                            [2.320808688650253, 49.06432043877425],
                            [2.320971545263676, 49.06458694625891],
                            [2.321170609771251, 49.064860597859216],
                            [2.321427604820848, 49.06516756616938],
                            [2.321662895628199, 49.06540315139011],
                            [2.321909058051313, 49.06562208260262],
                            [2.322184194740665, 49.065831499731104],
                            [2.322437617990567, 49.06600046380841],
                            [2.3225932944537, 49.06610041562377],
                            [2.322879310694304, 49.06626700427635],
                            [2.322920457193825, 49.06628869769713],
                        ],
                    },
                },
                1323: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.6803769899765, 2.325009400834563],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1574.54069322,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.31762640494754,
                            48.676381326172205,
                            2.333249457132578,
                            48.68571362817925,
                        ),
                        "coordinates": [
                            [2.31762640494754, 48.68571362817925],
                            [2.317792142143091, 48.68549491226578],
                            [2.317917195368779, 48.685330588465135],
                            [2.317955242307923, 48.68527933641483],
                            [2.318025900408485, 48.68518852152944],
                            [2.318202543452599, 48.684961935639386],
                            [2.318660418908339, 48.68445392235206],
                            [2.319028598491382, 48.68409247505133],
                            [2.319218800299125, 48.683906355616585],
                            [2.319786653577804, 48.68341993798818],
                            [2.320000218683265, 48.68323593657322],
                            [2.320427837264242, 48.682920937802926],
                            [2.32072396200351, 48.68272583896088],
                            [2.321189876027194, 48.682420152964944],
                            [2.322424582935043, 48.681636152897084],
                            [2.324087091277706, 48.68060758749037],
                            [2.325464316937487, 48.67973724088596],
                            [2.326655424701757, 48.679003550279134],
                            [2.327511031896385, 48.67854499609301],
                            [2.328166978540254, 48.678237497939705],
                            [2.328765875419987, 48.6779875448077],
                            [2.329413650235648, 48.677749282625044],
                            [2.330987559851962, 48.677221502370834],
                            [2.332160841780996, 48.67682317987782],
                            [2.332783482129072, 48.676590236454736],
                            [2.333083131159542, 48.676461763296835],
                            [2.333249457132578, 48.676381326172205],
                        ],
                    },
                },
                1324: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.03723791311105, 2.3282935298336507],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1882.94048772,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.322917846227109,
                            49.03297204677151,
                            2.336829689836827,
                            49.045169460276206,
                        ),
                        "coordinates": [
                            [2.336829689836827, 49.03297204677151],
                            [2.333064263333692, 49.03374705691817],
                            [2.330408070052809, 49.034296565814984],
                            [2.330020851695396, 49.034389336126274],
                            [2.32956487214166, 49.034510655044976],
                            [2.329098029981884, 49.03466766032541],
                            [2.328703558317814, 49.034827049292154],
                            [2.32830546200745, 49.03500784921652],
                            [2.327871163158731, 49.03525288756775],
                            [2.327415139404125, 49.03553361254796],
                            [2.327045964523047, 49.035816723357385],
                            [2.326760021360279, 49.0360760453743],
                            [2.326481305745596, 49.036378195790334],
                            [2.326264113513084, 49.0366565587332],
                            [2.326101208501819, 49.036906374028256],
                            [2.325960013264103, 49.03716570756672],
                            [2.325851392708387, 49.03739887170784],
                            [2.325728276642763, 49.03771531217994],
                            [2.32560153743536, 49.03804364741978],
                            [2.322917846227109, 49.045169460276206],
                        ],
                    },
                },
                1325: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.83054288769246, 2.3532445684157577],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 449.45219115,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350414872010464,
                            48.82979051369296,
                            2.356121938797104,
                            48.83094298462233,
                        ),
                        "coordinates": [
                            [2.350414872010464, 48.82979051369296],
                            [2.350974955208672, 48.82996935214237],
                            [2.351302171811984, 48.8300660534989],
                            [2.352306364654541, 48.83036568072765],
                            [2.353779917509148, 48.83083877636098],
                            [2.3537983706304, 48.83084460236527],
                            [2.353919670038477, 48.83087824484494],
                            [2.354044808496265, 48.83090506731314],
                            [2.354172908261287, 48.830924882446354],
                            [2.354303069189323, 48.83093755136963],
                            [2.354434380983891, 48.83094298462233],
                            [2.35456592042987, 48.83094114574086],
                            [2.354696765094762, 48.83093204503706],
                            [2.354825998667634, 48.83091574862068],
                            [2.354952712446063, 48.830892368514284],
                            [2.354959133612225, 48.830890979440525],
                            [2.355069128009453, 48.83086982312006],
                            [2.355200709317521, 48.83085158642341],
                            [2.355334121839944, 48.83084058500461],
                            [2.355468454703141, 48.830836894892165],
                            [2.355602790869723, 48.83084053992165],
                            [2.355736209793716, 48.83085149714649],
                            [2.355879943716534, 48.83087469805872],
                            [2.355996674155135, 48.83089499592296],
                            [2.356121938797104, 48.8309272410005],
                        ],
                    },
                },
                1326: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.835909298060905, 2.37051404436079],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 417.934156914,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.368126330413209,
                            48.83494772325454,
                            2.372825724542572,
                            48.837045120157924,
                        ),
                        "coordinates": [
                            [2.368126330413209, 48.83494772325454],
                            [2.368276669169425, 48.83499679449596],
                            [2.368751044435821, 48.83515867310856],
                            [2.369089886820094, 48.83527486754298],
                            [2.369410654785986, 48.83538013283862],
                            [2.369624506258915, 48.83545958501526],
                            [2.370249526470707, 48.83572975267067],
                            [2.370617012822731, 48.83589066068064],
                            [2.370952878095621, 48.83604362531558],
                            [2.371298178275392, 48.836227562363526],
                            [2.371625244812621, 48.83640440731855],
                            [2.372065979422662, 48.83664262723271],
                            [2.372358791225242, 48.83680572872966],
                            [2.372825724542572, 48.837045120157924],
                        ],
                    },
                },
                1327: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.833524371688824, 2.334963462579586],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 352.797606083,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332852309960891,
                            48.832900815660246,
                            2.3371351933439,
                            48.8342929804732,
                        ),
                        "coordinates": [
                            [2.332852309960891, 48.8342929804732],
                            [2.332943867622319, 48.834227651772245],
                            [2.333070682273899, 48.83414776091627],
                            [2.333204772404067, 48.83407322756448],
                            [2.333345623442758, 48.834004341121044],
                            [2.33349268975151, 48.83394137103192],
                            [2.333645398836586, 48.8338845569158],
                            [2.333803163458478, 48.83383412032375],
                            [2.333878306920026, 48.83381283071595],
                            [2.3371351933439, 48.832900815660246],
                        ],
                    },
                },
                1328: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.84958812864565, 2.296271681241666],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 433.312062146,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.293612437187803,
                            48.84874166571782,
                            2.298930911748061,
                            48.85043454901341,
                        ),
                        "coordinates": [
                            [2.293612437187803, 48.85043454901341],
                            [2.297563415315288, 48.84917698920804],
                            [2.297916591840311, 48.84906456347491],
                            [2.298930911748061, 48.84874166571782],
                        ],
                    },
                },
                1329: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.76437037389192, 1.9754262052250464],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 5114.58099421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.943835201056777,
                            48.75538926869322,
                            2.006566869057667,
                            48.77480280977951,
                        ),
                        "coordinates": [
                            [1.943835201056777, 48.75538926869322],
                            [1.944667364028943, 48.75559099755985],
                            [1.948089958754974, 48.75630451146039],
                            [1.949761965640149, 48.756630626206295],
                            [1.95098834279538, 48.756882240266435],
                            [1.952070762970246, 48.757136527119066],
                            [1.952832360409277, 48.75730723778661],
                            [1.953986601811341, 48.7575839563403],
                            [1.954719421973728, 48.75775455743983],
                            [1.955667704796042, 48.757986153882165],
                            [1.956716320331152, 48.75827518109275],
                            [1.957348324839237, 48.75845494657275],
                            [1.957817558002823, 48.75858658021936],
                            [1.958387340651808, 48.75874709874267],
                            [1.959028977802339, 48.7589237145464],
                            [1.959890836127262, 48.759167678353315],
                            [1.960465357045865, 48.75933771841221],
                            [1.961490013672851, 48.75962979542499],
                            [1.963711603908849, 48.76028110622803],
                            [1.964640567422104, 48.76054111619817],
                            [1.965665533965252, 48.760798257957504],
                            [1.966455716218026, 48.76101021319322],
                            [1.967217280111452, 48.7611998632285],
                            [1.968953232641303, 48.76164350480127],
                            [1.970096989484728, 48.761931271902014],
                            [1.972363822311808, 48.762495317178804],
                            [1.973067927450299, 48.76267363942385],
                            [1.973477410427192, 48.762784396444744],
                            [1.973861701975016, 48.762895072320156],
                            [1.974156210934549, 48.76297928689983],
                            [1.974608660204442, 48.763121108864894],
                            [1.975000051483632, 48.763246078785315],
                            [1.975477595433308, 48.76340225333082],
                            [1.976016101591305, 48.76358954949254],
                            [1.976525801437547, 48.763779131923826],
                            [1.977049780801759, 48.763985413454215],
                            [1.977548571904761, 48.76419161190875],
                            [1.978083152615097, 48.76442647291585],
                            [1.978606956344336, 48.76465891864899],
                            [1.979378354397805, 48.76499683059387],
                            [1.979963167727697, 48.765255635022584],
                            [1.980558770292436, 48.76551684829816],
                            [1.981279957062491, 48.765833176924154],
                            [1.981983210036676, 48.76614230624942],
                            [1.982568066930035, 48.76639871782676],
                            [1.983063272717583, 48.76660963986517],
                            [1.983709346963289, 48.766863855856535],
                            [1.984341132099917, 48.767103748659196],
                            [1.985030494888863, 48.7673461933727],
                            [1.98565887661744, 48.7675598945088],
                            [1.986423754093624, 48.76781446201408],
                            [1.989239064432506, 48.76876293098881],
                            [1.989673531314358, 48.768916534790684],
                            [1.990079236590753, 48.76906528943964],
                            [1.990459781456195, 48.76920920857999],
                            [1.990750473904049, 48.76933381857678],
                            [1.991134506371609, 48.76949440145146],
                            [1.991547189518956, 48.76967648375796],
                            [1.992006518777412, 48.76988011989825],
                            [1.994963320565364, 48.77122384796468],
                            [1.995709732354749, 48.771561574582485],
                            [1.996108116283379, 48.77173407956733],
                            [1.996470650399578, 48.771885062822726],
                            [1.996901436443583, 48.772057661878335],
                            [1.99727125625033, 48.772196767058944],
                            [1.997691377615981, 48.77235029773417],
                            [1.998107983785947, 48.772491918234685],
                            [1.998564203646575, 48.77263127620023],
                            [1.999006107936467, 48.772758692624365],
                            [1.999451597836565, 48.77288849759675],
                            [2.000008601457484, 48.773030528035186],
                            [2.000486510994423, 48.77315804509535],
                            [2.001219583688146, 48.773348177122166],
                            [2.005718365196384, 48.774574809731874],
                            [2.006480182944973, 48.7747792669428],
                            [2.006566869057667, 48.77480280977951],
                        ],
                    },
                },
                1330: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.878150523525754, 2.6718618432719228],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 5106.56513654,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.637590717167975,
                            48.87520826545471,
                            2.706014179759928,
                            48.8821891367053,
                        ),
                        "coordinates": [
                            [2.637590717167975, 48.87520826545471],
                            [2.639501827967145, 48.87529591500355],
                            [2.641728063574485, 48.87538206469342],
                            [2.642860912098314, 48.87542258609675],
                            [2.644592904687644, 48.875508348157425],
                            [2.645740306052573, 48.87555759715815],
                            [2.646847971766107, 48.87559742442043],
                            [2.648197452884676, 48.87565799533788],
                            [2.650239784360432, 48.875759480792986],
                            [2.651527983023901, 48.875824940472356],
                            [2.652693479845031, 48.87588120718402],
                            [2.654032184690428, 48.87594649862967],
                            [2.655002820985922, 48.87599138595938],
                            [2.658041477654103, 48.87613856290198],
                            [2.659874089851316, 48.87621802751477],
                            [2.661779253654797, 48.876298279687475],
                            [2.663781960604314, 48.87639963597834],
                            [2.66670141427873, 48.87654575534861],
                            [2.667853296516822, 48.876610948266325],
                            [2.668444902453116, 48.87665638116822],
                            [2.669067415276588, 48.87671021522502],
                            [2.669631968750593, 48.876769432162604],
                            [2.670175480945566, 48.876835662451896],
                            [2.670679473282603, 48.87690548312522],
                            [2.671257387461126, 48.876990735437936],
                            [2.671943587250825, 48.87710522699537],
                            [2.672582326610504, 48.877218115328304],
                            [2.673213265600698, 48.877346673729996],
                            [2.673828414690495, 48.877478752432765],
                            [2.674681265399872, 48.87767446280215],
                            [2.67706832449245, 48.87823598321064],
                            [2.681074115056026, 48.87917165785329],
                            [2.683553734313555, 48.879753630437634],
                            [2.684224475693452, 48.8799098281598],
                            [2.684768429176102, 48.88003163238509],
                            [2.685285925293604, 48.8801396015488],
                            [2.686001384905116, 48.88028000340225],
                            [2.686925294353807, 48.88044410523126],
                            [2.689005393083607, 48.8808080890086],
                            [2.689865839666754, 48.88094280261593],
                            [2.690623294172337, 48.88105348419797],
                            [2.691562729337255, 48.88117229023932],
                            [2.6926339902513, 48.88129067917066],
                            [2.693689288654845, 48.88138824005221],
                            [2.694607306828951, 48.88146013950243],
                            [2.696142508184224, 48.88156486880858],
                            [2.699260271915324, 48.88175846503482],
                            [2.704285183743431, 48.882078003297934],
                            [2.706014179759928, 48.8821891367053],
                        ],
                    },
                },
                1331: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.68897770552408, 2.518668897394993],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2938.60368335,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.506078153203696,
                            48.681016616342724,
                            2.533130656571037,
                            48.69973243390383,
                        ),
                        "coordinates": [
                            [2.533130656571037, 48.681016616342724],
                            [2.533083199969267, 48.681036908862126],
                            [2.532420245237413, 48.68130501241577],
                            [2.531858424403045, 48.681525827311454],
                            [2.531122229286065, 48.68181260863568],
                            [2.530166395190735, 48.68216971084296],
                            [2.528636439410602, 48.68275970284952],
                            [2.527384140172082, 48.68325092711469],
                            [2.525814500754922, 48.68386873852389],
                            [2.523791239115818, 48.684675135001115],
                            [2.523209316117805, 48.68491878306068],
                            [2.522627803766856, 48.68516714672711],
                            [2.522191252125509, 48.685373793459576],
                            [2.521766940500577, 48.6855858134296],
                            [2.521402301317052, 48.68577525356521],
                            [2.520762555585214, 48.6861279063839],
                            [2.520261087236943, 48.68641378661939],
                            [2.519931057683086, 48.68662008435654],
                            [2.519620171125085, 48.68682218937744],
                            [2.519292327448007, 48.68705023251167],
                            [2.518727460664905, 48.68746030672398],
                            [2.518210210107044, 48.687894582783834],
                            [2.51777291551441, 48.688281967524496],
                            [2.517136591601049, 48.688849148509895],
                            [2.516363556401142, 48.68954408354144],
                            [2.515953333460746, 48.68991343226858],
                            [2.514893183474851, 48.69085663669972],
                            [2.514105095249711, 48.69154131564824],
                            [2.513505313585758, 48.69209080553229],
                            [2.513079321689099, 48.69247661522168],
                            [2.512688850727272, 48.69282947523966],
                            [2.512481714053253, 48.69302493737972],
                            [2.512251587380239, 48.69325011164466],
                            [2.511942940635518, 48.693550943881],
                            [2.511427253655409, 48.694078710836905],
                            [2.510991505145755, 48.69455059822122],
                            [2.510715444432601, 48.69485137801083],
                            [2.510463726849502, 48.69512244423393],
                            [2.509782952423262, 48.69584379944969],
                            [2.509643544375335, 48.69599059291947],
                            [2.50936473457913, 48.69628687684477],
                            [2.508931620430535, 48.69674616261593],
                            [2.508348323378641, 48.69738372928118],
                            [2.508257641925479, 48.69748098686163],
                            [2.507689269499808, 48.69803704997495],
                            [2.507471029928957, 48.69825734323042],
                            [2.507270728216306, 48.69847796559789],
                            [2.506974287412474, 48.698791356624],
                            [2.506750944552601, 48.69902909851392],
                            [2.506562788768913, 48.69922811883625],
                            [2.506385470274386, 48.69941813059212],
                            [2.506078153203696, 48.69973243390383],
                        ],
                    },
                },
                1332: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.89109158080235, 2.4721954798482786],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2295.95789598,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461119310778047,
                            48.88230400665456,
                            2.481421258690829,
                            48.89660443742263,
                        ),
                        "coordinates": [
                            [2.461119310778047, 48.89660443742263],
                            [2.461509388952238, 48.896564144824815],
                            [2.461942319234399, 48.896518464178925],
                            [2.462588083726939, 48.89644161661581],
                            [2.463309586236366, 48.896348025332145],
                            [2.464736211707876, 48.8961396272551],
                            [2.46575794919192, 48.89595594168199],
                            [2.466266478813435, 48.89584353822975],
                            [2.466673988232067, 48.89574076403453],
                            [2.46711032183098, 48.89562130052526],
                            [2.467604317266228, 48.89547321674713],
                            [2.468091059302494, 48.895313243107005],
                            [2.4684551646126, 48.89517482194836],
                            [2.468797602632725, 48.895031666723526],
                            [2.46906794191135, 48.894917145066536],
                            [2.469586562636219, 48.8946674619619],
                            [2.469966504422374, 48.89445209207242],
                            [2.470264708692414, 48.89427115822417],
                            [2.470529759151449, 48.894091514130714],
                            [2.470991920934919, 48.89375636188796],
                            [2.471290672819598, 48.89352263557229],
                            [2.471726930019748, 48.89312794489909],
                            [2.471973921861432, 48.89287779812293],
                            [2.472547704070426, 48.892236831521885],
                            [2.472884567031517, 48.891817137298425],
                            [2.473438216363358, 48.89107412219748],
                            [2.473772279787147, 48.89070839675303],
                            [2.474049663126856, 48.89040950291347],
                            [2.47452551469536, 48.889881953956994],
                            [2.474881753233817, 48.88950023007377],
                            [2.47572536852113, 48.888574373860074],
                            [2.477607310168708, 48.88650309680817],
                            [2.478720811781256, 48.88525812621543],
                            [2.479059291873576, 48.884888102203035],
                            [2.479390955409872, 48.88451988389745],
                            [2.479752531767738, 48.88412374931917],
                            [2.480115496258058, 48.88373840328366],
                            [2.48045801797166, 48.88335847745387],
                            [2.480921498927064, 48.88284350718845],
                            [2.481421258690829, 48.88230400665456],
                        ],
                    },
                },
                1333: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.81379763817774, 2.599340702456658],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3501.36963764,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.579837253911679,
                            48.80577037511879,
                            2.619395781719303,
                            48.823151855834304,
                        ),
                        "coordinates": [
                            [2.579837253911679, 48.823151855834304],
                            [2.581155115207787, 48.822485147533854],
                            [2.581903655396125, 48.82210674278792],
                            [2.583772966236383, 48.82117105773609],
                            [2.584755116675035, 48.820674323635544],
                            [2.585718270738693, 48.8201956079777],
                            [2.587732764523767, 48.81918310213227],
                            [2.588892832544682, 48.81860770290041],
                            [2.58997945661268, 48.8180558366566],
                            [2.591739847255778, 48.817183211036536],
                            [2.593047809445939, 48.816522007670784],
                            [2.596057164017709, 48.81501142567895],
                            [2.597463202560697, 48.81430696788385],
                            [2.601688035105247, 48.81217763115321],
                            [2.602899419478348, 48.81158308451889],
                            [2.603615272568844, 48.81125336823382],
                            [2.60426040544961, 48.81096209537898],
                            [2.604814585533072, 48.81072440047871],
                            [2.605364211069727, 48.810498588395],
                            [2.606162384032739, 48.81017884333655],
                            [2.606962718033112, 48.80987928904391],
                            [2.607975113109869, 48.8095189727751],
                            [2.608923743215775, 48.8092028645714],
                            [2.610235267042617, 48.808773469632065],
                            [2.611328027659545, 48.80842821916969],
                            [2.612176119719753, 48.8081581898816],
                            [2.614861444541515, 48.807260487950884],
                            [2.616367137447408, 48.80676303587094],
                            [2.617409824810454, 48.80641546873197],
                            [2.618337498783522, 48.80611576400223],
                            [2.618952317516781, 48.80591200030611],
                            [2.619395781719303, 48.80577037511879],
                        ],
                    },
                },
                1334: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.82350969214343, 2.52727402884048],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2287.98565054,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.511855553451007,
                            48.8226267426856,
                            2.542679794015853,
                            48.82484856949889,
                        ),
                        "coordinates": [
                            [2.511855553451007, 48.82484856949889],
                            [2.512217423074874, 48.824814209134196],
                            [2.512766104006487, 48.824761206978174],
                            [2.513779054037772, 48.82466431774589],
                            [2.514398530826373, 48.82460490286682],
                            [2.515277862235902, 48.8245217806584],
                            [2.516086782843057, 48.82444758916252],
                            [2.517586244095618, 48.82430360031815],
                            [2.519199053721701, 48.824154236778675],
                            [2.521241312349522, 48.823960514265316],
                            [2.524109452066047, 48.823686052109736],
                            [2.525845360479719, 48.823526472729434],
                            [2.527401006831997, 48.82336915348054],
                            [2.529221956706923, 48.8231825061319],
                            [2.530345099939552, 48.82307089557032],
                            [2.533322450370636, 48.822780738035966],
                            [2.534735677133574, 48.82267308066506],
                            [2.53526263108855, 48.8226478853317],
                            [2.535856350601355, 48.822630665180206],
                            [2.536557711833274, 48.8226267426856],
                            [2.537180108559238, 48.82262924851815],
                            [2.537611893034019, 48.822644677351896],
                            [2.538214618943187, 48.82267325433027],
                            [2.538975174795262, 48.822733773378026],
                            [2.539696134074657, 48.822803874373214],
                            [2.54044406314881, 48.8228917732283],
                            [2.541219710124115, 48.822995674472836],
                            [2.54197740742918, 48.82312792268585],
                            [2.542679794015853, 48.823266634124074],
                        ],
                    },
                },
                1335: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.02902212266669, 2.3498710263222318],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2186.61970193,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.336829689836827,
                            49.02320637806201,
                            2.362222981011115,
                            49.03297204677151,
                        ),
                        "coordinates": [
                            [2.362222981011115, 49.02320637806201],
                            [2.362062785664122, 49.023299049476606],
                            [2.354325519588647, 49.02752619658293],
                            [2.35180402234732, 49.0289018103816],
                            [2.351080465120606, 49.029289735538576],
                            [2.350447341166052, 49.02962054047568],
                            [2.349973391976561, 49.029849011707185],
                            [2.349452396514655, 49.03007272834155],
                            [2.348963955802607, 49.03026312735066],
                            [2.348392289277997, 49.030463051266445],
                            [2.347867649231807, 49.030627276676256],
                            [2.347357476394044, 49.030767706288785],
                            [2.346894336240289, 49.03088671417556],
                            [2.346333493604799, 49.031008109096796],
                            [2.345736464135617, 49.03113426156674],
                            [2.343619700272693, 49.03157458345275],
                            [2.337526101484952, 49.03282869248634],
                            [2.336829689836827, 49.03297204677151],
                        ],
                    },
                },
                1336: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.611218813280196, 2.4703880513160783],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 616.523094373,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.467812581880024,
                            48.60904470232516,
                            2.472933650458744,
                            48.61342791359473,
                        ),
                        "coordinates": [
                            [2.472933650458744, 48.61342791359473],
                            [2.472716139702782, 48.61323959036092],
                            [2.472395120885973, 48.61295624235953],
                            [2.471979677955268, 48.61258556755173],
                            [2.471588535549442, 48.61224162869113],
                            [2.471291793057478, 48.61197430954407],
                            [2.470234402930154, 48.61104763023371],
                            [2.469770535557786, 48.61066986632499],
                            [2.469303983549453, 48.6102921028896],
                            [2.468867116678716, 48.6099428555382],
                            [2.468141603332862, 48.6093209158854],
                            [2.467812581880024, 48.60904470232516],
                        ],
                    },
                },
                1337: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.96848959985272, 1.760976031613833],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 7554.73964061,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.715210986447546,
                            48.96309520715419,
                            1.809094508773784,
                            48.983654507541004,
                        ),
                        "coordinates": [
                            [1.809094508773784, 48.96334411275807],
                            [1.80751423281709, 48.96325064241118],
                            [1.805456304559444, 48.96316890655146],
                            [1.803191036621014, 48.963110230415914],
                            [1.801692782735805, 48.96309520715419],
                            [1.79934146825186, 48.963108244055825],
                            [1.792204806172105, 48.96326539029052],
                            [1.782026620456471, 48.96345915675499],
                            [1.776948362263403, 48.96355337477295],
                            [1.775099652863674, 48.963590948124676],
                            [1.773613949196232, 48.96363360909356],
                            [1.772211191739051, 48.963690935560294],
                            [1.769672844099819, 48.96382589443027],
                            [1.767235389594588, 48.963985097537076],
                            [1.765629489902814, 48.96410795388584],
                            [1.764417700490392, 48.964211345998606],
                            [1.763343221870768, 48.96431541627785],
                            [1.762174483775721, 48.964445174002414],
                            [1.760611090710833, 48.964639556318616],
                            [1.759315143228286, 48.96483050902828],
                            [1.758261546780888, 48.96500126089294],
                            [1.757320044285388, 48.9651654299684],
                            [1.755712131011992, 48.96545469591098],
                            [1.754762826784092, 48.965666393247496],
                            [1.752479520296583, 48.9662258061199],
                            [1.751747233380135, 48.96641955140475],
                            [1.750789935183282, 48.96669304138924],
                            [1.749948321962167, 48.96696235705018],
                            [1.749258897543363, 48.96719675619359],
                            [1.74843494005744, 48.96749946352447],
                            [1.747472689567889, 48.96788235148487],
                            [1.746223205312962, 48.968408892905884],
                            [1.744414288685574, 48.969172843744644],
                            [1.743081221101059, 48.969732229617016],
                            [1.742260283059671, 48.97007773759341],
                            [1.740999302518121, 48.9706493696809],
                            [1.740257613960113, 48.97101431042357],
                            [1.739671949524783, 48.9713277163682],
                            [1.739136988581911, 48.97163186407823],
                            [1.738569093653484, 48.97196915082827],
                            [1.737986331490821, 48.97233966732065],
                            [1.737406942404305, 48.97272923479087],
                            [1.736714214009256, 48.97322527819537],
                            [1.736155971960294, 48.97365777816402],
                            [1.735447806546557, 48.9742322545396],
                            [1.735060972266274, 48.97453716214809],
                            [1.734546623902395, 48.97492467822281],
                            [1.7341272785774, 48.975227033636926],
                            [1.733569628129071, 48.97560717877947],
                            [1.732666373100019, 48.97616871062862],
                            [1.731923671988704, 48.97660497542186],
                            [1.730103599862883, 48.977647032933106],
                            [1.728862982753179, 48.97829954063289],
                            [1.728113742786351, 48.978673882942175],
                            [1.727503048619697, 48.97895140103639],
                            [1.72683809647815, 48.979231005763666],
                            [1.726086328698559, 48.979514904576845],
                            [1.725298437784954, 48.979796223139395],
                            [1.72402769662093, 48.98024389026234],
                            [1.723319687472679, 48.98049469202141],
                            [1.72246249361554, 48.98082320878138],
                            [1.720264259571234, 48.98172269510186],
                            [1.71949191677146, 48.98201047192969],
                            [1.718462645660327, 48.98237410203644],
                            [1.717594407918111, 48.982703772839415],
                            [1.716985230225326, 48.98294677854624],
                            [1.715210986447546, 48.983654507541004],
                        ],
                    },
                },
                1338: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.86418569899696, 2.2182244218238187],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 1741.80985106,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.216428094448963,
                            48.85641999136021,
                            2.22102955043113,
                            48.87171419115656,
                        ),
                        "coordinates": [
                            [2.216572237792291, 48.85641999136021],
                            [2.216570050176368, 48.85645163199814],
                            [2.216525865305397, 48.85725194211249],
                            [2.216428094448963, 48.85823115299411],
                            [2.216429122011755, 48.858369641962824],
                            [2.216444609293364, 48.85872757137128],
                            [2.216449827210608, 48.85882379964996],
                            [2.216495339606462, 48.85916467391442],
                            [2.21657466926078, 48.85961169819425],
                            [2.216596133208005, 48.859752907341374],
                            [2.216605567841313, 48.85979698211102],
                            [2.216647343487939, 48.85999306838162],
                            [2.216686366197515, 48.860200842680115],
                            [2.21673362826217, 48.860382546184184],
                            [2.216884930684409, 48.860940257566156],
                            [2.217040551897419, 48.861403548497684],
                            [2.217178618969485, 48.861800274912206],
                            [2.217453558740573, 48.86252538019936],
                            [2.217488762878157, 48.86262253893962],
                            [2.217502311227092, 48.86265672586783],
                            [2.217511774179814, 48.86268910894574],
                            [2.217546994015398, 48.862779973134785],
                            [2.217672941003725, 48.86311823276067],
                            [2.217961438504086, 48.863880221831714],
                            [2.218260627857895, 48.86473484593172],
                            [2.218718426828335, 48.865959237033714],
                            [2.219468869000787, 48.86795101063171],
                            [2.219659898570216, 48.86844850707879],
                            [2.21970597124377, 48.86857929398958],
                            [2.220315456853119, 48.87025617106526],
                            [2.220491695521402, 48.870673615286826],
                            [2.220509323901252, 48.87071320090687],
                            [2.220529673973555, 48.87075548791683],
                            [2.220742622310365, 48.87121613449376],
                            [2.220894669092794, 48.871487870802966],
                            [2.22102955043113, 48.87171419115656],
                        ],
                    },
                },
                1339: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.887769373141786, 2.2353815318139385],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 1021.40188656,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.233691920150409,
                            48.883383813825255,
                            2.2370182854985,
                            48.89218735760208,
                        ),
                        "coordinates": [
                            [2.233691920150409, 48.883383813825255],
                            [2.233768728819554, 48.88346418582298],
                            [2.233907461047741, 48.88363337454792],
                            [2.233968663111559, 48.883709868399215],
                            [2.234032590326588, 48.883787263699645],
                            [2.234115559444409, 48.88388805661572],
                            [2.234183546855574, 48.88398074320581],
                            [2.234436441129308, 48.88433528523546],
                            [2.234591286860087, 48.88462768944146],
                            [2.234708086634803, 48.884856210174824],
                            [2.234815339394884, 48.88508562122766],
                            [2.234933420331685, 48.88535461021591],
                            [2.235014793117077, 48.88557140874087],
                            [2.235079905141784, 48.88573783290799],
                            [2.235190974947321, 48.886103038333516],
                            [2.235307274632951, 48.886578858714955],
                            [2.235379821595172, 48.88711219444047],
                            [2.235391910667516, 48.887202133511735],
                            [2.235406605812297, 48.88735142664091],
                            [2.235407504920138, 48.88757894419381],
                            [2.235407352650535, 48.88765358376268],
                            [2.235409909001369, 48.8877372196105],
                            [2.235416435186294, 48.887880210104],
                            [2.235420236190109, 48.888022299127854],
                            [2.235424178418346, 48.888095144553006],
                            [2.235426808880497, 48.88814280824479],
                            [2.235425371077484, 48.8881787779541],
                            [2.23542533702923, 48.888195864246754],
                            [2.235426535201084, 48.888276800562906],
                            [2.23543164576526, 48.88844496968036],
                            [2.23543157078741, 48.88848184022446],
                            [2.235431501330873, 48.8885160127913],
                            [2.235435222869895, 48.888696770014626],
                            [2.235451156765767, 48.888908115185785],
                            [2.235453838811784, 48.888929700204564],
                            [2.235471339434205, 48.88904122537198],
                            [2.235502312481371, 48.88923369858623],
                            [2.235526703932197, 48.889310158515435],
                            [2.235651199841928, 48.88978418759566],
                            [2.235790804463067, 48.89020697148228],
                            [2.235831524982709, 48.89030143136774],
                            [2.235859998789124, 48.89038239139515],
                            [2.236028515567895, 48.890672107456865],
                            [2.23645945873214, 48.89134874307954],
                            [2.237008762476744, 48.892175658644554],
                            [2.2370182854985, 48.89218735760208],
                        ],
                    },
                },
                1340: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.909374228317056, 2.263620257855337],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1447.62417207,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.257326023785208,
                            48.9056030867462,
                            2.269964779194514,
                            48.9136368630564,
                        ),
                        "coordinates": [
                            [2.257326023785208, 48.9136368630564],
                            [2.257620535199223, 48.913610946440826],
                            [2.257957870522599, 48.91357067781523],
                            [2.258293572534825, 48.91352099490191],
                            [2.258600610970937, 48.91346404976476],
                            [2.259203689706809, 48.91332169957774],
                            [2.259839356654243, 48.91311750492119],
                            [2.260345060219475, 48.91291322038175],
                            [2.260916377944355, 48.91264124422892],
                            [2.261325839875283, 48.912416271020845],
                            [2.261557059126316, 48.9122926971882],
                            [2.261977430530826, 48.91205436129345],
                            [2.262487559646235, 48.91169164997459],
                            [2.26272977586309, 48.91145149405898],
                            [2.262925073657234, 48.91120416827554],
                            [2.263087872829459, 48.91096158125622],
                            [2.263247155308831, 48.9106547477026],
                            [2.263377551386861, 48.91035503508525],
                            [2.263504381627251, 48.91002200943715],
                            [2.26360232477903, 48.909696103039124],
                            [2.263882605364243, 48.908474569238514],
                            [2.263993936678764, 48.90804001323428],
                            [2.264071304278886, 48.907792611358325],
                            [2.264274040663371, 48.90738032143446],
                            [2.264568232451091, 48.90695539867278],
                            [2.264838141654149, 48.90667639341582],
                            [2.265233155073414, 48.90641332739693],
                            [2.265656970068928, 48.90619786401656],
                            [2.266143325627413, 48.90599512815634],
                            [2.266793294453611, 48.905798836425326],
                            [2.267351709590916, 48.90568179580404],
                            [2.267895605988227, 48.905621847075366],
                            [2.268352817670627, 48.9056030867462],
                            [2.268862929235737, 48.90561290690306],
                            [2.269522130738855, 48.9056926075046],
                            [2.269964779194514, 48.90576265710707],
                        ],
                    },
                },
                1341: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.851253327138146, 2.2172000345642897],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 1152.26395896,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.216572237792291,
                            48.84610294864101,
                            2.217785185939174,
                            48.85641999136021,
                        ),
                        "coordinates": [
                            [2.217621080890435, 48.84610294864101],
                            [2.217677850199557, 48.846293654285255],
                            [2.217723662074243, 48.84650862975517],
                            [2.217755892601807, 48.846704705976016],
                            [2.217785185939174, 48.84698980715465],
                            [2.217759589607089, 48.847604367235505],
                            [2.217713051009426, 48.84809314509538],
                            [2.21763671982561, 48.84867220018686],
                            [2.217441897458479, 48.84979429531697],
                            [2.217320445004932, 48.85043445332479],
                            [2.217284516088511, 48.85064214902991],
                            [2.217270677953445, 48.8507302642016],
                            [2.217090790594797, 48.85186766191821],
                            [2.21688027197423, 48.8532721121523],
                            [2.216876140734322, 48.85329009315532],
                            [2.216866440187264, 48.85335662964841],
                            [2.216854017892107, 48.85342226424424],
                            [2.216852626529476, 48.85343395321325],
                            [2.216759874326773, 48.85403367388381],
                            [2.216726191708887, 48.854437414007705],
                            [2.216688010001731, 48.85501111289101],
                            [2.216579936038335, 48.85630865716042],
                            [2.216572237792291, 48.85641999136021],
                        ],
                    },
                },
                1342: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.01877759276227, 2.235980964305266],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1181.78822059,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.229376488386948,
                            49.015584975459475,
                            2.242479108496568,
                            49.02177395624445,
                        ),
                        "coordinates": [
                            [2.229376488386948, 49.02177395624445],
                            [2.229782565441072, 49.02159168744298],
                            [2.230405307962166, 49.02131529049074],
                            [2.23090351568045, 49.02108553755557],
                            [2.231916333809215, 49.020621543401255],
                            [2.233104294101219, 49.02008688591308],
                            [2.235002521418409, 49.01923404597375],
                            [2.235543105019262, 49.01898812370755],
                            [2.236943116450256, 49.01835536291396],
                            [2.237702643080775, 49.01800980115395],
                            [2.239198282595041, 49.017348860962805],
                            [2.239857151502305, 49.01706024488593],
                            [2.24039850736022, 49.016811287614544],
                            [2.240903643902251, 49.01656512026528],
                            [2.241496124230893, 49.01622435879959],
                            [2.241928664590731, 49.01596302864393],
                            [2.24235166954054, 49.015680106451185],
                            [2.242479108496568, 49.015584975459475],
                        ],
                    },
                },
                1343: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.92879071327043, 2.1710667342244236],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2834.83343407,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.157086496469818,
                            48.920379373924355,
                            2.185353376302864,
                            48.93773606341459,
                        ),
                        "coordinates": [
                            [2.157086496469818, 48.93773606341459],
                            [2.159197405123777, 48.93641370175961],
                            [2.161018108093818, 48.93526729322632],
                            [2.163222511688236, 48.93384305627839],
                            [2.165271328905886, 48.93246851051073],
                            [2.167844735351957, 48.93077825372754],
                            [2.168677232891343, 48.93021081769022],
                            [2.169625501214284, 48.929574546127455],
                            [2.172737711964865, 48.92756137399833],
                            [2.175144080165984, 48.926003956090945],
                            [2.177159517778266, 48.924700530967506],
                            [2.177716684610704, 48.92435392458564],
                            [2.178190624459705, 48.924061924895064],
                            [2.178769411868191, 48.9237248614286],
                            [2.179221561827801, 48.923468515339664],
                            [2.179691766691154, 48.92320981530839],
                            [2.180295726453799, 48.92289895093932],
                            [2.181319146329174, 48.92238403128845],
                            [2.182027886422397, 48.922042369149914],
                            [2.183726181297828, 48.92118856022069],
                            [2.184525333215453, 48.92078752097505],
                            [2.185353376302864, 48.920379373924355],
                        ],
                    },
                },
                1344: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.92879071327043, 2.1710667342244236],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 2834.83343407,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.157086496469818,
                            48.920379373924355,
                            2.185353376302864,
                            48.93773606341459,
                        ),
                        "coordinates": [
                            [2.157086496469818, 48.93773606341459],
                            [2.159197405123777, 48.93641370175961],
                            [2.161018108093818, 48.93526729322632],
                            [2.163222511688236, 48.93384305627839],
                            [2.165271328905886, 48.93246851051073],
                            [2.167844735351957, 48.93077825372754],
                            [2.168677232891343, 48.93021081769022],
                            [2.169625501214284, 48.929574546127455],
                            [2.172737711964865, 48.92756137399833],
                            [2.175144080165984, 48.926003956090945],
                            [2.177159517778266, 48.924700530967506],
                            [2.177716684610704, 48.92435392458564],
                            [2.178190624459705, 48.924061924895064],
                            [2.178769411868191, 48.9237248614286],
                            [2.179221561827801, 48.923468515339664],
                            [2.179691766691154, 48.92320981530839],
                            [2.180295726453799, 48.92289895093932],
                            [2.181319146329174, 48.92238403128845],
                            [2.182027886422397, 48.922042369149914],
                            [2.183726181297828, 48.92118856022069],
                            [2.184525333215453, 48.92078752097505],
                            [2.185353376302864, 48.920379373924355],
                        ],
                    },
                },
                1345: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.98330064304362, 1.716098108336436],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 151.854398319,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.715210986447546,
                            48.98294677854624,
                            1.716985230225326,
                            48.983654507541004,
                        ),
                        "coordinates": [
                            [1.716985230225326, 48.98294677854624],
                            [1.715210986447546, 48.983654507541004],
                        ],
                    },
                },
                1346: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.023280348033, 2.2260537831875817],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 590.063120613,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.222727322175325,
                            49.02177395624445,
                            2.229376488386948,
                            49.02477854792459,
                        ),
                        "coordinates": [
                            [2.222727322175325, 49.02477854792459],
                            [2.224586745203469, 49.02394102138565],
                            [2.225260201728623, 49.02363772338902],
                            [2.2256680978113, 49.02345646592867],
                            [2.226292266646845, 49.0231746971702],
                            [2.226601601256457, 49.02303920403792],
                            [2.227095715482583, 49.02282115490708],
                            [2.228788889933695, 49.02203769485087],
                            [2.229376488386948, 49.02177395624445],
                        ],
                    },
                },
                1347: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.53772572523229, 3.270844147915459],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3252.84546959,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.255368150025012,
                            48.52914896682657,
                            3.287312848478531,
                            48.54559534692547,
                        ),
                        "coordinates": [
                            [3.255368150025012, 48.52914896682657],
                            [3.255690089588158, 48.52935320174904],
                            [3.25602354297575, 48.529527262609776],
                            [3.256402560125219, 48.52969681903616],
                            [3.256828379538952, 48.529864684489255],
                            [3.25722493329347, 48.529999473179565],
                            [3.25760322964848, 48.53011537394126],
                            [3.257991717162337, 48.53022664555353],
                            [3.258449791736273, 48.53032274623187],
                            [3.258779947190074, 48.53038391249398],
                            [3.259128806856056, 48.53043143550042],
                            [3.259408141998831, 48.530453443435675],
                            [3.259736182160061, 48.53047325550467],
                            [3.260351691178092, 48.530501323485346],
                            [3.260831410569387, 48.53052168365509],
                            [3.261220347061276, 48.530554687910474],
                            [3.261639775358048, 48.53061062052243],
                            [3.26216968109057, 48.53070971705964],
                            [3.262614429562589, 48.530816701526504],
                            [3.263003723686052, 48.53092683588099],
                            [3.263375522516217, 48.531051995524656],
                            [3.263685421679234, 48.531179368419025],
                            [3.263865596088829, 48.53125703553626],
                            [3.26419871780733, 48.531404497902145],
                            [3.264685907534571, 48.53168199889534],
                            [3.26507928515967, 48.531938683101195],
                            [3.265433872537972, 48.53222086462935],
                            [3.265801567799281, 48.53255240052916],
                            [3.266112738689205, 48.532902386052214],
                            [3.266341225324263, 48.53324765235497],
                            [3.266486174939783, 48.53346949689121],
                            [3.266604146961927, 48.53369695837147],
                            [3.26670492126056, 48.53394614427062],
                            [3.266766783458831, 48.53414169038891],
                            [3.266807417949374, 48.53428794794007],
                            [3.266846566316326, 48.534499867670725],
                            [3.266867794175553, 48.53462200171069],
                            [3.266886030864735, 48.53472887221476],
                            [3.266913195120464, 48.53517021944645],
                            [3.266947965302395, 48.5356564713358],
                            [3.266960754447912, 48.5359072790684],
                            [3.266999987747873, 48.53634223160657],
                            [3.267036133351005, 48.536597119371606],
                            [3.26713823286924, 48.53700390160913],
                            [3.26722358754864, 48.537224435577514],
                            [3.267287562092798, 48.537387588056625],
                            [3.267484065632095, 48.537759196615404],
                            [3.267646285942883, 48.53803485736007],
                            [3.26791320474016, 48.53840588641006],
                            [3.268341580061928, 48.538865520587166],
                            [3.268457313031621, 48.53897158931293],
                            [3.268541383922185, 48.53905003889695],
                            [3.26862956785558, 48.539131152644025],
                            [3.269003452069697, 48.539427554617],
                            [3.269428944902274, 48.539731625092585],
                            [3.269995558012287, 48.54012487618467],
                            [3.270450869254986, 48.540427386365785],
                            [3.270776785868712, 48.54061985476306],
                            [3.271169140056286, 48.540816272784134],
                            [3.271634434834693, 48.54100219405207],
                            [3.272013112575873, 48.541118681519286],
                            [3.272494838702689, 48.54124151111355],
                            [3.272915925673128, 48.541308181205274],
                            [3.273214706008951, 48.5413524779723],
                            [3.273446713134813, 48.541374843174474],
                            [3.273880636760325, 48.54140363282713],
                            [3.274364629843324, 48.54143020669234],
                            [3.275008610449638, 48.54146624726361],
                            [3.275514286412088, 48.54149353723249],
                            [3.275838393964453, 48.54151603337482],
                            [3.276183015119749, 48.54154915076131],
                            [3.276444951197132, 48.54157845632615],
                            [3.27680893660531, 48.54163299505676],
                            [3.277186718020794, 48.54170090856699],
                            [3.277360789644695, 48.541739034748545],
                            [3.277836739944862, 48.54185750584774],
                            [3.278238684146535, 48.541970068945105],
                            [3.278578433637547, 48.5420826306666],
                            [3.278895761533684, 48.54219753609615],
                            [3.279653256206776, 48.54250690293604],
                            [3.280540133744272, 48.542853858477905],
                            [3.281222371344977, 48.5431215727747],
                            [3.281921020027558, 48.54339723955717],
                            [3.282364456002428, 48.543569810059196],
                            [3.282854294994619, 48.54376087785212],
                            [3.283701360478453, 48.54409582488643],
                            [3.284452369935438, 48.5443986445424],
                            [3.285056778986954, 48.544631013290136],
                            [3.286469421507604, 48.545201054831054],
                            [3.286943123611345, 48.54541013667705],
                            [3.287312848478531, 48.54559534692547],
                        ],
                    },
                },
                1348: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.08858576614457, 2.3565459690056496],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2273.35690815,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35083083355881,
                            49.079470233982065,
                            2.361270555241057,
                            49.09840026247686,
                        ),
                        "coordinates": [
                            [2.35083083355881, 49.079470233982065],
                            [2.350972687817406, 49.07955993269019],
                            [2.351237252861799, 49.07974553747962],
                            [2.351569982228981, 49.07998290374525],
                            [2.352066795750535, 49.08037590492253],
                            [2.352483453921169, 49.08074702437984],
                            [2.352675485087074, 49.08092782728793],
                            [2.352856655735549, 49.08112290762148],
                            [2.352994346154071, 49.08127040644488],
                            [2.353213259884614, 49.081534827650366],
                            [2.353447458948779, 49.08182615887204],
                            [2.353617293706934, 49.082051851768284],
                            [2.354353296314638, 49.08307136239222],
                            [2.354800737889736, 49.08371712716377],
                            [2.354997994459554, 49.08401655470446],
                            [2.355437707103021, 49.08464687506328],
                            [2.355897274303016, 49.085350517296966],
                            [2.356162410887202, 49.08580142210274],
                            [2.3562987977645, 49.086049193304646],
                            [2.35645105824857, 49.08634182459115],
                            [2.35660117192342, 49.086692989105835],
                            [2.356766533392021, 49.08711981258591],
                            [2.356903679092715, 49.087640861930495],
                            [2.357027815885794, 49.08823472231403],
                            [2.35708009807407, 49.08852023197048],
                            [2.357369847004412, 49.09010338755587],
                            [2.357417772047567, 49.090353683962576],
                            [2.357761988303362, 49.09218237676576],
                            [2.357936245178144, 49.093013207253854],
                            [2.358053798988859, 49.093404347016744],
                            [2.358193077257261, 49.09375979380259],
                            [2.35831927793891, 49.09402958578735],
                            [2.358523808291113, 49.0943701737494],
                            [2.359082886636688, 49.095207289892414],
                            [2.360035669599188, 49.09662034401773],
                            [2.360213415890133, 49.09685992909395],
                            [2.360668734397019, 49.09752959546552],
                            [2.361108191985409, 49.09815336383457],
                            [2.361236557413978, 49.09835034471274],
                            [2.361270555241057, 49.09840026247686],
                        ],
                    },
                },
                1349: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.128051381836364, 2.223634602836481],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 3625.59315599,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.210019869292197,
                            49.114783970085064,
                            2.242677776778168,
                            49.13600056459098,
                        ),
                        "coordinates": [
                            [2.242677776778168, 49.13600056459098],
                            [2.241404282416625, 49.1355703825226],
                            [2.240852323823804, 49.13538647153163],
                            [2.239903183445893, 49.135070030821836],
                            [2.239733353511173, 49.13501323374128],
                            [2.238975968880641, 49.134760794546416],
                            [2.23626698026539, 49.13385738564339],
                            [2.236053332870124, 49.133786156468716],
                            [2.234913897603343, 49.1334038604228],
                            [2.233299268950995, 49.13286285319506],
                            [2.232265317849512, 49.13251839510503],
                            [2.230411092950836, 49.131898893401264],
                            [2.227976310400957, 49.13107917438867],
                            [2.225163674043916, 49.130132239341],
                            [2.224399589170243, 49.12987879906107],
                            [2.223561565325184, 49.129602798510454],
                            [2.222749622606446, 49.129311530450956],
                            [2.222014466740057, 49.12900324716752],
                            [2.22145734679115, 49.128744598056585],
                            [2.219669739220031, 49.12788668171439],
                            [2.218502185456426, 49.1273387281673],
                            [2.216959664985112, 49.126601524850045],
                            [2.21657232880148, 49.1264167691166],
                            [2.215867501979152, 49.126067111456834],
                            [2.215692350594532, 49.12596890618907],
                            [2.215155950925862, 49.12566978102914],
                            [2.21467847964165, 49.12536981698402],
                            [2.214511599403723, 49.12525363348429],
                            [2.214258536460963, 49.12508070339735],
                            [2.213887936254705, 49.12478714432074],
                            [2.213618539565318, 49.12457282931554],
                            [2.213059357801466, 49.1240803267129],
                            [2.212499109566168, 49.12347181356781],
                            [2.212317456009334, 49.123241404054305],
                            [2.211986931907959, 49.12282288389816],
                            [2.211543402886758, 49.12212366657644],
                            [2.211261266494421, 49.1215406304532],
                            [2.211214921604879, 49.12144615593669],
                            [2.211086443078509, 49.12114608550616],
                            [2.210991765668457, 49.12083980317458],
                            [2.210890299210122, 49.12033340171316],
                            [2.210767574732576, 49.11956708727531],
                            [2.210635861786001, 49.11856695283363],
                            [2.21050845506467, 49.117492183205364],
                            [2.210364598647382, 49.116423690022614],
                            [2.210244763764672, 49.11560611982857],
                            [2.210087426728598, 49.1149908444586],
                            [2.210019869292197, 49.114783970085064],
                        ],
                    },
                },
                1350: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.982797574591515, 2.2636157549922533],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 1016.7562533,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25747415725031,
                            48.98091190326584,
                            2.269851993930268,
                            48.98500470125915,
                        ),
                        "coordinates": [
                            [2.269851993930268, 48.98091190326584],
                            [2.26954526509951, 48.98096437982222],
                            [2.269004726617549, 48.98105798659492],
                            [2.268027562605059, 48.981275029387575],
                            [2.267747367056282, 48.98135669483977],
                            [2.266934115114945, 48.98159361082247],
                            [2.266826128905727, 48.98163041570474],
                            [2.266060654556562, 48.981888936410705],
                            [2.26429179731313, 48.98251102926852],
                            [2.263314407492389, 48.982847635066406],
                            [2.261622025452842, 48.983449052471265],
                            [2.261108001244041, 48.9836411590941],
                            [2.260894732323527, 48.983721952743366],
                            [2.258429804144584, 48.984645647981104],
                            [2.257613609603145, 48.984951740311374],
                            [2.25747415725031, 48.98500470125915],
                        ],
                    },
                },
                1351: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.87951177074579, 2.5389265225235627],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2173.91762563,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.525434250765843,
                            48.877157839702775,
                            2.552881649780832,
                            48.88373428097723,
                        ),
                        "coordinates": [
                            [2.525434250765843, 48.88373428097723],
                            [2.526666287004969, 48.88322464273962],
                            [2.529893665234711, 48.88189251276156],
                            [2.532193078549603, 48.88094638425414],
                            [2.53263711346043, 48.880766017590894],
                            [2.533258374056588, 48.88052186468117],
                            [2.533787208099623, 48.880321963756685],
                            [2.534420641712197, 48.88009741051807],
                            [2.535060507629551, 48.87988882378437],
                            [2.53570041386419, 48.87969165420274],
                            [2.536810253929025, 48.87937564330709],
                            [2.53760020105514, 48.87917439357388],
                            [2.538355588221693, 48.87899223367205],
                            [2.538972613438071, 48.87885219000443],
                            [2.539638713895057, 48.878715863499934],
                            [2.540322132397052, 48.87858140561485],
                            [2.54108058223252, 48.878446808795324],
                            [2.541775614810747, 48.87833135645167],
                            [2.542626436694511, 48.878204198988534],
                            [2.543448481188119, 48.87809802464671],
                            [2.5444321247588, 48.87798964755984],
                            [2.545955286181782, 48.87784791717988],
                            [2.54833518545465, 48.87762083257569],
                            [2.552881649780832, 48.877157839702775],
                        ],
                    },
                },
                1352: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.863620297952025, 2.3549039426883405],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 558.051977733,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.353495741491146,
                            48.86120499033039,
                            2.356729869173701,
                            48.86540743543024,
                        ),
                        "coordinates": [
                            [2.353495741491146, 48.86120499033039],
                            [2.353951246423372, 48.86203319909788],
                            [2.355651559539433, 48.8651316525941],
                            [2.355681916076442, 48.86517801532076],
                            [2.355725118090814, 48.865226109175325],
                            [2.355777647405688, 48.86526997414084],
                            [2.355838571781983, 48.86530882635633],
                            [2.3559068037637, 48.86534197645589],
                            [2.355981122476644, 48.86536883058657],
                            [2.356060203393973, 48.86538890855637],
                            [2.356142635924732, 48.86540185472184],
                            [2.356226949347834, 48.86540743543024],
                            [2.356311638524229, 48.86540555444716],
                            [2.35639518721672, 48.865396241390734],
                            [2.356453303725956, 48.86538513583588],
                            [2.356727701162055, 48.86532320095986],
                            [2.356729869173701, 48.865322711678054],
                        ],
                    },
                },
                1353: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.85920940904995, 2.35236436416537],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 463.112828702,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351008461406026,
                            48.85745183174311,
                            2.353495741491146,
                            48.86120499033039,
                        ),
                        "coordinates": [
                            [2.351008461406026, 48.85745183174311],
                            [2.351107935501583, 48.85747851171868],
                            [2.351202723360607, 48.85751179891258],
                            [2.351292209334574, 48.85755155329652],
                            [2.351374289934534, 48.857596717535294],
                            [2.35144924805845, 48.857647449663695],
                            [2.351515904555908, 48.85770299864217],
                            [2.351573551198283, 48.85776277516925],
                            [2.351621578432567, 48.85782614551006],
                            [2.351685280781979, 48.85793731037844],
                            [2.351766499609593, 48.85808391364578],
                            [2.353495741491146, 48.86120499033039],
                        ],
                    },
                },
                1354: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.87621616189028, 2.40269772291691],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 591.335208927,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.398867596625601,
                            48.875474456679164,
                            2.406480156998486,
                            48.87717481930547,
                        ),
                        "coordinates": [
                            [2.398867596625601, 48.875474456679164],
                            [2.399945452476499, 48.875653293342644],
                            [2.401975577705545, 48.875962704851986],
                            [2.402980284862134, 48.876189865304625],
                            [2.406322842229573, 48.877130549468404],
                            [2.406480156998486, 48.87717481930547],
                        ],
                    },
                },
                1355: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.87088869543883, 2.3738489583480864],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 455.14436136,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.371094839731201,
                            48.86995751270301,
                            2.376593684096822,
                            48.871848794661254,
                        ),
                        "coordinates": [
                            [2.371094839731201, 48.86995751270301],
                            [2.373011334610331, 48.870558233558576],
                            [2.374350782277543, 48.871075383502955],
                            [2.375543723017723, 48.87149595198893],
                            [2.376593684096822, 48.871848794661254],
                        ],
                    },
                },
                1356: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.87563212896821, 2.5681045470920836],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2258.39682042,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.552881649780832,
                            48.87414408301457,
                            2.583331158055108,
                            48.877157839702775,
                        ),
                        "coordinates": [
                            [2.552881649780832, 48.877157839702775],
                            [2.556435116941477, 48.8767984829346],
                            [2.570329594400424, 48.87539282571081],
                            [2.583331158055108, 48.87414408301457],
                        ],
                    },
                },
                1357: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.84428014624863, 2.3673206450935265],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 690.302404299,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.365338652974602,
                            48.84226538647533,
                            2.36887365661624,
                            48.8465154041934,
                        ),
                        "coordinates": [
                            [2.365338652974602, 48.84226538647533],
                            [2.365581702747743, 48.842360082466925],
                            [2.365896837207859, 48.84248286129579],
                            [2.366179766294811, 48.84259420684467],
                            [2.366378276917268, 48.842678473626485],
                            [2.36652093491528, 48.8427406779857],
                            [2.367805756420793, 48.843516753593015],
                            [2.368603743534249, 48.84398359154772],
                            [2.368613952845228, 48.843990955427174],
                            [2.368680517280679, 48.8440451648817],
                            [2.36873812934944, 48.844103666467916],
                            [2.36878616720975, 48.84416582466734],
                            [2.368824094075066, 48.84423095584373],
                            [2.368851498872246, 48.844298346444134],
                            [2.36886807981777, 48.844367259207466],
                            [2.36887365661624, 48.84443693862438],
                            [2.368868170343802, 48.84450662082955],
                            [2.368851676528389, 48.84457554255854],
                            [2.368824357317036, 48.84464294930634],
                            [2.368786513226873, 48.844708101579585],
                            [2.368738554819308, 48.844770287444064],
                            [2.368681016316495, 48.84482882349635],
                            [2.368614520013647, 48.84488306816705],
                            [2.368539795267914, 48.84493242901664],
                            [2.368457664862869, 48.84497636356341],
                            [2.36839852946815, 48.84500268949175],
                            [2.367793985153708, 48.845283093874386],
                            [2.367623738238008, 48.845356273378954],
                            [2.367409105772909, 48.84545616184081],
                            [2.367200954908359, 48.84556185718046],
                            [2.366999644864983, 48.84567317516374],
                            [2.366805521335414, 48.845789924291104],
                            [2.366618926088273, 48.84591190045218],
                            [2.36653348424462, 48.84597128419046],
                            [2.36607939438648, 48.846344541826525],
                            [2.365954764486818, 48.84644698650262],
                            [2.365873469406567, 48.8465154041934],
                        ],
                    },
                },
                1358: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.871851611307754, 2.3327754078219627],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 307.128497401,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332346275459939,
                            48.87048670327018,
                            2.333451218566291,
                            48.87310927520845,
                        ),
                        "coordinates": [
                            [2.332407406427907, 48.87048670327018],
                            [2.332368422651606, 48.870604790640684],
                            [2.332354639251744, 48.8706776827435],
                            [2.332346275459939, 48.870780954250364],
                            [2.33235181051724, 48.87086933823204],
                            [2.332368389280324, 48.87095712189018],
                            [2.332395899609788, 48.87104369843858],
                            [2.332406957946197, 48.87107099576781],
                            [2.333169836686885, 48.87280328423632],
                            [2.3331721701563, 48.872811956978644],
                            [2.333194201115822, 48.87286974897049],
                            [2.333226830727106, 48.8729253174692],
                            [2.333257090439438, 48.872968139904444],
                            [2.333321759456249, 48.87302645983943],
                            [2.333350122051081, 48.87304931983174],
                            [2.333382616687077, 48.87307050217698],
                            [2.333451218566291, 48.87310927520845],
                        ],
                    },
                },
                1359: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.85004455692397, 2.3668638984250387],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 816.864703322,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.365534578350255,
                            48.8465154041934,
                            2.368736572626169,
                            48.853436962301636,
                        ),
                        "coordinates": [
                            [2.365873469406567, 48.8465154041934],
                            [2.365796015714314, 48.846591975983046],
                            [2.365727901976567, 48.84667231787929],
                            [2.36566955252252, 48.846755940198214],
                            [2.365621321164146, 48.84684232589973],
                            [2.36558350875538, 48.84693094327148],
                            [2.365556345487816, 48.84702124493503],
                            [2.365540003076054, 48.8471126742059],
                            [2.365534578350255, 48.847204669502965],
                            [2.365540108286864, 48.847296660830715],
                            [2.365543529548753, 48.847321769247976],
                            [2.365668613138265, 48.84761945874878],
                            [2.365831798750164, 48.8479409338374],
                            [2.368003155770195, 48.85262050948478],
                            [2.368044460969868, 48.85268394136593],
                            [2.368091741936538, 48.85274908657777],
                            [2.368145500042675, 48.85281663396646],
                            [2.368206803666388, 48.85288794179045],
                            [2.368317059376905, 48.85300677889183],
                            [2.368562033862506, 48.853256268027536],
                            [2.368736572626169, 48.853436962301636],
                        ],
                    },
                },
                1360: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.875823642710046, 2.391298504816888],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 338.483209832,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.389415032035528,
                            48.87511181695599,
                            2.393056091960662,
                            48.876806389212895,
                        ),
                        "coordinates": [
                            [2.389415032035528, 48.87511181695599],
                            [2.38959917634133, 48.875198775448666],
                            [2.389599302435571, 48.87519883544759],
                            [2.389671022580827, 48.875223106297355],
                            [2.389830532275632, 48.875271066067825],
                            [2.389994333133892, 48.87531225662931],
                            [2.39016176308479, 48.87534651001447],
                            [2.390332151480617, 48.87537369149088],
                            [2.390504811045136, 48.875393688728344],
                            [2.390569555648629, 48.87539928305279],
                            [2.390648925489887, 48.875406988778295],
                            [2.390772355286604, 48.87542497682706],
                            [2.390892936609155, 48.87544999202627],
                            [2.391009756868058, 48.87548184447868],
                            [2.391121921821131, 48.87552029042376],
                            [2.391228580028366, 48.875565039556044],
                            [2.391328921560709, 48.87561574872303],
                            [2.391422180589778, 48.875672033628724],
                            [2.391507646324979, 48.875733466191136],
                            [2.391518302173143, 48.87574192821111],
                            [2.392606654806674, 48.876616432759896],
                            [2.392638395776645, 48.876640529505565],
                            [2.39270929504965, 48.87668591061746],
                            [2.392787574977286, 48.87672566423549],
                            [2.392872213532804, 48.87675927344305],
                            [2.392962111418201, 48.87678629917537],
                            [2.393056091960662, 48.876806389212895],
                        ],
                    },
                },
                1361: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.865074564780095, 2.412352340408054],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 646.418240375,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.408031037075815,
                            48.86458308535296,
                            2.416697272847641,
                            48.865335318160284,
                        ),
                        "coordinates": [
                            [2.416697272847641, 48.865335318160284],
                            [2.414022583265388, 48.86531423768445],
                            [2.413709975100392, 48.86531177051379],
                            [2.413591929622808, 48.86531025867502],
                            [2.413297569440246, 48.86530142528098],
                            [2.413003910864711, 48.86528537830979],
                            [2.412711358617368, 48.8652621404364],
                            [2.41242031867911, 48.86523174333924],
                            [2.412131194169822, 48.86519423037787],
                            [2.411844382682452, 48.86514965118368],
                            [2.411560281653655, 48.86509806888105],
                            [2.411416040545009, 48.86506898006742],
                            [2.411182709007964, 48.86502031666559],
                            [2.409501686299345, 48.86466970908372],
                            [2.409385558893798, 48.864647278517744],
                            [2.409214315706944, 48.864620547640165],
                            [2.409040885024014, 48.864600892510786],
                            [2.408865936583966, 48.86458838837602],
                            [2.40869014995004, 48.86458308535296],
                            [2.408514203688139, 48.86458500118141],
                            [2.408512563247717, 48.86458505332982],
                            [2.408031037075815, 48.864600373375616],
                        ],
                    },
                },
                1362: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M5",
                        "rer": 0,
                        "extcode": "100110005:5",
                        "geo_point_2d": [48.884094650538735, 2.3753420886350396],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01375",
                        "navette": 0,
                        "idrefliga": "A01538",
                        "shape_leng": 679.296781792,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.371001440751848,
                            48.883122748932166,
                            2.379662256377633,
                            48.88521596739824,
                        ),
                        "coordinates": [
                            [2.371001440751848, 48.883147451389796],
                            [2.37111289403824, 48.883133767240594],
                            [2.371247864128303, 48.88312461499602],
                            [2.371383515299263, 48.883122748932166],
                            [2.371518946125887, 48.88312817960312],
                            [2.371653255714528, 48.8831408735027],
                            [2.371785547900056, 48.88316074409304],
                            [2.371914946134883, 48.88318766087589],
                            [2.3719670251197, 48.88320070992152],
                            [2.372364591068896, 48.883305380130466],
                            [2.376317674986654, 48.88434604988338],
                            [2.379662256377633, 48.88521596739824],
                        ],
                    },
                },
                1363: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.8734036963521, 2.334523199957223],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 170.216199076,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.333451218566291,
                            48.87310927520845,
                            2.335599675289124,
                            48.87368465719511,
                        ),
                        "coordinates": [
                            [2.333451218566291, 48.87310927520845],
                            [2.333521867958418, 48.87314040532045],
                            [2.333657459225254, 48.873176184969495],
                            [2.33450976068859, 48.87340109099358],
                            [2.334827868045458, 48.87348503172225],
                            [2.335599675289124, 48.87368465719511],
                        ],
                    },
                },
                1364: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.88631717924536, 2.3718054677617246],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 557.608014134,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.36939198436133,
                            48.884385145353036,
                            2.374204014730727,
                            48.888267619682566,
                        ),
                        "coordinates": [
                            [2.36939198436133, 48.884385145353036],
                            [2.369758586388047, 48.884677463805176],
                            [2.372599125794742, 48.88694227893127],
                            [2.373539510477335, 48.88771887507836],
                            [2.374204014730727, 48.888267619682566],
                        ],
                    },
                },
                1365: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.89241466676118, 2.3169705545210277],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 621.688283431,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313772157405782,
                            48.8905871866118,
                            2.320174757151551,
                            48.89425226223872,
                        ),
                        "coordinates": [
                            [2.320174757151551, 48.8905871866118],
                            [2.319851561468693, 48.890771180013346],
                            [2.315945642323179, 48.892994635476356],
                            [2.313772157405782, 48.89425226223872],
                        ],
                    },
                },
                1366: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86613458774467, 2.359139142521024],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 372.961108054,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356736756794993,
                            48.865586478498976,
                            2.361541532068171,
                            48.86668268024132,
                        ),
                        "coordinates": [
                            [2.361541532068171, 48.86668268024132],
                            [2.360761298893558, 48.866504688919626],
                            [2.356736756794993, 48.865586478498976],
                        ],
                    },
                },
                1367: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M11",
                        "rer": 0,
                        "extcode": "100110011:11",
                        "geo_point_2d": [48.85736682476314, 2.3496517934775927],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01381",
                        "navette": 0,
                        "idrefliga": "A01544",
                        "shape_leng": 205.960598724,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.348308895125139,
                            48.857273612159226,
                            2.351008461406026,
                            48.857556359369646,
                        ),
                        "coordinates": [
                            [2.348308895125139, 48.857556359369646],
                            [2.349022286753301, 48.85735959632077],
                            [2.349074886884622, 48.85734576174955],
                            [2.349204898269474, 48.8573171059861],
                            [2.349337980103433, 48.857295445739595],
                            [2.349473274754338, 48.857280921133174],
                            [2.349609899250331, 48.85727362808741],
                            [2.349746969888123, 48.857273612159226],
                            [2.349883599437835, 48.85728087392269],
                            [2.350018899889665, 48.85729536718528],
                            [2.350067341689887, 48.85730237273176],
                            [2.3509041023079, 48.85743184783179],
                            [2.350905356513154, 48.85743204349865],
                            [2.351008461406026, 48.85745183174311],
                        ],
                    },
                },
                1368: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.853926890433584, 2.3453964871118984],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 371.045692715,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.343285978923924,
                            48.853167984890604,
                            2.347321317067427,
                            48.85493637835866,
                        ),
                        "coordinates": [
                            [2.343285978923924, 48.853167984890604],
                            [2.343746951927781, 48.85340986468363],
                            [2.343786634718435, 48.85343036906093],
                            [2.34394208894752, 48.85350488493737],
                            [2.344103733984837, 48.853573423255405],
                            [2.344271046546, 48.85363576078165],
                            [2.344443478592846, 48.85369169123702],
                            [2.344620469462434, 48.853741036155675],
                            [2.34480144058685, 48.85378363136603],
                            [2.344985800798257, 48.853819338711894],
                            [2.345172951825837, 48.853848042485254],
                            [2.345362280131947, 48.85386964848251],
                            [2.345416846468415, 48.853874521118875],
                            [2.345807918379932, 48.853930614810615],
                            [2.345834660871488, 48.85393622729009],
                            [2.345984478613268, 48.85397219660927],
                            [2.346130129342023, 48.85401497445932],
                            [2.346270901561544, 48.854064353713184],
                            [2.346406112837068, 48.854120091431355],
                            [2.34653510286675, 48.85418191781675],
                            [2.34665724308871, 48.85424953087096],
                            [2.346771939338151, 48.85432260180413],
                            [2.346878631858237, 48.854400774135364],
                            [2.346976800717718, 48.854483666419775],
                            [2.34706596847975, 48.854570876759205],
                            [2.347112605710473, 48.854622362895185],
                            [2.347321317067427, 48.85493637835866],
                        ],
                    },
                },
                1369: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.8603319127353, 2.346326464471448],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 482.320417096,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345352231665122,
                            48.858382369405476,
                            2.347564829759891,
                            48.8623162786956,
                        ),
                        "coordinates": [
                            [2.347564829759891, 48.858382369405476],
                            [2.347536451750718, 48.85860391976291],
                            [2.347521620800156, 48.858688402076126],
                            [2.347504651314359, 48.8587629771744],
                            [2.347480790795597, 48.85884275250362],
                            [2.347452334920229, 48.85891485199608],
                            [2.347418784116171, 48.85898052931728],
                            [2.347379813115494, 48.85904039784534],
                            [2.346837613314393, 48.85964207230848],
                            [2.345567053572672, 48.86105193960667],
                            [2.345546335861474, 48.86107565274057],
                            [2.345487910262844, 48.86115213214898],
                            [2.345439529415214, 48.8612316028369],
                            [2.345401533093947, 48.86131349558822],
                            [2.345374200007672, 48.86139722016574],
                            [2.345357725921898, 48.86148217058706],
                            [2.345352231665122, 48.86156773865874],
                            [2.34535775507353, 48.86165330403883],
                            [2.345374257555494, 48.86173825405865],
                            [2.345401618773269, 48.86182197290159],
                            [2.345439643229877, 48.8619038596261],
                            [2.345449658746103, 48.861922003881126],
                            [2.345673828222722, 48.8623162786956],
                        ],
                    },
                },
                1370: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.84354757022039, 2.3269515979331534],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 498.918701621,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.324353041157966,
                            48.842882664850144,
                            2.32888186190577,
                            48.84494263342595,
                        ),
                        "coordinates": [
                            [2.324353041157966, 48.84373548931853],
                            [2.324681501196454, 48.84362769254908],
                            [2.325294694508671, 48.84342282373244],
                            [2.326855734750079, 48.842915429299445],
                            [2.326885497782932, 48.84290433132922],
                            [2.326941693363467, 48.842889967182465],
                            [2.327000931647931, 48.842882664850144],
                            [2.327061192871636, 48.84288267018436],
                            [2.327120427754954, 48.84288998244921],
                            [2.327176617435257, 48.84290435555716],
                            [2.32722784701426, 48.84292530028108],
                            [2.327272377592033, 48.84295209814901],
                            [2.327306546428163, 48.84298159248768],
                            [2.327386678309612, 48.84305433757233],
                            [2.328688875356715, 48.844178562201584],
                            [2.328745301210279, 48.844229963562164],
                            [2.328793606101851, 48.84428643580812],
                            [2.328831845628299, 48.84434617560892],
                            [2.328859518824038, 48.84440840311356],
                            [2.328876261385134, 48.84447230685859],
                            [2.32888186190577, 48.84453705285236],
                            [2.32887916228468, 48.8445819393109],
                            [2.32877802689008, 48.84494263342595],
                        ],
                    },
                },
                1371: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.878195407476674, 2.3910994020589666],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 407.401470358,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.389224171125526,
                            48.876949848110215,
                            2.392983964817394,
                            48.87948139490827,
                        ),
                        "coordinates": [
                            [2.392983964817394, 48.876949848110215],
                            [2.392865674363053, 48.876951447103544],
                            [2.392811628170215, 48.87695484495557],
                            [2.392760250042924, 48.87696001540845],
                            [2.392638570555997, 48.87697641526248],
                            [2.392595942488783, 48.876984908999184],
                            [2.392559168733455, 48.876994720268776],
                            [2.392509693383977, 48.877013380340685],
                            [2.392458713739995, 48.877039435150365],
                            [2.392408024927069, 48.87707106007096],
                            [2.392320802628307, 48.87713138513165],
                            [2.38986204128852, 48.8792655331372],
                            [2.389837639392525, 48.87928569763933],
                            [2.389772105573856, 48.87933157564967],
                            [2.389698941082792, 48.87937212576759],
                            [2.389619132720282, 48.87940679992347],
                            [2.389533760458124, 48.879435128765664],
                            [2.389443981003073, 48.87945672787306],
                            [2.38935100586424, 48.87947130753626],
                            [2.389256094575559, 48.87947866912641],
                            [2.389224171125526, 48.87948139490827],
                        ],
                    },
                },
                1372: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.85661961446308, 2.3477904649503265],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 395.368508135,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347321317067427,
                            48.85493637835866,
                            2.348022501739844,
                            48.858382369405476,
                        ),
                        "coordinates": [
                            [2.347321317067427, 48.85493637835866],
                            [2.347658793896028, 48.8554441171689],
                            [2.347677622364321, 48.85547416465537],
                            [2.347757651488049, 48.85561334850553],
                            [2.347827393875214, 48.855754921556624],
                            [2.347886692769494, 48.855898552909586],
                            [2.347935405104332, 48.8560439063417],
                            [2.347973419175773, 48.85619064399999],
                            [2.348000643796975, 48.8563384218454],
                            [2.348017017771351, 48.85648689510021],
                            [2.348022501739844, 48.85663571640501],
                            [2.348017083576132, 48.8567845403446],
                            [2.348000774389873, 48.856933016231594],
                            [2.347973615195533, 48.85708079983409],
                            [2.347935664760365, 48.85722754431622],
                            [2.347887014495468, 48.85737290841345],
                            [2.347880238514288, 48.857390827028695],
                            [2.347651859077071, 48.85798718189509],
                            [2.347625155718968, 48.85806186227697],
                            [2.347592556365331, 48.8581942083244],
                            [2.347564829759891, 48.858382369405476],
                        ],
                    },
                },
                1373: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.87925174443731, 2.3853299624004913],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 569.492067698,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.381614511928966,
                            48.878514114023815,
                            2.389115807376888,
                            48.87951289197097,
                        ),
                        "coordinates": [
                            [2.381614511928966, 48.878514114023815],
                            [2.382034705143964, 48.87863369499425],
                            [2.382986854488347, 48.87892846033401],
                            [2.383489296157436, 48.87908153555889],
                            [2.383704425213071, 48.87913761207848],
                            [2.383958117714156, 48.879196457838056],
                            [2.384152943677156, 48.87923649743454],
                            [2.384398978317489, 48.879276535641736],
                            [2.384765123780869, 48.8793299125785],
                            [2.385133469376788, 48.8793762417499],
                            [2.385503701815854, 48.879415483757306],
                            [2.385875509094121, 48.87944760550768],
                            [2.38624857639284, 48.87947258109184],
                            [2.386263411153951, 48.87947342427202],
                            [2.387000996636222, 48.87949599386146],
                            [2.387608417651995, 48.87951289197097],
                            [2.388259716460196, 48.87949944840888],
                            [2.389115807376888, 48.87948177191293],
                        ],
                    },
                },
                1374: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.852483943948606, 2.3415549676131526],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 295.922708276,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.339727782955844,
                            48.85219125525291,
                            2.343285978923924,
                            48.853167984890604,
                        ),
                        "coordinates": [
                            [2.339727782955844, 48.85230076310175],
                            [2.339806676621358, 48.852281402713636],
                            [2.339960608116233, 48.852249156558436],
                            [2.340117517013976, 48.852223918218236],
                            [2.340276668703159, 48.85220580414481],
                            [2.340437322161296, 48.85219489928057],
                            [2.340598728613911, 48.85219125525291],
                            [2.340760134292423, 48.852194887691226],
                            [2.340920791277333, 48.85220578078369],
                            [2.341079945277978, 48.85222388361241],
                            [2.341236856071344, 48.8522491102658],
                            [2.341390793344841, 48.852281345211814],
                            [2.341541038125168, 48.85232043790946],
                            [2.341686889568309, 48.85236620464457],
                            [2.341827668989818, 48.85241843304836],
                            [2.341962721271525, 48.85247687850748],
                            [2.342076290909316, 48.852533221707866],
                            [2.343285978923924, 48.853167984890604],
                        ],
                    },
                },
                1375: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7bis",
                        "rer": 0,
                        "extcode": "100110107:7B",
                        "geo_point_2d": [48.88168774800399, 2.3721670803962023],
                        "indice_lig": "7b",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01387",
                        "navette": 0,
                        "idrefliga": "A01550",
                        "shape_leng": 346.215570925,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.370157961739611,
                            48.88082126138327,
                            2.374147155202552,
                            48.882465245572064,
                        ),
                        "coordinates": [
                            [2.370157961739611, 48.882465245572064],
                            [2.370296568275096, 48.88244380982026],
                            [2.370432280397605, 48.88241544105327],
                            [2.370564301094928, 48.88238030326493],
                            [2.370691857404662, 48.882338601947616],
                            [2.370699706715681, 48.88233552073726],
                            [2.370814196314108, 48.88229058496973],
                            [2.370836094707487, 48.88228107723509],
                            [2.370876680266147, 48.88226318432865],
                            [2.374147155202552, 48.88082126138327],
                        ],
                    },
                },
                1376: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.84297223433604, 2.3266902816054675],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 381.364802691,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.324397012385794,
                            48.84221841361352,
                            2.329008926235403,
                            48.84378130573585,
                        ),
                        "coordinates": [
                            [2.329008926235403, 48.84221841361352],
                            [2.326885497782932, 48.84290433132922],
                            [2.325450508555287, 48.84337530851426],
                            [2.324681501196454, 48.84362769254908],
                            [2.324604863697648, 48.8436558443974],
                            [2.324528213318254, 48.84369213267198],
                            [2.324458601335629, 48.8437341500202],
                            [2.324397012385794, 48.84378130573585],
                        ],
                    },
                },
                1377: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.86691027265499, 2.362887841846435],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 203.339145924,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.361541532068171,
                            48.86668268024132,
                            2.364247995104706,
                            48.86702678847435,
                        ),
                        "coordinates": [
                            [2.364247995104706, 48.86702678847435],
                            [2.363968632426944, 48.86702323664648],
                            [2.363689696211736, 48.867012451229996],
                            [2.363411618495016, 48.866994449813795],
                            [2.363134825770753, 48.86696925715589],
                            [2.362859747036705, 48.866936916018155],
                            [2.362586804417083, 48.866897473626416],
                            [2.362316419844854, 48.866850992497895],
                            [2.362049011070817, 48.86679754232588],
                            [2.361920251417281, 48.86676907436977],
                            [2.361541532068171, 48.86668268024132],
                        ],
                    },
                },
                1378: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.8447546221843, 2.3532207049857803],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 435.824515943,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352224728183084,
                            48.84286683068266,
                            2.355050264434754,
                            48.845950665750145,
                        ),
                        "coordinates": [
                            [2.352224728183084, 48.84286683068266],
                            [2.352390010515285, 48.84396747775431],
                            [2.352440043845328, 48.84422135137808],
                            [2.352445722264842, 48.844247307099025],
                            [2.352478772635126, 48.84436737172292],
                            [2.35252264214395, 48.84448591470273],
                            [2.352577175300277, 48.84460251518367],
                            [2.352591617014774, 48.8446297720215],
                            [2.352631253595562, 48.84469520096154],
                            [2.352685336010534, 48.84476562935041],
                            [2.352749173990135, 48.84483240512455],
                            [2.352822206607225, 48.84489494334812],
                            [2.352903789396866, 48.84495269190916],
                            [2.35299320782415, 48.84500514418397],
                            [2.353059140364366, 48.84503804050377],
                            [2.354490607420507, 48.84579549461105],
                            [2.354533578845669, 48.845816923468924],
                            [2.354627769630674, 48.8458570538036],
                            [2.354727547509367, 48.84589079456798],
                            [2.354831920487733, 48.84591781213303],
                            [2.354939849456949, 48.84593783557358],
                            [2.355050264434754, 48.845950665750145],
                        ],
                    },
                },
                1379: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.87673164410766, 2.360436206107352],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 495.440617049,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358057907074739,
                            48.87594885178755,
                            2.362160071922951,
                            48.878565625799595,
                        ),
                        "coordinates": [
                            [2.358057907074739, 48.87627270260409],
                            [2.359053148382046, 48.876114491463035],
                            [2.360024784174921, 48.87596002379328],
                            [2.360066816404764, 48.875954347960075],
                            [2.360149360931282, 48.87594885178755],
                            [2.360232276511298, 48.87595066373626],
                            [2.360314089732908, 48.87595974895182],
                            [2.360393332840342, 48.87597594490822],
                            [2.360468596880101, 48.87599896349056],
                            [2.360538538470702, 48.87602839462773],
                            [2.360601912476787, 48.87606371006388],
                            [2.360657579923172, 48.87610428498354],
                            [2.360704551731527, 48.87614938925123],
                            [2.360741995096407, 48.876198223417816],
                            [2.360747915381803, 48.876207759198955],
                            [2.362065213930345, 48.87840725153912],
                            [2.362160071922951, 48.878565625799595],
                        ],
                    },
                },
                1380: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.86471104613968, 2.385477541209681],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 558.33300654,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.383383250455203,
                            48.86265401909355,
                            2.387607288151709,
                            48.86680003509802,
                        ),
                        "coordinates": [
                            [2.383383250455203, 48.86680003509802],
                            [2.383453405662847, 48.86668809861342],
                            [2.383538563935678, 48.86654216964851],
                            [2.383620421896906, 48.86640691856516],
                            [2.383671727720077, 48.86632214385058],
                            [2.383824428568791, 48.866159182681635],
                            [2.38720766515553, 48.8631790271213],
                            [2.38722556823914, 48.863164412738875],
                            [2.387312811735819, 48.863086313519005],
                            [2.387390962093239, 48.86300412963641],
                            [2.387434950999083, 48.862949833042585],
                            [2.387518298580755, 48.86282937445551],
                            [2.387548213712643, 48.862775508518176],
                            [2.387607288151709, 48.86265401909355],
                        ],
                    },
                },
                1381: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.83366233440972, 2.3541381448680383],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 541.374678258,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352588924250765,
                            48.83143363013256,
                            2.355643643033711,
                            48.83586348597116,
                        ),
                        "coordinates": [
                            [2.355643643033711, 48.83143363013256],
                            [2.355531266307394, 48.83164465655125],
                            [2.355408645247036, 48.831853182229345],
                            [2.355275911825454, 48.83205899199974],
                            [2.355133204811917, 48.83226187252883],
                            [2.355068046618973, 48.83234916305273],
                            [2.352723687200511, 48.83567130718695],
                            [2.352588924250765, 48.83586348597116],
                        ],
                    },
                },
                1382: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.820672870114386, 2.366899508865895],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 388.322863777,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.364531953109201,
                            48.819876221057115,
                            2.369290587346029,
                            48.82135648127286,
                        ),
                        "coordinates": [
                            [2.369290587346029, 48.82135578381408],
                            [2.369222639246174, 48.82135648127286],
                            [2.369154998135254, 48.82135533299024],
                            [2.369088073904047, 48.82135234562626],
                            [2.369022288591543, 48.82134753489973],
                            [2.368958008201807, 48.821340932423446],
                            [2.368895600034807, 48.82133257521403],
                            [2.368835402702159, 48.821322507332425],
                            [2.365169326134656, 48.820102534922086],
                            [2.365011474166985, 48.8200500022397],
                            [2.364531953109201, 48.819876221057115],
                        ],
                    },
                },
                1383: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.89495125198186, 2.2824088011760435],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 743.31428909,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.279809586693102,
                            48.89208278596665,
                            2.285009501382414,
                            48.89782106711132,
                        ),
                        "coordinates": [
                            [2.285009501382414, 48.89208278596665],
                            [2.284433481383714, 48.89271545479225],
                            [2.279809586693102, 48.89782106711132],
                        ],
                    },
                },
                1384: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.86822533565882, 2.3333472596127898],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 520.622103979,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332407405064785,
                            48.865980920486436,
                            2.334330724377939,
                            48.87048670326257,
                        ),
                        "coordinates": [
                            [2.334330724377939, 48.865980920486436],
                            [2.333226950258093, 48.868488273789666],
                            [2.332694019926554, 48.869709276118165],
                            [2.332579545677322, 48.86997153898507],
                            [2.332407405064785, 48.87048670326257],
                        ],
                    },
                },
                1385: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M3",
                        "rer": 0,
                        "extcode": "100110003:3",
                        "geo_point_2d": [48.864756814281606, 2.403507681179144],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01373",
                        "navette": 0,
                        "idrefliga": "A01536",
                        "shape_leng": 664.611211748,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.398984440248072,
                            48.864600373375616,
                            2.408031037075815,
                            48.86491668505183,
                        ),
                        "coordinates": [
                            [2.408031037075815, 48.864600373375616],
                            [2.40712473805035, 48.86462920324635],
                            [2.406881925067015, 48.864636925207485],
                            [2.400463279850202, 48.864864519215416],
                            [2.398984440248072, 48.86491668505183],
                        ],
                    },
                },
                1386: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M7",
                        "rer": 0,
                        "extcode": "100110007:7",
                        "geo_point_2d": [48.82443192183126, 2.3578597673175765],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01377",
                        "navette": 0,
                        "idrefliga": "A01540",
                        "shape_leng": 452.528442752,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.357245650758686,
                            48.822437832786854,
                            2.358473883876467,
                            48.826426010875664,
                        ),
                        "coordinates": [
                            [2.358473883876467, 48.822437832786854],
                            [2.357245650758686, 48.826426010875664],
                        ],
                    },
                },
                1387: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.97223170313227, 3.1697507985494515],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 8651.28935396,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.124909020747328,
                            48.95081998757722,
                            3.219302814192089,
                            48.98246065112459,
                        ),
                        "coordinates": [
                            [3.124909020747328, 48.95081998757722],
                            [3.125532361102864, 48.95093282567122],
                            [3.126131637670971, 48.951054975027354],
                            [3.126993307849193, 48.95125440623625],
                            [3.127727014196896, 48.951453477527785],
                            [3.128416940368112, 48.95165441216765],
                            [3.128915151921372, 48.95181252748242],
                            [3.129428910479689, 48.951993849587296],
                            [3.129894707430746, 48.952180499994164],
                            [3.13050320903193, 48.95243444914874],
                            [3.131132320266545, 48.95271156949441],
                            [3.131767030592901, 48.95302196039651],
                            [3.13218780597492, 48.953238896330284],
                            [3.132857675305325, 48.953614009578956],
                            [3.133623510188735, 48.95410959769555],
                            [3.134053121356395, 48.954415969996695],
                            [3.134507820102423, 48.954753642104166],
                            [3.134867403185272, 48.955049078646645],
                            [3.135134935613193, 48.95528256389862],
                            [3.135621281081817, 48.955718936969525],
                            [3.13605137882392, 48.956150026651265],
                            [3.136932018248188, 48.95718844825551],
                            [3.137576746599118, 48.95799943532865],
                            [3.137925599521509, 48.95846014428227],
                            [3.13852081974705, 48.95919924777172],
                            [3.139166476069633, 48.96002253701357],
                            [3.139515373742767, 48.96048146715773],
                            [3.139962218507301, 48.96105297140063],
                            [3.140523025178239, 48.961743338745755],
                            [3.140991241062145, 48.962318312385435],
                            [3.141446098202791, 48.96282682912966],
                            [3.141930993990476, 48.96333423198621],
                            [3.142525226297184, 48.96389648911052],
                            [3.142984875917881, 48.96431066851411],
                            [3.143213077322861, 48.96450625734359],
                            [3.143541397028079, 48.964768996644935],
                            [3.143801570635898, 48.96497760286572],
                            [3.144151132728645, 48.96525583297495],
                            [3.144518065566148, 48.96552922567605],
                            [3.144778432794733, 48.96571777742348],
                            [3.145268295101276, 48.96605452572265],
                            [3.145599477136683, 48.96626995866742],
                            [3.146191726813418, 48.96664604326499],
                            [3.146715980514363, 48.96696518955857],
                            [3.147471279353009, 48.967379821298046],
                            [3.148362698764427, 48.967848341570495],
                            [3.151567237110152, 48.96943084792525],
                            [3.152290592606458, 48.96980880386555],
                            [3.15289167402663, 48.970143561233556],
                            [3.153407694952441, 48.97045554075306],
                            [3.153774221677392, 48.97069573369543],
                            [3.154238193501051, 48.97100387356466],
                            [3.154524897846064, 48.971206695893464],
                            [3.15475755211529, 48.971381192337496],
                            [3.154919471741657, 48.971507019066934],
                            [3.155293458270931, 48.97179836625396],
                            [3.155560369796835, 48.9720154454609],
                            [3.15591553028124, 48.97233048174985],
                            [3.156286972571181, 48.97267222520073],
                            [3.156598433176894, 48.97297907210925],
                            [3.156809537551431, 48.97319908789223],
                            [3.157507885148485, 48.973971332787656],
                            [3.15862899461206, 48.975262809852524],
                            [3.159223131748126, 48.97593837694274],
                            [3.159522184373867, 48.97627268334102],
                            [3.159894317528267, 48.97667914410811],
                            [3.160327721350512, 48.97708970758034],
                            [3.160612922850991, 48.97735082369557],
                            [3.160918367691503, 48.977611793220895],
                            [3.16121842195983, 48.977852812709244],
                            [3.161647483231408, 48.978179180853076],
                            [3.162045713793032, 48.978453135605264],
                            [3.162485601738245, 48.97873311848536],
                            [3.162937812428256, 48.978993022214716],
                            [3.163440879040387, 48.979267547281246],
                            [3.163961439847653, 48.97952861909513],
                            [3.164484093628026, 48.9797630238229],
                            [3.165322467474692, 48.98011339746255],
                            [3.166474211978496, 48.98058974577814],
                            [3.167143226149126, 48.98085035191221],
                            [3.167721770905793, 48.98107457964559],
                            [3.168361890484968, 48.98130549466876],
                            [3.168964166370808, 48.98149108402195],
                            [3.169449820253576, 48.98162912791877],
                            [3.170156186645249, 48.981808779493186],
                            [3.170763419241965, 48.98194330043995],
                            [3.171375317213532, 48.982064811624724],
                            [3.171932593777157, 48.98216229800182],
                            [3.172777571842304, 48.98227753380334],
                            [3.17341969069499, 48.98234469077135],
                            [3.174183053629787, 48.98241024306385],
                            [3.174836743579621, 48.98244412522527],
                            [3.17540405996758, 48.98246065112459],
                            [3.175936918764654, 48.98245944012747],
                            [3.176408193129162, 48.982452383390886],
                            [3.177104490322327, 48.98242028857699],
                            [3.177650400893474, 48.98238300100869],
                            [3.178537185301694, 48.98230363054828],
                            [3.179197463866602, 48.982227945261094],
                            [3.179752711814658, 48.98214057193101],
                            [3.180277276067164, 48.982046838792805],
                            [3.181016552191365, 48.98189743170445],
                            [3.184073409254422, 48.981249197816936],
                            [3.185736684434239, 48.98089641661013],
                            [3.18889122823709, 48.98024667234983],
                            [3.19468775173385, 48.97902572265206],
                            [3.196389605759639, 48.97866815401577],
                            [3.198035862972011, 48.978315975374535],
                            [3.199581983239517, 48.97799276524006],
                            [3.202685608081007, 48.97734065710165],
                            [3.205790498334898, 48.97668755324807],
                            [3.207202005285402, 48.97638902394772],
                            [3.209005541236397, 48.97601014122036],
                            [3.211998682415604, 48.97538200308321],
                            [3.213731884024146, 48.97502188599922],
                            [3.215869555067603, 48.974572392288195],
                            [3.216489394183057, 48.97444863412616],
                            [3.217213448844801, 48.9743072012922],
                            [3.217773537622495, 48.974216271110286],
                            [3.21840142911666, 48.97412677412533],
                            [3.219302814192089, 48.974026580478466],
                        ],
                    },
                },
                1388: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.971398626344104, 3.000666216545214],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 4989.5011259,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.973519215077535,
                            48.959160968311494,
                            3.026111294286066,
                            48.97846727884664,
                        ),
                        "coordinates": [
                            [2.973519215077535, 48.97436062282584],
                            [2.973772895317904, 48.9746097652687],
                            [2.974039591773709, 48.97485883529857],
                            [2.97436853189884, 48.975141821396356],
                            [2.974700483365715, 48.97540551702581],
                            [2.975005891586773, 48.9756286700914],
                            [2.97538647611226, 48.97587924248098],
                            [2.975753777429205, 48.976108474176925],
                            [2.97610776720775, 48.97631422246366],
                            [2.976445220003553, 48.97649864677014],
                            [2.976838166508574, 48.976697750724576],
                            [2.977325811626418, 48.976924161762916],
                            [2.977767396085792, 48.97711014134753],
                            [2.97820881560314, 48.97728327117223],
                            [2.978666392472243, 48.9774477427205],
                            [2.979228290126303, 48.97762875918514],
                            [2.979776874881422, 48.97778629119148],
                            [2.980308921137792, 48.9779225001296],
                            [2.980879948547887, 48.978054202419784],
                            [2.981506143445581, 48.97817488515208],
                            [2.982083127039654, 48.97826371767019],
                            [2.982676184071168, 48.978337468905565],
                            [2.983392828782192, 48.978408376655196],
                            [2.984027702664223, 48.97844547746635],
                            [2.984620037854598, 48.97846354287163],
                            [2.985095066719508, 48.97846727884664],
                            [2.985745563550632, 48.9784550287008],
                            [2.986285287869332, 48.9784305537024],
                            [2.986850786308361, 48.978386655947766],
                            [2.987451811970465, 48.97832328123823],
                            [2.987909702713267, 48.978260717354765],
                            [2.988497291922027, 48.97816529052971],
                            [2.989091159669055, 48.97805269347273],
                            [2.989610148759171, 48.977936237438776],
                            [2.990158271622399, 48.97780890456781],
                            [2.990696464199218, 48.97766877789147],
                            [2.999917254677413, 48.97531793183979],
                            [3.002131596220587, 48.97475686073431],
                            [3.002731354481651, 48.97460346896076],
                            [3.003314729255557, 48.974441603035615],
                            [3.003839607144153, 48.974284358144736],
                            [3.00436099993864, 48.97410999973166],
                            [3.004836850832929, 48.97393590344203],
                            [3.005302765361638, 48.97374901511267],
                            [3.005739316082717, 48.973555872244766],
                            [3.006233863558562, 48.97332169943727],
                            [3.006634365827703, 48.973109489742136],
                            [3.007060453954556, 48.97286500668348],
                            [3.007437893521372, 48.9726315154097],
                            [3.007795810700965, 48.972398135671284],
                            [3.008143853232041, 48.97215624881205],
                            [3.008485125405614, 48.971895125132356],
                            [3.008819568851032, 48.97161048526421],
                            [3.009182673486361, 48.97128070464139],
                            [3.009461902708602, 48.971002811230136],
                            [3.009734333801408, 48.97070354213192],
                            [3.00998730443577, 48.97040867027304],
                            [3.010207863399986, 48.97012255363876],
                            [3.010405739879971, 48.96984299565804],
                            [3.010609506870402, 48.96951843131334],
                            [3.010768437491048, 48.96924552580462],
                            [3.010923879978115, 48.96895550892149],
                            [3.011088291405763, 48.96860761838882],
                            [3.011960218556504, 48.96647169234861],
                            [3.01229074511897, 48.965664540165804],
                            [3.01243008175896, 48.96538746553912],
                            [3.012563174732215, 48.96512970052752],
                            [3.012734650739944, 48.96482459658548],
                            [3.013021451530569, 48.964390319569105],
                            [3.013184362612078, 48.9641730670892],
                            [3.013536049563837, 48.96372769838496],
                            [3.013843691822617, 48.96339180526326],
                            [3.014106766867075, 48.963126845302845],
                            [3.014357210387531, 48.96288979841196],
                            [3.014765419763678, 48.962536175678885],
                            [3.01508075155229, 48.96228803518338],
                            [3.015476764371755, 48.96199444332488],
                            [3.015792557376289, 48.96178056249288],
                            [3.016121443474653, 48.96157302672188],
                            [3.016547296176869, 48.96132208500435],
                            [3.016928206566057, 48.96111423759807],
                            [3.017273871957416, 48.960945145651145],
                            [3.017622814663952, 48.960778176192306],
                            [3.018026891966558, 48.9606001682969],
                            [3.018634920201428, 48.960354558046866],
                            [3.019117123019213, 48.96018250516372],
                            [3.019550955065364, 48.96004072018662],
                            [3.019968763398198, 48.95991616115088],
                            [3.020493642737157, 48.95977382878023],
                            [3.020898792578962, 48.95967504073729],
                            [3.021372169011701, 48.959571559551165],
                            [3.021784056451335, 48.95948985817831],
                            [3.022296717126513, 48.959405412003036],
                            [3.022736234303315, 48.95933941366113],
                            [3.02320559212246, 48.95928218088204],
                            [3.023624510936894, 48.95923897890156],
                            [3.024082567545182, 48.95920410622047],
                            [3.024589490762557, 48.959175361763535],
                            [3.02507060456231, 48.95916176190395],
                            [3.025558403424575, 48.959160968311494],
                            [3.026111294286066, 48.959164063062694],
                        ],
                    },
                },
                1389: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.780158328704076, 2.4346983885028064],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2000.81066407,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.432070116592686,
                            48.771266038121055,
                            2.436086604214256,
                            48.78891489668918,
                        ),
                        "coordinates": [
                            [2.435306339706323, 48.771266038121055],
                            [2.435440225383158, 48.771483751195284],
                            [2.435599222770678, 48.77179292605963],
                            [2.435707728226891, 48.772052178641204],
                            [2.435801803257095, 48.77229478945914],
                            [2.435888725779706, 48.772561198963075],
                            [2.435964941428433, 48.77287282512524],
                            [2.436030391339495, 48.77320111586854],
                            [2.436045485215397, 48.773325107882],
                            [2.436070647682407, 48.77353180770079],
                            [2.436081968925176, 48.77379352470407],
                            [2.436086604214256, 48.774312214586466],
                            [2.436069378558162, 48.774700061127184],
                            [2.436034282355853, 48.77515216508829],
                            [2.435981075256809, 48.77554956048242],
                            [2.435934794066609, 48.775808948132415],
                            [2.435874186419337, 48.77610641735578],
                            [2.435742251869427, 48.77674181418208],
                            [2.435556595845548, 48.77752001822261],
                            [2.435435118980712, 48.77798647205676],
                            [2.435349417951659, 48.77834106731402],
                            [2.435281670358444, 48.77867185364237],
                            [2.435224660798823, 48.778971698871864],
                            [2.435203497645432, 48.77919299477181],
                            [2.435125864478978, 48.779987759728854],
                            [2.435072837405683, 48.7804827069834],
                            [2.435047950953678, 48.780642143702984],
                            [2.435019534129465, 48.78083727365759],
                            [2.434948213410398, 48.78118471805605],
                            [2.434866002252994, 48.7814869643202],
                            [2.434765819013104, 48.781805881325134],
                            [2.434536769171052, 48.782505602836856],
                            [2.434296855593278, 48.78317678079791],
                            [2.43390645793184, 48.7842287804001],
                            [2.433211275030803, 48.785944871156936],
                            [2.432913868180616, 48.786694614061545],
                            [2.432634422468911, 48.7874276843418],
                            [2.432222909326854, 48.78854485112556],
                            [2.432070116592686, 48.78891489668918],
                        ],
                    },
                },
                1390: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.102765644793315, 2.2065049546336812],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2723.15578191,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.201823484236059,
                            49.091073452190784,
                            2.210019869292197,
                            49.114783970085064,
                        ),
                        "coordinates": [
                            [2.210019869292197, 49.114783970085064],
                            [2.209905287355804, 49.11443309398685],
                            [2.209571462191194, 49.11373129263828],
                            [2.208931932224397, 49.112588506036516],
                            [2.208754877303718, 49.112191730025366],
                            [2.208690859330901, 49.112050473242945],
                            [2.20849372942117, 49.11147291984737],
                            [2.208347530096024, 49.11080189978026],
                            [2.20829376362407, 49.110407058586986],
                            [2.208251389250461, 49.10984586550507],
                            [2.208251588433557, 49.109769427217294],
                            [2.208249052626379, 49.109691187901205],
                            [2.208199239455729, 49.10883052850721],
                            [2.20818224207847, 49.10851936185565],
                            [2.208098938314571, 49.107392634374335],
                            [2.208043830023013, 49.10628856382146],
                            [2.207974382447253, 49.10512499395677],
                            [2.207943275419631, 49.104546781745384],
                            [2.207907792382327, 49.10425646391118],
                            [2.207725193781185, 49.10340683792403],
                            [2.207585024884563, 49.10296412489829],
                            [2.207432109535791, 49.1025734283271],
                            [2.207037411877319, 49.10174528981345],
                            [2.206545329911213, 49.1007415059105],
                            [2.206082236900937, 49.099816948326385],
                            [2.20567135075664, 49.098988472939396],
                            [2.205253377454526, 49.09810526328376],
                            [2.204788443360864, 49.09717441149549],
                            [2.204526779703096, 49.09658455843854],
                            [2.204306099611187, 49.09614905646674],
                            [2.203721931498399, 49.09494612675242],
                            [2.20341199452994, 49.094331900130705],
                            [2.203130863229058, 49.09378670700129],
                            [2.202641884285912, 49.09275146960124],
                            [2.202456717071126, 49.09236096837448],
                            [2.2023395836078, 49.092129718375276],
                            [2.201823484236059, 49.091073452190784],
                        ],
                    },
                },
                1391: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78108425592836, 2.1859336977150448],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 822.757068535,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.180493750928926,
                            48.78045471153041,
                            2.191409919273295,
                            48.7819866725001,
                        ),
                        "coordinates": [
                            [2.180493750928926, 48.7819866725001],
                            [2.180797724134129, 48.781943771188104],
                            [2.18133056499837, 48.78185889704087],
                            [2.181542997400344, 48.78181466142279],
                            [2.182185285806371, 48.78163915026326],
                            [2.182486672069218, 48.78157124801389],
                            [2.182844137232793, 48.781509440831385],
                            [2.183199397199509, 48.78145047229444],
                            [2.184496616881469, 48.78125657965057],
                            [2.185715898965635, 48.78107213626998],
                            [2.18720806435837, 48.78084527356158],
                            [2.188144671769632, 48.78070621908569],
                            [2.18885163863782, 48.78060657014449],
                            [2.189143880930801, 48.78057000252186],
                            [2.189383986996914, 48.780551641988694],
                            [2.189665093817604, 48.78053641474774],
                            [2.189954710109331, 48.780529811601276],
                            [2.190317842062232, 48.780519421999756],
                            [2.190577213804919, 48.78051261237905],
                            [2.190973038618517, 48.780483880751994],
                            [2.191100629088969, 48.78047617758488],
                            [2.191409919273295, 48.78045471153041],
                        ],
                    },
                },
                1392: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.486676062841916, 3.343493481311605],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 19798.2099696,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.250034982583049,
                            48.47245285614752,
                            3.463021506165072,
                            48.51375459097529,
                        ),
                        "coordinates": [
                            [3.463021506165072, 48.496792167629955],
                            [3.458293360211975, 48.497086643484934],
                            [3.456263209724038, 48.4972137418609],
                            [3.454686514458647, 48.4973246358375],
                            [3.453473419364681, 48.49741753642304],
                            [3.451945416547361, 48.49752791122701],
                            [3.451146612796102, 48.49756994339156],
                            [3.45062606539276, 48.49758945046633],
                            [3.45000387034121, 48.497601858267444],
                            [3.449339395714041, 48.497599389372056],
                            [3.448716561684891, 48.49758301798915],
                            [3.447989055128923, 48.49754518570112],
                            [3.447257151839072, 48.49749210186653],
                            [3.446492243575087, 48.49741505506476],
                            [3.445846252125553, 48.497330543803805],
                            [3.444370123065097, 48.49709496025202],
                            [3.440040897306924, 48.49644386879941],
                            [3.438618133508118, 48.496217377459764],
                            [3.436925930068359, 48.495948273384656],
                            [3.435689897354265, 48.49574610699725],
                            [3.434198903785162, 48.495508324050334],
                            [3.432546278302512, 48.49524591025367],
                            [3.429941598865989, 48.49483085144197],
                            [3.426507027447631, 48.494280945441325],
                            [3.424430260025156, 48.49393682766716],
                            [3.422034038012353, 48.49355290186219],
                            [3.419770849560997, 48.493193828515324],
                            [3.417359921196385, 48.49278852887714],
                            [3.415076935440914, 48.492402272865064],
                            [3.413500644781673, 48.492151053845376],
                            [3.410061389360986, 48.49159101166359],
                            [3.408125345113864, 48.49128107108218],
                            [3.405762934402383, 48.49089867649468],
                            [3.4033992061572, 48.49051624570106],
                            [3.401819535019183, 48.49026063701919],
                            [3.400550915531923, 48.49005917338434],
                            [3.399753488307741, 48.489930697274595],
                            [3.398517164809461, 48.48972930834621],
                            [3.397500258230482, 48.4895633530621],
                            [3.396373495389023, 48.48938245151542],
                            [3.394707840869531, 48.48911832601292],
                            [3.393161409934395, 48.48886115852113],
                            [3.392562719759523, 48.48876421554895],
                            [3.390264399705276, 48.48839350414756],
                            [3.389322213860398, 48.48823858373134],
                            [3.388821521817038, 48.48815805053019],
                            [3.388314935684207, 48.48807616527872],
                            [3.387805783815522, 48.48799005807156],
                            [3.387171179356911, 48.48788401924235],
                            [3.38647938111807, 48.487770329307814],
                            [3.385826460604843, 48.48766665848425],
                            [3.383681670394485, 48.487322271483336],
                            [3.380763102237725, 48.486850077499774],
                            [3.37965718120881, 48.48667240598083],
                            [3.378171727228848, 48.48643056102908],
                            [3.376590221933715, 48.48616989341066],
                            [3.375016978981487, 48.485915424651004],
                            [3.373571323364483, 48.48568045035818],
                            [3.371732221806675, 48.48540544233406],
                            [3.370193113038518, 48.48515828401921],
                            [3.36913642349542, 48.484981937209696],
                            [3.366770896676277, 48.484578758631336],
                            [3.366329908627431, 48.48451441814197],
                            [3.365906578292105, 48.484453513915454],
                            [3.365271549103709, 48.484360355176115],
                            [3.364560980182402, 48.48427256980115],
                            [3.364293585450512, 48.48424172655263],
                            [3.363947224642295, 48.484206782260614],
                            [3.363634990616203, 48.4841791506889],
                            [3.363370328052095, 48.484158127962225],
                            [3.363066541695254, 48.48413600616717],
                            [3.362780091300263, 48.48411674988987],
                            [3.362480241056483, 48.48409880586796],
                            [3.362100226263291, 48.484079738992506],
                            [3.361718854533319, 48.48406323443134],
                            [3.361381285635275, 48.48405027209891],
                            [3.36098828971522, 48.48404255828521],
                            [3.360708662731593, 48.48403656894837],
                            [3.360526285867916, 48.48403381028813],
                            [3.360323020121887, 48.484031961253656],
                            [3.35972117146836, 48.48403919756991],
                            [3.359091028824445, 48.484052081380064],
                            [3.358608406403202, 48.4840681284917],
                            [3.357969599434631, 48.48409226596567],
                            [3.357163388664529, 48.48412342479133],
                            [3.356187393046651, 48.484159194139224],
                            [3.354108587162402, 48.48424803378581],
                            [3.351720164048564, 48.484345905634136],
                            [3.34949524663305, 48.48443507006355],
                            [3.346311822315902, 48.48455612250539],
                            [3.345170959020312, 48.48460135982609],
                            [3.343436732707501, 48.48467254513352],
                            [3.342189011880194, 48.484718702337446],
                            [3.341280423777343, 48.48474385166108],
                            [3.340545994403008, 48.48475126279128],
                            [3.33966499934529, 48.484735684322615],
                            [3.338856629558179, 48.48469877199363],
                            [3.338018001728847, 48.48463694099429],
                            [3.337283327050318, 48.48456429248677],
                            [3.336530639458914, 48.48447021406538],
                            [3.335961993566183, 48.48437900378977],
                            [3.335465214915415, 48.48429615033331],
                            [3.33476177328192, 48.48416115663822],
                            [3.334334038358594, 48.484067190654244],
                            [3.333920635111204, 48.48397251082781],
                            [3.333581836521413, 48.483885953154875],
                            [3.332747119960706, 48.48366528901043],
                            [3.331672050123524, 48.48334746755837],
                            [3.329676819867594, 48.48273904381112],
                            [3.326068860325702, 48.481635665403715],
                            [3.324553826513623, 48.48116882027492],
                            [3.322968611402739, 48.48068423619671],
                            [3.318554209485903, 48.47934572294844],
                            [3.317099426604049, 48.47889697095513],
                            [3.315622944726175, 48.47844389109323],
                            [3.314160151997661, 48.47799786982264],
                            [3.312775121917082, 48.47758443371509],
                            [3.311362803667428, 48.477157726931964],
                            [3.310455243970646, 48.476881347322696],
                            [3.308562546149064, 48.47630225172683],
                            [3.306551403321506, 48.4756809724612],
                            [3.303861370045449, 48.474851418614506],
                            [3.301207311627645, 48.47405926766351],
                            [3.300314912579205, 48.473791671620894],
                            [3.299895899867602, 48.47366483472234],
                            [3.299155697189876, 48.47343370816679],
                            [3.298321357168601, 48.47318219967288],
                            [3.297680097641378, 48.47301002356389],
                            [3.297041823720503, 48.47287339477869],
                            [3.296311050995648, 48.472741621029925],
                            [3.295640508144714, 48.4726359175893],
                            [3.295039520212264, 48.472557613537234],
                            [3.294446010829532, 48.47250038572481],
                            [3.293829440449774, 48.47246798657047],
                            [3.293147208519148, 48.47245285614752],
                            [3.292378912446531, 48.47247128704765],
                            [3.290868020383127, 48.47253259544576],
                            [3.288892700490079, 48.47263736123502],
                            [3.287069852899195, 48.47272372521498],
                            [3.286047112234194, 48.472780869208556],
                            [3.284640445491824, 48.47284751569854],
                            [3.283929664850456, 48.47288044476988],
                            [3.28247723653526, 48.47295913812286],
                            [3.281142180783708, 48.4730224448121],
                            [3.279900376132054, 48.47308226011194],
                            [3.278397731847725, 48.473152326189215],
                            [3.27676005928135, 48.47323428585959],
                            [3.276085780052606, 48.47326686246731],
                            [3.275415657289604, 48.473304796311076],
                            [3.274803681911603, 48.47334224547351],
                            [3.274348519458233, 48.47337569395652],
                            [3.274067648522751, 48.47339960297589],
                            [3.273773322688309, 48.47342722087873],
                            [3.273348109795828, 48.47347120923892],
                            [3.272927122010783, 48.47352415373214],
                            [3.272514398263128, 48.4735851230273],
                            [3.272128601386239, 48.47363957264069],
                            [3.271809033473143, 48.47369167526401],
                            [3.271439680447473, 48.47375767833702],
                            [3.271054182570829, 48.473828309644034],
                            [3.270672909127654, 48.47390789833002],
                            [3.270247276558174, 48.47400223967363],
                            [3.269812344157009, 48.47410564984002],
                            [3.269451635064687, 48.4742003535654],
                            [3.26905195961247, 48.47430886630185],
                            [3.268751900446239, 48.47439227523107],
                            [3.268383359177498, 48.47450232824058],
                            [3.267971842328197, 48.474628921133416],
                            [3.267564614181914, 48.474768066938225],
                            [3.267160138640832, 48.47490988778461],
                            [3.266710181193497, 48.47507905960621],
                            [3.26635834198499, 48.47521504870034],
                            [3.265963726466071, 48.4753783674595],
                            [3.265569157311952, 48.47554438182009],
                            [3.265194938642624, 48.47571382550822],
                            [3.264820816483046, 48.47588866365717],
                            [3.264538018792118, 48.47602857751865],
                            [3.264216467648707, 48.47619398829566],
                            [3.263913764392248, 48.47635474847329],
                            [3.263509677551733, 48.47659187971229],
                            [3.263195280983253, 48.47677881389543],
                            [3.262227576566449, 48.47740456074097],
                            [3.261303109765989, 48.4780290473201],
                            [3.260664471132201, 48.478457840157084],
                            [3.260032551251972, 48.47888477587736],
                            [3.259721279491422, 48.4790959561461],
                            [3.25939931791557, 48.479314416969366],
                            [3.25905205398099, 48.479554666668434],
                            [3.258778311368281, 48.47974755165379],
                            [3.25848200596318, 48.47996400270252],
                            [3.258204367286103, 48.48016591066931],
                            [3.25794288881369, 48.480364090854124],
                            [3.257710866517082, 48.480545841708036],
                            [3.257464212983203, 48.48074120161154],
                            [3.257239048231614, 48.48092829199494],
                            [3.257053977456482, 48.48108897616942],
                            [3.256828826326155, 48.481276964398425],
                            [3.25662649969213, 48.48145577451787],
                            [3.256477513194969, 48.48159278209437],
                            [3.256299283410938, 48.48175790599128],
                            [3.2561358788976, 48.48192021063767],
                            [3.255985735448221, 48.48206801894384],
                            [3.25582780636426, 48.482233876471994],
                            [3.255669825254157, 48.48239703595167],
                            [3.25550791893254, 48.48256742210231],
                            [3.255364616217371, 48.48271966968621],
                            [3.255235943485703, 48.48285830964863],
                            [3.255096846187749, 48.48301861732111],
                            [3.254961640657241, 48.48316990058126],
                            [3.254777543524924, 48.483384531900064],
                            [3.254561873145757, 48.48364798121743],
                            [3.254393820610281, 48.483852590021485],
                            [3.254161139268266, 48.48414765296181],
                            [3.253931507417379, 48.484461577216344],
                            [3.25369035650517, 48.48481156650363],
                            [3.253474737028027, 48.485152355315215],
                            [3.253227540638468, 48.48554196333649],
                            [3.253045303931323, 48.485859098609694],
                            [3.252835743862772, 48.48623581051539],
                            [3.252710135684663, 48.4864688508397],
                            [3.252605410701557, 48.48666035316628],
                            [3.252407587648871, 48.48708733064582],
                            [3.252276460682723, 48.48738876376275],
                            [3.25214798787715, 48.487687476918474],
                            [3.252030302692155, 48.48798430389311],
                            [3.25198123457772, 48.4881124037444],
                            [3.251915486328386, 48.48829010084913],
                            [3.251852523959353, 48.48847227201499],
                            [3.251775650827966, 48.4887076149259],
                            [3.251691400748642, 48.48898348793945],
                            [3.251626782878343, 48.48922322804152],
                            [3.251533172289541, 48.48957921596302],
                            [3.251524688482359, 48.489633243425764],
                            [3.251479374069811, 48.4898188690875],
                            [3.251394862469402, 48.49022874168652],
                            [3.251309417937061, 48.490735747976885],
                            [3.251261451176073, 48.49107248074796],
                            [3.251225000552941, 48.491373147389645],
                            [3.251205347913726, 48.49163051116553],
                            [3.251183416937204, 48.491911276550084],
                            [3.251171971887063, 48.4922477140397],
                            [3.251163207609418, 48.49250858734409],
                            [3.251164968244382, 48.492753187944444],
                            [3.251175585655616, 48.49303818615266],
                            [3.251192321584584, 48.493361805620026],
                            [3.251213115255851, 48.49368539213361],
                            [3.251255811269231, 48.49409693565204],
                            [3.251301926622903, 48.494473378390545],
                            [3.251346349803379, 48.494757204476095],
                            [3.251438951401028, 48.495233995205574],
                            [3.251533119825361, 48.495722463666574],
                            [3.251551013546073, 48.495813150360895],
                            [3.25163487664973, 48.49625583726696],
                            [3.251751629105443, 48.49686912970009],
                            [3.25191039122806, 48.49770781148594],
                            [3.252090368979738, 48.49867042729374],
                            [3.252298708233386, 48.4997776046151],
                            [3.252427779895295, 48.500471736834],
                            [3.252523601215831, 48.500975482252834],
                            [3.252591117208588, 48.50133736293001],
                            [3.252748866429346, 48.502193141450924],
                            [3.252891810083034, 48.50290514878391],
                            [3.252978353623821, 48.5033451170353],
                            [3.253193611621223, 48.50445853612454],
                            [3.253252047739601, 48.504767429886684],
                            [3.253381145658466, 48.50546156193396],
                            [3.25351908990244, 48.50619519276749],
                            [3.253584523602308, 48.50659036524922],
                            [3.253616610555607, 48.506864399606464],
                            [3.253648366307296, 48.507194193964885],
                            [3.253665565675298, 48.50754209298491],
                            [3.253667060166042, 48.50777140809766],
                            [3.253654762859746, 48.50804911190015],
                            [3.253624668176478, 48.508361065946886],
                            [3.253568442193835, 48.50866793271284],
                            [3.25347168676825, 48.50907520989243],
                            [3.253356744672284, 48.509450259155365],
                            [3.253202602782387, 48.50990206731152],
                            [3.25301390144539, 48.51031458447186],
                            [3.252780851406455, 48.51074454769751],
                            [3.252539017878902, 48.51113860841534],
                            [3.252259010532431, 48.51151768774303],
                            [3.25183560068865, 48.512049012418046],
                            [3.251557371706239, 48.512373254378616],
                            [3.251223506577709, 48.51272097189865],
                            [3.250811513485691, 48.513105011277396],
                            [3.250034982583049, 48.51375459097529],
                        ],
                    },
                },
                1393: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.892455464731384, 2.7582854399744288],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 8655.33980794,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.706014179759928,
                            48.8821891367053,
                            2.810248220733339,
                            48.903072914208664,
                        ),
                        "coordinates": [
                            [2.706014179759928, 48.8821891367053],
                            [2.709375484980779, 48.8824111676089],
                            [2.710428777822778, 48.88248024410835],
                            [2.715016478477014, 48.8827798994872],
                            [2.726280027769635, 48.88351967938649],
                            [2.733400652177743, 48.88398428339932],
                            [2.739468032494127, 48.88437964400651],
                            [2.743862614581742, 48.88466438091066],
                            [2.744726926529753, 48.88472610325666],
                            [2.745340448209582, 48.88477309701174],
                            [2.745882480979813, 48.88482517884707],
                            [2.746495718033818, 48.88489159190308],
                            [2.746840051525796, 48.88494127218361],
                            [2.747203192642843, 48.885001685685246],
                            [2.747624962042376, 48.885078859665086],
                            [2.748006974436393, 48.88515771831079],
                            [2.748417177408356, 48.88525036101571],
                            [2.74881106788649, 48.88535077492454],
                            [2.749277757544674, 48.885483327259614],
                            [2.750009668731057, 48.885716753406264],
                            [2.750448469377692, 48.8858710023898],
                            [2.750929706032121, 48.88606366984338],
                            [2.751295984417808, 48.886218180256925],
                            [2.751824445451146, 48.886461590756376],
                            [2.752360201792092, 48.886737373488415],
                            [2.75292206344036, 48.887056262525334],
                            [2.753284295874559, 48.88728484180385],
                            [2.753778447093127, 48.88761940219653],
                            [2.754265859448557, 48.8879863870438],
                            [2.754675859175334, 48.8883289660809],
                            [2.755043763381204, 48.8886732407984],
                            [2.755357689361623, 48.88899765449675],
                            [2.755558413213702, 48.889216018463884],
                            [2.75576878506965, 48.88946829178819],
                            [2.755974544595164, 48.88972829554118],
                            [2.756187637709572, 48.890025302831944],
                            [2.756360684190425, 48.890290056707435],
                            [2.75652209584913, 48.890562565532406],
                            [2.756671969373155, 48.890853633702314],
                            [2.756840993479977, 48.891195548075224],
                            [2.75698903908279, 48.891546797393445],
                            [2.75721378960307, 48.892113777664406],
                            [2.757603999355214, 48.89315229252828],
                            [2.757814398444073, 48.893680750144405],
                            [2.757971831374042, 48.8940335065392],
                            [2.758138402333915, 48.89435999828909],
                            [2.758337842922513, 48.894698712696865],
                            [2.758487293073494, 48.89493731988943],
                            [2.758683886851511, 48.895215867748966],
                            [2.758920498766613, 48.895522042031395],
                            [2.759211263597993, 48.895866588669385],
                            [2.759520635252419, 48.89619717975332],
                            [2.759820052266498, 48.896486183767394],
                            [2.760180044938074, 48.896806065861604],
                            [2.760608430153115, 48.897147107148456],
                            [2.761154160992185, 48.89753696420038],
                            [2.761634268536855, 48.89784782916249],
                            [2.762159759267567, 48.898147816280115],
                            [2.762649218468428, 48.898411531340855],
                            [2.763239459277655, 48.8986855750103],
                            [2.76386205664282, 48.89894450396552],
                            [2.764416048543446, 48.89915657475931],
                            [2.765184816505803, 48.89941494959372],
                            [2.765920799171059, 48.8996370382502],
                            [2.766617588765472, 48.89983357178607],
                            [2.767307833512905, 48.90002370265334],
                            [2.767975180775979, 48.90019464107499],
                            [2.768805210766345, 48.90039708352339],
                            [2.769557015633235, 48.90056769493517],
                            [2.770292473736756, 48.90072551383138],
                            [2.770891181636923, 48.90084530194581],
                            [2.77208670812417, 48.90105967288213],
                            [2.773405842432053, 48.90128113630096],
                            [2.774270944580586, 48.90140417193767],
                            [2.774992813700457, 48.9014913456884],
                            [2.77582835188858, 48.90157593559043],
                            [2.776572583156457, 48.90162018447221],
                            [2.77737836005821, 48.90164491708148],
                            [2.778235840434936, 48.90163946549079],
                            [2.778781351905856, 48.901618082922695],
                            [2.779355998920116, 48.90158587736057],
                            [2.780037604331866, 48.90152755685707],
                            [2.780702814484427, 48.901452164550804],
                            [2.781419761235691, 48.90135086906315],
                            [2.781935479120705, 48.901267484700895],
                            [2.782768946833287, 48.90112075705325],
                            [2.787251530648178, 48.900322385530146],
                            [2.789125085937413, 48.89998863475841],
                            [2.789851562247297, 48.89986797619329],
                            [2.790419099092084, 48.89977149854775],
                            [2.790931655312532, 48.899700935975645],
                            [2.791567610992399, 48.89962773797598],
                            [2.792109629840084, 48.899582749744525],
                            [2.79266804479731, 48.89955482537314],
                            [2.793262283951812, 48.899537461239184],
                            [2.793973666945937, 48.89954318173152],
                            [2.794500015915063, 48.89956034695148],
                            [2.795058981720607, 48.89959236796883],
                            [2.795663677426774, 48.89965204289343],
                            [2.796294497248336, 48.89972659925727],
                            [2.796919020764601, 48.899822591446465],
                            [2.797680440216833, 48.899969421854344],
                            [2.798360702739717, 48.90012085993051],
                            [2.801170345093357, 48.90081829129491],
                            [2.802954501630847, 48.901262871821125],
                            [2.804185168500983, 48.9015662124856],
                            [2.807294562927077, 48.902343645665994],
                            [2.808327509011944, 48.902598694966855],
                            [2.810248220733339, 48.903072914208664],
                        ],
                    },
                },
                1394: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.7425820689349, 2.744175510506277],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2304.5739703,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.729481333043577,
                            48.73948720730179,
                            2.758824548674894,
                            48.74472077575101,
                        ),
                        "coordinates": [
                            [2.758824548674894, 48.73948720730179],
                            [2.757463153104825, 48.73992300184102],
                            [2.755815676866813, 48.740457855891115],
                            [2.755213628316272, 48.740653415483834],
                            [2.753632277764686, 48.74116286995946],
                            [2.752746065101737, 48.74144687524047],
                            [2.751953159560979, 48.74170436051471],
                            [2.751124289360127, 48.74196434953959],
                            [2.750342140477953, 48.74221940453988],
                            [2.749793146582966, 48.74239271141803],
                            [2.74940920181095, 48.742513070996154],
                            [2.749107760020873, 48.74260457858254],
                            [2.74882064994764, 48.74268889594417],
                            [2.748498111428065, 48.7427786199245],
                            [2.74822812030214, 48.74285063912414],
                            [2.748034078807947, 48.74289900239088],
                            [2.747778961740407, 48.74296107384181],
                            [2.747518547365853, 48.743020849027594],
                            [2.74724286191312, 48.743081712886344],
                            [2.746940721709728, 48.74313655151526],
                            [2.746653441037735, 48.743189669748624],
                            [2.746365778130365, 48.74324044619832],
                            [2.746113191513724, 48.74328002417393],
                            [2.745942068107599, 48.743304919344126],
                            [2.745659538454691, 48.74334100586608],
                            [2.745469357047838, 48.74336327124011],
                            [2.745272370539994, 48.74338466105186],
                            [2.745107971776274, 48.74340053834247],
                            [2.744942205102114, 48.74341552116371],
                            [2.74476147497997, 48.74342965779589],
                            [2.744542688273962, 48.74344572922272],
                            [2.744357878048428, 48.74345987989882],
                            [2.744162139971035, 48.743467774823486],
                            [2.743808747418527, 48.74348522480896],
                            [2.743519571546724, 48.743490109272265],
                            [2.743284480852506, 48.743491593525064],
                            [2.743085420140631, 48.74349230310473],
                            [2.742783528808296, 48.74348888380099],
                            [2.742458485902403, 48.7434810489327],
                            [2.742199233724328, 48.74346781575678],
                            [2.741850157497902, 48.74344966320503],
                            [2.741617806472173, 48.743437276614756],
                            [2.741342441262852, 48.74341626183757],
                            [2.740945726052493, 48.743392000722906],
                            [2.739929502656484, 48.74333085272223],
                            [2.738226255276761, 48.74322535702782],
                            [2.73715831957738, 48.74315807112082],
                            [2.736823660136452, 48.74313766457197],
                            [2.73647403012768, 48.743115510654086],
                            [2.736142112869119, 48.743097789404686],
                            [2.735773547631447, 48.74308828954061],
                            [2.735526069480017, 48.743087357539466],
                            [2.735254144235954, 48.74309010789132],
                            [2.734942895406095, 48.7431064837264],
                            [2.734656121499252, 48.74312277373787],
                            [2.734321880609803, 48.743154516442054],
                            [2.734056968219893, 48.74318421718361],
                            [2.733798876921888, 48.74321659211917],
                            [2.733578834398465, 48.743246136400366],
                            [2.73333435331182, 48.74328026128418],
                            [2.733073626086733, 48.74332343524674],
                            [2.732876741095101, 48.74335829248691],
                            [2.732612006844383, 48.74341047222009],
                            [2.732362235230184, 48.74346349797909],
                            [2.732098950879702, 48.74352736233483],
                            [2.731842479611189, 48.743593000667566],
                            [2.731595561497767, 48.743663101238646],
                            [2.731420558593534, 48.74371406792822],
                            [2.731195428804425, 48.74378858873805],
                            [2.730935075927499, 48.74387941889811],
                            [2.730537964968577, 48.74404356246989],
                            [2.730262986426534, 48.74417670801468],
                            [2.730022118880164, 48.74432502224007],
                            [2.729844987446206, 48.74445153356572],
                            [2.729481333043577, 48.74472077575101],
                        ],
                    },
                },
                1395: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.82774157628693, 2.3359534367840684],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1550.72415398,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332852309960891,
                            48.82108965061529,
                            2.338978472013182,
                            48.8342929804732,
                        ),
                        "coordinates": [
                            [2.338978472013182, 48.82108965061529],
                            [2.338924006385144, 48.82131806747744],
                            [2.338864090968602, 48.82149792355914],
                            [2.338721104938068, 48.82174612643093],
                            [2.33846508431298, 48.82210134433574],
                            [2.338356138186996, 48.822253323220984],
                            [2.33826761864787, 48.82237562576368],
                            [2.338100112311461, 48.822618432461745],
                            [2.337996928226392, 48.822810531807555],
                            [2.337909454449114, 48.82297454765369],
                            [2.337807314252127, 48.823195769971775],
                            [2.337706536389927, 48.82341969065179],
                            [2.337607777058346, 48.82368375178273],
                            [2.337517236752479, 48.82396465240984],
                            [2.337386494680366, 48.82436752871972],
                            [2.337142708865092, 48.82510763318646],
                            [2.336852609509903, 48.826007807393616],
                            [2.33657067069274, 48.826855823885765],
                            [2.336394964244692, 48.827465531881394],
                            [2.336247858478459, 48.82794394529524],
                            [2.336144338232679, 48.828273079117004],
                            [2.336068058389473, 48.8285176815094],
                            [2.335995865532534, 48.82874070170551],
                            [2.3359198330592, 48.82897668387401],
                            [2.335818920459555, 48.829217790019925],
                            [2.335690745579853, 48.82945562287713],
                            [2.33554772072838, 48.82968943289165],
                            [2.33544147286932, 48.82983781223233],
                            [2.335322967339117, 48.829972701978065],
                            [2.33510502349798, 48.830184029737076],
                            [2.334978344133266, 48.83029553761004],
                            [2.334767210567158, 48.83048078565805],
                            [2.334560160155621, 48.830671427988804],
                            [2.334376265874533, 48.83084228758057],
                            [2.334153404047327, 48.831046538621834],
                            [2.334008473171083, 48.8312055862989],
                            [2.333828098297988, 48.83143494902651],
                            [2.3337619051947, 48.831547305050364],
                            [2.333644744734299, 48.83180449450437],
                            [2.333500329586613, 48.83220197075587],
                            [2.333219662861723, 48.833032892375115],
                            [2.333125654533778, 48.8332658020289],
                            [2.3329962195161, 48.833601226738885],
                            [2.33294402044519, 48.83375047862503],
                            [2.332895390332943, 48.833933055893866],
                            [2.332871331558357, 48.834081325151914],
                            [2.332852309960891, 48.8342929804732],
                        ],
                    },
                },
                1396: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.00994974561732, 2.3654523489543666],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 3147.41079582,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362222981011115,
                            48.996006830493926,
                            2.368960279608916,
                            49.02320637806201,
                        ),
                        "coordinates": [
                            [2.368684562796334, 48.996006830493926],
                            [2.368771154667153, 48.99632756433704],
                            [2.368843693123019, 48.99666778872084],
                            [2.368898142460405, 48.99699374320308],
                            [2.368930901007874, 48.997324462727505],
                            [2.368960059428528, 48.99768135605111],
                            [2.368960279608916, 48.99802160156042],
                            [2.368949687302651, 48.998421333643044],
                            [2.368902936805866, 48.99882345442325],
                            [2.368852510363171, 48.99913278291407],
                            [2.368791217750417, 48.99941594227207],
                            [2.368722696600605, 48.99970861962811],
                            [2.368639712300396, 49.000001301709375],
                            [2.368538656135477, 49.00031302329015],
                            [2.368412313272612, 49.00066758043242],
                            [2.368249828840886, 49.001060216502275],
                            [2.36412890002287, 49.010654771111795],
                            [2.363460589499867, 49.01221101549923],
                            [2.363290809425421, 49.01263219836392],
                            [2.363160796637514, 49.01301768146685],
                            [2.363085002178378, 49.013331771585726],
                            [2.363023687387352, 49.01366965171829],
                            [2.362998514654563, 49.0139504189681],
                            [2.362991432013492, 49.014238321221946],
                            [2.362998804517702, 49.014500046513504],
                            [2.363035138474289, 49.01480459333183],
                            [2.363085922331879, 49.01507106738294],
                            [2.363169289456207, 49.01538988053047],
                            [2.363285226207473, 49.01573009859627],
                            [2.363915566816413, 49.01740738456985],
                            [2.364303204260612, 49.018428028891734],
                            [2.364462631451012, 49.01888244423293],
                            [2.364542373667896, 49.01916080731666],
                            [2.364593197039238, 49.01947486799246],
                            [2.364607814609137, 49.01973897083355],
                            [2.36459712902502, 49.020036390445995],
                            [2.364553882734649, 49.02033381748194],
                            [2.364478092166131, 49.020659805616184],
                            [2.364366119038977, 49.02097866462008],
                            [2.364232419228614, 49.021264216636695],
                            [2.364069770580538, 49.02154025969524],
                            [2.363874564248708, 49.02182344596416],
                            [2.363628708202079, 49.022111404382365],
                            [2.363343050975764, 49.02239699127758],
                            [2.363057366734686, 49.022637370318186],
                            [2.362847615767337, 49.02280159274873],
                            [2.362511274457447, 49.02303960192606],
                            [2.362222981011115, 49.02320637806201],
                        ],
                    },
                },
                1397: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.90173726203837, 2.330378251087347],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 992.432315111,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.328942812768303,
                            48.89737479642876,
                            2.33183083796241,
                            48.90609405024862,
                        ),
                        "coordinates": [
                            [2.328942812768303, 48.89737479642876],
                            [2.32990873830309, 48.90032477979048],
                            [2.330280763566573, 48.9014885724091],
                            [2.331396966664166, 48.90479065839261],
                            [2.33183083796241, 48.90609405024862],
                        ],
                    },
                },
                1398: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M12",
                        "rer": 0,
                        "extcode": "100110012:12",
                        "geo_point_2d": [48.82970770231764, 2.2837538113614553],
                        "indice_lig": "12",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01382",
                        "navette": 0,
                        "idrefliga": "A01545",
                        "shape_leng": 869.416974968,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.279411682050421,
                            48.82708544889643,
                            2.288022141100325,
                            48.83244909914335,
                        ),
                        "coordinates": [
                            [2.279411682050421, 48.82708544889643],
                            [2.279821504643865, 48.82732309606827],
                            [2.282769734799747, 48.82903259896359],
                            [2.284422936176537, 48.8300743872798],
                            [2.288022141100325, 48.83244909914335],
                        ],
                    },
                },
                1399: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M13",
                        "rer": 0,
                        "extcode": "100110013:13",
                        "geo_point_2d": [48.88550484643907, 2.3265413451805057],
                        "indice_lig": "13",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01383",
                        "navette": 0,
                        "idrefliga": "A01546",
                        "shape_leng": 391.09815597,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325779674806892,
                            48.8838045280338,
                            2.327243410587406,
                            48.88718394686578,
                        ),
                        "coordinates": [
                            [2.327243410587406, 48.8838045280338],
                            [2.327226855984568, 48.88390711796815],
                            [2.327199368518344, 48.88400868327131],
                            [2.327193109058084, 48.88402728223976],
                            [2.327145015435022, 48.88415606329525],
                            [2.327101632335039, 48.88427223339227],
                            [2.325898944773093, 48.88693404469857],
                            [2.325857119505378, 48.88702661186946],
                            [2.325826135299813, 48.887089196181705],
                            [2.325779674806892, 48.88718394686578],
                        ],
                    },
                },
                1400: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.81230510273162, 3.018014617606854],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3969.32199369,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.993109893419177,
                            48.80750444314894,
                            3.042938266046296,
                            48.81644247834819,
                        ),
                        "coordinates": [
                            [3.042938266046296, 48.81379848212747],
                            [3.042121736623088, 48.81402566644309],
                            [3.040134520287092, 48.81457033480368],
                            [3.038848846660223, 48.814932885511325],
                            [3.037517997304488, 48.81529870021223],
                            [3.036983149926324, 48.81544740237658],
                            [3.036149266509647, 48.815674023001115],
                            [3.035195187868966, 48.815940408448085],
                            [3.034555840731028, 48.81608233036785],
                            [3.03409836533646, 48.81615146640572],
                            [3.033603802272337, 48.8162336895156],
                            [3.032873875474482, 48.816329876820845],
                            [3.03229450164895, 48.81638315591415],
                            [3.031254803834969, 48.816433275268295],
                            [3.030481440442632, 48.81644247834819],
                            [3.029859095588981, 48.81642438750487],
                            [3.029147508365243, 48.816388530498955],
                            [3.028481386535548, 48.81632950098686],
                            [3.027760697889824, 48.81625304917499],
                            [3.027016873319617, 48.8161334472645],
                            [3.026301209629056, 48.815982194364445],
                            [3.025715055928007, 48.81584094616563],
                            [3.025312836935027, 48.81573161481586],
                            [3.024961828243268, 48.81563145562454],
                            [3.024375497514552, 48.81543032096307],
                            [3.02370902294493, 48.81518262535233],
                            [3.022188959029509, 48.814618435481684],
                            [3.020985668437348, 48.81417627447019],
                            [3.020387721286609, 48.81394846425004],
                            [3.019845651514395, 48.813742929557655],
                            [3.018705507240842, 48.81331552376905],
                            [3.017829956321435, 48.81299638352285],
                            [3.015818952293022, 48.81223468241593],
                            [3.015109306501715, 48.81197142548206],
                            [3.014332681127686, 48.81168324844338],
                            [3.013728136601833, 48.811459180713854],
                            [3.012943622694571, 48.81116899076084],
                            [3.012472841736781, 48.810993716457304],
                            [3.012048587207488, 48.81083525268262],
                            [3.011267298597183, 48.81053784648982],
                            [3.010484125032099, 48.810234770222074],
                            [3.009858827340953, 48.81000014038359],
                            [3.009332038999837, 48.809802281541934],
                            [3.008767817612011, 48.80959036791872],
                            [3.008269828674817, 48.80940337365922],
                            [3.007662290909256, 48.80918122122874],
                            [3.006777462474078, 48.808892347458155],
                            [3.006077660480574, 48.80869321207291],
                            [3.005191842813429, 48.80848592628662],
                            [3.004080890590235, 48.808243606338834],
                            [3.002986283382667, 48.808014442237535],
                            [3.001761552473069, 48.807779578905006],
                            [3.001234826746375, 48.80769391875484],
                            [3.000754668518439, 48.80762446875945],
                            [3.00030399721439, 48.80757494478489],
                            [2.999724151455256, 48.80753245907337],
                            [2.999368494150505, 48.807512023358065],
                            [2.999038445899633, 48.80750444314894],
                            [2.998613398490185, 48.80750691041667],
                            [2.998217326903673, 48.807521105166614],
                            [2.997720680679125, 48.8075572977796],
                            [2.997245802480583, 48.807605257859876],
                            [2.996756705984263, 48.80766757575118],
                            [2.996267953656574, 48.807756063028705],
                            [2.995876298519266, 48.807832089257516],
                            [2.995567524821274, 48.80791001584889],
                            [2.995262319211721, 48.80798554138714],
                            [2.99485200910139, 48.808106541390295],
                            [2.99423371223053, 48.80830076228515],
                            [2.993109893419177, 48.80865396493307],
                        ],
                    },
                },
                1401: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.98352840272177, 1.7323652453972609],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2339.87486742,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.716985230225326,
                            48.98197836893915,
                            1.747786182906161,
                            48.98505986509816,
                        ),
                        "coordinates": [
                            [1.716985230225326, 48.98294677854624],
                            [1.717603813449699, 48.98276171412389],
                            [1.718137148382026, 48.98262346421197],
                            [1.718650457288927, 48.98249548247999],
                            [1.719433362534453, 48.98233077283618],
                            [1.719889836779225, 48.982252335013236],
                            [1.720360649706443, 48.98218348964009],
                            [1.7208336224081, 48.982121381692764],
                            [1.721650294106043, 48.98204214067667],
                            [1.722206559977197, 48.982003070959436],
                            [1.722832243256125, 48.98198025759216],
                            [1.723367292837499, 48.98197836893915],
                            [1.723952830556004, 48.98198626643678],
                            [1.724581510966729, 48.982013425771505],
                            [1.725152178371905, 48.982054549784955],
                            [1.725686498344667, 48.98211213308127],
                            [1.726173704524123, 48.982178979556664],
                            [1.726646307084847, 48.98225764095034],
                            [1.727259536453248, 48.98236560627509],
                            [1.729463412792157, 48.98276755041199],
                            [1.729986375405204, 48.982867881476785],
                            [1.730444267978145, 48.98296786604116],
                            [1.730966941804259, 48.983091985148995],
                            [1.73139204442747, 48.98321320671891],
                            [1.731929143247268, 48.983377550132],
                            [1.732331542729272, 48.98350816643865],
                            [1.733684328160941, 48.98396858368231],
                            [1.734408156824341, 48.9842008202285],
                            [1.73486477049055, 48.98433349713143],
                            [1.735305293981077, 48.98445180939565],
                            [1.735808110097762, 48.98457580103273],
                            [1.736267900242778, 48.98467101468146],
                            [1.736771133672103, 48.98476109737522],
                            [1.737260941888888, 48.98484040114616],
                            [1.738048753009511, 48.98494089302297],
                            [1.738775919150704, 48.98501161734152],
                            [1.739513627118635, 48.98505594926107],
                            [1.740308955801521, 48.98505986509816],
                            [1.740985081039136, 48.985053870449875],
                            [1.741777342671697, 48.985010407297985],
                            [1.742425081476358, 48.984943289714394],
                            [1.742953237977467, 48.98486920222355],
                            [1.743912892897122, 48.98473379587805],
                            [1.745868513597715, 48.984448868780746],
                            [1.747212049926789, 48.984255932912646],
                            [1.747786182906161, 48.98417275530591],
                        ],
                    },
                },
                1402: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.06903271870311, 2.1585479773429914],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 2519.94968128,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.141696932779959,
                            49.0681762438397,
                            2.17530420994616,
                            49.07046236344271,
                        ),
                        "coordinates": [
                            [2.141696932779959, 49.06931413549863],
                            [2.141894722344571, 49.06936555492483],
                            [2.142317331590504, 49.06946558238912],
                            [2.142793529079225, 49.06956324985639],
                            [2.143075005089424, 49.069613446945446],
                            [2.14367555297842, 49.06969179710713],
                            [2.143998414905505, 49.06973011001583],
                            [2.144207728686709, 49.06975474243604],
                            [2.144885032383994, 49.06980623732963],
                            [2.145511848556825, 49.06981807552708],
                            [2.146163359909774, 49.06981466383134],
                            [2.146307089686741, 49.0698104066627],
                            [2.146872422916509, 49.069783152720916],
                            [2.147444743009804, 49.06974034916665],
                            [2.147792148523682, 49.069704789924835],
                            [2.148137598548268, 49.069662354967726],
                            [2.148390924100857, 49.069631296543065],
                            [2.14928107417728, 49.069498763835306],
                            [2.150032973123, 49.0693686961187],
                            [2.151707803017233, 49.06911961458292],
                            [2.154747989715312, 49.06864966373161],
                            [2.155550110997946, 49.06853376869588],
                            [2.15615513489806, 49.06845858474576],
                            [2.156832044747036, 49.06838766797942],
                            [2.157672986566504, 49.06830630936155],
                            [2.158496830972967, 49.06824818261551],
                            [2.160242117918889, 49.0681762438397],
                            [2.161788678659724, 49.06817951317964],
                            [2.16322012508999, 49.0682248544408],
                            [2.163822196822458, 49.068263533842966],
                            [2.164878508432512, 49.06834605716377],
                            [2.165557113681162, 49.068417216112934],
                            [2.166795233059659, 49.068566539575514],
                            [2.168016779613148, 49.068761687813286],
                            [2.169364061728551, 49.06901366110011],
                            [2.170796031537739, 49.06932059741474],
                            [2.172018660404792, 49.069611927351154],
                            [2.173597198513241, 49.07000037204879],
                            [2.175280226542526, 49.070455590709585],
                            [2.17530420994616, 49.07046236344271],
                        ],
                    },
                },
                1403: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.585015544181076, 2.2316501282304406],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1477.83665606,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.22243331383282,
                            48.58248559694799,
                            2.241070080902974,
                            48.58632790141752,
                        ),
                        "coordinates": [
                            [2.22243331383282, 48.58248559694799],
                            [2.223030270952659, 48.58262405439505],
                            [2.224021659880004, 48.58284820389986],
                            [2.224606218467712, 48.58299368274531],
                            [2.225170664737299, 48.58315412710434],
                            [2.2257225406609, 48.58332455050398],
                            [2.226269352313955, 48.58351661722245],
                            [2.227016784877082, 48.58380214510024],
                            [2.227751670375946, 48.58408932022777],
                            [2.229131150795893, 48.58463858891828],
                            [2.231235572742492, 48.5854616594381],
                            [2.231945435806981, 48.5857337962075],
                            [2.232266526528431, 48.58584734652248],
                            [2.232581508771994, 48.58594581931543],
                            [2.23295896669429, 48.58605283865107],
                            [2.233307744257541, 48.58613310135934],
                            [2.233626444503126, 48.58619168488598],
                            [2.233972773017592, 48.58624363022461],
                            [2.234251359525463, 48.58627719225871],
                            [2.234710685197544, 48.58631591275238],
                            [2.235077179814213, 48.58632790141752],
                            [2.235441195156416, 48.5863248951593],
                            [2.235812755577665, 48.5863152335268],
                            [2.236392713474805, 48.58628910008277],
                            [2.23888082315863, 48.58613804772422],
                            [2.241070080902974, 48.58600789080001],
                        ],
                    },
                },
                1404: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.55684371677862, 2.148664039097329],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3686.51940304,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.125707269059876,
                            48.551091975575105,
                            2.170976266414434,
                            48.56459702646747,
                        ),
                        "coordinates": [
                            [2.125707269059876, 48.551091975575105],
                            [2.126789913795467, 48.55132510271452],
                            [2.12896546467409, 48.5517954504796],
                            [2.131890509438409, 48.55242367232928],
                            [2.133658068003907, 48.55280301427043],
                            [2.135675392558938, 48.553233219469504],
                            [2.137650577218092, 48.55366140857071],
                            [2.14007951322794, 48.554183618925485],
                            [2.14171138019304, 48.55453119651698],
                            [2.142518544348514, 48.554704129145016],
                            [2.143333213733597, 48.55488373138448],
                            [2.144142858458884, 48.55506664914837],
                            [2.144958776230192, 48.55527166383912],
                            [2.145734380099473, 48.555482386378145],
                            [2.148862060813467, 48.556378656182126],
                            [2.149779004613058, 48.55662830760487],
                            [2.151408493271612, 48.557082358878276],
                            [2.153609071392398, 48.55770050523466],
                            [2.154839717419387, 48.558045579947716],
                            [2.157526642226454, 48.55879933518742],
                            [2.158085579555874, 48.55896010557366],
                            [2.158521679477913, 48.55909236685552],
                            [2.158957702515967, 48.55924627754289],
                            [2.159361065521268, 48.55941345968396],
                            [2.15977692797825, 48.55959398341209],
                            [2.161891270731794, 48.56053827358643],
                            [2.163294200748161, 48.56116332681434],
                            [2.165406154639093, 48.56211087853001],
                            [2.16592727645762, 48.56234150458849],
                            [2.169692978201667, 48.564022611808895],
                            [2.170976266414434, 48.56459702646747],
                        ],
                    },
                },
                1405: {
                    "attributes": {
                        "reseau": "CDGVAL",
                        "val": 1,
                        "metro": 0,
                        "res_com": "CDGVAL",
                        "rer": 0,
                        "extcode": "043043100:CDGVAL",
                        "geo_point_2d": [49.01072338118906, 2.56597150864519],
                        "indice_lig": "CDG",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Navette",
                        "tramway": 0,
                        "idrefligc": "C00563",
                        "navette": 1,
                        "idrefliga": "A01516",
                        "shape_leng": 886.723273551,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.560558843901876,
                            49.01000186615112,
                            2.570640068890432,
                            49.01142693384418,
                        ),
                        "coordinates": [
                            [2.560558843901876, 49.01000186615112],
                            [2.560850945485178, 49.010008412245604],
                            [2.561156333640305, 49.01002176194895],
                            [2.564902120596101, 49.01038145693991],
                            [2.56517746298344, 49.010438503122984],
                            [2.565380915703538, 49.01051825322931],
                            [2.565564285924245, 49.010647027868714],
                            [2.565945045119212, 49.01096338826333],
                            [2.566100127088225, 49.011099437709326],
                            [2.566263117868257, 49.01118734505533],
                            [2.566486988342713, 49.01125641338675],
                            [2.566751383977676, 49.01129866308604],
                            [2.567017349960649, 49.01132378080207],
                            [2.569179537772544, 49.01142693384418],
                            [2.569361819118484, 49.011422282611996],
                            [2.569615836314412, 49.011381812204604],
                            [2.569726672723763, 49.01136035705756],
                            [2.569859395067021, 49.01131634273727],
                            [2.569972328030778, 49.011270961620866],
                            [2.570105116783073, 49.01120037214237],
                            [2.570219832273564, 49.01112288294286],
                            [2.570313882832194, 49.011047742118365],
                            [2.570381912805165, 49.01097693577825],
                            [2.570442572082756, 49.01090248011877],
                            [2.570501573175319, 49.01080966210145],
                            [2.570533763093567, 49.01073250491147],
                            [2.570562526155269, 49.01061895177199],
                            [2.570640068890432, 49.01004496004053],
                        ],
                    },
                },
                1406: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.01877759276227, 2.235980964305266],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1181.78822059,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.229376488386948,
                            49.015584975459475,
                            2.242479108496568,
                            49.02177395624445,
                        ),
                        "coordinates": [
                            [2.229376488386948, 49.02177395624445],
                            [2.229782565441072, 49.02159168744298],
                            [2.230405307962166, 49.02131529049074],
                            [2.23090351568045, 49.02108553755557],
                            [2.231916333809215, 49.020621543401255],
                            [2.233104294101219, 49.02008688591308],
                            [2.235002521418409, 49.01923404597375],
                            [2.235543105019262, 49.01898812370755],
                            [2.236943116450256, 49.01835536291396],
                            [2.237702643080775, 49.01800980115395],
                            [2.239198282595041, 49.017348860962805],
                            [2.239857151502305, 49.01706024488593],
                            [2.24039850736022, 49.016811287614544],
                            [2.240903643902251, 49.01656512026528],
                            [2.241496124230893, 49.01622435879959],
                            [2.241928664590731, 49.01596302864393],
                            [2.24235166954054, 49.015680106451185],
                            [2.242479108496568, 49.015584975459475],
                        ],
                    },
                },
                1407: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.57128981382939, 2.181358047525474],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2135.7834798,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.170976266414434,
                            48.56459702646747,
                            2.192063068770897,
                            48.577508489431835,
                        ),
                        "coordinates": [
                            [2.170976266414434, 48.56459702646747],
                            [2.17172654415447, 48.564932847306856],
                            [2.17335369672128, 48.56565514387435],
                            [2.173646850060759, 48.56579047151535],
                            [2.174032706859375, 48.56597089998105],
                            [2.174418509952119, 48.56616798274798],
                            [2.174789190539962, 48.56638669348678],
                            [2.175132222885808, 48.56662035326221],
                            [2.175440110215418, 48.56685895995195],
                            [2.175747934074798, 48.5671175497863],
                            [2.176113277517944, 48.56743951034772],
                            [2.178403133233052, 48.569424682301666],
                            [2.180395316125702, 48.571156239567884],
                            [2.180788282429595, 48.571491547285916],
                            [2.18125389301595, 48.571871921797424],
                            [2.181738052320768, 48.57224322899794],
                            [2.182242973895478, 48.5725961029814],
                            [2.182776503358541, 48.57293326106523],
                            [2.183342731624164, 48.57324880897363],
                            [2.183903994797406, 48.57354935717823],
                            [2.184505461193709, 48.573836633991796],
                            [2.186713867521629, 48.5749165503998],
                            [2.187821077369343, 48.57544991426277],
                            [2.189555424622037, 48.57628826163466],
                            [2.191683312357492, 48.57732528310781],
                            [2.192063068770897, 48.577508489431835],
                        ],
                    },
                },
                1408: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.98157569154329, 1.7658630585593014],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2705.71434164,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.747786182906161,
                            48.979292248544446,
                            1.783973407729849,
                            48.98417275530591,
                        ),
                        "coordinates": [
                            [1.747786182906161, 48.98417275530591],
                            [1.759122520798526, 48.98252977029969],
                            [1.767128730690744, 48.981370708786486],
                            [1.772770149784534, 48.98055397986733],
                            [1.775760987262731, 48.98011898427532],
                            [1.778114472372165, 48.9797807330306],
                            [1.779200418719123, 48.97964802640779],
                            [1.780492421408916, 48.97951393367839],
                            [1.780984520853248, 48.97947111849838],
                            [1.781733441623526, 48.9794128910443],
                            [1.782576340971883, 48.97935511455806],
                            [1.783397339540274, 48.97931626028895],
                            [1.783973407729849, 48.979292248544446],
                        ],
                    },
                },
                1409: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.30309453632192, 2.6804725098122493],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 7769.49621604,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.675087359405762,
                            48.26775810993438,
                            2.692480190584066,
                            48.33268364471056,
                        ),
                        "coordinates": [
                            [2.692480190584066, 48.33268364471056],
                            [2.691391542696429, 48.33228253572326],
                            [2.690409659957772, 48.33188545383876],
                            [2.689891583311462, 48.33165854002862],
                            [2.689365292574413, 48.33142201410298],
                            [2.688976489120495, 48.33124160855934],
                            [2.688567755902449, 48.33105060194479],
                            [2.688224663627763, 48.330881354474236],
                            [2.687906605869653, 48.33071885864362],
                            [2.687186506511966, 48.33033712063469],
                            [2.686885963109403, 48.33016989525797],
                            [2.686326809117357, 48.32985329650773],
                            [2.685774311968423, 48.3295231863682],
                            [2.685479084020273, 48.32934335199067],
                            [2.684668996449672, 48.328813500717516],
                            [2.683713695973193, 48.32814740678432],
                            [2.683383025525658, 48.32791012344695],
                            [2.683121055646814, 48.32770777996683],
                            [2.682790452979792, 48.327452082357176],
                            [2.682153260702667, 48.32693731803789],
                            [2.681755051210831, 48.32659203543299],
                            [2.681401695730068, 48.326278674410815],
                            [2.681131622688666, 48.32602591303681],
                            [2.680477248554331, 48.325378656047334],
                            [2.680155400057916, 48.32504601765736],
                            [2.679700310292202, 48.324551919654894],
                            [2.679560783117677, 48.32439220277733],
                            [2.679167143689837, 48.323924324626525],
                            [2.678839764978314, 48.323522203512624],
                            [2.678227216244546, 48.322691027298724],
                            [2.677805255589131, 48.32208565175546],
                            [2.677553142176157, 48.3216916470262],
                            [2.677295450940819, 48.32126978275815],
                            [2.677145310799483, 48.320999362541734],
                            [2.676969236280938, 48.32068356313474],
                            [2.676847640708833, 48.3204474295201],
                            [2.676464748696359, 48.319652755993324],
                            [2.67635262448922, 48.31938531382368],
                            [2.676218087039629, 48.31906449622371],
                            [2.676042468360639, 48.318613606385675],
                            [2.675867792771375, 48.31810246423378],
                            [2.675775357664548, 48.31781570405213],
                            [2.675666409491944, 48.317445755014326],
                            [2.675604279729833, 48.31721211001296],
                            [2.675540681467895, 48.316977599876836],
                            [2.675343439648102, 48.31611672096722],
                            [2.675214788432753, 48.315230457377574],
                            [2.675151705996511, 48.31467131988922],
                            [2.675131120092048, 48.3144168974097],
                            [2.675108316409423, 48.31399898315524],
                            [2.675095519346699, 48.31373448159181],
                            [2.675087359405762, 48.313123023917676],
                            [2.675094816930023, 48.312828950667935],
                            [2.67512727420026, 48.31224344963654],
                            [2.675181590587328, 48.31170104590739],
                            [2.675252050455233, 48.311154097619095],
                            [2.675309182499671, 48.31083020105635],
                            [2.67537031673438, 48.310499996574585],
                            [2.675554531998818, 48.309651523900655],
                            [2.67563568576462, 48.309271740314486],
                            [2.675732306515464, 48.308807443262225],
                            [2.676145201050875, 48.30687194226511],
                            [2.67649548931721, 48.30525046147873],
                            [2.676843052150074, 48.30362809042412],
                            [2.67727174197208, 48.30164937494295],
                            [2.677545458196509, 48.300447129148516],
                            [2.677714704225114, 48.29959418052138],
                            [2.677858594165325, 48.298907658264426],
                            [2.677996551817388, 48.29823008433304],
                            [2.678371884700336, 48.29654467685652],
                            [2.67852609549913, 48.2957817440343],
                            [2.678652454175343, 48.29519587096144],
                            [2.678869395527883, 48.29420245564648],
                            [2.679083633352303, 48.293209048105716],
                            [2.67925889634775, 48.29242977727173],
                            [2.679359271467391, 48.2919330939816],
                            [2.679501832487909, 48.29129959855797],
                            [2.67960090049538, 48.29081936469478],
                            [2.679752578554305, 48.29013072910954],
                            [2.679910707559019, 48.28941152731955],
                            [2.680064927673276, 48.2887107843005],
                            [2.680577903473908, 48.28628847977151],
                            [2.68087705776792, 48.284916232946394],
                            [2.681022053102365, 48.284250356419314],
                            [2.681190351235858, 48.283446826214714],
                            [2.681451544515652, 48.28224105380438],
                            [2.68169569844899, 48.28110637158191],
                            [2.681939833803385, 48.27997079085949],
                            [2.682086054852688, 48.27929142140013],
                            [2.682183953269003, 48.278834310742916],
                            [2.682280577162314, 48.278387994324305],
                            [2.682365427510876, 48.27799297047525],
                            [2.682507199262286, 48.277343525884795],
                            [2.68258741824988, 48.276971659519575],
                            [2.682860271339749, 48.27570829790955],
                            [2.683079586109003, 48.274692390137474],
                            [2.683300225465166, 48.27367467898567],
                            [2.683520868410259, 48.27265876621789],
                            [2.683721336208414, 48.27184344425305],
                            [2.683865485817682, 48.271261197016436],
                            [2.684020252387677, 48.270712689713825],
                            [2.684114353037021, 48.270426873280144],
                            [2.684240444271282, 48.27010766946594],
                            [2.684391161337541, 48.26977983773528],
                            [2.684616347604972, 48.26932374455536],
                            [2.68486627154594, 48.268875678655775],
                            [2.685109490180194, 48.268489492910525],
                            [2.685439261376148, 48.26803259197371],
                            [2.68564708993975, 48.26775810993438],
                        ],
                    },
                },
                1410: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.40433013072447, 2.104381096350852],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 9460.40823473,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.059912347637065,
                            48.37452501337592,
                            2.149101178683954,
                            48.43222560109566,
                        ),
                        "coordinates": [
                            [2.059912347637065, 48.37452501337592],
                            [2.060168803169756, 48.37476038914822],
                            [2.061710531611523, 48.37618405340427],
                            [2.062927894503412, 48.377358610760176],
                            [2.063620769564241, 48.37801220066923],
                            [2.064139769967333, 48.37846075292266],
                            [2.064687390471871, 48.37890223255506],
                            [2.065245773145158, 48.379336599108804],
                            [2.065807854236245, 48.37974955751449],
                            [2.066398553121912, 48.38015544430071],
                            [2.067010717206384, 48.38055662033569],
                            [2.067633669884333, 48.38094592397704],
                            [2.068263812466392, 48.381328101679486],
                            [2.069492285313193, 48.38203527138113],
                            [2.07090948041989, 48.38285945467348],
                            [2.07285529362164, 48.3839854680865],
                            [2.07552548087518, 48.38556534448141],
                            [2.076401711430008, 48.386076337037196],
                            [2.079637778220721, 48.38797837819667],
                            [2.081539576374458, 48.389108073926565],
                            [2.082520522777127, 48.389741189237874],
                            [2.082964470808629, 48.39005871943705],
                            [2.083465542247325, 48.39042099301155],
                            [2.083906022011038, 48.39076673508047],
                            [2.084996596657437, 48.391649527684564],
                            [2.085265469000333, 48.391883029414736],
                            [2.085714341437449, 48.39230307439687],
                            [2.086144408899705, 48.392705090482025],
                            [2.087410448368193, 48.39389039443015],
                            [2.088148242965005, 48.394597924090974],
                            [2.09006358498378, 48.3963934115477],
                            [2.091622755851054, 48.39787246014661],
                            [2.093299166412603, 48.399481371851394],
                            [2.094565468382839, 48.40065944098271],
                            [2.095806883386784, 48.40182316716078],
                            [2.096251584180544, 48.40222858754525],
                            [2.096699992372325, 48.40260784083122],
                            [2.097174040358048, 48.40298846160678],
                            [2.098139241958962, 48.40364335274027],
                            [2.098661680469242, 48.40397357759639],
                            [2.099748671820835, 48.40458554810459],
                            [2.100387438753176, 48.40490444967329],
                            [2.100990009960433, 48.40518645933453],
                            [2.101596228561625, 48.40545419787553],
                            [2.10222042154967, 48.40570055619972],
                            [2.102862553057961, 48.40593267390702],
                            [2.10350831850859, 48.4061528988013],
                            [2.104172055644254, 48.40635174368305],
                            [2.104835875992749, 48.40653392989631],
                            [2.105521185752344, 48.40670663938108],
                            [2.106210137087386, 48.40686507673815],
                            [2.106902776282214, 48.4069997250884],
                            [2.107620477758488, 48.40712490221656],
                            [2.108323867610861, 48.40725480511758],
                            [2.109016506766977, 48.4073918198457],
                            [2.109712583665996, 48.40755976683952],
                            [2.110380056119475, 48.407732411153916],
                            [2.111051000751848, 48.40792885079203],
                            [2.111707590845548, 48.40813953306351],
                            [2.112356932021685, 48.40837398984909],
                            [2.11299909158775, 48.408617946922384],
                            [2.113623367922046, 48.40886662161723],
                            [2.116512813944235, 48.4100500155159],
                            [2.117964740912412, 48.4106405085283],
                            [2.118688945348009, 48.41093217630599],
                            [2.120144486791436, 48.41152502867152],
                            [2.122948628493163, 48.41267002507358],
                            [2.123558659046227, 48.412930515767094],
                            [2.124161467322893, 48.413210022792796],
                            [2.124739203577912, 48.41350375494061],
                            [2.125309719620492, 48.41381650560042],
                            [2.125858768117994, 48.41413635041247],
                            [2.126379161766188, 48.414472794312815],
                            [2.126892395941267, 48.41481398032549],
                            [2.127380488541522, 48.4151860485527],
                            [2.127843549798885, 48.415562826758496],
                            [2.12829222294517, 48.41596336913338],
                            [2.12870878688836, 48.416351953328345],
                            [2.129107436045245, 48.41675240012632],
                            [2.129481004039119, 48.41716945522616],
                            [2.129829479658945, 48.41760549578576],
                            [2.130156525587779, 48.41803911793409],
                            [2.130447777035282, 48.41848694922984],
                            [2.130724725523139, 48.41893713189465],
                            [2.130969451965991, 48.41940153228353],
                            [2.131185596546078, 48.41986349947151],
                            [2.131383854705379, 48.42033019439206],
                            [2.131557045911323, 48.42080873788324],
                            [2.131737371265931, 48.42129205387224],
                            [2.131917825595686, 48.421744438621964],
                            [2.132130414325363, 48.42220639870331],
                            [2.132368030312491, 48.422668402707785],
                            [2.132620075154726, 48.423099503396514],
                            [2.132904246887806, 48.423542556786565],
                            [2.133238546350169, 48.42396666533281],
                            [2.133640480963952, 48.424462273618595],
                            [2.134010550865685, 48.4248840649883],
                            [2.134405725706067, 48.42528686653815],
                            [2.134829524437905, 48.425684959403846],
                            [2.135267658074579, 48.426075939502745],
                            [2.135734454004454, 48.42645269098857],
                            [2.13622633693355, 48.42681521179467],
                            [2.136736141446994, 48.427168243963536],
                            [2.137260336011829, 48.42749988560343],
                            [2.137795348775547, 48.42781013127767],
                            [2.138351818431337, 48.42812041149511],
                            [2.138936978315949, 48.42840932701696],
                            [2.139540047517639, 48.42869113228561],
                            [2.140143170492681, 48.428961038109115],
                            [2.14072141455014, 48.42919520826077],
                            [2.141363977826216, 48.42943900349808],
                            [2.144722479960393, 48.43076222518112],
                            [2.145247255411907, 48.43096535178929],
                            [2.145779140398241, 48.43118038424757],
                            [2.14628086337047, 48.43136957579935],
                            [2.146706703942693, 48.43152182243611],
                            [2.147315025374545, 48.43172721480351],
                            [2.147975313047437, 48.43192288802247],
                            [2.149101178683954, 48.43222560109566],
                        ],
                    },
                },
                1411: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.72986474847673, 2.266040131755341],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1593.43807056,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.258966434308785,
                            48.72430941924522,
                            2.273483464396533,
                            48.734716586800225,
                        ),
                        "coordinates": [
                            [2.258966434308785, 48.72430941924522],
                            [2.259157325028898, 48.72445608745586],
                            [2.259553722795044, 48.72477380091713],
                            [2.260220278027434, 48.72530841977614],
                            [2.26079996876785, 48.725769236176404],
                            [2.261216735508188, 48.72611303640149],
                            [2.261583298669818, 48.726402845368355],
                            [2.261930849689614, 48.72668274938338],
                            [2.262268911328239, 48.72694825710337],
                            [2.262437291054081, 48.72708532891778],
                            [2.262655961138146, 48.7272607098675],
                            [2.26283777226967, 48.727404559642835],
                            [2.263204343079003, 48.727706957513256],
                            [2.263570755428057, 48.72799842471422],
                            [2.263875021859707, 48.728258639694914],
                            [2.264799722081263, 48.72894627391443],
                            [2.265255975621555, 48.72928199098207],
                            [2.265762490903652, 48.72964741333558],
                            [2.266270371537665, 48.7300128345787],
                            [2.266748383314503, 48.73035755154009],
                            [2.267000972115777, 48.73053846152615],
                            [2.267192454588363, 48.73067436911632],
                            [2.267374419755593, 48.73081206904795],
                            [2.267538729817031, 48.73093896666993],
                            [2.267626979047966, 48.731019055447256],
                            [2.267700288987441, 48.73108834443829],
                            [2.267770888455745, 48.73115313474746],
                            [2.267821116749616, 48.731203524739634],
                            [2.267888999294699, 48.7312665146777],
                            [2.267994872928667, 48.731381685807314],
                            [2.268129231231665, 48.731542737476985],
                            [2.268283932990716, 48.73173977149017],
                            [2.268496992020729, 48.732008782275635],
                            [2.268677481496553, 48.732237306337],
                            [2.268841707640744, 48.73243164729621],
                            [2.268967948326848, 48.732568412231466],
                            [2.269090138597789, 48.73268539022797],
                            [2.269229993950003, 48.73280777493845],
                            [2.269363067770866, 48.73291936404564],
                            [2.26949616459388, 48.73301476559795],
                            [2.269630629412124, 48.733103872864696],
                            [2.269746088860731, 48.733174084834246],
                            [2.269876492269379, 48.733250599745354],
                            [2.270023211285168, 48.73332712433958],
                            [2.270195748828812, 48.73341175690314],
                            [2.270399540609814, 48.733506299777446],
                            [2.270614211545861, 48.73359905049133],
                            [2.270778613981166, 48.733669289735666],
                            [2.27096203231618, 48.73375212934618],
                            [2.271186213048966, 48.73385117840906],
                            [2.271496334618988, 48.73398599406839],
                            [2.271683497278407, 48.73406639087547],
                            [2.271932139426364, 48.73417444558605],
                            [2.272145466301575, 48.734260898063596],
                            [2.272372394705531, 48.73434106221353],
                            [2.272748801728018, 48.73447346776019],
                            [2.273085810156915, 48.73458516686029],
                            [2.273483464396533, 48.734716586800225],
                        ],
                    },
                },
                1412: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.54852245951594, 2.5347994778327165],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4188.03933699,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.528089329788019,
                            48.535139766989644,
                            2.544348950368585,
                            48.56448587191694,
                        ),
                        "coordinates": [
                            [2.544348950368585, 48.535139766989644],
                            [2.543533094989149, 48.535376810547056],
                            [2.5428067377061, 48.53559941074588],
                            [2.541822882236705, 48.535934298756914],
                            [2.541207591619603, 48.53616144616372],
                            [2.54042062749174, 48.53646265601041],
                            [2.539873442654213, 48.53670156892596],
                            [2.539430035903228, 48.53691174211748],
                            [2.538790008242987, 48.5372293337655],
                            [2.537928262205616, 48.537652004058046],
                            [2.536877629820398, 48.538141610562725],
                            [2.535471512758736, 48.53881744023492],
                            [2.534592166387668, 48.539249919827206],
                            [2.534127220300702, 48.53947464731595],
                            [2.533836631213788, 48.53961633821536],
                            [2.533443388669111, 48.539825650018905],
                            [2.533001565176017, 48.54007910905133],
                            [2.532600492674632, 48.54035709168129],
                            [2.532211147488611, 48.54066469358805],
                            [2.531633257220233, 48.541206557455105],
                            [2.531029413386713, 48.54175644635524],
                            [2.530533118936787, 48.54220936300475],
                            [2.530090598926598, 48.54267170343082],
                            [2.529630449241557, 48.54321020876787],
                            [2.529302539405852, 48.5436628331208],
                            [2.528790543116243, 48.54444324419517],
                            [2.528487825707959, 48.544965328406356],
                            [2.528266708633503, 48.54546135532744],
                            [2.52814963588372, 48.5458833151186],
                            [2.528089329788019, 48.546552958486366],
                            [2.528118037700997, 48.54742722633246],
                            [2.528158387307683, 48.548061135992675],
                            [2.528221353447969, 48.54921318274103],
                            [2.528293150571983, 48.55018143412573],
                            [2.528340869588219, 48.550476386026816],
                            [2.52843529613006, 48.550802190324255],
                            [2.52858376983135, 48.55120403983381],
                            [2.528766425769203, 48.551564520062456],
                            [2.529075753661072, 48.5520468976442],
                            [2.52931660986601, 48.552334250837916],
                            [2.529614521338702, 48.55270600278147],
                            [2.529884377037311, 48.552981541040864],
                            [2.530103775050081, 48.553183406947426],
                            [2.530432951516048, 48.55343843501189],
                            [2.531877298547034, 48.55458071285865],
                            [2.53256630106962, 48.55514965390539],
                            [2.534668471070157, 48.55681772207365],
                            [2.535259260818608, 48.557252598178536],
                            [2.536037979530353, 48.55782788709188],
                            [2.53771818763571, 48.55894179806745],
                            [2.538189512870904, 48.55925966567274],
                            [2.538598395791155, 48.55952655009743],
                            [2.540625258524213, 48.560905083194875],
                            [2.541062913783764, 48.561253207678924],
                            [2.541440982779752, 48.56160593410765],
                            [2.541849378201203, 48.56208450153871],
                            [2.542108393829923, 48.5624752106823],
                            [2.542311814043763, 48.5628534307242],
                            [2.542451122206134, 48.56322864027295],
                            [2.542561631802292, 48.563640729656434],
                            [2.542635270964211, 48.56408573051026],
                            [2.54265182270078, 48.56448587191694],
                        ],
                    },
                },
                1413: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.83555894327316, 2.222590630823824],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 1658.12465929,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.221740757924928,
                            48.829010503694406,
                            2.225312853267071,
                            48.843124399912504,
                        ),
                        "coordinates": [
                            [2.225312853267071, 48.829010503694406],
                            [2.225241710767137, 48.82939218577289],
                            [2.225187167032456, 48.82960865190766],
                            [2.225165394708794, 48.829675253382305],
                            [2.225111110756835, 48.82977513193665],
                            [2.225056894113777, 48.82984645899424],
                            [2.224981051867569, 48.82991776460468],
                            [2.224883574463833, 48.82999380821445],
                            [2.224778928431366, 48.830053189125294],
                            [2.224641840475614, 48.8301149174762],
                            [2.224457907452625, 48.83017422025485],
                            [2.224169408422321, 48.83025721242609],
                            [2.224017931184959, 48.83030702878866],
                            [2.223848402504801, 48.83037110359],
                            [2.223646365911615, 48.830466076876405],
                            [2.223379324020538, 48.830620469223376],
                            [2.223169925658279, 48.83078205632735],
                            [2.223000159518909, 48.830948440631545],
                            [2.222844715613904, 48.83115528843786],
                            [2.222725270821347, 48.83137882691736],
                            [2.222659946223454, 48.831576247214656],
                            [2.222492744483296, 48.832192329664814],
                            [2.222459876384806, 48.83238026445015],
                            [2.222434225668882, 48.83256344790544],
                            [2.222426464247664, 48.83280375326954],
                            [2.222425654010157, 48.8331558953393],
                            [2.222421497754679, 48.834961811679435],
                            [2.222408211532137, 48.83524046622692],
                            [2.222354002218114, 48.83557687105209],
                            [2.22229327254918, 48.83586345350897],
                            [2.22221323623893, 48.83618458416057],
                            [2.221791222936306, 48.83818253039061],
                            [2.221763470243971, 48.83839399538205],
                            [2.221742462724004, 48.83858202592225],
                            [2.221740757924928, 48.83872950580344],
                            [2.221742656558786, 48.838920077666224],
                            [2.221760287836883, 48.83908902916004],
                            [2.221792225964162, 48.83930558157608],
                            [2.22183556202241, 48.83956053329735],
                            [2.221866185303675, 48.8398681165951],
                            [2.221909883193333, 48.84041312253391],
                            [2.221906301822095, 48.84078362117973],
                            [2.221848136383741, 48.84119183437596],
                            [2.221784552333333, 48.841586552977695],
                            [2.221749659353687, 48.84212267994316],
                            [2.22177930515036, 48.84267647204438],
                            [2.221851494752013, 48.843124399912504],
                        ],
                    },
                },
                1414: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.63120420275908, 2.4182347613759663],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2145.63659327,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.407796286173906,
                            48.62602242896445,
                            2.428738987337901,
                            48.636358686719134,
                        ),
                        "coordinates": [
                            [2.407796286173906, 48.63635136710195],
                            [2.409748304368246, 48.636358686719134],
                            [2.410381905588299, 48.63634208875944],
                            [2.410759056733474, 48.63631486433514],
                            [2.411190458418859, 48.636274113654686],
                            [2.411594705089148, 48.63622079057155],
                            [2.411882287125418, 48.636181031569514],
                            [2.412129301211006, 48.636132452523114],
                            [2.41257877527955, 48.63603353504474],
                            [2.412900377787771, 48.63595900586637],
                            [2.413210112687331, 48.63586809562087],
                            [2.413449368551375, 48.63579208171608],
                            [2.413702371406039, 48.635702296803764],
                            [2.413987126466788, 48.635593291031746],
                            [2.414278147589484, 48.63548696446222],
                            [2.414615360395664, 48.635339215582626],
                            [2.414880633818829, 48.63520239508682],
                            [2.415204628131616, 48.63502771369348],
                            [2.415512032179902, 48.63484607679206],
                            [2.415795580380604, 48.63465050909502],
                            [2.416057127010252, 48.634457883126274],
                            [2.416267154358345, 48.63428867406272],
                            [2.416471729007712, 48.634105079787204],
                            [2.41670607036253, 48.633871104920246],
                            [2.416901101877382, 48.63366053873288],
                            [2.417171735357627, 48.63331650714684],
                            [2.417449343943716, 48.632897571811036],
                            [2.417684653320542, 48.63243068513497],
                            [2.417808932277844, 48.63210056519519],
                            [2.418250251878738, 48.63068210756625],
                            [2.418348825761309, 48.630399667041054],
                            [2.418451239126567, 48.63015030972618],
                            [2.418616469046946, 48.62980775720328],
                            [2.418721966581229, 48.6296134392464],
                            [2.418851873552151, 48.62941370819756],
                            [2.419003466308015, 48.62920316975035],
                            [2.41917947629299, 48.62899171389047],
                            [2.419415795670585, 48.62873749246906],
                            [2.419631787793351, 48.628513874002344],
                            [2.419884996981506, 48.62829088972888],
                            [2.420133004215352, 48.628081858147624],
                            [2.420413477189043, 48.6278802152626],
                            [2.42064655019675, 48.62772716727065],
                            [2.42115310460655, 48.6274386459426],
                            [2.421614245191313, 48.62720127368928],
                            [2.422042594369127, 48.6270130056213],
                            [2.422311012387059, 48.626909386405366],
                            [2.422635032239384, 48.62679583371031],
                            [2.423269574987957, 48.62661189951721],
                            [2.423584155273361, 48.62653342222709],
                            [2.423832893783851, 48.62648859255065],
                            [2.424099497426619, 48.626452990592476],
                            [2.424570130587496, 48.62640496467613],
                            [2.426958556533334, 48.626169274799594],
                            [2.427848470070308, 48.626102358210304],
                            [2.428738987337901, 48.62602242896445],
                        ],
                    },
                },
                1415: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.33606074025781, 2.7150681704821813],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 3453.05578905,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.692480190584066,
                            48.33268364471056,
                            2.738001618532588,
                            48.336948497679415,
                        ),
                        "coordinates": [
                            [2.738001618532588, 48.336481780613234],
                            [2.736762659171073, 48.33651262837991],
                            [2.735878364828087, 48.33653770750051],
                            [2.734612970880228, 48.33656975861058],
                            [2.732432980645761, 48.336617268752406],
                            [2.728731439796928, 48.33671110369936],
                            [2.726687246750097, 48.33676630014547],
                            [2.725137717425952, 48.33679635238013],
                            [2.724783071117859, 48.33680566399128],
                            [2.724328648426573, 48.336818914286134],
                            [2.723615322912011, 48.33683934410153],
                            [2.721535973996009, 48.33689230567229],
                            [2.720261667635255, 48.33692541422257],
                            [2.718930609839109, 48.33694521164816],
                            [2.717691142274704, 48.336948497679415],
                            [2.716711299646037, 48.33693927068468],
                            [2.715662428958664, 48.33692114809484],
                            [2.714664095502014, 48.33688582487598],
                            [2.712594360656635, 48.33678302090136],
                            [2.711390648661376, 48.336697093654635],
                            [2.709557805600562, 48.33652690442291],
                            [2.708508937160571, 48.33640446636896],
                            [2.707582817398796, 48.336283414393336],
                            [2.70713516862115, 48.336220739296465],
                            [2.706625597587514, 48.33615076632596],
                            [2.706148975814798, 48.336079486461344],
                            [2.705589999602982, 48.33599678418312],
                            [2.704894644748266, 48.335892042088645],
                            [2.703832519572033, 48.335702041279276],
                            [2.702830726332853, 48.33550738864384],
                            [2.701987278172267, 48.33532929475771],
                            [2.700781637483038, 48.33507676757434],
                            [2.699665057682811, 48.33481535695403],
                            [2.698849565787158, 48.33461183433904],
                            [2.697963621192474, 48.33439020234251],
                            [2.697279883743135, 48.33420714392918],
                            [2.696614967483384, 48.33401502916253],
                            [2.695685998889145, 48.333741127829356],
                            [2.694716520807782, 48.33344153318228],
                            [2.693826264481449, 48.33314745535343],
                            [2.692853203481901, 48.33282107583971],
                            [2.692480190584066, 48.33268364471056],
                        ],
                    },
                },
                1416: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.71263581942408, 2.241354670503502],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1166.21484676,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.237314364639455,
                            48.708140583645324,
                            2.245672514581905,
                            48.716946287585145,
                        ),
                        "coordinates": [
                            [2.237314364639455, 48.708140583645324],
                            [2.237418729027951, 48.708421883985864],
                            [2.23751068891853, 48.70868128351076],
                            [2.237599954351252, 48.70888909313602],
                            [2.237758413604321, 48.70915002094207],
                            [2.237868749915824, 48.70932827578574],
                            [2.238009085210477, 48.70950635060971],
                            [2.238108011855649, 48.70964042815748],
                            [2.23820428101999, 48.70974482742951],
                            [2.238361009722594, 48.709909092400444],
                            [2.23854602296599, 48.71008864529387],
                            [2.238936685087797, 48.71043430322595],
                            [2.239146558234102, 48.710611888190925],
                            [2.239478386022655, 48.71090668576399],
                            [2.239735628503226, 48.711157103589045],
                            [2.239907827811197, 48.711349694942875],
                            [2.240199359255079, 48.7116709830965],
                            [2.240416273687491, 48.711931057358235],
                            [2.240615581872578, 48.71216233929159],
                            [2.240880611870904, 48.71244428553845],
                            [2.241162169545972, 48.71270416234277],
                            [2.24142673497641, 48.712922907984044],
                            [2.241820804228654, 48.713203817499334],
                            [2.242375353554048, 48.713582867354766],
                            [2.242928152201952, 48.71399277062986],
                            [2.243207192420011, 48.714209448692856],
                            [2.243401227071621, 48.714365182857414],
                            [2.243809588631124, 48.71472882323571],
                            [2.24426530233853, 48.71520940664861],
                            [2.244914779981872, 48.7160039917927],
                            [2.245401532355817, 48.71661588903325],
                            [2.245672514581905, 48.716946287585145],
                        ],
                    },
                },
                1417: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.69652643735059, 2.1727222773840906],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1258.91711331,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.164378242774173,
                            48.695952781238496,
                            2.181054439041218,
                            48.69750567080331,
                        ),
                        "coordinates": [
                            [2.164378242774173, 48.69625274781443],
                            [2.164562600182352, 48.69630311132026],
                            [2.164803930959636, 48.69636058014051],
                            [2.165086706613482, 48.69641795989094],
                            [2.165416652629512, 48.69646252107539],
                            [2.165720839951485, 48.696492654940194],
                            [2.166311668092928, 48.69651962064425],
                            [2.166660187170277, 48.696508984626384],
                            [2.166996455432278, 48.696480177647864],
                            [2.167337431873322, 48.69643667602634],
                            [2.16775889059878, 48.696376997177516],
                            [2.168626066303874, 48.69623080211004],
                            [2.168931899102439, 48.69617549874024],
                            [2.169582967027905, 48.696062250514906],
                            [2.169896596279814, 48.69602120471368],
                            [2.170318158298957, 48.695977898303134],
                            [2.170656480004767, 48.69595591080355],
                            [2.170977077441362, 48.695952781238496],
                            [2.171303071203551, 48.69596134938194],
                            [2.17158285442948, 48.69597704352551],
                            [2.171849023426976, 48.69600171031339],
                            [2.172180341456346, 48.696043555723],
                            [2.172667400445018, 48.69611808258775],
                            [2.173251521551024, 48.69620743473952],
                            [2.174536081947678, 48.6964291227148],
                            [2.175828510918088, 48.69663779672639],
                            [2.176539597344807, 48.696764506020315],
                            [2.177110146486703, 48.6968662187377],
                            [2.177764544967649, 48.696983140630735],
                            [2.179180706165651, 48.69720543252379],
                            [2.181054439041218, 48.69750567080331],
                        ],
                    },
                },
                1418: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.69716988244036, 2.1441496857490288],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1177.983616,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.136566717058361,
                            48.695264122108014,
                            2.151642038623571,
                            48.69840767611977,
                        ),
                        "coordinates": [
                            [2.136566717058361, 48.69819697630193],
                            [2.136988268538911, 48.69824077345183],
                            [2.137322316656399, 48.698275532262805],
                            [2.138083159666832, 48.698351852767765],
                            [2.138477670538784, 48.69838918242388],
                            [2.138794644359828, 48.698401155392176],
                            [2.139060087097898, 48.69840767611977],
                            [2.139316557394117, 48.69839777952454],
                            [2.13957110835724, 48.698379661505705],
                            [2.139834309470235, 48.698355848530625],
                            [2.140147139734653, 48.698324982673405],
                            [2.140401770066898, 48.69828687749274],
                            [2.140624078801426, 48.69824157768681],
                            [2.141053659917522, 48.698135247860755],
                            [2.141392602596471, 48.69804446496301],
                            [2.141956285761559, 48.6978860833468],
                            [2.142575180753822, 48.69771364911209],
                            [2.143201976203466, 48.69754558691578],
                            [2.146732169183826, 48.69660011004246],
                            [2.146808778712953, 48.69657908356537],
                            [2.150133568491403, 48.69566649025854],
                            [2.151642038623571, 48.695264122108014],
                        ],
                    },
                },
                1419: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.68661811975293, 2.7670889329581394],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 14077.1554893,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.729481333043577,
                            48.64437362491682,
                            2.825169932970373,
                            48.74472077575101,
                        ),
                        "coordinates": [
                            [2.825169932970373, 48.64437362491682],
                            [2.825117696515625, 48.64439914860716],
                            [2.823496840242104, 48.645178593959585],
                            [2.821874584697003, 48.645958922320666],
                            [2.820254983810116, 48.64673831648759],
                            [2.819574150450681, 48.64706405674784],
                            [2.818415257598208, 48.64763552839771],
                            [2.817226627793429, 48.648222402401736],
                            [2.816063479394435, 48.6487803779819],
                            [2.813788402842773, 48.64986730221834],
                            [2.812261790861088, 48.65060392438641],
                            [2.810736499704717, 48.651341420098895],
                            [2.809208433866786, 48.652077107785914],
                            [2.8053442084936, 48.65394294837771],
                            [2.802790323211953, 48.655165693855764],
                            [2.799943177985535, 48.65654065758471],
                            [2.799297228351776, 48.656850842950064],
                            [2.796932216431252, 48.65797915129158],
                            [2.795886268824165, 48.65848877873689],
                            [2.795191642720393, 48.65882521637912],
                            [2.793994223815369, 48.6594001852802],
                            [2.793200818753637, 48.65977387841077],
                            [2.792293986443532, 48.66021456853259],
                            [2.790523433108257, 48.66106517836583],
                            [2.788754168730758, 48.66191485520677],
                            [2.786984851358499, 48.662765404664015],
                            [2.785494015154736, 48.6634916257155],
                            [2.78485190976048, 48.66379631707029],
                            [2.784393728459598, 48.66402144095147],
                            [2.783963938325626, 48.66424775142953],
                            [2.783635731604783, 48.664425207186454],
                            [2.783307604607718, 48.66462254054954],
                            [2.783046100590704, 48.66478735772437],
                            [2.782732588264209, 48.66499350481364],
                            [2.782349477022271, 48.66526749005375],
                            [2.782054210877877, 48.66549706571446],
                            [2.781709249484484, 48.66578708689376],
                            [2.781491355036558, 48.66599288302623],
                            [2.781332586280571, 48.66614757208109],
                            [2.781170878004105, 48.66631167749327],
                            [2.780994850659576, 48.666500099702496],
                            [2.780819967744134, 48.666697043537106],
                            [2.780614440787319, 48.66694335133204],
                            [2.780298876569061, 48.66733487282282],
                            [2.779874898545251, 48.66790217676214],
                            [2.779425556448623, 48.668519038778406],
                            [2.777975124804106, 48.670466235782264],
                            [2.77724627782877, 48.67141780884133],
                            [2.776980522191153, 48.67176686112896],
                            [2.776234462842174, 48.67277245109426],
                            [2.775648057634928, 48.67356249080601],
                            [2.774924836798414, 48.674546401883596],
                            [2.773943658838933, 48.675847847865775],
                            [2.772870074822791, 48.67730251945651],
                            [2.771213704019179, 48.679518405375376],
                            [2.7697504655931, 48.68147183983985],
                            [2.769332772232794, 48.6820085052128],
                            [2.769061409054049, 48.68235036637321],
                            [2.768803334507701, 48.682658902362],
                            [2.768462719453608, 48.683002824185195],
                            [2.768172228141294, 48.68327074081385],
                            [2.767845612849305, 48.68356901691351],
                            [2.767492209728382, 48.68384913458479],
                            [2.767189717959314, 48.68406249277007],
                            [2.766856407964228, 48.68429758562561],
                            [2.766468784706438, 48.68454815340436],
                            [2.766079661167236, 48.684782537451525],
                            [2.765589025582491, 48.685063443125564],
                            [2.76514537510212, 48.68528877531804],
                            [2.764705088014628, 48.68548791930636],
                            [2.764236176877805, 48.685676174668686],
                            [2.763812409269565, 48.68583244376893],
                            [2.762926677176741, 48.686126234108656],
                            [2.761879597440152, 48.68645389318209],
                            [2.758384652914698, 48.68753974602893],
                            [2.757347528975372, 48.687859651664915],
                            [2.756327147083079, 48.68818297158534],
                            [2.755671451252733, 48.688409484241674],
                            [2.755004758277538, 48.688664636373076],
                            [2.754397506837519, 48.68890607620955],
                            [2.753670930566782, 48.6892414765325],
                            [2.752935111263798, 48.6895917634978],
                            [2.752377757974552, 48.689880203811],
                            [2.75184791114504, 48.69018340750379],
                            [2.751288421117146, 48.69052088459583],
                            [2.750778247623626, 48.690857327830365],
                            [2.750395412661966, 48.691114952536715],
                            [2.749597733265244, 48.691728464750206],
                            [2.749321191393923, 48.69195968508854],
                            [2.747096162755428, 48.6937645037213],
                            [2.746502358959065, 48.694236970019325],
                            [2.745483706343688, 48.69508236517169],
                            [2.742846687132863, 48.697208725070176],
                            [2.742270661278355, 48.69770538644625],
                            [2.741674817272218, 48.698272259808],
                            [2.741259812566582, 48.69869280225192],
                            [2.740756468444926, 48.699277327718264],
                            [2.740284476727836, 48.699876128557754],
                            [2.739944903354887, 48.700388125067825],
                            [2.73964987923887, 48.70086579034941],
                            [2.739298072109031, 48.70154689371933],
                            [2.739117634042364, 48.70191533942363],
                            [2.738957739862195, 48.70230439466664],
                            [2.738815597955051, 48.70270305945618],
                            [2.738717448597016, 48.70300129003301],
                            [2.738559548908253, 48.70363854022837],
                            [2.738450842054682, 48.70414252339305],
                            [2.738439077757731, 48.70420011880874],
                            [2.738422190998628, 48.704296402548536],
                            [2.738393823546856, 48.7044853516894],
                            [2.738228043974364, 48.70549493387133],
                            [2.738147339810723, 48.70593406899578],
                            [2.738046792880056, 48.70660888667897],
                            [2.737739171207388, 48.70839864748905],
                            [2.737556929618997, 48.70939209911832],
                            [2.737351878628549, 48.71059156770303],
                            [2.737183556229141, 48.71162813526213],
                            [2.737060846788115, 48.712253569390924],
                            [2.736587042420871, 48.71501963607373],
                            [2.736353367469476, 48.71638377221482],
                            [2.736246066377876, 48.71706940303441],
                            [2.736018526257642, 48.71835348110869],
                            [2.735908620606001, 48.719054409505105],
                            [2.735791794113421, 48.71974007395691],
                            [2.735709795202926, 48.72019270161116],
                            [2.735631930372989, 48.720652509377494],
                            [2.735557805867888, 48.72106731937025],
                            [2.735473180556589, 48.72153526327249],
                            [2.735382633103439, 48.72210932411769],
                            [2.735105348616268, 48.7236372805973],
                            [2.734879746481517, 48.725001385886365],
                            [2.734741669724737, 48.72575277214805],
                            [2.734549702813608, 48.72690542691385],
                            [2.734433838994908, 48.72754612252524],
                            [2.734265041297676, 48.72853772481095],
                            [2.734146688983983, 48.72920810560002],
                            [2.73394509378695, 48.73035000173071],
                            [2.733767519783255, 48.73143695734663],
                            [2.733573490469702, 48.732506883945625],
                            [2.733420763224158, 48.73347234981333],
                            [2.73332028898587, 48.73400057980367],
                            [2.73321869028409, 48.734558490610226],
                            [2.733106449878491, 48.73520761467232],
                            [2.733053629111172, 48.735513207452804],
                            [2.732892461155463, 48.73644542758566],
                            [2.732786981612087, 48.73702943117864],
                            [2.732691072686723, 48.737620594519825],
                            [2.732565048748073, 48.73835754805241],
                            [2.732416908234033, 48.73922047804262],
                            [2.732327218551144, 48.739735881499605],
                            [2.73222919612983, 48.74023732229124],
                            [2.73214791922954, 48.74061800222027],
                            [2.732075380938231, 48.740900629960485],
                            [2.731959323584673, 48.741271364878955],
                            [2.731851616784648, 48.74158388285163],
                            [2.731718964525705, 48.74190636859668],
                            [2.731534096457797, 48.7422559323722],
                            [2.731314044676415, 48.742627200456035],
                            [2.731100690136974, 48.74295436044052],
                            [2.73087568397883, 48.74324742651045],
                            [2.730657489573668, 48.74351077276526],
                            [2.730262604008351, 48.74395638453341],
                            [2.730035925174012, 48.7441792906083],
                            [2.729481333043577, 48.74472077575101],
                        ],
                    },
                },
                1420: {
                    "attributes": {
                        "reseau": "LA VERRIERE-LA DEFENSE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE U",
                        "rer": 0,
                        "extcode": "800:U",
                        "geo_point_2d": [48.801211261704616, 2.1632640248407977],
                        "indice_lig": "U",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01741",
                        "navette": 0,
                        "idrefliga": "A01855",
                        "shape_leng": 4534.56419207,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.136050489663708,
                            48.79528024627206,
                            2.188259860000294,
                            48.81257171717766,
                        ),
                        "coordinates": [
                            [2.136050489663708, 48.79528024627206],
                            [2.136078615729023, 48.795284586940234],
                            [2.136184386259406, 48.79530090881185],
                            [2.136923051747886, 48.79540922138856],
                            [2.137193773686322, 48.79544566723029],
                            [2.137540717011488, 48.7954831446176],
                            [2.137935303232737, 48.79551980530034],
                            [2.138672898157999, 48.79555706102029],
                            [2.139428190102225, 48.79559434337222],
                            [2.141261337567381, 48.79567663989319],
                            [2.142141851963426, 48.795715917344765],
                            [2.142706607881934, 48.79574745613372],
                            [2.143856757254184, 48.79579486437915],
                            [2.147234244824272, 48.795959949065534],
                            [2.148995074205409, 48.79602948652837],
                            [2.150017745902113, 48.796064478878215],
                            [2.150442631394686, 48.79608658921006],
                            [2.150781082583517, 48.79610855609176],
                            [2.151285101512348, 48.7961569644232],
                            [2.151641490132594, 48.796197992654015],
                            [2.152030230622056, 48.79625572855427],
                            [2.152480159919246, 48.796323079295],
                            [2.152976821918897, 48.79641429648562],
                            [2.154495584415558, 48.796699879271635],
                            [2.155085753590148, 48.7968293061806],
                            [2.155636272857649, 48.79696818445126],
                            [2.155923219353944, 48.797048173958764],
                            [2.15683568548617, 48.797310081377546],
                            [2.157683680908086, 48.79753481665686],
                            [2.158322075302499, 48.79769604510322],
                            [2.15939704124788, 48.797973103336034],
                            [2.15992599538207, 48.79810716886839],
                            [2.160246219863137, 48.79819570134629],
                            [2.160494482932771, 48.79826508796951],
                            [2.161958736431169, 48.79873738058273],
                            [2.162547601834495, 48.79897889228789],
                            [2.163005309457361, 48.79918246887177],
                            [2.16358211082685, 48.79946135965422],
                            [2.163959181807098, 48.79962581731218],
                            [2.164347828841171, 48.799826152363146],
                            [2.164962663621792, 48.800214940094854],
                            [2.16522854160145, 48.80040331016468],
                            [2.165429769816557, 48.800539235663145],
                            [2.165627315579427, 48.80069894803],
                            [2.165875125465583, 48.80090632368993],
                            [2.166126488581109, 48.801127979309776],
                            [2.166381366167477, 48.80137581205262],
                            [2.166614684924689, 48.801609337074595],
                            [2.166995128183698, 48.802004875047],
                            [2.167289480111606, 48.80229797300467],
                            [2.167494145720219, 48.802486245684435],
                            [2.167691658444953, 48.80266023133961],
                            [2.167932304693969, 48.80286045239814],
                            [2.168151473170487, 48.80302257269248],
                            [2.168385065343533, 48.80317995585612],
                            [2.168582719210991, 48.8033134906527],
                            [2.168949327824064, 48.803527842928844],
                            [2.169344732131114, 48.80376873793727],
                            [2.169675471955967, 48.80395957078341],
                            [2.170006351351759, 48.80410995434757],
                            [2.170337224755478, 48.804262716766615],
                            [2.170614180788673, 48.804382088514565],
                            [2.170945128492624, 48.80451343469936],
                            [2.171470374790364, 48.80470930423408],
                            [2.17192014680004, 48.80485509548221],
                            [2.172290780131342, 48.80496983979191],
                            [2.172661460453775, 48.80507030689409],
                            [2.17306455377721, 48.8051731988197],
                            [2.173453288231497, 48.80526179287259],
                            [2.17388173641079, 48.80534363391178],
                            [2.174324519650796, 48.805427543026894],
                            [2.17463412883275, 48.80548032881508],
                            [2.174990557536692, 48.8055355613457],
                            [2.175383029678644, 48.80558370405854],
                            [2.175926961285955, 48.80565394221556],
                            [2.176244638619483, 48.805679292531046],
                            [2.17656767040842, 48.805715322509414],
                            [2.17689606892237, 48.80575669508684],
                            [2.177326734230471, 48.80581777695293],
                            [2.177638972296932, 48.805860904333926],
                            [2.178005026800091, 48.80591655560105],
                            [2.178361930196951, 48.80597628912136],
                            [2.178674146174967, 48.806039175468044],
                            [2.179190473531706, 48.80615097582032],
                            [2.179753287461502, 48.80630031318024],
                            [2.180502944889887, 48.80652909207602],
                            [2.181168601358515, 48.80676793712481],
                            [2.181952907942329, 48.80708449884279],
                            [2.182283280876487, 48.807233327760564],
                            [2.182570148964991, 48.807363212613986],
                            [2.182654420360782, 48.807408290671304],
                            [2.183077167195768, 48.80762558765231],
                            [2.183673794332594, 48.807970814262994],
                            [2.183866752034676, 48.80809247613725],
                            [2.184095040000431, 48.80823666704375],
                            [2.184445568997908, 48.808477243660235],
                            [2.184800126216717, 48.808737608421566],
                            [2.184900651661447, 48.808811483142634],
                            [2.184948188647466, 48.80884931613252],
                            [2.185184526909117, 48.809034882060224],
                            [2.185188603857815, 48.80903758558408],
                            [2.185350196212467, 48.80917808774469],
                            [2.18570591159766, 48.809508595010904],
                            [2.185944795589196, 48.809754414369046],
                            [2.186011303512924, 48.80982284705895],
                            [2.186081874321824, 48.809898480132325],
                            [2.18618366436315, 48.810005628614604],
                            [2.186374967047272, 48.810228902338324],
                            [2.186994866749312, 48.811002198597095],
                            [2.187059974091799, 48.81108501696183],
                            [2.187663595616336, 48.811844799010636],
                            [2.18772599747772, 48.811922219215646],
                            [2.187763981332981, 48.81196903135119],
                            [2.187880677253543, 48.81210317609318],
                            [2.187978376784385, 48.81221571300756],
                            [2.187994650228365, 48.81223731749701],
                            [2.188259860000294, 48.81257171717766],
                        ],
                    },
                },
                1421: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.59215579265243, 2.952014767881464],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 10976.0690939,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.888252894073074,
                            48.562124835009335,
                            3.011769326340159,
                            48.61401524181304,
                        ),
                        "coordinates": [
                            [3.011769326340159, 48.562124835009335],
                            [3.011226891509093, 48.56253092583289],
                            [3.010795465472182, 48.56284826556181],
                            [3.009993230798577, 48.56344027043157],
                            [3.008925378979757, 48.56423079076438],
                            [3.007976790278708, 48.56492526843745],
                            [3.00717185256031, 48.56552266512501],
                            [3.006647470419285, 48.56590790301021],
                            [3.00617761987365, 48.56625247085581],
                            [3.005702256953254, 48.56660219499814],
                            [3.005206164306193, 48.56696504688912],
                            [3.004547424324002, 48.5674554464708],
                            [3.003848469906697, 48.56797935238775],
                            [3.00269584278038, 48.56882876540765],
                            [3.001888033314354, 48.569423442986384],
                            [3.000880228979461, 48.570163172870124],
                            [2.999784569293052, 48.57096327081697],
                            [2.999343380860185, 48.57127199960639],
                            [2.998246225738218, 48.57202481813805],
                            [2.997071123265755, 48.572829340514495],
                            [2.995682638928761, 48.573795164671495],
                            [2.994352896535735, 48.57469768048869],
                            [2.993866704902402, 48.57503143801881],
                            [2.992552049907145, 48.57595273031148],
                            [2.991314022441687, 48.57679716831864],
                            [2.990805794164422, 48.57713999018386],
                            [2.989891205325824, 48.57777836341677],
                            [2.989175638877831, 48.57827127291864],
                            [2.988640681185174, 48.5786398876568],
                            [2.987873659028496, 48.57916588424166],
                            [2.986719801444277, 48.57996208197389],
                            [2.986085809194948, 48.58040277036514],
                            [2.985422239778113, 48.58086220417641],
                            [2.984868732975652, 48.58124067938653],
                            [2.98428767728862, 48.58164362186359],
                            [2.983876040481968, 48.58192981072165],
                            [2.982489620112649, 48.582884668047136],
                            [2.981818761639758, 48.58334349957637],
                            [2.980439307674015, 48.584285730565036],
                            [2.97857981096076, 48.58556607105648],
                            [2.977864572533398, 48.586030429504724],
                            [2.977335764572858, 48.58636821846457],
                            [2.97685282678557, 48.586653817831944],
                            [2.976026577722111, 48.587108180905624],
                            [2.975350612933426, 48.58744133712915],
                            [2.97482595851147, 48.587700711618716],
                            [2.974336663394183, 48.58793234092389],
                            [2.973834731479977, 48.588154907149345],
                            [2.973059350183268, 48.58847401174176],
                            [2.972388337442415, 48.588729745743585],
                            [2.971704809436496, 48.5889760494858],
                            [2.970946293093624, 48.58923046450041],
                            [2.970112381183803, 48.5894864910627],
                            [2.969443855387594, 48.58968343558977],
                            [2.968678602728465, 48.58990229487591],
                            [2.967938385347133, 48.590112354082],
                            [2.966539013256185, 48.59051222316226],
                            [2.964797968828982, 48.59101738517702],
                            [2.963001913166871, 48.59152320607119],
                            [2.96150437312926, 48.59195023519319],
                            [2.960085326570524, 48.59234588005332],
                            [2.957795055602938, 48.59300380491686],
                            [2.956063256816088, 48.593503385862036],
                            [2.953049554471621, 48.59438401711514],
                            [2.95136087829297, 48.59486074500292],
                            [2.949898922877148, 48.595273402112134],
                            [2.948891095303162, 48.59556391987036],
                            [2.948050787617785, 48.59580676278953],
                            [2.945006760697396, 48.59666935700941],
                            [2.943147708199963, 48.59720539479138],
                            [2.939248183658887, 48.59830891642245],
                            [2.935906847545137, 48.59927806190474],
                            [2.933626003623716, 48.59993397622023],
                            [2.931647749610685, 48.60050012986618],
                            [2.927774708145882, 48.60159322795373],
                            [2.924480136697615, 48.60254111006643],
                            [2.922036645378133, 48.603228211184515],
                            [2.921005433979269, 48.60351770225044],
                            [2.917502320940796, 48.60451141907943],
                            [2.913782875368526, 48.60557177625513],
                            [2.912017741368709, 48.606078047491245],
                            [2.910274154084748, 48.60657428981424],
                            [2.908434112596616, 48.60709652361592],
                            [2.907355922451583, 48.607403760755325],
                            [2.905909667304607, 48.607816236894244],
                            [2.903799596169402, 48.60841620606059],
                            [2.902812779368984, 48.60869271848928],
                            [2.900770309436264, 48.609277536455295],
                            [2.899844320120906, 48.609539332669044],
                            [2.898023436898308, 48.6100564489932],
                            [2.896829788457083, 48.61039688024103],
                            [2.896417476453498, 48.61051402290028],
                            [2.896006692213395, 48.61064644457216],
                            [2.89561075042617, 48.6107724966874],
                            [2.89528223538252, 48.61088284104059],
                            [2.894933007532868, 48.61100491832953],
                            [2.894555761699582, 48.61114549522509],
                            [2.89360916395734, 48.6115107581527],
                            [2.892552313811294, 48.61196288508396],
                            [2.889773096807634, 48.61327413369311],
                            [2.888252894073074, 48.61401524181304],
                        ],
                    },
                },
                1422: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.583073588206304, 2.4704855598605784],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2674.76653146,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.461806387476935,
                            48.57380779355899,
                            2.479469169601778,
                            48.59262774217932,
                        ),
                        "coordinates": [
                            [2.479469169601778, 48.57380779355899],
                            [2.479357314892576, 48.574024656296],
                            [2.47928059078915, 48.57420640367357],
                            [2.479154225455219, 48.57456266917153],
                            [2.479045840294161, 48.575047506823054],
                            [2.478829018672113, 48.575965037363275],
                            [2.478649367322957, 48.57668465827947],
                            [2.478559118563712, 48.576911209124525],
                            [2.478448796743211, 48.5771615173096],
                            [2.478376627138994, 48.57728452556271],
                            [2.478266105869235, 48.57745885257871],
                            [2.478145280851609, 48.577621883544865],
                            [2.478022297530456, 48.57777804399431],
                            [2.47783393525247, 48.577967928716305],
                            [2.477676320616452, 48.578109842574904],
                            [2.477163504690807, 48.578534365523126],
                            [2.47689104957836, 48.578716294116674],
                            [2.476591554140037, 48.57887601997072],
                            [2.476253204344149, 48.57904100286986],
                            [2.476033955978881, 48.57914918425569],
                            [2.475699660215732, 48.57931146225782],
                            [2.475276292295121, 48.57951829641589],
                            [2.474938112422104, 48.57965683478018],
                            [2.474620394784755, 48.579783928432775],
                            [2.474280644999451, 48.57990793378341],
                            [2.473848959613193, 48.58006567608672],
                            [2.473479214802921, 48.58018239776077],
                            [2.473063673058709, 48.58029846123175],
                            [2.471601538045066, 48.58067288962167],
                            [2.470885898648852, 48.580863103161285],
                            [2.470583895253587, 48.58094799123116],
                            [2.470108480865278, 48.58109847827381],
                            [2.469813393928726, 48.58119709627892],
                            [2.469506488624496, 48.581320266350964],
                            [2.46923668346206, 48.58144237230697],
                            [2.468903730518143, 48.58161362180081],
                            [2.46853542925058, 48.58183378221665],
                            [2.468283233315783, 48.581991290066405],
                            [2.4680918869761, 48.582126246796214],
                            [2.467890361641018, 48.58228564892074],
                            [2.467709207130496, 48.58244678078844],
                            [2.467475260645703, 48.58266292037181],
                            [2.467265814116154, 48.58290506275602],
                            [2.467076668960577, 48.583136391270955],
                            [2.466882260579852, 48.583429773960034],
                            [2.4667257709891, 48.58371142241669],
                            [2.466613936444353, 48.58396604132433],
                            [2.466487332059518, 48.5843777311117],
                            [2.466433248547302, 48.584642842788305],
                            [2.466400722709321, 48.584849359835154],
                            [2.466397514389484, 48.585090333350465],
                            [2.466404626484875, 48.58530977646686],
                            [2.466442005297627, 48.585610985845605],
                            [2.466708248430035, 48.58687683847644],
                            [2.466752945967985, 48.58738576897757],
                            [2.466741502409226, 48.58767624326193],
                            [2.466706938877428, 48.587862290517954],
                            [2.466673305541975, 48.58803512573577],
                            [2.466642552445876, 48.58819792766931],
                            [2.466587468157129, 48.58838683607376],
                            [2.466466186005301, 48.5886612493169],
                            [2.46634760065887, 48.588931163238605],
                            [2.466042462564625, 48.58939822890894],
                            [2.465888432997967, 48.58959174566147],
                            [2.46571002008105, 48.58979248494971],
                            [2.465346258991088, 48.59013371849937],
                            [2.464995039465635, 48.590406777492454],
                            [2.464489815450447, 48.59076687004323],
                            [2.462242722436937, 48.592315679199565],
                            [2.461983501821284, 48.59249919447487],
                            [2.461806387476935, 48.59262774217932],
                        ],
                    },
                },
                1423: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.70105137791739, 2.1870411247086605],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1289.30887795,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.181054439041218,
                            48.69750567080331,
                            2.192734884806757,
                            48.70540392478545,
                        ),
                        "coordinates": [
                            [2.181054439041218, 48.69750567080331],
                            [2.181718386073955, 48.69761538915748],
                            [2.182271004785933, 48.697705167902654],
                            [2.182849555217605, 48.697796887427636],
                            [2.183308356010197, 48.69787383672692],
                            [2.183597452039906, 48.69793922829017],
                            [2.184010090764342, 48.698068123091154],
                            [2.184368310422876, 48.69820529296809],
                            [2.184641009525943, 48.69832166377009],
                            [2.184917715160081, 48.698461420249465],
                            [2.185125207155934, 48.69857860179969],
                            [2.185352986619492, 48.69872548606668],
                            [2.185605054854383, 48.69892725725588],
                            [2.185886848639559, 48.69918302400759],
                            [2.18610076012317, 48.69942521046462],
                            [2.186349673640667, 48.69977355673601],
                            [2.186568468793548, 48.70020010029068],
                            [2.186687360964525, 48.70041878046614],
                            [2.186819745765206, 48.700668953702085],
                            [2.186908898394472, 48.700839033689675],
                            [2.186997511074339, 48.70103163226071],
                            [2.187120453174225, 48.70126782373158],
                            [2.187244960745564, 48.701462140899594],
                            [2.187433986146703, 48.70171792962909],
                            [2.1875328588396, 48.701830839706446],
                            [2.187599491566925, 48.701906588958344],
                            [2.187738119108233, 48.7020343566118],
                            [2.187961699529856, 48.7022306912705],
                            [2.188348170490751, 48.70253571196519],
                            [2.188720805596109, 48.702805417690485],
                            [2.189447395965157, 48.70335491755937],
                            [2.189626342597655, 48.70348734175786],
                            [2.190076432198339, 48.70381885572682],
                            [2.190902001496882, 48.704447609888476],
                            [2.191090192618483, 48.70458205170136],
                            [2.191287076347827, 48.70471608618828],
                            [2.191505437036929, 48.7048508433539],
                            [2.191726465732583, 48.70497247396164],
                            [2.191888753347821, 48.70505713308766],
                            [2.192203798211223, 48.705202614465435],
                            [2.192455285560884, 48.705309110049384],
                            [2.192734884806757, 48.70540392478545],
                        ],
                    },
                },
                1424: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.98853238427416, 2.9890235170340156],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 3841.8942451,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.973519215077535,
                            48.97436062282584,
                            3.007953055749719,
                            48.99841539320162,
                        ),
                        "coordinates": [
                            [3.007953055749719, 48.99841539320162],
                            [3.007125728100396, 48.99802739127617],
                            [3.006450656574785, 48.997711544616415],
                            [3.004797499726691, 48.99694502991142],
                            [2.99974153111668, 48.99459298037562],
                            [2.995681704351054, 48.99270557937993],
                            [2.994920354698954, 48.9923618452237],
                            [2.994530902278736, 48.9921958567157],
                            [2.994113703333233, 48.99203668785531],
                            [2.993803484381748, 48.991928537900534],
                            [2.993473043308315, 48.99182216916534],
                            [2.993018263179704, 48.99169152718738],
                            [2.992617028580308, 48.991590557076],
                            [2.992122022095117, 48.99148012970509],
                            [2.98948221174346, 48.9909692205317],
                            [2.989104850145396, 48.99088607651864],
                            [2.988696124984179, 48.99079179884357],
                            [2.988231286540687, 48.990664526767176],
                            [2.987853238373825, 48.99054952062019],
                            [2.987487950910211, 48.99043604685454],
                            [2.987138251901406, 48.99030430528466],
                            [2.986770647104063, 48.990155186166724],
                            [2.986346761424596, 48.989970680978416],
                            [2.985743031677043, 48.98967262948967],
                            [2.985328415704607, 48.98944150573327],
                            [2.98507226498396, 48.98929007400256],
                            [2.984579605773865, 48.98895801037631],
                            [2.984334245705464, 48.98877451700547],
                            [2.984058043713823, 48.98855455328085],
                            [2.98376670862844, 48.988305517109964],
                            [2.983471528923542, 48.988021543458395],
                            [2.983137837055643, 48.98766199199822],
                            [2.982901828257867, 48.987366633848374],
                            [2.982545690659099, 48.98688916352555],
                            [2.982185304420239, 48.98638542167882],
                            [2.981800663532403, 48.98584070305271],
                            [2.981123236656392, 48.9849284372329],
                            [2.980896336654976, 48.984604921388105],
                            [2.980509657124992, 48.98405911382655],
                            [2.978669153023966, 48.981459451784694],
                            [2.978081563790149, 48.98063660731409],
                            [2.977506774347654, 48.97982368190999],
                            [2.976246890619957, 48.978046509836474],
                            [2.975092197812238, 48.976405677170035],
                            [2.974597437043156, 48.975708883057294],
                            [2.974345299848863, 48.975383830566564],
                            [2.974027816182958, 48.975010784370674],
                            [2.973519215077535, 48.97436062282584],
                        ],
                    },
                },
                1425: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.28836931934232, 1.990088286991256],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 5497.35427321,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.977381874807355,
                            48.265029175961345,
                            2.003525000097989,
                            48.31129627475171,
                        ),
                        "coordinates": [
                            [1.977381874807355, 48.265029175961345],
                            [1.981484289421749, 48.2728492778265],
                            [1.986082550412378, 48.28161677227275],
                            [1.988874997122848, 48.286938974206436],
                            [1.989609136468927, 48.28833414525246],
                            [1.990420855012075, 48.28975356317323],
                            [1.992065552148522, 48.29245925978734],
                            [1.993094235568977, 48.29416104764083],
                            [1.994318945532952, 48.29617815340115],
                            [1.997427108581022, 48.301292675853624],
                            [1.998743253829308, 48.303407835476634],
                            [1.999829652734041, 48.30516849298202],
                            [2.003525000097989, 48.31129627475171],
                        ],
                    },
                },
                1426: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.98550517065901, 2.403355582328755],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2646.63525035,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.390763932713399,
                            48.97686858845462,
                            2.416187488926984,
                            48.99377714689271,
                        ),
                        "coordinates": [
                            [2.416187488926984, 48.99377714689271],
                            [2.415543364629177, 48.99336419260263],
                            [2.414519126943772, 48.99273674349286],
                            [2.413603510445466, 48.9921924897475],
                            [2.412247274999493, 48.9913635749675],
                            [2.411773210763645, 48.99108550257167],
                            [2.410604288473538, 48.9903510426507],
                            [2.408575693042949, 48.98907013552481],
                            [2.406020941025929, 48.98745137051067],
                            [2.404381782694417, 48.986407814293294],
                            [2.40349162633148, 48.9858063607705],
                            [2.401092570394125, 48.984120773847636],
                            [2.398722629214109, 48.98246129652324],
                            [2.396472231527975, 48.98088022978824],
                            [2.394359444460042, 48.97939184415406],
                            [2.392156364001073, 48.9778558765243],
                            [2.390763932713399, 48.97686858845462],
                        ],
                    },
                },
                1427: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M6",
                        "rer": 0,
                        "extcode": "100110006:6",
                        "geo_point_2d": [48.851996351072536, 2.2913508320974163],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01376",
                        "navette": 0,
                        "idrefliga": "A01539",
                        "shape_leng": 510.404272346,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.289334532778807,
                            48.85043454901341,
                            2.293612437187803,
                            48.85394260621378,
                        ),
                        "coordinates": [
                            [2.289334532778807, 48.85394260621378],
                            [2.290543911680313, 48.85270482429609],
                            [2.291904690451808, 48.8513628906114],
                            [2.292093632263854, 48.85116947857888],
                            [2.292254426521448, 48.85101051075684],
                            [2.292312715477684, 48.85095354821661],
                            [2.292409171065363, 48.85088069660598],
                            [2.292475476633709, 48.850838314176634],
                            [2.292585977924452, 48.85077872112488],
                            [2.292674373866667, 48.85073634777649],
                            [2.292790882162008, 48.850695309701855],
                            [2.292909397368847, 48.85065559824074],
                            [2.293070094060826, 48.85060397472711],
                            [2.293612437187803, 48.85043454901341],
                        ],
                    },
                },
                1428: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.97680821837428, 2.3906787926776185],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 18.3213560761,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.390593652641838,
                            48.976747848293925,
                            2.390763932713399,
                            48.97686858845462,
                        ),
                        "coordinates": [
                            [2.390763932713399, 48.97686858845462],
                            [2.390593652641838, 48.976747848293925],
                        ],
                    },
                },
                1429: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.0573237318088, 1.529019984282989],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 11048.1629342,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.478703609465158,
                            49.03299339039881,
                            1.581532102335019,
                            49.0910096786847,
                        ),
                        "coordinates": [
                            [1.581532102335019, 49.0387620447533],
                            [1.581276262372023, 49.03872299880559],
                            [1.580518126519983, 49.038565111837634],
                            [1.579910510694322, 49.03841698952659],
                            [1.579249951959872, 49.03821678884989],
                            [1.578830096527714, 49.038064707427736],
                            [1.578337350272843, 49.03787440495051],
                            [1.578297961716302, 49.037856157388845],
                            [1.578263988899655, 49.037841543312524],
                            [1.578001629738589, 49.03773458583084],
                            [1.577080850405673, 49.03730220497555],
                            [1.577018362884167, 49.03727391220525],
                            [1.576981669309402, 49.03725838058277],
                            [1.574027287881379, 49.035825915190614],
                            [1.573696000444206, 49.035666327729714],
                            [1.572716391312308, 49.03523981481945],
                            [1.571928535883366, 49.03492541875965],
                            [1.571073801351587, 49.034611912225465],
                            [1.570392711973072, 49.034391673147894],
                            [1.569909918764586, 49.034248218679274],
                            [1.569310157442812, 49.03407182770409],
                            [1.568512241808568, 49.0338622320899],
                            [1.567849457910452, 49.03370764898351],
                            [1.567132510747216, 49.03356287405248],
                            [1.566287425290697, 49.033414294110635],
                            [1.565543762581622, 49.03330137010243],
                            [1.563921664235111, 49.03312316123833],
                            [1.563070495006647, 49.03306345471545],
                            [1.562230002343015, 49.03302090134391],
                            [1.561977068031699, 49.033014693415836],
                            [1.561301702873599, 49.032995733366505],
                            [1.560823031984419, 49.03299339039881],
                            [1.559143939616171, 49.033049450106226],
                            [1.558842773497118, 49.033066290130186],
                            [1.558329445060223, 49.03309337970564],
                            [1.557283613713525, 49.03314921768815],
                            [1.55677155275009, 49.03318260392136],
                            [1.555762486739533, 49.03324857158051],
                            [1.555073023262373, 49.033298673776365],
                            [1.554357045205925, 49.0333837683706],
                            [1.553583884006641, 49.03349449583932],
                            [1.55226010223712, 49.0337408424074],
                            [1.550478105966066, 49.03415939641561],
                            [1.550175943233786, 49.03423825973146],
                            [1.549875205145137, 49.034313535904836],
                            [1.549371013086333, 49.034453061951105],
                            [1.548922819966511, 49.03459746874591],
                            [1.548393261689953, 49.03478358123359],
                            [1.548184192012527, 49.03485678488816],
                            [1.547646377832877, 49.03504553542393],
                            [1.54748544688406, 49.0351019829139],
                            [1.547068640862204, 49.035250196102055],
                            [1.545578927243583, 49.03577501031975],
                            [1.545285875883721, 49.035881803139446],
                            [1.543845360090701, 49.03640693563929],
                            [1.543069015055703, 49.03671182378234],
                            [1.542720768418656, 49.03684790527007],
                            [1.542332337983386, 49.03701608317419],
                            [1.54154111365109, 49.03739460271761],
                            [1.540401509024111, 49.03800092115488],
                            [1.539773563249925, 49.03834638933434],
                            [1.538535737401306, 49.039103092664746],
                            [1.537790086595059, 49.039620399349914],
                            [1.537104777979092, 49.04012733156154],
                            [1.536989668453411, 49.040224553453996],
                            [1.536036707265728, 49.04103987663916],
                            [1.535382966057178, 49.04162256194857],
                            [1.534687081633557, 49.04227239784787],
                            [1.533960094216572, 49.04298316550007],
                            [1.533551100565966, 49.04340208116082],
                            [1.532900769369306, 49.0441079836356],
                            [1.532378410437217, 49.04476711765207],
                            [1.531847998520263, 49.04549993707329],
                            [1.53126455752894, 49.0463798704645],
                            [1.530515587864895, 49.0475095473659],
                            [1.529943312223785, 49.048457001843715],
                            [1.529423527805069, 49.04937244779646],
                            [1.529348499469841, 49.04952660265586],
                            [1.528941003650431, 49.05035110681632],
                            [1.528678619351795, 49.050918528026806],
                            [1.528457243309889, 49.051488036290706],
                            [1.528224062779394, 49.05202598534768],
                            [1.527334264317489, 49.054311177064506],
                            [1.527070708922736, 49.05494783465414],
                            [1.52680561541536, 49.05567800978445],
                            [1.526291252689631, 49.057006269919086],
                            [1.526048121373296, 49.05756392916333],
                            [1.525428100747455, 49.05915763734414],
                            [1.525159449683598, 49.05976817377859],
                            [1.524778578765379, 49.06054518886602],
                            [1.524524913022502, 49.060992153454215],
                            [1.524444598415076, 49.061132778173054],
                            [1.524411586902485, 49.06118996611213],
                            [1.524352954568542, 49.06129670409302],
                            [1.524230924289281, 49.06147750267928],
                            [1.524044102535795, 49.061754221948036],
                            [1.523669953703582, 49.062302699882096],
                            [1.523532807943096, 49.0624869873695],
                            [1.523234701487187, 49.062888667493745],
                            [1.522079029966925, 49.064338260157065],
                            [1.522018942956616, 49.06441337644401],
                            [1.52196303543089, 49.06448402510848],
                            [1.521370557753488, 49.06522355140208],
                            [1.520600555062029, 49.06618664173986],
                            [1.520001060181972, 49.06693420563649],
                            [1.518406414494689, 49.068928321396285],
                            [1.516899001937751, 49.07060647822849],
                            [1.516181544377341, 49.0713621724539],
                            [1.514880718305695, 49.07254355662357],
                            [1.514514111518433, 49.07285838878731],
                            [1.514172436918312, 49.07315541169595],
                            [1.513099182575742, 49.074064116292455],
                            [1.51252716653694, 49.07454653862474],
                            [1.512443889261567, 49.074615187190375],
                            [1.512432774710515, 49.074625000336894],
                            [1.51217027738229, 49.07485154012976],
                            [1.511848096876696, 49.07512711367843],
                            [1.511025941861798, 49.075831659805054],
                            [1.509430747984814, 49.077164648221654],
                            [1.509383470876559, 49.07720837375053],
                            [1.509359841105364, 49.077229786968836],
                            [1.509284841631437, 49.07729399719712],
                            [1.50914728460961, 49.07741531183557],
                            [1.508723581757911, 49.07778367371438],
                            [1.508108096534845, 49.0783224180098],
                            [1.5071440287561, 49.07907447523395],
                            [1.506584114888967, 49.079481413173475],
                            [1.506324920323401, 49.07967109175234],
                            [1.505397651767913, 49.08026691879266],
                            [1.505049243559004, 49.080469437700735],
                            [1.504810066371897, 49.08060799698905],
                            [1.504723038646763, 49.080654129940854],
                            [1.504641518360784, 49.08069850488468],
                            [1.504402473861098, 49.0808289695692],
                            [1.503758552587811, 49.08118132466787],
                            [1.502123803660662, 49.082077753074486],
                            [1.500487626695681, 49.082974148551884],
                            [1.498850022963881, 49.08387051195875],
                            [1.497725265206916, 49.0844756268522],
                            [1.497658942411302, 49.08451111492802],
                            [1.497576024720438, 49.08455637408547],
                            [1.49646536958483, 49.08513550023593],
                            [1.495684112874506, 49.08550569050356],
                            [1.495617894664926, 49.08553488282281],
                            [1.495558582604798, 49.08556052750571],
                            [1.494550332992961, 49.08599289697331],
                            [1.494175240863612, 49.086149322907595],
                            [1.493752122771307, 49.086311689133325],
                            [1.492889465827328, 49.08663539650534],
                            [1.492813661029106, 49.08666451655277],
                            [1.492419791993912, 49.08679741536718],
                            [1.49204110170919, 49.08692322984871],
                            [1.49099495120055, 49.087246470646534],
                            [1.490209283007259, 49.08747000189864],
                            [1.489426730991015, 49.08767106785773],
                            [1.489264530315387, 49.08770764054453],
                            [1.489104884279971, 49.08775502402131],
                            [1.487619291827881, 49.08807048941299],
                            [1.486061937492089, 49.088337738223565],
                            [1.485618338358145, 49.08841448617119],
                            [1.484798021628155, 49.08858016656981],
                            [1.483750026595684, 49.08884667071334],
                            [1.483374378568234, 49.08895269498391],
                            [1.482159865774084, 49.08934564974116],
                            [1.481958682805087, 49.08941879459835],
                            [1.480973899340743, 49.08982873820999],
                            [1.480139879298803, 49.09022990718184],
                            [1.479435372955225, 49.0905843735567],
                            [1.4789527604403, 49.09085595916263],
                            [1.478703609465158, 49.0910096786847],
                        ],
                    },
                },
                1430: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.48720502968073, 2.7230846449776993],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 4196.6630107,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.69503731516767,
                            48.48610095239564,
                            2.751153658380149,
                            48.488224297839004,
                        ),
                        "coordinates": [
                            [2.751153658380149, 48.487222875528246],
                            [2.750811983801073, 48.48730073616169],
                            [2.749747283783193, 48.487533035691584],
                            [2.749007710722303, 48.48769514221473],
                            [2.748296512086821, 48.487826211208805],
                            [2.747660218607561, 48.48792607216334],
                            [2.747206169495083, 48.48798958052788],
                            [2.746701972392033, 48.48804850919689],
                            [2.746001032679646, 48.48812242182931],
                            [2.745282022136315, 48.488174982641226],
                            [2.744698864033415, 48.48820801466586],
                            [2.744040093935752, 48.48822346817715],
                            [2.743478451420567, 48.488224297839004],
                            [2.742995182922323, 48.4882165142968],
                            [2.742379289406653, 48.48818541044871],
                            [2.741638105880442, 48.48815237119443],
                            [2.740939834349916, 48.48811441640423],
                            [2.740281014156473, 48.48808583309067],
                            [2.739650808096746, 48.488054764756065],
                            [2.739024124486071, 48.48801654355693],
                            [2.738443283681822, 48.487983302155456],
                            [2.737502262661784, 48.48793390176399],
                            [2.73662749746451, 48.48788779574794],
                            [2.735701100376435, 48.487835568048226],
                            [2.734784433431131, 48.48778882534265],
                            [2.734200781053006, 48.48775994427691],
                            [2.733223233991172, 48.487708644305776],
                            [2.732460532588034, 48.48766848249593],
                            [2.731258959189431, 48.48761318369091],
                            [2.730523547642252, 48.487591954794496],
                            [2.729007059343425, 48.487559358494124],
                            [2.72863773006876, 48.48755703909364],
                            [2.727783218926979, 48.48754663751616],
                            [2.726854329619693, 48.48753088784818],
                            [2.725987951369075, 48.487505316493404],
                            [2.725221606933592, 48.48745560083504],
                            [2.724397867333202, 48.48738942192397],
                            [2.723588445316262, 48.48732318874582],
                            [2.722761539498901, 48.487247179997816],
                            [2.721901608245138, 48.487190935282754],
                            [2.721145917116859, 48.48712925977201],
                            [2.720208641420853, 48.48704362176508],
                            [2.719709624572499, 48.4870277916152],
                            [2.719140726037449, 48.487021152763596],
                            [2.718593143733495, 48.48702606405739],
                            [2.718034838729163, 48.487057252769375],
                            [2.717019164707373, 48.48712951470483],
                            [2.716446189067496, 48.4871704990984],
                            [2.715863512492456, 48.48719940189754],
                            [2.715287098899902, 48.48720225435033],
                            [2.714742989406122, 48.48716983514569],
                            [2.714320275491372, 48.487121278650385],
                            [2.713975249029712, 48.48706814252182],
                            [2.713528248718653, 48.48698591630918],
                            [2.713112189980551, 48.48688936133404],
                            [2.712174337790873, 48.48665776471667],
                            [2.711595594454895, 48.486523603224626],
                            [2.711026947651539, 48.486408957944505],
                            [2.710584833637423, 48.48633183864669],
                            [2.710136953427396, 48.486266694491746],
                            [2.709520731988535, 48.48618544793254],
                            [2.709137507305188, 48.48615101865946],
                            [2.708686297795189, 48.48611919042639],
                            [2.708027626298147, 48.4861046962229],
                            [2.707308393057996, 48.48610095239564],
                            [2.706101938384312, 48.48612737351743],
                            [2.703870163645964, 48.4861625036262],
                            [2.703254730024604, 48.48617169015183],
                            [2.702732634690095, 48.486180571849836],
                            [2.701618107313714, 48.4861994543294],
                            [2.700701155161749, 48.486228481642726],
                            [2.700037237733369, 48.48626748266829],
                            [2.699390661628627, 48.48632561445008],
                            [2.69879488344611, 48.48638117001345],
                            [2.698076702743616, 48.48647710888577],
                            [2.697401010623497, 48.48658395145305],
                            [2.696725431993009, 48.48670744490158],
                            [2.696185722507929, 48.48681146913696],
                            [2.695556753246093, 48.48694670346259],
                            [2.69503731516767, 48.487076395248074],
                        ],
                    },
                },
                1431: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [49.11517623165698, 2.5197203171049836],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 3599.69716977,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.506143689252232,
                            49.0995869391937,
                            2.526463637892827,
                            49.12678094198271,
                        ),
                        "coordinates": [
                            [2.506143689252232, 49.12678094198271],
                            [2.506887269943709, 49.12629547418165],
                            [2.508340625409566, 49.12532564128292],
                            [2.509634446989854, 49.124470951804845],
                            [2.511214322296226, 49.12342760786834],
                            [2.512465000584569, 49.122599600305705],
                            [2.513930812480357, 49.12162634632489],
                            [2.515670038799358, 49.12049109172255],
                            [2.517100498349076, 49.11959946301517],
                            [2.517941025838817, 49.119088903520534],
                            [2.520143645099111, 49.11774584787595],
                            [2.520780156790105, 49.1173522399332],
                            [2.52132264408256, 49.11702064411832],
                            [2.521684242075068, 49.11678450879804],
                            [2.522089138284026, 49.11649595770762],
                            [2.522378323654706, 49.11628372954367],
                            [2.522580736919733, 49.11613112653699],
                            [2.52276864883617, 49.11597854476354],
                            [2.522949320549317, 49.11582835439004],
                            [2.523176949593234, 49.115635259646076],
                            [2.523375652520484, 49.115461246002],
                            [2.523603242564199, 49.11525863307339],
                            [2.523816324006448, 49.115053664100394],
                            [2.524022162121535, 49.114851085581996],
                            [2.524209940831935, 49.11466519122262],
                            [2.524412089379553, 49.11444596367849],
                            [2.524621421038634, 49.11421006750092],
                            [2.52483071475988, 49.11396465448349],
                            [2.52502911450683, 49.11371449923568],
                            [2.525259881365917, 49.1133976694584],
                            [2.5253715972193, 49.11322855340959],
                            [2.52553010370472, 49.11297370549167],
                            [2.525659722755146, 49.1127474559007],
                            [2.525828909298395, 49.112442623428734],
                            [2.525958244250419, 49.11214261381345],
                            [2.526065939293247, 49.11187119258258],
                            [2.52613764378801, 49.11166645209505],
                            [2.526234344817988, 49.11136411774319],
                            [2.526309355078754, 49.11107609454382],
                            [2.526373399017927, 49.11076429571217],
                            [2.526440941102093, 49.11017668404954],
                            [2.526461537942227, 49.1098768537888],
                            [2.526463637892827, 49.10947950185519],
                            [2.526440497787389, 49.10911550228004],
                            [2.526406074523773, 49.10864445161508],
                            [2.526296737503929, 49.10753824191231],
                            [2.526184610458316, 49.10638838262464],
                            [2.526007358679905, 49.10457800199242],
                            [2.525852517039498, 49.10293889586863],
                            [2.525716722902096, 49.101540070052955],
                            [2.525531713992054, 49.0995869391937],
                        ],
                    },
                },
                1432: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.74403587274116, 2.3624519751917648],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1825.5595376,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351633198171911,
                            48.74019544820276,
                            2.373111940704935,
                            48.74834968236464,
                        ),
                        "coordinates": [
                            [2.351633198171911, 48.74019544820276],
                            [2.352236916922279, 48.74032036530058],
                            [2.353077245479699, 48.74052887785052],
                            [2.353113958939442, 48.740537865249046],
                            [2.35315747031416, 48.74054775113523],
                            [2.353207781560344, 48.74056123294213],
                            [2.35330589785325, 48.740586107900334],
                            [2.353307044734945, 48.740586398336916],
                            [2.353414466434745, 48.74061515883646],
                            [2.354003247487515, 48.7407652486571],
                            [2.354804165995392, 48.740990840915295],
                            [2.355670376940542, 48.74126857451371],
                            [2.35616128189506, 48.74143485667468],
                            [2.35679226208796, 48.74166136263422],
                            [2.35790194501933, 48.74209550893488],
                            [2.358802224598667, 48.74246583725283],
                            [2.359357089785589, 48.74270133676104],
                            [2.360926400648249, 48.74334798768189],
                            [2.362408915943983, 48.74394797669073],
                            [2.362884931398351, 48.744147505868405],
                            [2.364741405272006, 48.74489165967841],
                            [2.365639069459852, 48.74526643089964],
                            [2.366342249064091, 48.74556121050418],
                            [2.367650703426875, 48.74610941748587],
                            [2.369199929076181, 48.74674117237808],
                            [2.37068107684206, 48.74737448341556],
                            [2.371660000479114, 48.74779294690864],
                            [2.372288619188905, 48.748043375061656],
                            [2.373111940704935, 48.74834968236464],
                        ],
                    },
                },
                1433: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.91503873782667, 2.428164362263311],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 500.709926998,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.425009894274451,
                            48.914093263505734,
                            2.431278002116334,
                            48.915837892883054,
                        ),
                        "coordinates": [
                            [2.431278002116334, 48.914093263505734],
                            [2.430392553813354, 48.91440452484984],
                            [2.429946312776472, 48.914562472692346],
                            [2.42974631014034, 48.914631003229815],
                            [2.429535173750536, 48.914690265321646],
                            [2.429030260897549, 48.914811739942685],
                            [2.428452699239341, 48.91494605225547],
                            [2.428287083889757, 48.914993364517024],
                            [2.428133408092903, 48.91505487408242],
                            [2.428010058533673, 48.915116360074116],
                            [2.427910504334019, 48.915162122954705],
                            [2.427800112685995, 48.91520361179333],
                            [2.427695216883365, 48.91523641619711],
                            [2.427595357560987, 48.91526422200128],
                            [2.427198191970649, 48.915347961952975],
                            [2.426853064410223, 48.915421904409406],
                            [2.42670964164884, 48.9154526315085],
                            [2.426351162694722, 48.91554329129799],
                            [2.425795856316936, 48.915678134402896],
                            [2.425009894274451, 48.915837892883054],
                        ],
                    },
                },
                1434: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.90646537677724, 2.4411903356289772],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 429.320607437,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.438624497227672,
                            48.90638320316224,
                            2.443992334554137,
                            48.906931832134305,
                        ),
                        "coordinates": [
                            [2.443992334554137, 48.906536559058885],
                            [2.443561896915817, 48.90653064831422],
                            [2.443198038713003, 48.906518138887826],
                            [2.442938491229835, 48.90650278069318],
                            [2.442369716730072, 48.906454396569146],
                            [2.441948810278225, 48.90643042502921],
                            [2.441521596774201, 48.90641261430091],
                            [2.441247091388755, 48.906408583154516],
                            [2.439380582805497, 48.90638320316224],
                            [2.439311850578705, 48.90638535004033],
                            [2.439225121964699, 48.90639467270058],
                            [2.43914091285363, 48.90641122939676],
                            [2.439060608087591, 48.90643474963393],
                            [2.438985525567464, 48.90646484569756],
                            [2.438916895667224, 48.90650102424718],
                            [2.43885584754489, 48.90654269074811],
                            [2.438803384462777, 48.906589161045815],
                            [2.438760365926989, 48.90663967297222],
                            [2.438734345986258, 48.90668040997349],
                            [2.438624497227672, 48.906931832134305],
                        ],
                    },
                },
                1435: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [49.04104047317543, 2.4900424224678406],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2498.23681611,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.478033365115083,
                            49.033182769031264,
                            2.501758065846462,
                            49.049325600885666,
                        ),
                        "coordinates": [
                            [2.501758065846462, 49.049325600885666],
                            [2.499468515941002, 49.047639242234766],
                            [2.498165910202896, 49.04667982477075],
                            [2.494537561781734, 49.043948620000975],
                            [2.492890514043921, 49.0427374052095],
                            [2.492306454832931, 49.04230991613465],
                            [2.491983598212982, 49.042074797289295],
                            [2.491555584413875, 49.041775577332004],
                            [2.490191988374697, 49.04088991134044],
                            [2.485895009227335, 49.03816646514511],
                            [2.483313414919215, 49.036528040503256],
                            [2.48072112443948, 49.03488481347117],
                            [2.478033365115083, 49.033182769031264],
                        ],
                    },
                },
                1436: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.92366358408288, 2.404394160218968],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 384.405151019,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.40207341299691,
                            48.922711188353,
                            2.406622752354694,
                            48.9243751434303,
                        ),
                        "coordinates": [
                            [2.406622752354694, 48.922711188353],
                            [2.406214126514633, 48.92293591336989],
                            [2.405319340267815, 48.9233847288514],
                            [2.405109332643564, 48.92348267683067],
                            [2.404950446823028, 48.923550758348874],
                            [2.404779524008168, 48.9236205190912],
                            [2.404610634740652, 48.92368628874409],
                            [2.404458721002706, 48.923735426499356],
                            [2.404260668817219, 48.92379775660441],
                            [2.403806556186552, 48.92392224682504],
                            [2.40207341299691, 48.9243751434303],
                        ],
                    },
                },
                1437: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.907228330529676, 2.4574326451551234],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 469.269678933,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.454352826517924,
                            48.90670063080091,
                            2.460523403674419,
                            48.90781254678193,
                        ),
                        "coordinates": [
                            [2.460523403674419, 48.90670063080091],
                            [2.459753873374277, 48.906847458211935],
                            [2.459395454022229, 48.906912730239924],
                            [2.459037002751747, 48.90696641535866],
                            [2.458091667434576, 48.90710414914671],
                            [2.457434518401862, 48.90720912734715],
                            [2.456478676939154, 48.90736771586326],
                            [2.455777167455424, 48.907498200085755],
                            [2.455241772497124, 48.90760537947685],
                            [2.454352826517924, 48.90781254678193],
                        ],
                    },
                },
                1438: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.918441160581146, 2.4157481703449117],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 322.91346509,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.41383718095636,
                            48.917783725255454,
                            2.417691093337975,
                            48.919179027725846,
                        ),
                        "coordinates": [
                            [2.417691093337975, 48.917783725255454],
                            [2.417332632824128, 48.91790680018407],
                            [2.416903882645316, 48.918053097996044],
                            [2.415849528827013, 48.91838985599673],
                            [2.415301265270446, 48.91856867462971],
                            [2.414937574985343, 48.918692894911636],
                            [2.41471386583641, 48.918776324305774],
                            [2.414457836151247, 48.91888210017629],
                            [2.41383718095636, 48.919179027725846],
                        ],
                    },
                },
                1439: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.36103048165457, 3.0068445248968345],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 10590.8855949,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.94252341270237,
                            48.342613680163964,
                            3.071746453743138,
                            48.37952610418487,
                        ),
                        "coordinates": [
                            [3.071746453743138, 48.342613680163964],
                            [3.069620137167791, 48.34328995333346],
                            [3.067272238314291, 48.34399902437577],
                            [3.065296396819176, 48.34458463022875],
                            [3.062770458118077, 48.345380572462254],
                            [3.060719943246469, 48.346034023962304],
                            [3.059074718061156, 48.34654365910788],
                            [3.057363915450539, 48.34709235701518],
                            [3.055153519978664, 48.34780158235617],
                            [3.053140347662746, 48.34843846994234],
                            [3.051587814073967, 48.348931220572375],
                            [3.050506588032263, 48.34926899315362],
                            [3.046832153534438, 48.350452224293896],
                            [3.045327947640048, 48.350936490533535],
                            [3.04375651465713, 48.35143914308664],
                            [3.043001598484323, 48.35167498096122],
                            [3.042241317626471, 48.35191354466524],
                            [3.040844106836416, 48.3523265377811],
                            [3.039944784679675, 48.352571749923904],
                            [3.038896751676554, 48.352882226454064],
                            [3.037971047311971, 48.35316135778083],
                            [3.036314588262471, 48.35367252732854],
                            [3.034580108746514, 48.35420303968987],
                            [3.032594450173469, 48.35481780604871],
                            [3.031365260239576, 48.35520666511804],
                            [3.031054936006789, 48.355304796128046],
                            [3.030195276186502, 48.35558525595862],
                            [3.030086465163259, 48.35562009628787],
                            [3.029968260704483, 48.35565859163832],
                            [3.029566647527834, 48.35579055125915],
                            [3.029040029077688, 48.3559574491165],
                            [3.028356223414265, 48.35617386712594],
                            [3.027661691163694, 48.35639574297978],
                            [3.027624074903182, 48.35640766365917],
                            [3.027394353786808, 48.35648101028601],
                            [3.026780333036664, 48.35667091337346],
                            [3.026349056865662, 48.356805741396656],
                            [3.023890609524299, 48.35759410227716],
                            [3.023060368962455, 48.357860838523706],
                            [3.022345650943215, 48.35808999863012],
                            [3.021684687196183, 48.35830353944896],
                            [3.020867829779888, 48.35856388433931],
                            [3.019944899576808, 48.35886353356243],
                            [3.019054156804454, 48.35914949238894],
                            [3.019016536625892, 48.35916141031103],
                            [3.018989661109251, 48.359169665666286],
                            [3.018116423653336, 48.35945371172837],
                            [3.017287532675229, 48.35972489458341],
                            [3.017163923377798, 48.359764308104495],
                            [3.016297398470691, 48.36004740038497],
                            [3.015013057080697, 48.360467888088905],
                            [3.013656195462382, 48.3609157727994],
                            [3.012796427050629, 48.36120239491432],
                            [3.012263107620063, 48.361380943860304],
                            [3.011504075944509, 48.36163368091033],
                            [3.01060378993258, 48.36191962871718],
                            [3.00912299799861, 48.362389780677496],
                            [3.007674382765824, 48.362846233057496],
                            [3.006452802119464, 48.3632275802347],
                            [3.005246094522422, 48.36361242372542],
                            [3.004642672277634, 48.36380034464506],
                            [3.003993439159968, 48.36399392843745],
                            [3.003396506363737, 48.36416291875803],
                            [3.002846439455345, 48.364304652569224],
                            [3.002041926231412, 48.36449284550912],
                            [3.001416274066953, 48.364634117784504],
                            [3.000346105720238, 48.364838250755355],
                            [2.999597490959377, 48.36496854293083],
                            [2.999212397847971, 48.36503464983172],
                            [2.99826939865783, 48.365161575423166],
                            [2.997327812711038, 48.365259387835074],
                            [2.996243603374665, 48.36535613479232],
                            [2.995264760359061, 48.36542642355783],
                            [2.994300253581188, 48.365458118359435],
                            [2.994023653647615, 48.36546242501699],
                            [2.99376457358985, 48.365464830918874],
                            [2.993153205863124, 48.3654629879063],
                            [2.99227313743224, 48.36545011148603],
                            [2.990636984063946, 48.36541102996915],
                            [2.989573216843628, 48.365385704993],
                            [2.989224968577806, 48.3653805222454],
                            [2.988979335711332, 48.365379242796415],
                            [2.988467804493185, 48.36537499978976],
                            [2.988023886956224, 48.36538115638232],
                            [2.987573360427455, 48.3653981401212],
                            [2.987116227322813, 48.36542595093088],
                            [2.986514948172458, 48.3654734746402],
                            [2.985415279609685, 48.36559399927253],
                            [2.984412615150609, 48.365702266491624],
                            [2.983722823756743, 48.36578155199225],
                            [2.983024605645941, 48.365859491736906],
                            [2.982374805586906, 48.365912665370566],
                            [2.982007962733607, 48.36593094760254],
                            [2.981722005492305, 48.36594247197904],
                            [2.981102848259501, 48.36596488855582],
                            [2.97985085366272, 48.36599540200187],
                            [2.97795932935276, 48.366038523622464],
                            [2.976347071713632, 48.366074638290264],
                            [2.976024664727523, 48.3660854551775],
                            [2.97579945456557, 48.36609841972958],
                            [2.975501453067776, 48.366118089466966],
                            [2.97521428123918, 48.36614039589489],
                            [2.974807235351215, 48.3661813635389],
                            [2.974479829950273, 48.366223678493846],
                            [2.97414837616582, 48.36626601505168],
                            [2.97375507431266, 48.366326685153226],
                            [2.973375367911276, 48.36639537138607],
                            [2.972838241606501, 48.36650181163934],
                            [2.972293288185739, 48.36662987601668],
                            [2.971779392470981, 48.3667595620081],
                            [2.971245695943976, 48.366924427578596],
                            [2.970576434957954, 48.3671485039936],
                            [2.970147910502436, 48.367306480173795],
                            [2.969861840622734, 48.36741689426293],
                            [2.969432427625082, 48.36761174200957],
                            [2.968986952247294, 48.3678174701336],
                            [2.968528318144042, 48.368050247419255],
                            [2.967875435151935, 48.368398315096954],
                            [2.967327106435301, 48.36869004106492],
                            [2.966679604539356, 48.36903807108755],
                            [2.965973051053489, 48.369413404781874],
                            [2.965006361316299, 48.369925070951915],
                            [2.964083941083284, 48.370416698474045],
                            [2.963573108881168, 48.37068841359557],
                            [2.96296302882821, 48.37101103631454],
                            [2.962025655999246, 48.37149733374081],
                            [2.958569426157394, 48.37326907522013],
                            [2.957710952247177, 48.373702744855024],
                            [2.956514565335571, 48.37431811599466],
                            [2.955227188182732, 48.375000517753556],
                            [2.954187860693804, 48.37555025657569],
                            [2.952148157454206, 48.376639601489885],
                            [2.951300412470538, 48.37707676190081],
                            [2.950625867539463, 48.3774074082048],
                            [2.949943672032218, 48.37769662895973],
                            [2.949278774577817, 48.377940545438214],
                            [2.948791297067671, 48.37809395823899],
                            [2.94784686880817, 48.3783715409484],
                            [2.947251357277135, 48.37853397391627],
                            [2.946281063094428, 48.37876515427023],
                            [2.945599830354053, 48.37892556702795],
                            [2.944696038157394, 48.379121109810264],
                            [2.943877252342816, 48.379280513607995],
                            [2.94252341270237, 48.37952610418487],
                        ],
                    },
                },
                1440: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.92768771513562, 1.5236668495798031],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 4320.03501768,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.505347805525029,
                            48.915059197579,
                            1.541381156495169,
                            48.943236988151924,
                        ),
                        "coordinates": [
                            [1.505347805525029, 48.915096742859646],
                            [1.505500389468803, 48.9150880557395],
                            [1.506312122609392, 48.91506357615509],
                            [1.50653728246362, 48.91506251502207],
                            [1.506664163945533, 48.915063437531046],
                            [1.506766504306343, 48.915063281381435],
                            [1.507070854739219, 48.915059197579],
                            [1.507848251428718, 48.91508102863185],
                            [1.508358135003001, 48.915107210410255],
                            [1.50896043361733, 48.915155643740405],
                            [1.509227511632676, 48.91517736476495],
                            [1.509301111199966, 48.91518239377828],
                            [1.509674233420187, 48.9152273651605],
                            [1.510164284652401, 48.91529746183833],
                            [1.510412025381631, 48.91533342867135],
                            [1.511387158184164, 48.91552663935288],
                            [1.5115325433524, 48.91556366318936],
                            [1.511836900422785, 48.91564140488281],
                            [1.512593286465584, 48.9158609044861],
                            [1.513004356761666, 48.91600416414777],
                            [1.513477591599196, 48.91618384363701],
                            [1.514110544521696, 48.9164420142982],
                            [1.514425893053647, 48.91659806951325],
                            [1.515012773341863, 48.91691975456367],
                            [1.51578018449539, 48.91738213074856],
                            [1.516078338934206, 48.917588420037035],
                            [1.516273649050105, 48.91774270877493],
                            [1.516349074243613, 48.917802605918546],
                            [1.516428488561716, 48.9178688268305],
                            [1.516745956527388, 48.918145401021825],
                            [1.516959495703746, 48.91835287888368],
                            [1.51718208369486, 48.91859099941486],
                            [1.517347026791314, 48.91876665129111],
                            [1.517651957313288, 48.91914205863071],
                            [1.517710775723798, 48.91921622560708],
                            [1.518058304396867, 48.91973942653035],
                            [1.518356868115255, 48.920336020017864],
                            [1.518500702287704, 48.92071656629484],
                            [1.518605694692751, 48.921052766944996],
                            [1.518639332833152, 48.92116452376044],
                            [1.518798822053852, 48.92183746296563],
                            [1.518842220283867, 48.922019437028425],
                            [1.518866457121796, 48.92212213355386],
                            [1.519077762396286, 48.92296361689587],
                            [1.51915956406255, 48.923216912979576],
                            [1.51940881570257, 48.92382664153451],
                            [1.519578728317569, 48.924199278513946],
                            [1.519960135877056, 48.92490617748884],
                            [1.520040948551026, 48.925054244840325],
                            [1.520120812953942, 48.925177123760584],
                            [1.520426992704749, 48.925646062059656],
                            [1.52050159210478, 48.92575721281497],
                            [1.520641801413234, 48.92594527368688],
                            [1.520764699899342, 48.926107130946654],
                            [1.52119163658086, 48.92662009653014],
                            [1.521231776931205, 48.92666894661769],
                            [1.521498511292871, 48.92696492964108],
                            [1.521564344464064, 48.927028352444424],
                            [1.521995518314653, 48.927450513673115],
                            [1.522476838681397, 48.927894614012345],
                            [1.524993150422378, 48.93000794702683],
                            [1.526489037586183, 48.9312641294259],
                            [1.526552270425909, 48.93132033618133],
                            [1.526616898674601, 48.931374754028575],
                            [1.529529777945863, 48.933801061653945],
                            [1.530374193014193, 48.934504899077965],
                            [1.53120228368716, 48.935206816358495],
                            [1.53130615407757, 48.93528309133983],
                            [1.531385572055171, 48.93535199988797],
                            [1.532122204874603, 48.93597142749154],
                            [1.532258251579947, 48.93608390121597],
                            [1.532448166999103, 48.936241720766176],
                            [1.532554553088556, 48.93633150212164],
                            [1.534155862029473, 48.937676456768585],
                            [1.537680796970623, 48.94062845534036],
                            [1.537900328912967, 48.94081435161267],
                            [1.538830447098347, 48.941551998544654],
                            [1.539185423607504, 48.94180538786585],
                            [1.539674001051498, 48.942155935031074],
                            [1.540066992450145, 48.94242307605388],
                            [1.540138561425131, 48.94247213785021],
                            [1.540326403273629, 48.942592157579355],
                            [1.54056965183462, 48.94274763698881],
                            [1.540806233671051, 48.94289317634028],
                            [1.541238883508614, 48.943156991527474],
                            [1.541336306082151, 48.9432116296079],
                            [1.541381156495169, 48.943236988151924],
                        ],
                    },
                },
                1441: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.4003702698243, 2.7405343694033517],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 4402.83068922,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.725685583605634,
                            48.394308438758266,
                            2.764028188787889,
                            48.416377033006604,
                        ),
                        "coordinates": [
                            [2.764028188787889, 48.394308438758266],
                            [2.763126578901833, 48.394390386630114],
                            [2.762026571127661, 48.39448100457268],
                            [2.760321297610465, 48.3946230434602],
                            [2.758757356663343, 48.39474759230496],
                            [2.757649500724457, 48.394835351208386],
                            [2.753678371873878, 48.39517199467734],
                            [2.752523311883279, 48.39526886970745],
                            [2.75101743052066, 48.39539754823184],
                            [2.749543910243132, 48.395521684086276],
                            [2.748745012052305, 48.39558124961076],
                            [2.748059966033951, 48.39564154114412],
                            [2.747513063189951, 48.395690044916485],
                            [2.747003836064991, 48.39573429195899],
                            [2.746101646752111, 48.39581476324794],
                            [2.74517120107466, 48.39591275726854],
                            [2.74437895638145, 48.39602061988101],
                            [2.743765304410223, 48.396112755611945],
                            [2.742972482153477, 48.396257688308985],
                            [2.741899604358853, 48.39648365581718],
                            [2.740933356187616, 48.39671264009034],
                            [2.740403476486886, 48.3968460067594],
                            [2.739554684237278, 48.39708643592351],
                            [2.738666117220153, 48.397361251998305],
                            [2.737850994699494, 48.397650927942905],
                            [2.737066146164455, 48.397954059624844],
                            [2.736215541808712, 48.398310473739144],
                            [2.735514659130686, 48.3986465701702],
                            [2.73494568923817, 48.39893004162216],
                            [2.733783993354781, 48.39956899964746],
                            [2.732651236450351, 48.40028518015406],
                            [2.732374577850641, 48.40047948761717],
                            [2.732028077394721, 48.40072259821432],
                            [2.731342022896275, 48.40123487101453],
                            [2.730699324796302, 48.40176677257546],
                            [2.730068993722046, 48.402327403324286],
                            [2.729892050597703, 48.40249617967574],
                            [2.729666202231323, 48.402718855628486],
                            [2.729500733563992, 48.402883319327145],
                            [2.729119019656139, 48.40329020825842],
                            [2.72868944749457, 48.40379528004186],
                            [2.728181286937066, 48.40444180490654],
                            [2.727844643400242, 48.404915977642744],
                            [2.727568375879036, 48.40533958208344],
                            [2.727244435845665, 48.40588564973888],
                            [2.726944888618034, 48.406443322325785],
                            [2.726691253507572, 48.406999287830935],
                            [2.72659562693465, 48.40720889280618],
                            [2.726526744637031, 48.40738268714426],
                            [2.726336260139316, 48.407898616450986],
                            [2.726181693915671, 48.408344279214546],
                            [2.725995032288738, 48.409005874160734],
                            [2.725942750976443, 48.40923086816349],
                            [2.725909358202428, 48.409396668539735],
                            [2.725868777010266, 48.40961960137255],
                            [2.725808126471974, 48.40998490749837],
                            [2.725746424715627, 48.41038888472404],
                            [2.725685583605634, 48.41125237992094],
                            [2.725685950470871, 48.41182250615781],
                            [2.72569692547183, 48.412094060132304],
                            [2.725712845366715, 48.41232959417772],
                            [2.725730315681396, 48.41249229905219],
                            [2.725751985051398, 48.41267387404075],
                            [2.725798115494479, 48.413209447058115],
                            [2.72586359520443, 48.41381831824005],
                            [2.725942597037732, 48.41432721450449],
                            [2.726038806308719, 48.414750395910374],
                            [2.726141499049052, 48.41508790161538],
                            [2.726525245192769, 48.41605691116175],
                            [2.726661533081673, 48.416377033006604],
                        ],
                    },
                },
                1442: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.8353767151695, 2.1698302154288376],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 2706.2844929,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.152697400276265,
                            48.83385812826603,
                            2.187110711095018,
                            48.83828254600231,
                        ),
                        "coordinates": [
                            [2.187110711095018, 48.83828254600231],
                            [2.186902785218201, 48.83817045017662],
                            [2.186813015953219, 48.83812266996466],
                            [2.186679724593191, 48.83805145172539],
                            [2.186011933685184, 48.837687261856736],
                            [2.185852811275044, 48.837598922472665],
                            [2.185693690780542, 48.83751058197995],
                            [2.185541360469003, 48.837429444799376],
                            [2.185178158083906, 48.83725540193246],
                            [2.184866573769113, 48.837130886242626],
                            [2.184620279271228, 48.8370397313819],
                            [2.184355557276993, 48.83694778839742],
                            [2.183996990214071, 48.836832063462644],
                            [2.18344706972345, 48.836689238715046],
                            [2.182918844679338, 48.83657971454293],
                            [2.182333371507205, 48.8364817998749],
                            [2.180894061424934, 48.83628739546701],
                            [2.177823421375468, 48.83589016972944],
                            [2.177512944942725, 48.83585376495726],
                            [2.177344091548119, 48.835832845115334],
                            [2.174111399768803, 48.835436192360206],
                            [2.170709913256732, 48.83501851840832],
                            [2.170289152208264, 48.83496844455798],
                            [2.167580795017504, 48.834639816608984],
                            [2.162874925348611, 48.83407787934209],
                            [2.161649450390239, 48.8339330176852],
                            [2.161108827880473, 48.83388452380168],
                            [2.160595363123972, 48.833860350499485],
                            [2.160321568434736, 48.83385812826603],
                            [2.16005046077357, 48.833866701667795],
                            [2.159733015305709, 48.833881496486654],
                            [2.159461855265787, 48.8339044557322],
                            [2.159201580598183, 48.833931029087296],
                            [2.158843142594693, 48.83398082994141],
                            [2.158445111108386, 48.83405574722832],
                            [2.158029303684911, 48.834148621199034],
                            [2.157692522973405, 48.834236222237905],
                            [2.157280666949171, 48.834365969449046],
                            [2.15667769169629, 48.83460782410098],
                            [2.156519404603944, 48.83468221353352],
                            [2.156156408095739, 48.83485969656304],
                            [2.155690999947921, 48.83510356176716],
                            [2.155643213799837, 48.83513316242098],
                            [2.155438413727245, 48.8352605342671],
                            [2.154966002498705, 48.83555474534769],
                            [2.154815813841978, 48.8356480310223],
                            [2.154699504325805, 48.83572070719528],
                            [2.154575503215595, 48.83579962461211],
                            [2.154134677331525, 48.8360219407665],
                            [2.152697400276265, 48.83664331803193],
                        ],
                    },
                },
                1443: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.871365794135215, 2.086321736739978],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1638.45591262,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.076719102677291,
                            48.86806442324713,
                            2.096548252755343,
                            48.87260014288147,
                        ),
                        "coordinates": [
                            [2.096548252755343, 48.87150310365913],
                            [2.0944172728923, 48.87176947902444],
                            [2.093585187349833, 48.87187292437453],
                            [2.089180514832923, 48.87242460101601],
                            [2.088291114914456, 48.872535077849655],
                            [2.088152000038521, 48.872547364782235],
                            [2.087715575800199, 48.87258328325639],
                            [2.087565573306386, 48.87259194841411],
                            [2.087200176217248, 48.87260014288147],
                            [2.086953450453313, 48.87259510614335],
                            [2.086710846061466, 48.872583783180986],
                            [2.086187525967607, 48.87254936169677],
                            [2.085920460586939, 48.87252269602834],
                            [2.085363370510713, 48.872437720359954],
                            [2.08490436163345, 48.872345996621945],
                            [2.08464836728812, 48.87228697790779],
                            [2.084401981379509, 48.87221538971144],
                            [2.084147449136112, 48.872137488054115],
                            [2.083879349007718, 48.87204696638301],
                            [2.083664361928083, 48.87196735264829],
                            [2.083325617799111, 48.871829009936384],
                            [2.082874166259245, 48.871604984981],
                            [2.081134313055343, 48.87061548663749],
                            [2.080662693904844, 48.870341046678455],
                            [2.079103749865896, 48.86944454974426],
                            [2.078840080106558, 48.86929287431194],
                            [2.078796590389262, 48.86926759641885],
                            [2.078749028217129, 48.86923871216032],
                            [2.077334181265172, 48.86843154448144],
                            [2.077063758195709, 48.86826995842817],
                            [2.076805549551927, 48.868119190067056],
                            [2.076719102677291, 48.86806442324713],
                        ],
                    },
                },
                1444: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.89664213176752, 2.4597416844786677],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 202.215865307,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.458363412015992,
                            48.89660443742263,
                            2.461119310778047,
                            48.896652451144085,
                        ),
                        "coordinates": [
                            [2.458363412015992, 48.896652451144085],
                            [2.459993941439638, 48.896649064128454],
                            [2.46018274150254, 48.896644334185666],
                            [2.460390875309296, 48.89663911910006],
                            [2.461119310778047, 48.89660443742263],
                        ],
                    },
                },
                1445: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.99618857335681, 2.0962089501883305],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 249.219382669,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.094643974392771,
                            48.99574683395328,
                            2.097773988463467,
                            48.996630090663984,
                        ),
                        "coordinates": [
                            [2.097773988463467, 48.996630090663984],
                            [2.097642513489375, 48.996593229550804],
                            [2.094643974392771, 48.99574683395328],
                        ],
                    },
                },
                1446: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.315578311899486, 2.3818934919655317],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 6276.87938297,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.371615014452634,
                            48.29359176871632,
                            2.401133894429584,
                            48.34166354461877,
                        ),
                        "coordinates": [
                            [2.378815443311891, 48.34166354461877],
                            [2.378592407620918, 48.34109711132186],
                            [2.378431027627317, 48.34071308446125],
                            [2.378273447358897, 48.34033468071855],
                            [2.377913921051748, 48.3394373794722],
                            [2.377398964763345, 48.33813008365894],
                            [2.377078651839725, 48.337317293717],
                            [2.376928139391132, 48.336949521345055],
                            [2.376740855664715, 48.33655306785478],
                            [2.376542258926468, 48.33613319733864],
                            [2.376119985732918, 48.335432774999106],
                            [2.375668587148977, 48.3347720679585],
                            [2.37534587550431, 48.33428119925528],
                            [2.374438546203845, 48.33291197871051],
                            [2.373756747335517, 48.33190326974744],
                            [2.373304793619503, 48.33123266873365],
                            [2.372849490364948, 48.33051425478411],
                            [2.372579472892259, 48.33008720688021],
                            [2.372336433769355, 48.32966374720004],
                            [2.372130278796836, 48.3292119571876],
                            [2.372006023735392, 48.32891355546705],
                            [2.371858216284604, 48.32847511493103],
                            [2.371710786131955, 48.32784390181948],
                            [2.371653883438763, 48.32746444395276],
                            [2.371615014452634, 48.327033045280395],
                            [2.371615561929442, 48.32666054380551],
                            [2.371623133509439, 48.32592137464156],
                            [2.371625442633265, 48.32536924651759],
                            [2.371635774442562, 48.32433971816064],
                            [2.371639180320144, 48.32381177574735],
                            [2.37165289880818, 48.32213181137041],
                            [2.371650362887941, 48.321489457755874],
                            [2.371642742616637, 48.32079948767022],
                            [2.371688798246989, 48.3203450426068],
                            [2.371788371963878, 48.31990247726228],
                            [2.371895135391766, 48.31954318240907],
                            [2.372026887564641, 48.31921005040655],
                            [2.372158682990922, 48.3189411574217],
                            [2.372343936397966, 48.318603249396105],
                            [2.372522111292641, 48.318346237278035],
                            [2.372860673409388, 48.31790835233666],
                            [2.373177896232947, 48.31756326275965],
                            [2.373520098105348, 48.31723957712311],
                            [2.373862324717641, 48.31695157985648],
                            [2.374332912745161, 48.31659929843885],
                            [2.375042429432225, 48.31617793549036],
                            [2.375849156349601, 48.315720013074376],
                            [2.377286933281777, 48.31486433377011],
                            [2.377694767137757, 48.31461978245108],
                            [2.379242080194137, 48.31371259367743],
                            [2.380235109975214, 48.31312231757427],
                            [2.38088723690398, 48.31273539375731],
                            [2.381203872373287, 48.31255542193979],
                            [2.381974563531907, 48.31211359197623],
                            [2.38265361219082, 48.311712258912465],
                            [2.383188461212668, 48.3113658352692],
                            [2.383228874118268, 48.311336143631046],
                            [2.383258511160001, 48.31131544909624],
                            [2.38339591544362, 48.31121377902845],
                            [2.383945500469172, 48.31078101954956],
                            [2.384345507522832, 48.310410367448966],
                            [2.384512493482062, 48.31023674496449],
                            [2.384974340597791, 48.30970240509586],
                            [2.385145308419467, 48.30946853266783],
                            [2.385406428784265, 48.309070959894335],
                            [2.385670163779832, 48.30859515332121],
                            [2.385850368255809, 48.30816794089224],
                            [2.385971321848373, 48.30780100266702],
                            [2.386124525931349, 48.307336934323146],
                            [2.386295122045799, 48.30674246860858],
                            [2.386319296178659, 48.30665343497183],
                            [2.386668584458631, 48.305488779608766],
                            [2.386769396848835, 48.30521087301986],
                            [2.386878276116597, 48.30491497886052],
                            [2.386985846791623, 48.30465865065034],
                            [2.387217227371708, 48.30421432768565],
                            [2.387490396295152, 48.30377987746107],
                            [2.38765459836558, 48.30355229800201],
                            [2.388007265507567, 48.303101623977476],
                            [2.388170163584246, 48.302920805223884],
                            [2.388314214098628, 48.3027615755623],
                            [2.388796244064833, 48.30229914912838],
                            [2.389345658181296, 48.301840286745936],
                            [2.38969849075639, 48.30157215012753],
                            [2.390327455463326, 48.301160004460364],
                            [2.391030546395192, 48.30075591263214],
                            [2.391735045187628, 48.30041745906757],
                            [2.39578823630091, 48.29859805519485],
                            [2.396410500590593, 48.29829018893178],
                            [2.396592318182128, 48.298190277887066],
                            [2.397040798443662, 48.29794544783709],
                            [2.397450188406191, 48.297697039352514],
                            [2.398299847927723, 48.297114775015636],
                            [2.398682211951401, 48.296817819695775],
                            [2.399590498850988, 48.29583050983562],
                            [2.400386723038003, 48.29483469062227],
                            [2.400894688544958, 48.29408737072769],
                            [2.401133894429584, 48.29359176871632],
                        ],
                    },
                },
                1447: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.731641449478616, 2.8140072233964633],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 8463.68633386,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.758824548674894,
                            48.72925514765488,
                            2.868955830083688,
                            48.73948720730179,
                        ),
                        "coordinates": [
                            [2.868955830083688, 48.73493929649145],
                            [2.868197302691268, 48.73443743566381],
                            [2.867784049931228, 48.734185762817404],
                            [2.866931699093922, 48.7336798348921],
                            [2.866467032818083, 48.73341700564049],
                            [2.865770411682557, 48.73301256464791],
                            [2.865331488334355, 48.732773592596764],
                            [2.86491451820529, 48.73255340203805],
                            [2.86431192483627, 48.732263026884524],
                            [2.863926781786748, 48.732094843778995],
                            [2.863386419585624, 48.731888839287954],
                            [2.862669776306663, 48.73162493175473],
                            [2.86215283697806, 48.731453297434555],
                            [2.861474749666426, 48.73122936145288],
                            [2.860657897438782, 48.73098581865698],
                            [2.859842602125489, 48.730760247887204],
                            [2.858843548631731, 48.730511233945165],
                            [2.857846193296063, 48.730293678992105],
                            [2.857365006652782, 48.7302015077727],
                            [2.856702068323538, 48.730079483267176],
                            [2.855970820063126, 48.729958719090966],
                            [2.855183935923024, 48.729847196453115],
                            [2.854529198100088, 48.729762945540735],
                            [2.853897747940544, 48.729695671859105],
                            [2.853191557574606, 48.72963053169702],
                            [2.851881546394702, 48.72954024452118],
                            [2.851291327253678, 48.72951593585632],
                            [2.850289313424991, 48.729500676539644],
                            [2.848813059860551, 48.72950283259856],
                            [2.846650069532342, 48.729480169015424],
                            [2.844587862873845, 48.72947590076476],
                            [2.842957897144348, 48.72946787432002],
                            [2.841327933278764, 48.72945982471901],
                            [2.839697978038175, 48.72945265049482],
                            [2.838617228953117, 48.72944752988711],
                            [2.834801274197068, 48.72942652366336],
                            [2.833001362189048, 48.729415500497375],
                            [2.830217251370838, 48.729402427376],
                            [2.828952918301787, 48.729389916391014],
                            [2.827182940742363, 48.72938137035884],
                            [2.825198167301746, 48.729371021240574],
                            [2.823526070189561, 48.72936289797087],
                            [2.821852623183643, 48.729355654981276],
                            [2.820181885325143, 48.72934747609726],
                            [2.817659276193586, 48.72932879597313],
                            [2.81551622452184, 48.72931324282554],
                            [2.813880798114946, 48.72930122664587],
                            [2.812278021432503, 48.72929174790525],
                            [2.810675252952337, 48.72928314617924],
                            [2.809569988010802, 48.729276580494016],
                            [2.808710867407425, 48.729271525386054],
                            [2.808055626852463, 48.72926779049362],
                            [2.807275329761981, 48.72926577941091],
                            [2.806365818784903, 48.72925514765488],
                            [2.805297012574751, 48.72925817231656],
                            [2.804237432553437, 48.729294486642445],
                            [2.803577238118977, 48.72934306104721],
                            [2.802987912688529, 48.72941112509641],
                            [2.802299632290224, 48.72950926731548],
                            [2.801450153482003, 48.72966831636383],
                            [2.80012998990253, 48.729945453500264],
                            [2.799212966382549, 48.73014415858717],
                            [2.797993361492169, 48.730412596199635],
                            [2.796399209198989, 48.73075267688845],
                            [2.794159153000896, 48.73123988865306],
                            [2.79205090839847, 48.7316928130709],
                            [2.790899024014458, 48.731942017693825],
                            [2.789743033765943, 48.73218942937371],
                            [2.787939899744581, 48.732583280723404],
                            [2.785063439617828, 48.73320345654553],
                            [2.784081106842361, 48.733417752737886],
                            [2.782359249856981, 48.73378871327212],
                            [2.780638726774271, 48.73415964325189],
                            [2.779508098275174, 48.73440397197068],
                            [2.778300732026962, 48.734657943050266],
                            [2.775614065430515, 48.73524387055144],
                            [2.774174435725202, 48.73555270072453],
                            [2.772639595576318, 48.735884793566306],
                            [2.770620297800346, 48.7363097723162],
                            [2.768704250597731, 48.73672982799424],
                            [2.767106809819226, 48.73706111298733],
                            [2.766364602908161, 48.73722159331134],
                            [2.765857296023076, 48.73732993730883],
                            [2.765444426882826, 48.73742428718611],
                            [2.764999324593582, 48.73753541291024],
                            [2.764618862154339, 48.73764378179794],
                            [2.764187165104781, 48.737767558755415],
                            [2.763438587470111, 48.73801000557641],
                            [2.762579183285676, 48.738293368524225],
                            [2.760393815718868, 48.73898169495798],
                            [2.758824548674894, 48.73948720730179],
                        ],
                    },
                },
                1448: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.86768120735709, 2.1103206963647465],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 2511.17450253,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.096548252755343,
                            48.86121452860313,
                            2.123191095956036,
                            48.87150310365913,
                        ),
                        "coordinates": [
                            [2.123191095956036, 48.86121452860313],
                            [2.122947533964484, 48.861247377754005],
                            [2.122691107153909, 48.86129186171661],
                            [2.122520610578124, 48.86132121733242],
                            [2.122021290429632, 48.86143178887198],
                            [2.121725196529713, 48.86150856940682],
                            [2.121588742385169, 48.861545182343065],
                            [2.121149251572817, 48.861687338261994],
                            [2.120756125606404, 48.86182328489217],
                            [2.120358828056339, 48.861978107971005],
                            [2.1201881400909, 48.862050626038695],
                            [2.119966872901514, 48.86215721968658],
                            [2.119808407028294, 48.862239651827586],
                            [2.119608964842731, 48.86234179064853],
                            [2.118953073864068, 48.86272003685953],
                            [2.118362798806044, 48.863052541411754],
                            [2.118134669044333, 48.86316811166941],
                            [2.117952991057421, 48.863258590531295],
                            [2.117741300965189, 48.86335440688255],
                            [2.117555616385475, 48.86342599307997],
                            [2.117303083647368, 48.86351093897332],
                            [2.117124278984424, 48.86356724905488],
                            [2.116980961374785, 48.86361283668837],
                            [2.116447219281459, 48.86379346185197],
                            [2.116067400217828, 48.863923813539934],
                            [2.115711901436505, 48.86404521600562],
                            [2.11516933028402, 48.86425596211776],
                            [2.114975706513372, 48.864345927210785],
                            [2.114792693918983, 48.86444394249985],
                            [2.11461731360921, 48.864536953208805],
                            [2.11437630058357, 48.86467601144549],
                            [2.113959772560783, 48.86497284431049],
                            [2.113670991734284, 48.86518483715802],
                            [2.113479070576752, 48.865358154375585],
                            [2.113356445757392, 48.86548619232042],
                            [2.112923531093983, 48.86597095475029],
                            [2.112831702294152, 48.86608228612416],
                            [2.112746558762637, 48.86622240634457],
                            [2.112678952569031, 48.86640302922001],
                            [2.112659519905089, 48.866480328971996],
                            [2.112622014537452, 48.86663583070946],
                            [2.112526159334985, 48.867034922941244],
                            [2.112437911329388, 48.86755992995647],
                            [2.11236542824517, 48.867914103427914],
                            [2.112291930960637, 48.86819093794344],
                            [2.112210125248322, 48.868432165895335],
                            [2.112120876576277, 48.86863844305352],
                            [2.111991682548501, 48.86887200106747],
                            [2.111864046712078, 48.86906239721849],
                            [2.111735155356892, 48.86922850995978],
                            [2.111518723648845, 48.86946009783863],
                            [2.111299678159219, 48.86966649979044],
                            [2.111027385384257, 48.869890780988754],
                            [2.11079076126284, 48.87006477311481],
                            [2.110491367350583, 48.87025212965534],
                            [2.110205767377506, 48.87040354135544],
                            [2.109887491370605, 48.870545894677356],
                            [2.109618456219811, 48.870651474107426],
                            [2.109305780696459, 48.87076056398932],
                            [2.109150169894249, 48.8708052178538],
                            [2.108976814926662, 48.870854332491625],
                            [2.108686130504233, 48.870923895411615],
                            [2.108422783919133, 48.870977325170344],
                            [2.108208594581378, 48.87101286796738],
                            [2.107957615097646, 48.87104473929513],
                            [2.107503445538652, 48.87109148884379],
                            [2.107294820430063, 48.87110276072124],
                            [2.107133937042758, 48.871107831994394],
                            [2.106986683925553, 48.871112931896135],
                            [2.106255998281499, 48.871112357242616],
                            [2.105397174695979, 48.87111061902785],
                            [2.10516678796448, 48.87111105086444],
                            [2.103866180363402, 48.87110172788125],
                            [2.103061867498191, 48.871097703594735],
                            [2.102221451405113, 48.871100737452316],
                            [2.100417986937904, 48.871106534097166],
                            [2.099715168480021, 48.87112863202824],
                            [2.099495639767431, 48.871138966505406],
                            [2.099340163655925, 48.871153031987234],
                            [2.099021030805783, 48.87118204330567],
                            [2.098138435667657, 48.8713043010375],
                            [2.096548252755343, 48.87150310365913],
                        ],
                    },
                },
                1449: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.15279646886923, 2.301527104364562],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 3645.40482485,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.277823190629399,
                            49.14771950559884,
                            2.325754000363327,
                            49.15518985899016,
                        ),
                        "coordinates": [
                            [2.325754000363327, 49.15518985899016],
                            [2.325307868796063, 49.15516138812337],
                            [2.324468798871061, 49.15510194821677],
                            [2.320926077161986, 49.15485600789381],
                            [2.319390543853856, 49.15474966890901],
                            [2.318184057870791, 49.1546658464731],
                            [2.314833337706902, 49.15443323747292],
                            [2.313322508232997, 49.15432862124469],
                            [2.30943852590209, 49.15405887410161],
                            [2.307861912866378, 49.15394787592917],
                            [2.304689518045863, 49.15372131105978],
                            [2.303714773273508, 49.15365178956384],
                            [2.302583735815965, 49.15358221253618],
                            [2.301192231585941, 49.1534846669243],
                            [2.300635629770555, 49.1534458229058],
                            [2.297855381477818, 49.15325157032852],
                            [2.295988185549178, 49.153122325875124],
                            [2.295469985152017, 49.15307807657461],
                            [2.294806489987808, 49.15299959923148],
                            [2.294529577144989, 49.152967123976985],
                            [2.293564544953707, 49.152799500890346],
                            [2.292875072096586, 49.15264726238262],
                            [2.292282938359708, 49.15250225275338],
                            [2.291985510443952, 49.15241940361467],
                            [2.291804588700458, 49.15236807490797],
                            [2.29114945175872, 49.15216278337052],
                            [2.290313421592659, 49.15188457344438],
                            [2.28893878926767, 49.15142628084619],
                            [2.287629964701909, 49.150992280597904],
                            [2.28567292727528, 49.15035204531125],
                            [2.283707787583001, 49.14964522765518],
                            [2.28291845506287, 49.14936428770167],
                            [2.282267541783286, 49.14912837166805],
                            [2.281752268322335, 49.148967156548686],
                            [2.281180812366807, 49.148787927193325],
                            [2.280938254210719, 49.14871047223341],
                            [2.280925920623213, 49.14870686865076],
                            [2.280799843988752, 49.148668138829606],
                            [2.280666916298323, 49.148626707466526],
                            [2.280554542531452, 49.148593379302895],
                            [2.279717238875601, 49.14833487591467],
                            [2.278248235215121, 49.14786022134636],
                            [2.277823190629399, 49.14771950559884],
                        ],
                    },
                },
                1450: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.876525173157034, 2.484881107387862],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 1461.41150809,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.481421258690829,
                            48.86991241918608,
                            2.48624016101661,
                            48.88230400665456,
                        ),
                        "coordinates": [
                            [2.481421258690829, 48.88230400665456],
                            [2.482002110276723, 48.88167667369007],
                            [2.482400360106924, 48.88124631151913],
                            [2.482536273619913, 48.881097757575006],
                            [2.482896410749996, 48.880692622043405],
                            [2.483300285140525, 48.880235879488275],
                            [2.483961905991979, 48.87950457051255],
                            [2.484256765404425, 48.879182977480575],
                            [2.484468884423603, 48.878940011218695],
                            [2.484702474556856, 48.878639910392906],
                            [2.484878905805151, 48.87839870704009],
                            [2.485048557720638, 48.87813859564237],
                            [2.485198031495068, 48.87788025697987],
                            [2.485346909474769, 48.87760313675325],
                            [2.485459426487179, 48.87738716326004],
                            [2.485547415677536, 48.877175718432],
                            [2.485670460790816, 48.876833832459134],
                            [2.485760458163955, 48.876568504929374],
                            [2.485814032566226, 48.876389983656146],
                            [2.485906886925282, 48.8760781686341],
                            [2.485963930603088, 48.87585443509884],
                            [2.486017418568939, 48.8756473624002],
                            [2.486070768650098, 48.875395081796675],
                            [2.486120447842253, 48.87512139221512],
                            [2.486184326312482, 48.874771543890645],
                            [2.486226431624454, 48.87437889660741],
                            [2.48624016101661, 48.87414570285082],
                            [2.486239460219678, 48.87391252805102],
                            [2.486227988061312, 48.87369602184562],
                            [2.48610475195852, 48.87229474845391],
                            [2.486056305620401, 48.87177611417295],
                            [2.486011674208813, 48.8713264762644],
                            [2.485916040919188, 48.870707970752974],
                            [2.485761140611789, 48.86991241918608],
                        ],
                    },
                },
                1451: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.02956750650235, 2.2161423200398764],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1503.17482203,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.21024652105706,
                            49.02477854792459,
                            2.222727322175325,
                            49.0353113085212,
                        ),
                        "coordinates": [
                            [2.21024652105706, 49.0353113085212],
                            [2.211234958996772, 49.03428772109431],
                            [2.211934269416814, 49.033582554388474],
                            [2.212050828308599, 49.033461279179775],
                            [2.212334650991096, 49.03317831650688],
                            [2.213225941394156, 49.03225752362751],
                            [2.213538589551506, 49.031926927152576],
                            [2.213985600077804, 49.03145978343459],
                            [2.214118607509665, 49.03131963926773],
                            [2.214311899127952, 49.031135494912284],
                            [2.214701291296587, 49.030734833662926],
                            [2.215198981152886, 49.0302272718783],
                            [2.216408251732713, 49.02897316043149],
                            [2.217537890315237, 49.02782506743145],
                            [2.217861445474715, 49.027484578934526],
                            [2.218125983816123, 49.02723125711528],
                            [2.218428825015656, 49.02697167991636],
                            [2.218793227077343, 49.026701373666675],
                            [2.219173966359555, 49.02645986042647],
                            [2.219546440380735, 49.02624171788984],
                            [2.220100905316275, 49.02597340085845],
                            [2.221887363440193, 49.025156864773834],
                            [2.222727322175325, 49.02477854792459],
                        ],
                    },
                },
                1452: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.55099986160079, 2.609233018540175],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 3724.30098091,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.594551816007613,
                            48.538775256627815,
                            2.625522155066302,
                            48.564949495670916,
                        ),
                        "coordinates": [
                            [2.625522155066302, 48.538775256627815],
                            [2.624776075314098, 48.53927050573528],
                            [2.623773668056681, 48.539923214706796],
                            [2.621886582463923, 48.54122651069726],
                            [2.620600906228615, 48.5420903309967],
                            [2.62016785267195, 48.542383674367116],
                            [2.619575609748064, 48.54278622409057],
                            [2.619358423228824, 48.54293694225777],
                            [2.618162728204673, 48.54373677681227],
                            [2.615466359895904, 48.54551006899454],
                            [2.612957391262936, 48.547184692917895],
                            [2.612344481644246, 48.54764836369889],
                            [2.611726401402525, 48.54815159979666],
                            [2.610171376480844, 48.549506804871186],
                            [2.608755488832815, 48.55076172354525],
                            [2.607453748761432, 48.55193069679502],
                            [2.605149641679002, 48.55398951274059],
                            [2.603968136056954, 48.55504505232757],
                            [2.602431242894382, 48.55642903058628],
                            [2.601858207182686, 48.55693575710002],
                            [2.600732321721419, 48.55793026945286],
                            [2.599306285855718, 48.55917104011397],
                            [2.598596250642165, 48.559791303229716],
                            [2.597929111450562, 48.560392429278025],
                            [2.597558172959759, 48.56074542162348],
                            [2.59715174336718, 48.561167493858214],
                            [2.596734664983745, 48.561611003661056],
                            [2.596414028489294, 48.56199004836417],
                            [2.596040049681421, 48.56245249167125],
                            [2.595406892080137, 48.56339852389335],
                            [2.594826443424239, 48.56440594919895],
                            [2.594551816007613, 48.564949495670916],
                        ],
                    },
                },
                1453: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.4344627039764, 2.154361980927693],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 934.747457589,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.149101178683954,
                            48.43222560109566,
                            2.159530553968522,
                            48.43692392480675,
                        ),
                        "coordinates": [
                            [2.159530553968522, 48.43692392480675],
                            [2.158762830775237, 48.43663245077884],
                            [2.15828087410655, 48.4364223164085],
                            [2.157849002363648, 48.43620512206463],
                            [2.157106634802726, 48.43582802364478],
                            [2.154979652132243, 48.43471351329087],
                            [2.153805613821133, 48.43408587517735],
                            [2.153320265961851, 48.43383764698317],
                            [2.152681390830034, 48.43353206466669],
                            [2.152106678117004, 48.43328130648193],
                            [2.151546192305663, 48.433051980618124],
                            [2.150960669656199, 48.4328273707947],
                            [2.150378653997573, 48.432621797185966],
                            [2.149725165900776, 48.43240896531335],
                            [2.149214451943943, 48.432260606137234],
                            [2.149101178683954, 48.43222560109566],
                        ],
                    },
                },
                1454: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.96309571623342, 2.3213338503637733],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1000.01148057,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.3165820711557,
                            48.95987163649979,
                            2.32609015753849,
                            48.966326544842126,
                        ),
                        "coordinates": [
                            [2.32609015753849, 48.95987163649979],
                            [2.325514520974648, 48.96026447734647],
                            [2.324223720051144, 48.9611322848029],
                            [2.32393960916588, 48.96131660512335],
                            [2.323703300567215, 48.9614739519506],
                            [2.322263560000611, 48.96246208458023],
                            [2.319349758639264, 48.96444818215012],
                            [2.317871598635294, 48.96544614451625],
                            [2.317073748346804, 48.965986476118985],
                            [2.3165820711557, 48.966326544842126],
                        ],
                    },
                },
                1455: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.800711270491334, 2.634891262577311],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 2539.14660211,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.619395781719303,
                            48.795654821412064,
                            2.65038766844115,
                            48.80577037511879,
                        ),
                        "coordinates": [
                            [2.619395781719303, 48.80577037511879],
                            [2.62033659854746, 48.80546362845502],
                            [2.621418866793547, 48.80511830671614],
                            [2.624032578818235, 48.80424805111126],
                            [2.62658189777989, 48.80342286165644],
                            [2.627735511136074, 48.8030467235935],
                            [2.62950461280818, 48.80246845608912],
                            [2.631356544562773, 48.80186117094648],
                            [2.633205707528341, 48.80125386191333],
                            [2.635982862887326, 48.80035812165081],
                            [2.638420196546505, 48.79956123480164],
                            [2.640854733538161, 48.798765202380544],
                            [2.643290547448431, 48.79796821457687],
                            [2.647533065612068, 48.79659072762],
                            [2.648570874623787, 48.796248865871185],
                            [2.64934378727576, 48.79599405234788],
                            [2.65038766844115, 48.795654821412064],
                        ],
                    },
                },
                1456: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.96071631750698, 2.259755151442724],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 2298.94251917,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.255032689365674,
                            48.95101678180594,
                            2.264112769834031,
                            48.97051992210463,
                        ),
                        "coordinates": [
                            [2.263924959788352, 48.97051992210463],
                            [2.263992109928939, 48.97019280444279],
                            [2.264046731490777, 48.969913028985125],
                            [2.264079603745008, 48.969677496087265],
                            [2.264112769834031, 48.96908259899572],
                            [2.264102445871056, 48.96873045095783],
                            [2.264081190379899, 48.968437778931545],
                            [2.264056288828641, 48.9681688979576],
                            [2.264013355979051, 48.96787383197799],
                            [2.263952363043426, 48.96757161918285],
                            [2.26385890318257, 48.96723131360182],
                            [2.26374736648998, 48.966898134173015],
                            [2.263624976124514, 48.9665744660007],
                            [2.263488111905425, 48.96626268607745],
                            [2.263369218964826, 48.966017537966174],
                            [2.263210646843699, 48.9657271572229],
                            [2.263019582070232, 48.96541534203537],
                            [2.262857334875192, 48.96516778559439],
                            [2.262565269472823, 48.96473693713095],
                            [2.258830194746513, 48.95921914955461],
                            [2.257085585989827, 48.95660067595872],
                            [2.256155656117332, 48.95522238777198],
                            [2.255964649660679, 48.95492721550783],
                            [2.255788085807808, 48.95463919094129],
                            [2.255629586658888, 48.95435117925937],
                            [2.255488421137162, 48.95405098894533],
                            [2.255348090121299, 48.953703506775305],
                            [2.25521508387373, 48.953296545494695],
                            [2.25514686990983, 48.95303476987765],
                            [2.255089619571894, 48.952699241134],
                            [2.255050345752057, 48.95241607313774],
                            [2.255032689365674, 48.95216860868762],
                            [2.255040465136331, 48.951835507961334],
                            [2.25505160172218, 48.95165468557088],
                            [2.25508371139436, 48.95101678180594],
                        ],
                    },
                },
                1457: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.81472037497293, 2.0164666639083833],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 3965.75864441,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.992864535155556,
                            48.807246612101615,
                            2.040519204703665,
                            48.82365326874927,
                        ),
                        "coordinates": [
                            [1.992864535155556, 48.82365326874927],
                            [1.99288533932926, 48.823638516283985],
                            [1.993173968212166, 48.8234559323992],
                            [1.993801598424778, 48.823092712694276],
                            [1.994495853596732, 48.822744077281534],
                            [1.995058660200695, 48.82249666301098],
                            [1.995450628976955, 48.822335965982596],
                            [1.995647293475693, 48.82225561865065],
                            [1.996223460988295, 48.82204421060895],
                            [1.99816765014932, 48.82133057193942],
                            [1.998788828939766, 48.82110579537884],
                            [1.99970899187326, 48.82077128727937],
                            [1.99980864249568, 48.82073651006287],
                            [1.999906956427206, 48.82069813109099],
                            [2.000334289962784, 48.820539320188516],
                            [2.00269888196806, 48.81966497461229],
                            [2.002825836333504, 48.81961948293844],
                            [2.003216268131958, 48.81947763997557],
                            [2.003332298638633, 48.819436612271716],
                            [2.004833981501187, 48.81888433679842],
                            [2.006335638797191, 48.8183311428244],
                            [2.007969695173353, 48.817726153285854],
                            [2.009988623740037, 48.816984652894526],
                            [2.010156529473848, 48.81692218401139],
                            [2.011255416377446, 48.81651255617059],
                            [2.013790173841511, 48.81558630889112],
                            [2.015601490710889, 48.814916064795256],
                            [2.016769818577302, 48.81449308975608],
                            [2.017890390549869, 48.81408255929142],
                            [2.017899944647254, 48.81407898880855],
                            [2.019683798440779, 48.813427488165836],
                            [2.019737016227012, 48.813409650010065],
                            [2.019840752123614, 48.81337036998429],
                            [2.021384410911502, 48.81279731186423],
                            [2.022928021171722, 48.81222603045548],
                            [2.024471609455778, 48.81165293097308],
                            [2.025990540129969, 48.811097727791164],
                            [2.028189038378654, 48.81029434653903],
                            [2.028426482531518, 48.81020865800447],
                            [2.030353428070687, 48.80949083076688],
                            [2.030644101335289, 48.809382798778934],
                            [2.030960708364843, 48.80926404377657],
                            [2.031846204424275, 48.80896065986381],
                            [2.032050865970929, 48.80889016426948],
                            [2.032629226100943, 48.8087145503652],
                            [2.032701511268487, 48.8086940599197],
                            [2.033984760278743, 48.80835574858412],
                            [2.034390274715971, 48.808258936597746],
                            [2.034802815851451, 48.808166371304054],
                            [2.035482948039733, 48.808044070250574],
                            [2.035623337226263, 48.808018362189685],
                            [2.036428769588487, 48.80788829262692],
                            [2.037814735990416, 48.807668015720196],
                            [2.039798934711327, 48.807354857185835],
                            [2.040519204703665, 48.807246612101615],
                        ],
                    },
                },
                1458: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [48.92597657591952, 2.347894984251233],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 1911.66686144,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345604378196291,
                            48.91756717658463,
                            2.350389537889768,
                            48.93445554506131,
                        ),
                        "coordinates": [
                            [2.350389537889768, 48.91756717658463],
                            [2.350342314076203, 48.91772961853044],
                            [2.350147572995856, 48.91853147990211],
                            [2.350032161666563, 48.9189835689119],
                            [2.349880647907257, 48.91944280003035],
                            [2.349725516327031, 48.9198877536472],
                            [2.34962876261022, 48.92012699342345],
                            [2.349377376763388, 48.92070151550807],
                            [2.349135603843973, 48.921220238976524],
                            [2.348994880841532, 48.921577155113006],
                            [2.348854186780369, 48.922060176981844],
                            [2.348768465522529, 48.92240132913136],
                            [2.348602377838885, 48.92310495920607],
                            [2.348377223838913, 48.92403258160752],
                            [2.348085590837943, 48.92511602811331],
                            [2.347753317643256, 48.92626277785316],
                            [2.347557632219622, 48.92690554426731],
                            [2.347432100906438, 48.92735109569436],
                            [2.34734718790273, 48.9276870841212],
                            [2.347243819834142, 48.92810828689276],
                            [2.347085068572845, 48.9287498309092],
                            [2.346824778539624, 48.929780925648814],
                            [2.346512776343114, 48.93097514614477],
                            [2.346221077323989, 48.93214258298946],
                            [2.345918274910239, 48.93328202093088],
                            [2.345604378196291, 48.93445554506131],
                        ],
                    },
                },
                1459: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.88295715568775, 2.3196820795515647],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1516.1561858,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313732451520271,
                            48.87683695396951,
                            2.324738046836634,
                            48.88822016276462,
                        ),
                        "coordinates": [
                            [2.324738046836634, 48.87683695396951],
                            [2.32420142057937, 48.87748880417361],
                            [2.323956605544434, 48.877847241123426],
                            [2.32373720863479, 48.878224548844315],
                            [2.32352415360155, 48.87863539844985],
                            [2.323339714766086, 48.87900013217418],
                            [2.323107564883391, 48.87948434675638],
                            [2.322872780798152, 48.87990183133246],
                            [2.322699857158072, 48.880154733598346],
                            [2.322475211042448, 48.88042595099708],
                            [2.322188319175849, 48.88072928059579],
                            [2.321847299445921, 48.88108256843456],
                            [2.321165706465782, 48.88174482790253],
                            [2.320547906039082, 48.88237470681367],
                            [2.319826119003644, 48.88310506035692],
                            [2.319162051301495, 48.883785452158705],
                            [2.318772266168705, 48.88418512040464],
                            [2.317981852446237, 48.884977315949094],
                            [2.317371900145514, 48.88554825533218],
                            [2.316909910839129, 48.88598121765758],
                            [2.316419050997167, 48.88641655115975],
                            [2.316011197598551, 48.88677813862067],
                            [2.315596526577928, 48.88708453333479],
                            [2.314979371694457, 48.88749604387476],
                            [2.314105991626147, 48.8880026761262],
                            [2.313732451520271, 48.88822016276462],
                        ],
                    },
                },
                1460: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.83270442467216, 1.9344990372911435],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 1464.5908263,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.924597779359982,
                            48.83191618431854,
                            1.944401758066846,
                            48.833512070590515,
                        ),
                        "coordinates": [
                            [1.924597779359982, 48.833512070590515],
                            [1.925238459634334, 48.833458627761495],
                            [1.925896862450586, 48.833403446487424],
                            [1.927956558438825, 48.833232787567816],
                            [1.93191636657706, 48.832911476124735],
                            [1.932407092523259, 48.83287005084331],
                            [1.932416627194093, 48.83287008468565],
                            [1.932592476169921, 48.832854520237966],
                            [1.933471677148463, 48.83278209207269],
                            [1.934503543595752, 48.83269670602836],
                            [1.936961186030132, 48.83249491362395],
                            [1.939469215665072, 48.83229234392198],
                            [1.940259684883654, 48.832241137452655],
                            [1.941362302020195, 48.83216312969583],
                            [1.941479517491518, 48.832154543372155],
                            [1.941636255472948, 48.8321433952598],
                            [1.94201242430609, 48.832116820436845],
                            [1.944401758066846, 48.83191618431854],
                        ],
                    },
                },
                1461: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.98049002134593, 1.7965241944453054],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 1888.44445122,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.783973407729849,
                            48.9792514910568,
                            1.808907828712391,
                            48.98297976320563,
                        ),
                        "coordinates": [
                            [1.783973407729849, 48.979292248544446],
                            [1.784113406024897, 48.97928641196018],
                            [1.784684753516562, 48.979267754802265],
                            [1.785230693880385, 48.97925849278836],
                            [1.786246531847681, 48.9792514910568],
                            [1.787215225355044, 48.9792585299782],
                            [1.788415067419059, 48.97928332307666],
                            [1.789614595412037, 48.97933665726022],
                            [1.790770542598254, 48.97940880362781],
                            [1.791633681749685, 48.97948192403707],
                            [1.792330677892193, 48.979542350676304],
                            [1.793186382252216, 48.979634458772374],
                            [1.794070876534528, 48.979738593537874],
                            [1.794872162055996, 48.979849466189954],
                            [1.795575957804679, 48.97995035417782],
                            [1.796398700827595, 48.98008273246472],
                            [1.797080607015184, 48.980202542984564],
                            [1.797729985849793, 48.98032219624302],
                            [1.798606497125247, 48.980497639672166],
                            [1.799616295722199, 48.980716531137524],
                            [1.801375839773103, 48.98113641677692],
                            [1.804361145571652, 48.98186892776987],
                            [1.808907828712391, 48.98297976320563],
                        ],
                    },
                },
                1462: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.91138859502196, 2.2754253293176867],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 846.401391278,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.271598750389755,
                            48.908565915509755,
                            2.279278948726629,
                            48.91424647429558,
                        ),
                        "coordinates": [
                            [2.279278948726629, 48.908565915509755],
                            [2.278715110764272, 48.909008167762096],
                            [2.27845174898955, 48.90919967730751],
                            [2.278043500521469, 48.909504024340734],
                            [2.277501569592654, 48.90990823213004],
                            [2.276074501697972, 48.91092346191907],
                            [2.275008709374851, 48.91165810696018],
                            [2.274492039487923, 48.91202900532186],
                            [2.273828487873968, 48.912508176039466],
                            [2.27301910671105, 48.913107322124375],
                            [2.272550015129134, 48.91349096677442],
                            [2.272245761381376, 48.9137397941222],
                            [2.271642274483488, 48.9142153187575],
                            [2.271598750389755, 48.91424647429558],
                        ],
                    },
                },
                1463: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.98051337753165, 2.2710598814546117],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 152.960676604,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.270035426257897,
                            48.980377556311645,
                            2.272084772747633,
                            48.980646100425986,
                        ),
                        "coordinates": [
                            [2.272084772747633, 48.980646100425986],
                            [2.2707762199836, 48.980476521543785],
                            [2.270302760898295, 48.98041676450894],
                            [2.270035426257897, 48.980377556311645],
                        ],
                    },
                },
                1464: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.05477417638451, 2.076491814986491],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3358.17440629,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.057902989161614,
                            49.04664576264113,
                            2.095195067225969,
                            49.062969678597184,
                        ),
                        "coordinates": [
                            [2.095195067225969, 49.04664576264113],
                            [2.094126920089523, 49.046874735810704],
                            [2.093499901776588, 49.04703212246902],
                            [2.092920593297768, 49.04720250649252],
                            [2.091159286398372, 49.04767568235559],
                            [2.090079360752798, 49.047925572243905],
                            [2.089365325756049, 49.048114379438736],
                            [2.088875888051575, 49.04828292630655],
                            [2.088586733759366, 49.04837942216064],
                            [2.088282463472209, 49.048489374520706],
                            [2.088011043893093, 49.048595798794416],
                            [2.087919199938083, 49.04863157114024],
                            [2.087564035054227, 49.04879536629087],
                            [2.087321255508606, 49.048918938849724],
                            [2.08711964160572, 49.04901831911531],
                            [2.086742399599353, 49.04921803602306],
                            [2.086380108170661, 49.04943666812055],
                            [2.085943546619811, 49.049731575890895],
                            [2.085655127112803, 49.04995036857075],
                            [2.085085125800879, 49.05038706596251],
                            [2.084191046955512, 49.051055061107206],
                            [2.0834499148253, 49.05150756055048],
                            [2.083164513940505, 49.05166700098783],
                            [2.082850384475092, 49.05182547685646],
                            [2.082275798305706, 49.052080496960116],
                            [2.081993344976037, 49.05219767407753],
                            [2.08158070709133, 49.05235412949175],
                            [2.081465597200733, 49.0523889447606],
                            [2.081405294315293, 49.05240859467244],
                            [2.081340877238093, 49.052430034008474],
                            [2.081133875839146, 49.052507809537985],
                            [2.080461012986365, 49.05271403927922],
                            [2.079742889510717, 49.05293994862055],
                            [2.079013908555118, 49.053147842735186],
                            [2.078968686543511, 49.053161229787634],
                            [2.07839722346008, 49.0533353022831],
                            [2.077866873530738, 49.05349597458154],
                            [2.076632119279961, 49.05386997607687],
                            [2.076538917675931, 49.053900339330134],
                            [2.076481352443694, 49.053919093309645],
                            [2.076101638657753, 49.0540531218026],
                            [2.075614925514857, 49.05423906401237],
                            [2.075145899653117, 49.05444302942589],
                            [2.074532664979615, 49.05474828138031],
                            [2.074399595778393, 49.05481362380417],
                            [2.074335077758354, 49.054853044730535],
                            [2.07391778700268, 49.05510388620937],
                            [2.073552583806506, 49.05533686031318],
                            [2.073279280494053, 49.05552687986573],
                            [2.072781914389743, 49.05590972676529],
                            [2.072608669357216, 49.05606670100856],
                            [2.072427226918978, 49.056220959011256],
                            [2.072231875564163, 49.05641745067627],
                            [2.07210796360099, 49.05656014968658],
                            [2.071937393171934, 49.05672792064698],
                            [2.070613223507392, 49.05818438299689],
                            [2.07028297358326, 49.058526240368955],
                            [2.070181093504082, 49.05864111154397],
                            [2.069804365072053, 49.05897296732316],
                            [2.069731536102972, 49.059029452258955],
                            [2.069682080643006, 49.05906530853524],
                            [2.069443000103234, 49.059246404752855],
                            [2.069210862523064, 49.05940863301776],
                            [2.068753610679042, 49.05969893113579],
                            [2.068601146673209, 49.05978070353879],
                            [2.06805560213539, 49.060033612207086],
                            [2.066851653333208, 49.06049801807876],
                            [2.066184835043928, 49.06074684882443],
                            [2.06613274208745, 49.06076381224054],
                            [2.066050478703724, 49.06079239544044],
                            [2.064875560292593, 49.06118529581779],
                            [2.06424768462518, 49.061388840495226],
                            [2.063611648208768, 49.061582469221776],
                            [2.063552705376659, 49.06160031511514],
                            [2.063492385020961, 49.06161995496162],
                            [2.062713833074689, 49.061847412342175],
                            [2.061905204383233, 49.0620684963418],
                            [2.06041698661609, 49.062434520964196],
                            [2.05985653531546, 49.06256626160598],
                            [2.058432985971604, 49.06286497070554],
                            [2.057902989161614, 49.062969678597184],
                        ],
                    },
                },
                1465: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.85355206757962, 2.0523376719696924],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 3316.0588043,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.047427019652339,
                            48.84135963821712,
                            2.061326812936337,
                            48.8677920976795,
                        ),
                        "coordinates": [
                            [2.050767845333735, 48.8677920976795],
                            [2.050711250571374, 48.867599228024076],
                            [2.050676034900607, 48.86745161905403],
                            [2.050648032104639, 48.86730402949212],
                            [2.050630890660297, 48.86714932834167],
                            [2.050617368330776, 48.86699225723505],
                            [2.050614624246829, 48.86684235060371],
                            [2.050619383154367, 48.86664249626823],
                            [2.050642255738805, 48.86642841172334],
                            [2.050672136066618, 48.866250034067804],
                            [2.050716524166661, 48.86605741737421],
                            [2.050757125784023, 48.865895723606684],
                            [2.051199039017982, 48.86430741972475],
                            [2.051239748623674, 48.864126690145746],
                            [2.051273259034957, 48.863943564167734],
                            [2.051295922195775, 48.86376516834323],
                            [2.051307684823626, 48.86360102219611],
                            [2.051308819302095, 48.86340353808639],
                            [2.051291868021824, 48.863215526745726],
                            [2.051274685985254, 48.863067963182516],
                            [2.051236261515478, 48.862851345821646],
                            [2.051183398560127, 48.86263707103917],
                            [2.051130235573136, 48.86247514138686],
                            [2.051059153104219, 48.862294132222694],
                            [2.050973617735363, 48.862117845242025],
                            [2.050884462916271, 48.86194392901175],
                            [2.050791579058147, 48.861791417169364],
                            [2.050652077060664, 48.86159358161501],
                            [2.050541177482009, 48.86143864486712],
                            [2.050390749153894, 48.8612598152244],
                            [2.048366308932291, 48.8590133600925],
                            [2.048240985082046, 48.85886076496144],
                            [2.048137145472804, 48.85873439574001],
                            [2.048033430475296, 48.85858661305302],
                            [2.047944085032789, 48.858448384521424],
                            [2.047865530935165, 48.85831494195278],
                            [2.047776339007511, 48.858150539673765],
                            [2.047708671097193, 48.85800522805981],
                            [2.047637522847656, 48.85783849230997],
                            [2.047563018662817, 48.85762891992848],
                            [2.047506585972582, 48.85741225574815],
                            [2.047464452011967, 48.85721704144936],
                            [2.04744395356413, 48.857021881511656],
                            [2.047427019652339, 48.856833869452046],
                            [2.047427934806029, 48.856676834909386],
                            [2.047443562997782, 48.856469870213246],
                            [2.047466361701908, 48.85627006141684],
                            [2.047499922205768, 48.85607979799837],
                            [2.047566210163615, 48.8558420304044],
                            [2.04762130601421, 48.85566847712643],
                            [2.047694431206228, 48.85549496925704],
                            [2.047774768305834, 48.855321480038974],
                            [2.047862245696527, 48.85515990508637],
                            [2.047949694204142, 48.855003088480444],
                            [2.048058762971255, 48.85484870665942],
                            [2.048171450741103, 48.85469195394463],
                            [2.048305825872087, 48.8545257393613],
                            [2.049231278081586, 48.853488296205626],
                            [2.05058124710757, 48.85198080020309],
                            [2.052791131423521, 48.84950703302685],
                            [2.05420282214058, 48.847885438933744],
                            [2.055418279928057, 48.84652269309397],
                            [2.057943254303201, 48.84370221854692],
                            [2.058222561094012, 48.84339358487759],
                            [2.058367565842544, 48.84324879852307],
                            [2.058530701980177, 48.843085020932186],
                            [2.058679232388989, 48.842954518244085],
                            [2.058827773672669, 48.8428216365455],
                            [2.058976260890835, 48.84269827253524],
                            [2.059146403945708, 48.84257020123311],
                            [2.059316530464755, 48.84244450935307],
                            [2.059504695636216, 48.84231648210848],
                            [2.059721774497329, 48.84217424832126],
                            [2.059935183564138, 48.842043901395186],
                            [2.060115990245107, 48.84194202824937],
                            [2.060332946863808, 48.84182120700172],
                            [2.060614920809567, 48.84167674984585],
                            [2.06095827877674, 48.841513405393734],
                            [2.061157023721462, 48.84142584956137],
                            [2.061326812936337, 48.84135963821712],
                        ],
                    },
                },
                1466: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [49.04584665313769, 2.058061494538279],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 3860.48915715,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.034294461852662,
                            49.03646398072535,
                            2.079534939997374,
                            49.049647005256354,
                        ),
                        "coordinates": [
                            [2.034294461852662, 49.049647005256354],
                            [2.036699555177008, 49.04940111809993],
                            [2.038032451108977, 49.049271358279974],
                            [2.039600795400978, 49.04911364082945],
                            [2.047377116513116, 49.04834122395781],
                            [2.058365751178554, 49.047238265457736],
                            [2.059271172808136, 49.04715004729796],
                            [2.059825257312942, 49.047101421034434],
                            [2.060339435140608, 49.04706935220961],
                            [2.060795628329488, 49.04704903840108],
                            [2.061280752815287, 49.047033552094234],
                            [2.061878059147017, 49.047023089039115],
                            [2.062395774408933, 49.047005295364976],
                            [2.062804923993119, 49.04698248095369],
                            [2.063081184635633, 49.04696657874804],
                            [2.063513731204735, 49.04693725958154],
                            [2.064189534895152, 49.04687556029884],
                            [2.06492075559411, 49.046755206872064],
                            [2.065552960855347, 49.04662647492233],
                            [2.066165201070163, 49.04648499619211],
                            [2.066727696589304, 49.04633100990429],
                            [2.067278309739992, 49.04614023584278],
                            [2.067800729955743, 49.045920183796795],
                            [2.06830872490457, 49.04567589316136],
                            [2.068595574908552, 49.04550390368852],
                            [2.068856353054068, 49.045346240194384],
                            [2.069205162048956, 49.045099753904125],
                            [2.069577394428554, 49.04482184561982],
                            [2.070226057143948, 49.044271199019086],
                            [2.070869852053202, 49.04360542984601],
                            [2.071277342200432, 49.04312615961311],
                            [2.07152653878889, 49.042828175969404],
                            [2.071773373059466, 49.04246004273258],
                            [2.072131219151798, 49.042051697904476],
                            [2.072394003196743, 49.0417690312393],
                            [2.072757057099989, 49.04140835849702],
                            [2.073216098355186, 49.04100294140987],
                            [2.07331777149287, 49.04091864270687],
                            [2.074036174611757, 49.04035464611563],
                            [2.074828416347525, 49.039792612163396],
                            [2.075037209324431, 49.03962672357928],
                            [2.075186940796591, 49.03950656157843],
                            [2.076020730185133, 49.03884209699288],
                            [2.076296804012054, 49.03862599905197],
                            [2.076508199784972, 49.038483493418305],
                            [2.077215150022583, 49.03800308395509],
                            [2.079534939997374, 49.03646398072535],
                        ],
                    },
                },
                1467: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.957733520262124, 2.2118862744385672],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 3603.6938682,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.193442867808299,
                            48.949898714178275,
                            2.231110035011993,
                            48.968496267514055,
                        ),
                        "coordinates": [
                            [2.231110035011993, 48.950304353547466],
                            [2.230618923375161, 48.950208725581376],
                            [2.229958044697145, 48.950101041167706],
                            [2.22938379752255, 48.95002912244919],
                            [2.228719221894747, 48.949964254820316],
                            [2.228061820683885, 48.94992318525593],
                            [2.227350194319123, 48.949898714178275],
                            [2.226649336167539, 48.94990517906743],
                            [2.226031531561676, 48.949928377633626],
                            [2.225431751224789, 48.949968243554316],
                            [2.224752442393621, 48.950031823527716],
                            [2.224112818105142, 48.95011685180226],
                            [2.22355988812403, 48.95020434196695],
                            [2.222992454027753, 48.95031560806404],
                            [2.222284009217263, 48.950476698198116],
                            [2.221615253911829, 48.95065685763171],
                            [2.221018739938992, 48.950839463880364],
                            [2.220331783065522, 48.951074323815234],
                            [2.219738746613332, 48.951311650818],
                            [2.219214352979787, 48.951544288800854],
                            [2.218707984972419, 48.951791220091565],
                            [2.218244967362918, 48.952038193584286],
                            [2.217832526969044, 48.95228283694584],
                            [2.21743814174728, 48.95252987819864],
                            [2.217090747756366, 48.95276507024004],
                            [2.216736055056345, 48.95302880545211],
                            [2.216352355721841, 48.95333295902083],
                            [2.216033765586253, 48.95360386871602],
                            [2.206847714441461, 48.96132428890472],
                            [2.205670756552687, 48.9623056141098],
                            [2.205261567352605, 48.96263111460411],
                            [2.204751089968308, 48.96299694638334],
                            [2.204291394440727, 48.963286694893945],
                            [2.203734043965727, 48.96360725895176],
                            [2.203194870949078, 48.963885013209364],
                            [2.20272810794125, 48.964110506482974],
                            [2.199569281228541, 48.9656033682291],
                            [2.196750450023953, 48.96692524278801],
                            [2.193442867808299, 48.968496267514055],
                        ],
                    },
                },
                1468: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.89294686080906, 2.305586250545477],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1589.87147309,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.297419948146663,
                            48.88822016276462,
                            2.313732451520271,
                            48.89763744791706,
                        ),
                        "coordinates": [
                            [2.313732451520271, 48.88822016276462],
                            [2.312557681116819, 48.888904131906834],
                            [2.311861101364987, 48.88931322918998],
                            [2.310471156153221, 48.89009856750011],
                            [2.307915667206252, 48.89156362940108],
                            [2.305782353427846, 48.892812229255576],
                            [2.304508076579762, 48.89358040663048],
                            [2.302399845234058, 48.894833707686736],
                            [2.301472058910227, 48.89536877831059],
                            [2.300746415528593, 48.895794456467286],
                            [2.29982620296289, 48.896307637273466],
                            [2.299147473198817, 48.89669643774181],
                            [2.298473555854997, 48.89706897752753],
                            [2.297419948146663, 48.89763744791706],
                        ],
                    },
                },
                1469: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.89878282303108, 2.0719114361911872],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 993.65717464,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.069937966816875,
                            48.89460762842623,
                            2.072971456565674,
                            48.903204615452346,
                        ),
                        "coordinates": [
                            [2.072971456565674, 48.903204615452346],
                            [2.072952281751156, 48.90173947829764],
                            [2.072935443176995, 48.90083290480762],
                            [2.072929147396368, 48.90065919759242],
                            [2.072915332191866, 48.90054257665358],
                            [2.07290874532552, 48.90042359420955],
                            [2.072887748684445, 48.900299818203074],
                            [2.072856078013197, 48.90014746732309],
                            [2.072831358263529, 48.900045097498456],
                            [2.072795965957776, 48.89991415100403],
                            [2.072739147609998, 48.89974032677307],
                            [2.072667904938729, 48.899564089365406],
                            [2.072550153543546, 48.89931160473488],
                            [2.072424983911419, 48.89909717324923],
                            [2.071591643828122, 48.89768666134377],
                            [2.070511676670098, 48.89584252551611],
                            [2.070393678019111, 48.895640004705136],
                            [2.070307822990234, 48.895499422503434],
                            [2.070236355778501, 48.89536839062268],
                            [2.070179218070838, 48.895256428278614],
                            [2.070118561813076, 48.89512780146248],
                            [2.070054438426054, 48.89497299271971],
                            [2.070001115875841, 48.894822968712255],
                            [2.069954997637163, 48.894675340725286],
                            [2.069937966816875, 48.89460762842623],
                        ],
                    },
                },
                1470: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.00058748839264, 2.2159551033513307],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 3085.32946945,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.197619813968745,
                            48.99371348038584,
                            2.234276393996537,
                            49.00742329713069,
                        ),
                        "coordinates": [
                            [2.234276393996537, 48.99371348038584],
                            [2.232504861292808, 48.9943803276354],
                            [2.231359427180695, 48.994809666630914],
                            [2.230414903766395, 48.99517521281167],
                            [2.229683920708789, 48.995441016431265],
                            [2.228059050132284, 48.996046217987484],
                            [2.227121731667691, 48.99640222545707],
                            [2.226412418710857, 48.99666327110842],
                            [2.223423033436542, 48.997788159763694],
                            [2.222749859535978, 48.998042080573654],
                            [2.221005371270001, 48.99869702816867],
                            [2.219673320446388, 48.99919434307988],
                            [2.218975661356986, 48.99945531783884],
                            [2.217379205528473, 49.000060675939075],
                            [2.215785462942007, 49.00065882117623],
                            [2.214195783782723, 49.00125604913104],
                            [2.213191621323129, 49.00162906913297],
                            [2.210299417120758, 49.00271403690773],
                            [2.209001026064172, 49.003202701053084],
                            [2.208764333090145, 49.003290566148564],
                            [2.208537212324408, 49.00337664235786],
                            [2.208052885370861, 49.00355325664045],
                            [2.206133475048893, 49.00427013405321],
                            [2.203652642125176, 49.00519570211146],
                            [2.203086170973281, 49.005407272201836],
                            [2.200341329439513, 49.00642831184516],
                            [2.20001154742561, 49.00655471665025],
                            [2.199101295954952, 49.00689817438802],
                            [2.198359101214039, 49.00717090371677],
                            [2.197708619109245, 49.00739456289574],
                            [2.197619813968745, 49.00742329713069],
                        ],
                    },
                },
                1471: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE N",
                        "rer": 0,
                        "extcode": "800:N",
                        "geo_point_2d": [48.75023507331923, 1.9320404020357282],
                        "indice_lig": "N",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01736",
                        "navette": 0,
                        "idrefliga": "A01847",
                        "shape_leng": 2159.61345089,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.921036600039739,
                            48.74348398592533,
                            1.943835201056777,
                            48.75538926869322,
                        ),
                        "coordinates": [
                            [1.921036600039739, 48.74348398592533],
                            [1.921104399376312, 48.74353070764457],
                            [1.922480849069239, 48.74449205095635],
                            [1.925482786858743, 48.74657553602807],
                            [1.926341367775977, 48.74717109459183],
                            [1.927094073911974, 48.74768951280347],
                            [1.927227903971078, 48.747786217832804],
                            [1.928782911692224, 48.74886374680436],
                            [1.929289397065046, 48.74920652016492],
                            [1.929740368712389, 48.74949841506701],
                            [1.930277289391478, 48.74984058153969],
                            [1.931004135825545, 48.7502785971665],
                            [1.931555755456535, 48.7505851200898],
                            [1.932336468804178, 48.751003296015405],
                            [1.932984983605017, 48.75134346644805],
                            [1.933665968600685, 48.751674230292544],
                            [1.934368572357154, 48.75200268784397],
                            [1.935666393459057, 48.7525925899884],
                            [1.936534101462431, 48.7529763409054],
                            [1.936953682370978, 48.7531538871283],
                            [1.937534710307975, 48.75339148243475],
                            [1.938072775914866, 48.75360275073602],
                            [1.938711425237457, 48.75383578305956],
                            [1.939251441959425, 48.75402920757684],
                            [1.939795156534861, 48.754210746059584],
                            [1.940624174605661, 48.75448963784716],
                            [1.941044181533461, 48.75461720403976],
                            [1.94161861687091, 48.75478337433597],
                            [1.942189438321365, 48.75495190961877],
                            [1.942749601657392, 48.75510374870748],
                            [1.943835201056777, 48.75538926869322],
                        ],
                    },
                },
                1472: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.9447488719057, 2.0671612677018625],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 4574.55828958,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.041072289675926,
                            48.93326540612854,
                            2.093521901580612,
                            48.95540224453111,
                        ),
                        "coordinates": [
                            [2.041072289675926, 48.93326540612854],
                            [2.045668504587519, 48.93529966502182],
                            [2.048460294797077, 48.93653211266265],
                            [2.053997431953846, 48.938980034483606],
                            [2.063909453931477, 48.943358356350146],
                            [2.069404894499701, 48.94578163311858],
                            [2.072525787399531, 48.9471641609139],
                            [2.075109865164508, 48.94830505866521],
                            [2.087559970412699, 48.95376495153617],
                            [2.088475704144185, 48.9541523995623],
                            [2.089216048741711, 48.95442352812452],
                            [2.089784880943044, 48.954616830409066],
                            [2.09041982801554, 48.95480379054842],
                            [2.091033257892704, 48.954959769637476],
                            [2.091639584520061, 48.955091935833345],
                            [2.092029394089491, 48.955171289332526],
                            [2.092321810369193, 48.95521950257172],
                            [2.092971637236077, 48.95532320200608],
                            [2.093521901580612, 48.95540224453111],
                        ],
                    },
                },
                1473: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.86280236752063, 2.3074496200397405],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 948.564860772,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.300989969386769,
                            48.86266245169434,
                            2.313911078550822,
                            48.8629018908629,
                        ),
                        "coordinates": [
                            [2.313911078550822, 48.8629018908629],
                            [2.313908906380806, 48.86290184423484],
                            [2.313451252950004, 48.86289193046037],
                            [2.310728004457645, 48.86286527076938],
                            [2.310426784793952, 48.862862504872936],
                            [2.309152400773083, 48.86283702781332],
                            [2.306866373246121, 48.862788646784374],
                            [2.305428753405039, 48.86275873910871],
                            [2.303633707360317, 48.862740251256064],
                            [2.302454726223663, 48.862732712531155],
                            [2.302041747129463, 48.86272179776361],
                            [2.301770518482009, 48.862714520943285],
                            [2.301616503103, 48.862710877448414],
                            [2.301474759354554, 48.862700043122395],
                            [2.301309846776587, 48.86268740237203],
                            [2.301180370036378, 48.86267836966447],
                            [2.300989969386769, 48.86266245169434],
                        ],
                    },
                },
                1474: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.97223170313227, 3.1697507985494515],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 8651.28935396,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            3.124909020747328,
                            48.95081998757722,
                            3.219302814192089,
                            48.98246065112459,
                        ),
                        "coordinates": [
                            [3.124909020747328, 48.95081998757722],
                            [3.125532361102864, 48.95093282567122],
                            [3.126131637670971, 48.951054975027354],
                            [3.126993307849193, 48.95125440623625],
                            [3.127727014196896, 48.951453477527785],
                            [3.128416940368112, 48.95165441216765],
                            [3.128915151921372, 48.95181252748242],
                            [3.129428910479689, 48.951993849587296],
                            [3.129894707430746, 48.952180499994164],
                            [3.13050320903193, 48.95243444914874],
                            [3.131132320266545, 48.95271156949441],
                            [3.131767030592901, 48.95302196039651],
                            [3.13218780597492, 48.953238896330284],
                            [3.132857675305325, 48.953614009578956],
                            [3.133623510188735, 48.95410959769555],
                            [3.134053121356395, 48.954415969996695],
                            [3.134507820102423, 48.954753642104166],
                            [3.134867403185272, 48.955049078646645],
                            [3.135134935613193, 48.95528256389862],
                            [3.135621281081817, 48.955718936969525],
                            [3.13605137882392, 48.956150026651265],
                            [3.136932018248188, 48.95718844825551],
                            [3.137576746599118, 48.95799943532865],
                            [3.137925599521509, 48.95846014428227],
                            [3.13852081974705, 48.95919924777172],
                            [3.139166476069633, 48.96002253701357],
                            [3.139515373742767, 48.96048146715773],
                            [3.139962218507301, 48.96105297140063],
                            [3.140523025178239, 48.961743338745755],
                            [3.140991241062145, 48.962318312385435],
                            [3.141446098202791, 48.96282682912966],
                            [3.141930993990476, 48.96333423198621],
                            [3.142525226297184, 48.96389648911052],
                            [3.142984875917881, 48.96431066851411],
                            [3.143213077322861, 48.96450625734359],
                            [3.143541397028079, 48.964768996644935],
                            [3.143801570635898, 48.96497760286572],
                            [3.144151132728645, 48.96525583297495],
                            [3.144518065566148, 48.96552922567605],
                            [3.144778432794733, 48.96571777742348],
                            [3.145268295101276, 48.96605452572265],
                            [3.145599477136683, 48.96626995866742],
                            [3.146191726813418, 48.96664604326499],
                            [3.146715980514363, 48.96696518955857],
                            [3.147471279353009, 48.967379821298046],
                            [3.148362698764427, 48.967848341570495],
                            [3.151567237110152, 48.96943084792525],
                            [3.152290592606458, 48.96980880386555],
                            [3.15289167402663, 48.970143561233556],
                            [3.153407694952441, 48.97045554075306],
                            [3.153774221677392, 48.97069573369543],
                            [3.154238193501051, 48.97100387356466],
                            [3.154524897846064, 48.971206695893464],
                            [3.15475755211529, 48.971381192337496],
                            [3.154919471741657, 48.971507019066934],
                            [3.155293458270931, 48.97179836625396],
                            [3.155560369796835, 48.9720154454609],
                            [3.15591553028124, 48.97233048174985],
                            [3.156286972571181, 48.97267222520073],
                            [3.156598433176894, 48.97297907210925],
                            [3.156809537551431, 48.97319908789223],
                            [3.157507885148485, 48.973971332787656],
                            [3.15862899461206, 48.975262809852524],
                            [3.159223131748126, 48.97593837694274],
                            [3.159522184373867, 48.97627268334102],
                            [3.159894317528267, 48.97667914410811],
                            [3.160327721350512, 48.97708970758034],
                            [3.160612922850991, 48.97735082369557],
                            [3.160918367691503, 48.977611793220895],
                            [3.16121842195983, 48.977852812709244],
                            [3.161647483231408, 48.978179180853076],
                            [3.162045713793032, 48.978453135605264],
                            [3.162485601738245, 48.97873311848536],
                            [3.162937812428256, 48.978993022214716],
                            [3.163440879040387, 48.979267547281246],
                            [3.163961439847653, 48.97952861909513],
                            [3.164484093628026, 48.9797630238229],
                            [3.165322467474692, 48.98011339746255],
                            [3.166474211978496, 48.98058974577814],
                            [3.167143226149126, 48.98085035191221],
                            [3.167721770905793, 48.98107457964559],
                            [3.168361890484968, 48.98130549466876],
                            [3.168964166370808, 48.98149108402195],
                            [3.169449820253576, 48.98162912791877],
                            [3.170156186645249, 48.981808779493186],
                            [3.170763419241965, 48.98194330043995],
                            [3.171375317213532, 48.982064811624724],
                            [3.171932593777157, 48.98216229800182],
                            [3.172777571842304, 48.98227753380334],
                            [3.17341969069499, 48.98234469077135],
                            [3.174183053629787, 48.98241024306385],
                            [3.174836743579621, 48.98244412522527],
                            [3.17540405996758, 48.98246065112459],
                            [3.175936918764654, 48.98245944012747],
                            [3.176408193129162, 48.982452383390886],
                            [3.177104490322327, 48.98242028857699],
                            [3.177650400893474, 48.98238300100869],
                            [3.178537185301694, 48.98230363054828],
                            [3.179197463866602, 48.982227945261094],
                            [3.179752711814658, 48.98214057193101],
                            [3.180277276067164, 48.982046838792805],
                            [3.181016552191365, 48.98189743170445],
                            [3.184073409254422, 48.981249197816936],
                            [3.185736684434239, 48.98089641661013],
                            [3.18889122823709, 48.98024667234983],
                            [3.19468775173385, 48.97902572265206],
                            [3.196389605759639, 48.97866815401577],
                            [3.198035862972011, 48.978315975374535],
                            [3.199581983239517, 48.97799276524006],
                            [3.202685608081007, 48.97734065710165],
                            [3.205790498334898, 48.97668755324807],
                            [3.207202005285402, 48.97638902394772],
                            [3.209005541236397, 48.97601014122036],
                            [3.211998682415604, 48.97538200308321],
                            [3.213731884024146, 48.97502188599922],
                            [3.215869555067603, 48.974572392288195],
                            [3.216489394183057, 48.97444863412616],
                            [3.217213448844801, 48.9743072012922],
                            [3.217773537622495, 48.974216271110286],
                            [3.21840142911666, 48.97412677412533],
                            [3.219302814192089, 48.974026580478466],
                        ],
                    },
                },
                1475: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.873037661659566, 2.065451192761674],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 2816.90893086,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.050767845333735,
                            48.8677920976795,
                            2.079177394694269,
                            48.88099144075079,
                        ),
                        "coordinates": [
                            [2.079177394694269, 48.88099144075079],
                            [2.079116832128121, 48.88084378348164],
                            [2.079052636424956, 48.88070087652365],
                            [2.078984822377873, 48.88056034207181],
                            [2.07889543765041, 48.880405481130616],
                            [2.078795279337134, 48.88024108039484],
                            [2.078666399524636, 48.880050440834566],
                            [2.078519421984684, 48.8798716566006],
                            [2.078375952403076, 48.87971191439534],
                            [2.078250385775565, 48.879578385980174],
                            [2.078142719048017, 48.87947107139993],
                            [2.0780350298858, 48.87936851506951],
                            [2.077851894273868, 48.87920630367932],
                            [2.076059986211821, 48.87764136640355],
                            [2.075883990047609, 48.877495822535806],
                            [2.075715147802788, 48.87736219265422],
                            [2.075531927214102, 48.877219011730396],
                            [2.075348683130785, 48.87708058976273],
                            [2.073814138362516, 48.87598969825332],
                            [2.071722693550574, 48.87449776124226],
                            [2.07143162553731, 48.87429008159389],
                            [2.071205258876613, 48.87412537862892],
                            [2.070971704879578, 48.873955901327555],
                            [2.070759768335287, 48.87379123119793],
                            [2.070594535153036, 48.87366236114435],
                            [2.070436490069223, 48.87353826565436],
                            [2.070274863224432, 48.873409403337504],
                            [2.070048619157376, 48.873223284054525],
                            [2.069621244735773, 48.87287727874141],
                            [2.069136419147866, 48.87248354776873],
                            [2.068902971111835, 48.872297410548754],
                            [2.068597604423043, 48.87207065434552],
                            [2.068414332715701, 48.871944117498934],
                            [2.06822740426359, 48.8718270897155],
                            [2.068062029955894, 48.87172676618141],
                            [2.067864243306853, 48.87161685092301],
                            [2.067684378062785, 48.87152839091681],
                            [2.067522506795021, 48.871447110192584],
                            [2.067328202204499, 48.87136099512088],
                            [2.067141058327138, 48.871284413110075],
                            [2.066899917346197, 48.87118866965241],
                            [2.066665899303795, 48.87110959623391],
                            [2.066464266236112, 48.87104487618775],
                            [2.066259013711975, 48.87098252708332],
                            [2.066042890526558, 48.87092966841285],
                            [2.065790749775899, 48.870867206240106],
                            [2.065560174405691, 48.870819071608175],
                            [2.06531514634547, 48.87077565959163],
                            [2.065106132349638, 48.87074185216593],
                            [2.064857445495856, 48.870707948471136],
                            [2.064561844456872, 48.87067869161771],
                            [2.064320306336714, 48.87065669999825],
                            [2.064093142333734, 48.870644261000024],
                            [2.063801031681413, 48.87063642472984],
                            [2.063573816773588, 48.870633501508486],
                            [2.063335728942648, 48.870640068391204],
                            [2.063112054560782, 48.87064905001652],
                            [2.062906389451976, 48.87066283277323],
                            [2.06269350832898, 48.8706765982417],
                            [2.062253203847505, 48.87072550552699],
                            [2.0619283278013, 48.87077231019774],
                            [2.061422966082499, 48.870844851807846],
                            [2.060791258373061, 48.870936121394976],
                            [2.059293178921269, 48.87115614780671],
                            [2.058928595308762, 48.871207605812785],
                            [2.05865789544775, 48.87124025773004],
                            [2.058455779357471, 48.871263558149586],
                            [2.058268117000949, 48.87128213512134],
                            [2.058011923797747, 48.87130054482489],
                            [2.057759366561011, 48.87131420333575],
                            [2.057485218925932, 48.87131829105944],
                            [2.057261594290546, 48.87131774320502],
                            [2.057005547181832, 48.871309978353466],
                            [2.056771170210282, 48.87129750642269],
                            [2.056497170845708, 48.87127541859426],
                            [2.056270046740654, 48.87125582585267],
                            [2.056010529509107, 48.87122425657556],
                            [2.055659141880238, 48.871168343499676],
                            [2.055311491378478, 48.871101187031094],
                            [2.055070130518448, 48.871048245083976],
                            [2.054857652079898, 48.87099061563629],
                            [2.054591165379318, 48.87091619692107],
                            [2.054339136330283, 48.870837054096405],
                            [2.054094346279547, 48.87075317067712],
                            [2.053885612356267, 48.870671755437094],
                            [2.053662507081122, 48.870580786366055],
                            [2.053403497189306, 48.87046117564554],
                            [2.053176908447778, 48.87034878287155],
                            [2.052993560891563, 48.87024363538268],
                            [2.052759911015167, 48.87010505098663],
                            [2.052551467566056, 48.86997366817087],
                            [2.052364651065535, 48.86984471632795],
                            [2.052145635710518, 48.86967047747574],
                            [2.051966159563894, 48.86952012939217],
                            [2.051808296754708, 48.86937459481146],
                            [2.051661269649438, 48.86922670764495],
                            [2.051535774215191, 48.869097908366726],
                            [2.05143189015517, 48.86897392189402],
                            [2.051338801325932, 48.868854721016184],
                            [2.051227884246435, 48.86869978592087],
                            [2.051088427530924, 48.86849005298209],
                            [2.050999193302404, 48.868328033349144],
                            [2.050899384281335, 48.86812315901627],
                            [2.050831762912404, 48.86796595226428],
                            [2.050767845333735, 48.8677920976795],
                        ],
                    },
                },
                1476: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.97305593998584, 2.2798024847743994],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 2760.19412107,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272084772747633,
                            48.96358968487314,
                            2.285930718208942,
                            48.980646100425986,
                        ),
                        "coordinates": [
                            [2.285930718208942, 48.96358968487314],
                            [2.284744051392272, 48.96396199485136],
                            [2.28437653540835, 48.96407873331059],
                            [2.283299969841325, 48.96438938548],
                            [2.282834068218389, 48.964545640361884],
                            [2.282768484077399, 48.964568990629104],
                            [2.282727497280722, 48.96458156186698],
                            [2.282686510592002, 48.9645932329233],
                            [2.282623660820599, 48.964614785641366],
                            [2.2820443248147, 48.964833034262234],
                            [2.281769669040365, 48.96495070819779],
                            [2.281284556206615, 48.96517799120564],
                            [2.280888234187712, 48.96538912775556],
                            [2.280464103502219, 48.96564214141344],
                            [2.280054482123014, 48.96591929066568],
                            [2.279936916689496, 48.966010958536216],
                            [2.279833018871305, 48.966092741776464],
                            [2.279718166412136, 48.96619969797987],
                            [2.27947615323957, 48.96642529580836],
                            [2.279264167974465, 48.966666194762205],
                            [2.279009731586088, 48.96699969823211],
                            [2.278800387640981, 48.96731344018246],
                            [2.278671686634194, 48.967577761945904],
                            [2.278567574633555, 48.96783759930862],
                            [2.278482566889066, 48.96811183540651],
                            [2.278416683452642, 48.96838428179962],
                            [2.278393207498531, 48.96860189512554],
                            [2.278390445862359, 48.96862707324314],
                            [2.278389041742323, 48.96865944646126],
                            [2.278377932031889, 48.968813217022834],
                            [2.278384431702869, 48.96909379374354],
                            [2.278399296628258, 48.969229592235784],
                            [2.278404663885103, 48.969310529637504],
                            [2.278434533557881, 48.96946432094654],
                            [2.278456271451519, 48.96956325219488],
                            [2.278483479600466, 48.96965679107245],
                            [2.278512042130103, 48.96976022190393],
                            [2.27854471389659, 48.969854663205616],
                            [2.278585543282225, 48.96998058196329],
                            [2.278678174194398, 48.97019645544442],
                            [2.278774552599062, 48.97037856058188],
                            [2.278890002818901, 48.97054993065341],
                            [2.27898741074612, 48.970697499207944],
                            [2.279120921815418, 48.97087839646164],
                            [2.279416862498563, 48.97123782463948],
                            [2.279958297027355, 48.97183530774685],
                            [2.280544168469102, 48.97249683295363],
                            [2.281246775823954, 48.97328673967318],
                            [2.281600667855334, 48.97370151205668],
                            [2.281766681931098, 48.97392287023888],
                            [2.28193989258352, 48.974172783186255],
                            [2.282051716164722, 48.97437270089093],
                            [2.28218875505389, 48.97465114799701],
                            [2.282278870993692, 48.97487247006428],
                            [2.282354507105204, 48.97511519859585],
                            [2.282430082396942, 48.97541265201185],
                            [2.282455103309107, 48.975667251717205],
                            [2.282462121321247, 48.97585998162858],
                            [2.282454708939005, 48.97602653227489],
                            [2.282436448452967, 48.97619783533109],
                            [2.282410919386101, 48.976404826030446],
                            [2.282363616783094, 48.97669032390202],
                            [2.282308934422777, 48.976841435494855],
                            [2.282231654593548, 48.977028197816985],
                            [2.282174122883822, 48.977167558732155],
                            [2.282113850847086, 48.977314111657144],
                            [2.282056355987138, 48.97742019835361],
                            [2.281994751735471, 48.977535276376976],
                            [2.281685517494606, 48.97797127725441],
                            [2.281487167620754, 48.97820229472917],
                            [2.28135996382107, 48.97833622531282],
                            [2.281324405130109, 48.9783703809979],
                            [2.281275167580637, 48.97842071688438],
                            [2.2810768621806, 48.97860766936787],
                            [2.280869013087103, 48.97877663219963],
                            [2.280678951429134, 48.97891952394524],
                            [2.280538132035738, 48.97901028224878],
                            [2.280352196014253, 48.9791279956272],
                            [2.28014985878131, 48.979251995911085],
                            [2.27985456281361, 48.97942451025561],
                            [2.279631736005457, 48.97954310350527],
                            [2.279400716345353, 48.979656297441934],
                            [2.279105481435691, 48.979772155318614],
                            [2.278791122163645, 48.97988530583007],
                            [2.278423471630917, 48.98000382366384],
                            [2.278088640724288, 48.980095378541805],
                            [2.277707545186733, 48.980178506665645],
                            [2.277316553543077, 48.980241561913665],
                            [2.276361438381218, 48.98034717701068],
                            [2.27545275701002, 48.980463600667505],
                            [2.274714898034236, 48.98054054067926],
                            [2.272084772747633, 48.980646100425986],
                        ],
                    },
                },
                1477: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.83516358569444, 2.203728357002271],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 1745.98014057,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.200721257947835,
                            48.8272387754095,
                            2.209938360929272,
                            48.840517349814164,
                        ),
                        "coordinates": [
                            [2.200721257947835, 48.8272387754095],
                            [2.200961674989991, 48.828525941410284],
                            [2.201011184720281, 48.8288506396897],
                            [2.201013852316059, 48.82887132637703],
                            [2.201017877705458, 48.82889381371847],
                            [2.20103398391032, 48.82898106224347],
                            [2.201091691210765, 48.82929677715687],
                            [2.201161483197946, 48.8296763555138],
                            [2.201170876139126, 48.829728525231864],
                            [2.201181629975536, 48.82978069594199],
                            [2.201205767498219, 48.829920113078174],
                            [2.201251404308715, 48.83016746816239],
                            [2.20128361680769, 48.8303428652195],
                            [2.201326561826797, 48.83057852724593],
                            [2.20137893256546, 48.83085466792961],
                            [2.201408438807621, 48.83102376724514],
                            [2.201431241458818, 48.83115329009304],
                            [2.201460771208559, 48.83131429591918],
                            [2.201497041507713, 48.831500489084185],
                            [2.201570839075754, 48.83191244590117],
                            [2.201631230999146, 48.832245250661146],
                            [2.201687609378266, 48.832551071193336],
                            [2.20174800853441, 48.83288207697096],
                            [2.201803056318744, 48.83317710564945],
                            [2.201847332099155, 48.8334262575317],
                            [2.201903346434993, 48.833867869772206],
                            [2.201998554608239, 48.834423735830875],
                            [2.202071239480442, 48.8347466627161],
                            [2.202171187212725, 48.83506332632614],
                            [2.202271308131837, 48.835316140945395],
                            [2.202341714433056, 48.83547539672392],
                            [2.202548995907909, 48.83589830109822],
                            [2.202776875189194, 48.83626187680524],
                            [2.202926778311895, 48.83650930588347],
                            [2.20303990252678, 48.83666290528936],
                            [2.203226345695151, 48.83689511065908],
                            [2.203357847892823, 48.83705087371665],
                            [2.203435446003965, 48.83714661351711],
                            [2.203729820944669, 48.83745532043108],
                            [2.204051247864232, 48.83775834705329],
                            [2.204469864853319, 48.8381121659406],
                            [2.204877828163665, 48.838407438230334],
                            [2.205053770935466, 48.83852684747304],
                            [2.20527614237085, 48.838673433020745],
                            [2.205649714075431, 48.83889228743554],
                            [2.205934777811782, 48.83905036476533],
                            [2.206285392814635, 48.839228145581515],
                            [2.206497063820767, 48.8393340300196],
                            [2.206637474461507, 48.83939771921528],
                            [2.206851337174804, 48.83949289872554],
                            [2.207175979179549, 48.83962544926493],
                            [2.207363642258585, 48.83970049783722],
                            [2.207576896671259, 48.83978020264471],
                            [2.207856952896149, 48.8398702354335],
                            [2.208696666682112, 48.84013208396308],
                            [2.208854158946474, 48.840179775591274],
                            [2.209284475922477, 48.84031051075772],
                            [2.209938360929272, 48.840517349814164],
                        ],
                    },
                },
                1478: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.78821032628056, 2.3157119428877735],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1776.19764928,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.312307716888594,
                            48.78031379639698,
                            2.322201633670121,
                            48.793336296236205,
                        ),
                        "coordinates": [
                            [2.312307716888594, 48.78031379639698],
                            [2.312518129483469, 48.78073498320457],
                            [2.312577432652567, 48.78094556639586],
                            [2.312588161925085, 48.78109189825103],
                            [2.312593459906188, 48.78130247014825],
                            [2.312582580928953, 48.781463072775274],
                            [2.312571691976697, 48.78164508949107],
                            [2.312517458521404, 48.78211261790786],
                            [2.312386642048604, 48.78305863166844],
                            [2.312374311197217, 48.78323039010153],
                            [2.312375611136057, 48.783353591164534],
                            [2.312372825358335, 48.783483086181654],
                            [2.31238771693921, 48.78364405894849],
                            [2.312416225110177, 48.78378525100356],
                            [2.312478729612513, 48.78397591029854],
                            [2.312549637617946, 48.78415779193573],
                            [2.312649989442042, 48.7844022027594],
                            [2.313438576067882, 48.78590505168291],
                            [2.313494320822917, 48.78601657338726],
                            [2.313566392238163, 48.78613709031746],
                            [2.313764941439342, 48.78644378317275],
                            [2.314009736736321, 48.78680803805911],
                            [2.314274929262448, 48.78722085699711],
                            [2.314546924629037, 48.787644467541],
                            [2.314827092188519, 48.78806717976076],
                            [2.315022934758753, 48.788372970282516],
                            [2.315381987563249, 48.78893058747447],
                            [2.315488071990848, 48.789096973319715],
                            [2.31634370608703, 48.79044319743809],
                            [2.316768354656646, 48.79112138218416],
                            [2.316973481937481, 48.79145690296039],
                            [2.317137914769936, 48.79168717514915],
                            [2.317273952061505, 48.7918607580508],
                            [2.317430403695087, 48.792039740477556],
                            [2.31764673627239, 48.79223581782054],
                            [2.317863083529101, 48.79239862219223],
                            [2.318114818234135, 48.792564129306705],
                            [2.318380174185469, 48.79270805586168],
                            [2.31861288008957, 48.792810610073865],
                            [2.318890502517935, 48.792914069187965],
                            [2.319253871453089, 48.79302743377329],
                            [2.31955600652107, 48.79310121925106],
                            [2.319792817745865, 48.7931498148873],
                            [2.320018747871778, 48.793183121212024],
                            [2.320284149644076, 48.79321373484012],
                            [2.320503278966001, 48.79323265065819],
                            [2.320715602334735, 48.793249766353995],
                            [2.320933374218851, 48.793258788306396],
                            [2.321268196344529, 48.79327771876645],
                            [2.321555380995314, 48.793294842578945],
                            [2.321827593910072, 48.793311064981815],
                            [2.3221270288525, 48.79332998828729],
                            [2.322201633670121, 48.793336296236205],
                        ],
                    },
                },
                1479: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [49.06437757909368, 2.72208312985193],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 7811.02893931,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.69945308646072,
                            49.0325740895669,
                            2.744686207437996,
                            49.09612081072149,
                        ),
                        "coordinates": [
                            [2.69945308646072, 49.0325740895669],
                            [2.702669368485551, 49.036670656360904],
                            [2.706585976117261, 49.04164284464314],
                            [2.708844273363393, 49.044514561038376],
                            [2.709286516408457, 49.04508417167599],
                            [2.709666734898624, 49.045587358115355],
                            [2.709984893314095, 49.04601936706036],
                            [2.710387330557418, 49.04658672404211],
                            [2.710848516921564, 49.04726333563445],
                            [2.711438023799308, 49.04815367139899],
                            [2.717769982404683, 49.05769307714154],
                            [2.720572353378316, 49.06191423599426],
                            [2.729486360189672, 49.07533795999044],
                            [2.730366204722761, 49.076666725604724],
                            [2.73251030364449, 49.079888602399606],
                            [2.733541801844478, 49.081415682033104],
                            [2.73465314394954, 49.08308904425939],
                            [2.736808270580688, 49.08633153197838],
                            [2.737246216276035, 49.08698558167945],
                            [2.737613618590033, 49.087549948913704],
                            [2.739213361885679, 49.08997241603058],
                            [2.740146888119386, 49.091370975192994],
                            [2.740470225531092, 49.09183619253856],
                            [2.740864852063662, 49.09233446870444],
                            [2.741266576396518, 49.092769427718295],
                            [2.74162309771016, 49.09313301523283],
                            [2.744686207437996, 49.09612081072149],
                        ],
                    },
                },
                1480: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE P",
                        "rer": 0,
                        "extcode": "800:P",
                        "geo_point_2d": [48.88706461018841, 2.8406314599336078],
                        "indice_lig": "P",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01730",
                        "navette": 0,
                        "idrefliga": "A01844",
                        "shape_leng": 2300.11453513,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.826405497304068,
                            48.88268104666967,
                            2.854315926463895,
                            48.890856796314026,
                        ),
                        "coordinates": [
                            [2.826405497304068, 48.890856796314026],
                            [2.828109627719599, 48.89029571120087],
                            [2.830181328085556, 48.88961683903838],
                            [2.833494897683794, 48.888530230373526],
                            [2.834278169975499, 48.88827282305988],
                            [2.83549693328756, 48.887878838038574],
                            [2.835922188710759, 48.88775253784432],
                            [2.836352664039321, 48.887631328789936],
                            [2.836901854393411, 48.88749084521827],
                            [2.837373754018282, 48.887376269049554],
                            [2.837791590553476, 48.887284088539914],
                            [2.838297206493627, 48.887181292921426],
                            [2.838906113147297, 48.887067812020085],
                            [2.839479036920323, 48.88697494475018],
                            [2.839928140712233, 48.88690818945581],
                            [2.841577533586265, 48.88667248367306],
                            [2.848838249628895, 48.8856309867704],
                            [2.849501514004537, 48.88552913943682],
                            [2.84992202081599, 48.8854488355575],
                            [2.850362975342174, 48.88534627651727],
                            [2.850739274743056, 48.88524059833006],
                            [2.851074214411359, 48.885135104930185],
                            [2.851445060419211, 48.88500217345081],
                            [2.851820787635331, 48.88484194231902],
                            [2.852072890676682, 48.884724885570705],
                            [2.85236850635528, 48.88456672009391],
                            [2.852620319932025, 48.8844223896437],
                            [2.852866734757018, 48.88425592114007],
                            [2.853100100416383, 48.88407757882474],
                            [2.853292250204567, 48.8839130590367],
                            [2.853517505261642, 48.88370065930428],
                            [2.853727019238246, 48.88346616654684],
                            [2.853933696515699, 48.88320782315563],
                            [2.854315926463895, 48.88268104666967],
                        ],
                    },
                },
                1481: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.81472037497293, 2.0164666639083833],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 3965.75864441,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.992864535155556,
                            48.807246612101615,
                            2.040519204703665,
                            48.82365326874927,
                        ),
                        "coordinates": [
                            [1.992864535155556, 48.82365326874927],
                            [1.99288533932926, 48.823638516283985],
                            [1.993173968212166, 48.8234559323992],
                            [1.993801598424778, 48.823092712694276],
                            [1.994495853596732, 48.822744077281534],
                            [1.995058660200695, 48.82249666301098],
                            [1.995450628976955, 48.822335965982596],
                            [1.995647293475693, 48.82225561865065],
                            [1.996223460988295, 48.82204421060895],
                            [1.99816765014932, 48.82133057193942],
                            [1.998788828939766, 48.82110579537884],
                            [1.99970899187326, 48.82077128727937],
                            [1.99980864249568, 48.82073651006287],
                            [1.999906956427206, 48.82069813109099],
                            [2.000334289962784, 48.820539320188516],
                            [2.00269888196806, 48.81966497461229],
                            [2.002825836333504, 48.81961948293844],
                            [2.003216268131958, 48.81947763997557],
                            [2.003332298638633, 48.819436612271716],
                            [2.004833981501187, 48.81888433679842],
                            [2.006335638797191, 48.8183311428244],
                            [2.007969695173353, 48.817726153285854],
                            [2.009988623740037, 48.816984652894526],
                            [2.010156529473848, 48.81692218401139],
                            [2.011255416377446, 48.81651255617059],
                            [2.013790173841511, 48.81558630889112],
                            [2.015601490710889, 48.814916064795256],
                            [2.016769818577302, 48.81449308975608],
                            [2.017890390549869, 48.81408255929142],
                            [2.017899944647254, 48.81407898880855],
                            [2.019683798440779, 48.813427488165836],
                            [2.019737016227012, 48.813409650010065],
                            [2.019840752123614, 48.81337036998429],
                            [2.021384410911502, 48.81279731186423],
                            [2.022928021171722, 48.81222603045548],
                            [2.024471609455778, 48.81165293097308],
                            [2.025990540129969, 48.811097727791164],
                            [2.028189038378654, 48.81029434653903],
                            [2.028426482531518, 48.81020865800447],
                            [2.030353428070687, 48.80949083076688],
                            [2.030644101335289, 48.809382798778934],
                            [2.030960708364843, 48.80926404377657],
                            [2.031846204424275, 48.80896065986381],
                            [2.032050865970929, 48.80889016426948],
                            [2.032629226100943, 48.8087145503652],
                            [2.032701511268487, 48.8086940599197],
                            [2.033984760278743, 48.80835574858412],
                            [2.034390274715971, 48.808258936597746],
                            [2.034802815851451, 48.808166371304054],
                            [2.035482948039733, 48.808044070250574],
                            [2.035623337226263, 48.808018362189685],
                            [2.036428769588487, 48.80788829262692],
                            [2.037814735990416, 48.807668015720196],
                            [2.039798934711327, 48.807354857185835],
                            [2.040519204703665, 48.807246612101615],
                        ],
                    },
                },
                1482: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.66190377158619, 2.322200272894098],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2465.14936916,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.312736251060262,
                            48.65281140144265,
                            2.332622929210473,
                            48.66948372520816,
                        ),
                        "coordinates": [
                            [2.332622929210473, 48.66948372520816],
                            [2.332296788663631, 48.66942077887969],
                            [2.331653786157174, 48.66928037353886],
                            [2.331075447057345, 48.669137586771726],
                            [2.330665943623719, 48.66902097980732],
                            [2.330159455712163, 48.66887343509477],
                            [2.329821801425992, 48.668759207773284],
                            [2.329530846319508, 48.66865925904621],
                            [2.32921474739847, 48.66854265238589],
                            [2.328837587235284, 48.66840224752502],
                            [2.328438880597015, 48.668235666920424],
                            [2.327979114009102, 48.66803815051555],
                            [2.327720498987738, 48.667921543607704],
                            [2.327447495899119, 48.66779730903096],
                            [2.327120638710932, 48.667642626646305],
                            [2.326859506273298, 48.66750719502109],
                            [2.326337637124598, 48.66722142027909],
                            [2.325849170515177, 48.66694061560865],
                            [2.3253930394761, 48.66665743275124],
                            [2.325001563719769, 48.66639804891961],
                            [2.324523905063941, 48.6660529978715],
                            [2.324218640243014, 48.665826929837294],
                            [2.3238128255912, 48.665505678169986],
                            [2.323457305602836, 48.66517491307018],
                            [2.32303357396238, 48.66473944844091],
                            [2.322796582251215, 48.66446817726983],
                            [2.322625671222706, 48.66424164734318],
                            [2.322408803743226, 48.663949440308826],
                            [2.322243641483214, 48.66372814333286],
                            [2.322046174662046, 48.663440221300185],
                            [2.32176615057892, 48.66297621958201],
                            [2.321529234778441, 48.66250508372967],
                            [2.321339011815816, 48.66205060925855],
                            [2.321163174266132, 48.66154855046111],
                            [2.321026824852032, 48.66112263541551],
                            [2.32091559008354, 48.660787136795584],
                            [2.320782809463491, 48.660442118936366],
                            [2.320499281265241, 48.659799663841724],
                            [2.320226488214007, 48.659295210348226],
                            [2.319863954969306, 48.65866702019617],
                            [2.319372173117989, 48.65794363574333],
                            [2.318787031108134, 48.65721309657624],
                            [2.318603948531011, 48.65699654982629],
                            [2.318410087559867, 48.65679903681781],
                            [2.318079813646202, 48.6564492240343],
                            [2.317706454136176, 48.6560779890666],
                            [2.317318736979355, 48.65570913160594],
                            [2.31685920065073, 48.65533788036833],
                            [2.316360169027436, 48.654964240030665],
                            [2.315770771200066, 48.65453214106824],
                            [2.315295846296393, 48.654227201498145],
                            [2.314931305423895, 48.65398894754283],
                            [2.31456869679336, 48.65376522256193],
                            [2.314055291719007, 48.653481983890515],
                            [2.312992576625995, 48.65293928447645],
                            [2.312736251060262, 48.65281140144265],
                        ],
                    },
                },
                1483: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.70098871594943, 2.3933781192115724],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2979.62085903,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.382757203082266,
                            48.68969793365298,
                            2.403633104908493,
                            48.71262898747625,
                        ),
                        "coordinates": [
                            [2.382757203082266, 48.68969793365298],
                            [2.383045806984474, 48.68990339294061],
                            [2.383230663352005, 48.69004540272094],
                            [2.38345493979785, 48.69021796980802],
                            [2.384025918477654, 48.69074740314599],
                            [2.384494979877404, 48.69121752392339],
                            [2.384936890498618, 48.691695748125035],
                            [2.385571844184228, 48.69232856255648],
                            [2.386115722608555, 48.69287778020683],
                            [2.388439743080135, 48.69538570681775],
                            [2.389199942623788, 48.696188405541065],
                            [2.389924826868116, 48.696972231572516],
                            [2.390523270418308, 48.69763920728414],
                            [2.390955746082016, 48.69807964382771],
                            [2.391208720371253, 48.69835020305846],
                            [2.391541944909567, 48.698706153166206],
                            [2.392333599661923, 48.699605937312384],
                            [2.393121165310217, 48.700467948296954],
                            [2.39387341168129, 48.70130928933809],
                            [2.394578044363382, 48.702075110306524],
                            [2.395354774138076, 48.702899342748864],
                            [2.395813300584402, 48.703465645033965],
                            [2.396119453143499, 48.70385127241293],
                            [2.396779365218163, 48.7046539738991],
                            [2.397523664407638, 48.70556184101406],
                            [2.397633887097888, 48.70569937009275],
                            [2.39780262031756, 48.705907910418155],
                            [2.398790582515602, 48.707147467869454],
                            [2.399143026197246, 48.70757083148948],
                            [2.399769008776976, 48.708328569929],
                            [2.400420900819729, 48.70914474331237],
                            [2.400912159347558, 48.70971730056517],
                            [2.402222690553023, 48.711156499190864],
                            [2.402568361349131, 48.71155364541476],
                            [2.402816812970916, 48.711836640859524],
                            [2.403076020967614, 48.712095835821586],
                            [2.403390114759124, 48.71239119577324],
                            [2.403633104908493, 48.71262898747625],
                        ],
                    },
                },
                1484: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.829590814229746, 2.306428691903834],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 3287.91237839,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.292061814554318,
                            48.81838763956164,
                            2.320509227539884,
                            48.841186920243864,
                        ),
                        "coordinates": [
                            [2.292061814554318, 48.81838763956164],
                            [2.292063215351291, 48.81838838895092],
                            [2.292554771060914, 48.81865161255986],
                            [2.293235393541554, 48.819056361381406],
                            [2.294139273426576, 48.81963488165732],
                            [2.294801881437852, 48.82007054623802],
                            [2.2952938573242, 48.820437987625624],
                            [2.295885726493976, 48.82091377045482],
                            [2.296321399688822, 48.82130413649662],
                            [2.296850718517542, 48.821749259187285],
                            [2.297545684405248, 48.82234195481006],
                            [2.298071434702834, 48.82277041559989],
                            [2.299465078654862, 48.82390820243954],
                            [2.300945242268247, 48.82508406607587],
                            [2.303549153206343, 48.8272238682784],
                            [2.305288812554795, 48.82866385421778],
                            [2.306380208050093, 48.829558777861976],
                            [2.307323957912953, 48.830329927679344],
                            [2.309290836804992, 48.83186270435911],
                            [2.310022123292139, 48.83246722754302],
                            [2.310436406341613, 48.832809946388],
                            [2.310857899660154, 48.833162182809986],
                            [2.311582025943372, 48.83375003926354],
                            [2.312893438726868, 48.83477819039799],
                            [2.314255341069606, 48.83586343947946],
                            [2.314568807512882, 48.83610381335719],
                            [2.31484984447211, 48.836329903848586],
                            [2.315250124707188, 48.836680150934235],
                            [2.316400888248523, 48.83771801315104],
                            [2.31680803621099, 48.83809639901349],
                            [2.318112438906453, 48.839186352114176],
                            [2.320509227539884, 48.841186920243864],
                        ],
                    },
                },
                1485: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.620881306919074, 2.3068372804199155],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 3328.50757854,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.302059691582639,
                            48.60674494894811,
                            2.308841734746331,
                            48.63587586133943,
                        ),
                        "coordinates": [
                            [2.306833164014825, 48.63587586133943],
                            [2.307030374826495, 48.63462527064926],
                            [2.30717380077652, 48.63368618466834],
                            [2.307277314218528, 48.633008166481204],
                            [2.307382922215318, 48.632275039515875],
                            [2.307612452251724, 48.630645887326075],
                            [2.307750017598194, 48.6297142845968],
                            [2.307914861653962, 48.62852100444024],
                            [2.308267717822225, 48.62590603522561],
                            [2.308439331169083, 48.62469207282878],
                            [2.308748394611611, 48.62272324378916],
                            [2.308800300469259, 48.62232353345129],
                            [2.308834980221083, 48.621919536550266],
                            [2.308841734746331, 48.62139561477266],
                            [2.308816148021596, 48.620945920291376],
                            [2.308773381828687, 48.62041342144164],
                            [2.30873357795134, 48.620078027638165],
                            [2.308657864312481, 48.619648160758054],
                            [2.308558746733582, 48.61923419838383],
                            [2.308463245795803, 48.61888838253313],
                            [2.308337077188706, 48.618477241894105],
                            [2.308117682759952, 48.61790525586545],
                            [2.307937526977359, 48.61750144147813],
                            [2.307780876322851, 48.617176005394406],
                            [2.307555499278999, 48.616740568374766],
                            [2.306613939002589, 48.6150065456005],
                            [2.306109993412017, 48.61407747368937],
                            [2.305192934512777, 48.61235963316916],
                            [2.304909832188939, 48.61183708307746],
                            [2.304238856573783, 48.610594593989894],
                            [2.30364940737448, 48.60956671102588],
                            [2.303210751644092, 48.608807110806396],
                            [2.30293551347242, 48.60834734827669],
                            [2.302733394480765, 48.60799895894463],
                            [2.302354970072312, 48.607343585276624],
                            [2.302059691582639, 48.60674494894811],
                        ],
                    },
                },
                1486: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.67003972308248, 2.338573416745282],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 889.84312629,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332622929210473,
                            48.66948372520816,
                            2.344492790482471,
                            48.670783940999655,
                        ),
                        "coordinates": [
                            [2.344492790482471, 48.670783940999655],
                            [2.344000616577513, 48.67065073289476],
                            [2.343452536635048, 48.67051690183254],
                            [2.343045018523067, 48.670429513991444],
                            [2.342513337894879, 48.670329610743806],
                            [2.342035549685687, 48.670263013236685],
                            [2.341385884934257, 48.67019197883171],
                            [2.340880805352075, 48.670146135636],
                            [2.34021279968859, 48.67009579970791],
                            [2.33975117009595, 48.6700688351794],
                            [2.336582378460657, 48.66989196734917],
                            [2.335684299785311, 48.66984199761172],
                            [2.335264000352498, 48.66981344068433],
                            [2.334886809428474, 48.669782505244534],
                            [2.334283283091729, 48.66972966051765],
                            [2.333924076383457, 48.669689692530945],
                            [2.333500189677468, 48.669632578105414],
                            [2.33308708014005, 48.66956832376093],
                            [2.332753002791134, 48.669508830645235],
                            [2.332622929210473, 48.66948372520816],
                        ],
                    },
                },
                1487: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.91549666431126, 2.3578173457379856],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 925.627395173,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.35307378633796,
                            48.912728022078205,
                            2.362665598830465,
                            48.9181138030661,
                        ),
                        "coordinates": [
                            [2.35307378633796, 48.912728022078205],
                            [2.353250726293694, 48.91290168899872],
                            [2.353413217384326, 48.913042045626646],
                            [2.353608203857694, 48.913194294391865],
                            [2.353886235519248, 48.91339411698931],
                            [2.354084823170449, 48.91351543297699],
                            [2.354352010214886, 48.913665290853174],
                            [2.354843052535474, 48.91391266391197],
                            [2.355391879240095, 48.91421237233093],
                            [2.356077914021508, 48.91457153659441],
                            [2.357258650022995, 48.915211372236534],
                            [2.359176046589199, 48.916226987040226],
                            [2.361057416606341, 48.91723781822859],
                            [2.362665598830465, 48.9181138030661],
                        ],
                    },
                },
                1488: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.927531565634325, 2.4060922439431613],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 2973.3485505,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.386388291064694,
                            48.92435387966092,
                            2.425791425559954,
                            48.93073957031752,
                        ),
                        "coordinates": [
                            [2.386388291064694, 48.92435387966092],
                            [2.389018133977532, 48.92478587365258],
                            [2.392434522542798, 48.92533388242894],
                            [2.395446508129437, 48.92582965320484],
                            [2.397133090234305, 48.92609525835423],
                            [2.398863006496915, 48.9263512970188],
                            [2.401131064422231, 48.92668553071205],
                            [2.402452937452991, 48.926901301573565],
                            [2.404948641933777, 48.927313850034764],
                            [2.410962349463101, 48.92831419740778],
                            [2.413640642494941, 48.92875601693751],
                            [2.417329632422147, 48.929355067842664],
                            [2.420180742751204, 48.929829553573626],
                            [2.421591578284466, 48.93005923482367],
                            [2.423738953800848, 48.93040693302665],
                            [2.425791425559954, 48.93073957031752],
                        ],
                    },
                },
                1489: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.93221685583283, 2.5017760037516448],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 917.861437564,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.495513142584314,
                            48.93219600596196,
                            2.508038741924935,
                            48.9322501569209,
                        ),
                        "coordinates": [
                            [2.495513142584314, 48.93219600596196],
                            [2.496840135010492, 48.93222232191138],
                            [2.497785955199344, 48.932229620949464],
                            [2.498829914690119, 48.932223834707656],
                            [2.504747939281772, 48.932200278608676],
                            [2.505691099886219, 48.93220436669105],
                            [2.507153726961957, 48.93224052521622],
                            [2.508038741924935, 48.9322501569209],
                        ],
                    },
                },
                1490: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M8",
                        "rer": 0,
                        "extcode": "100110008:8",
                        "geo_point_2d": [48.83826458514613, 2.399251280304063],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01378",
                        "navette": 0,
                        "idrefliga": "A01541",
                        "shape_leng": 520.536225771,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.396182886452633,
                            48.83711700698871,
                            2.402333164555186,
                            48.839445428379506,
                        ),
                        "coordinates": [
                            [2.402333164555186, 48.83711700698871],
                            [2.401268024336948, 48.837509011278186],
                            [2.400990470216403, 48.83761115714669],
                            [2.396760868883154, 48.839195202227096],
                            [2.396583228836672, 48.83926474153598],
                            [2.396379965004696, 48.839352099830975],
                            [2.396182886452633, 48.839445428379506],
                        ],
                    },
                },
                1491: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.68305239679522, 2.3676079915120343],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 2706.5412615,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352481401048998,
                            48.676446656997726,
                            2.382757203082266,
                            48.68969793365298,
                        ),
                        "coordinates": [
                            [2.352481401048998, 48.676446656997726],
                            [2.352651710635371, 48.676611194955726],
                            [2.352968137765413, 48.676883253100854],
                            [2.353598371553556, 48.67736336978714],
                            [2.354080550656454, 48.67769512658065],
                            [2.354733699512631, 48.67809203212078],
                            [2.355333834707852, 48.67841314223769],
                            [2.355893769256218, 48.67867413588618],
                            [2.356466925031537, 48.67891773907016],
                            [2.356770974291829, 48.679041341532646],
                            [2.357072676012722, 48.67915503885028],
                            [2.357351910387353, 48.679254329499415],
                            [2.357633701449175, 48.67935257185632],
                            [2.358043358131362, 48.67948335743325],
                            [2.358302089057277, 48.67956420652395],
                            [2.358550040447846, 48.67963791717336],
                            [2.358866264717556, 48.67972589062563],
                            [2.359225608812028, 48.67981861398919],
                            [2.359761028415913, 48.67994461033868],
                            [2.360329534296937, 48.68007435902309],
                            [2.360932470570231, 48.68021749939525],
                            [2.361503833830279, 48.68035299737065],
                            [2.36184521812357, 48.68043619802744],
                            [2.362175820604817, 48.68051464199508],
                            [2.362409400013626, 48.68057407190389],
                            [2.36265736285523, 48.680650154000254],
                            [2.362952044943171, 48.680742880151506],
                            [2.363271883412531, 48.68084273701301],
                            [2.363523448957911, 48.68093071245555],
                            [2.363814547340856, 48.681035333723756],
                            [2.364173940603852, 48.681182764377915],
                            [2.364483016886978, 48.68130403400878],
                            [2.364971794667307, 48.68150139774188],
                            [2.36547136498358, 48.68171303144649],
                            [2.36578405258717, 48.68185333109283],
                            [2.366103925304415, 48.68199124936919],
                            [2.366466942603685, 48.68216722481026],
                            [2.366758083280973, 48.68231942448375],
                            [2.366959375894221, 48.68243833590251],
                            [2.367243339037844, 48.68260243332113],
                            [2.367469798856948, 48.68274037288902],
                            [2.367760957277161, 48.68291160412782],
                            [2.368059310811836, 48.683092350634624],
                            [2.368350488591731, 48.68328737456252],
                            [2.368612906265408, 48.68345623233758],
                            [2.368904079792835, 48.68363697817642],
                            [2.369166493762556, 48.68379393805232],
                            [2.369450472553815, 48.683958030034155],
                            [2.369730860075062, 48.68412212121583],
                            [2.370362016312544, 48.68445883056417],
                            [2.371006933646718, 48.68475940117238],
                            [2.371671910468043, 48.68504471697853],
                            [2.372390799871556, 48.68533477055899],
                            [2.373131245413605, 48.68560815673932],
                            [2.373775282734897, 48.68581978797649],
                            [2.374087336073916, 48.68592436399419],
                            [2.37434992310769, 48.6860039492812],
                            [2.374860705818699, 48.6861530574915],
                            [2.375603774728401, 48.686348846074864],
                            [2.376991511385021, 48.68672513374018],
                            [2.377465966812344, 48.686860586385485],
                            [2.377954820330918, 48.687019824363254],
                            [2.378508397119493, 48.68722424398286],
                            [2.379083571683295, 48.68746196250001],
                            [2.379601250329117, 48.687699700193626],
                            [2.380038646964371, 48.68791431984325],
                            [2.380633434791751, 48.68826138717864],
                            [2.382057704915416, 48.689197865937366],
                            [2.382407004307814, 48.689448621645965],
                            [2.382757203082266, 48.68969793365298],
                        ],
                    },
                },
                1492: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.758049042899664, 2.4346175166226756],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 2989.06693123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.433437421055713,
                            48.745230819408114,
                            2.438344239163614,
                            48.771266038121055,
                        ),
                        "coordinates": [
                            [2.438344239163614, 48.745230819408114],
                            [2.438273437857284, 48.745438709334884],
                            [2.438184096111448, 48.7457338260805],
                            [2.437969742303037, 48.74647874632876],
                            [2.43783754994237, 48.74693569602271],
                            [2.437733859271531, 48.74725461899908],
                            [2.437619329574165, 48.74755213737636],
                            [2.437508295033156, 48.747799685309374],
                            [2.437375710285186, 48.74806628850716],
                            [2.4371677731604, 48.74843526830044],
                            [2.436992015157528, 48.748704287466246],
                            [2.436823368444851, 48.748932852049585],
                            [2.43662955448261, 48.74917095568656],
                            [2.436371097049091, 48.74947097724524],
                            [2.435477185273351, 48.750480593926376],
                            [2.434870421722178, 48.751149711661746],
                            [2.434626308838914, 48.751435442046734],
                            [2.434403841699777, 48.751752084286196],
                            [2.434256798804391, 48.751999661119584],
                            [2.434131336835575, 48.752242460603284],
                            [2.434016731663686, 48.752518561377215],
                            [2.433952395286144, 48.75273989404596],
                            [2.433902488034662, 48.75298024865708],
                            [2.433874050444429, 48.75315872192501],
                            [2.433852837131601, 48.75335146642632],
                            [2.433846200429141, 48.75363937180893],
                            [2.433843154641313, 48.75392251459625],
                            [2.433851005477436, 48.75425799347498],
                            [2.433867417614227, 48.755292988377406],
                            [2.433871865888324, 48.75572840194772],
                            [2.433875961182599, 48.75598298628363],
                            [2.433876318366639, 48.756166194349106],
                            [2.433873216263952, 48.756420785841875],
                            [2.433817539681058, 48.75739635935004],
                            [2.433782745886303, 48.75800787740011],
                            [2.433713047511272, 48.759176187575164],
                            [2.433674716106457, 48.75982101953141],
                            [2.433619936619943, 48.76126056113242],
                            [2.433583295696, 48.76247957656717],
                            [2.433532294449451, 48.76407382361093],
                            [2.433527186465675, 48.764233480205604],
                            [2.433512045902057, 48.76470669175702],
                            [2.433457583756447, 48.76631516693117],
                            [2.433443893475024, 48.766679216121894],
                            [2.433437421055713, 48.76705277657283],
                            [2.43344875507995, 48.76732876915579],
                            [2.433470809000831, 48.76756430466045],
                            [2.433514528618688, 48.76783551112151],
                            [2.433547208387588, 48.76798300192939],
                            [2.433605313186639, 48.768247058669225],
                            [2.433692268519418, 48.768539642109744],
                            [2.433779131488626, 48.76878463877218],
                            [2.433880422467193, 48.769043900042725],
                            [2.433981629199955, 48.76926033248583],
                            [2.434100817640164, 48.76946723255786],
                            [2.434173058136915, 48.769595653939426],
                            [2.434266951982867, 48.76975261006521],
                            [2.434447454992141, 48.77002131901292],
                            [2.434761484095578, 48.77046360488249],
                            [2.435028593570148, 48.77083930919318],
                            [2.435158556251428, 48.77102954326885],
                            [2.435306339706323, 48.771266038121055],
                        ],
                    },
                },
                1493: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.792776166509405, 2.055443621894834],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 1973.87572994,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.04462198987871,
                            48.7873902392018,
                            2.066485347074011,
                            48.79761321151646,
                        ),
                        "coordinates": [
                            [2.04462198987871, 48.7873902392018],
                            [2.044851105628235, 48.78750349640637],
                            [2.046741304126305, 48.78844003846329],
                            [2.047258327554183, 48.78869832312603],
                            [2.048565214852195, 48.78936071667585],
                            [2.049383771745726, 48.78978630894997],
                            [2.051178973182095, 48.79070687265457],
                            [2.052959877315797, 48.79162023425542],
                            [2.054245460494912, 48.792256337309674],
                            [2.058741619891684, 48.794489710908344],
                            [2.061679413663929, 48.79595062396591],
                            [2.062070911434097, 48.79614191596519],
                            [2.062516342039329, 48.79634999307187],
                            [2.062907965074912, 48.79651986861153],
                            [2.063242176986505, 48.796651535583436],
                            [2.063705846985577, 48.79681920285661],
                            [2.064173185834679, 48.79697497863914],
                            [2.064637031043277, 48.797111711223465],
                            [2.066485347074011, 48.79761321151646],
                        ],
                    },
                },
                1494: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.5487902171526, 2.2921731814414175],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 3696.92764064,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.290082513840396,
                            48.532890103244725,
                            2.293345838644037,
                            48.565593862821814,
                        ),
                        "coordinates": [
                            [2.290924468489718, 48.565593862821814],
                            [2.290972006789592, 48.56509546162683],
                            [2.291148000784847, 48.56321825008443],
                            [2.291297998710955, 48.56163874002049],
                            [2.291574827260926, 48.55879638260679],
                            [2.291716157634594, 48.557296510204196],
                            [2.291929536551554, 48.555077992546174],
                            [2.292039101985673, 48.553938393509846],
                            [2.292142942379187, 48.552808274246324],
                            [2.29223821542927, 48.55167056703662],
                            [2.292330633024033, 48.55052716981879],
                            [2.29247494684281, 48.54883198676967],
                            [2.292578771243155, 48.54769617977506],
                            [2.292737312139606, 48.54604082317767],
                            [2.292846832334936, 48.54491070670284],
                            [2.293025395188173, 48.5431984712315],
                            [2.293189658953251, 48.54149760819737],
                            [2.293299152455664, 48.540375076162796],
                            [2.293339624970796, 48.53980621955245],
                            [2.293345838644037, 48.53922976526901],
                            [2.293334903723072, 48.538670371374145],
                            [2.293286793866014, 48.5381735375931],
                            [2.293230100977195, 48.53769566383412],
                            [2.293144795015966, 48.53728793977789],
                            [2.293062266209859, 48.53697123570309],
                            [2.292954038609729, 48.536654522602966],
                            [2.292797336868192, 48.53626573277849],
                            [2.29260922842184, 48.535876931181676],
                            [2.292389711432258, 48.53549001221115],
                            [2.292144486379712, 48.535120149043685],
                            [2.291859291505608, 48.53475027028643],
                            [2.291565504082937, 48.53441451904097],
                            [2.291149043743194, 48.533970632854846],
                            [2.290826703998391, 48.53364624580547],
                            [2.290433058581351, 48.53324597882319],
                            [2.290082513840396, 48.532890103244725],
                        ],
                    },
                },
                1495: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.84274008653178, 2.2734880252814365],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 917.935919265,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.270458243787242,
                            48.83908975542995,
                            2.276760967379574,
                            48.84619214048855,
                        ),
                        "coordinates": [
                            [2.276760967379574, 48.84619214048855],
                            [2.27640528039278, 48.845900076003126],
                            [2.276248761905203, 48.84575880632776],
                            [2.276048715764371, 48.84555906146355],
                            [2.275758873341016, 48.84525405204969],
                            [2.27521189487021, 48.8446485459268],
                            [2.274668449793864, 48.84405862639776],
                            [2.274150611499837, 48.84348880290342],
                            [2.273792751069634, 48.84311990317913],
                            [2.273100203459649, 48.84238660911527],
                            [2.272172288952394, 48.84141397065998],
                            [2.271792048236195, 48.841013583918645],
                            [2.271680467423908, 48.840887415272164],
                            [2.27158330340678, 48.84076363398678],
                            [2.271478953749894, 48.84062319384473],
                            [2.271407014557938, 48.84050656491617],
                            [2.271331500660505, 48.84036614014792],
                            [2.271245194079831, 48.84021143408095],
                            [2.271133725710957, 48.840004367835625],
                            [2.27100788249679, 48.839763982014965],
                            [2.270707708565289, 48.839361884557206],
                            [2.270458243787242, 48.83908975542995],
                        ],
                    },
                },
                1496: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.731852810439946, 2.267089525473667],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 764.630107751,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263073689251946,
                            48.72964839824706,
                            2.271186213048966,
                            48.73385117840906,
                        ),
                        "coordinates": [
                            [2.263073689251946, 48.72964839824706],
                            [2.263780803303505, 48.72997807971013],
                            [2.264330728328628, 48.7302282616453],
                            [2.264772813360702, 48.73044030344223],
                            [2.265275667283824, 48.7307172430537],
                            [2.265669558141648, 48.73094770426779],
                            [2.266063437781901, 48.731189854315865],
                            [2.266580415573251, 48.731526409288755],
                            [2.267092883857536, 48.731887427348006],
                            [2.267477224061654, 48.732155645835896],
                            [2.267713658471377, 48.732321335835614],
                            [2.267997593410009, 48.73252095186934],
                            [2.268239123627565, 48.732691174691105],
                            [2.268379013233885, 48.73278748174654],
                            [2.268584124577665, 48.7329072081117],
                            [2.268806902787484, 48.73303234103279],
                            [2.269002533673032, 48.73312688132901],
                            [2.269255248686636, 48.73323224674788],
                            [2.269491673615637, 48.73332051578235],
                            [2.269758006001752, 48.73340970126169],
                            [2.270145698147873, 48.73352865461254],
                            [2.270574346671643, 48.73365300545505],
                            [2.271186213048966, 48.73385117840906],
                        ],
                    },
                },
                1497: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.7359277254377, 2.277239712218349],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 610.842024942,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.273483464396533,
                            48.734716586800225,
                            2.281050094857402,
                            48.736934177101105,
                        ),
                        "coordinates": [
                            [2.273483464396533, 48.734716586800225],
                            [2.274031620340385, 48.73489774142893],
                            [2.275473449753474, 48.73538233747892],
                            [2.276333671280968, 48.73566876733563],
                            [2.276904428808763, 48.73586780974144],
                            [2.277130016218571, 48.73594616481338],
                            [2.277400450874468, 48.736038931251876],
                            [2.278114751585832, 48.73629061184682],
                            [2.278288585868304, 48.73634661778088],
                            [2.278468848814772, 48.736401603656944],
                            [2.278655448101448, 48.73645132616507],
                            [2.278824707294772, 48.736493872116554],
                            [2.27896942208531, 48.73652677404454],
                            [2.27917117419971, 48.73656756304211],
                            [2.279459465816022, 48.73662002100706],
                            [2.279772100456614, 48.73667323497265],
                            [2.280207071036519, 48.73674719326826],
                            [2.280557756121379, 48.73681571212309],
                            [2.28079833681008, 48.736868888460535],
                            [2.281050094857402, 48.736934177101105],
                        ],
                    },
                },
                1498: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.79555547220965, 2.139090971211456],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 450.857659874,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.136050489663708,
                            48.79528024627206,
                            2.142141851963426,
                            48.795715917344765,
                        ),
                        "coordinates": [
                            [2.136050489663708, 48.79528024627206],
                            [2.136078615729023, 48.795284586940234],
                            [2.136184386259406, 48.79530090881185],
                            [2.136923051747886, 48.79540922138856],
                            [2.137193773686322, 48.79544566723029],
                            [2.137540717011488, 48.7954831446176],
                            [2.137935303232737, 48.79551980530034],
                            [2.138672898157999, 48.79555706102029],
                            [2.139428190102225, 48.79559434337222],
                            [2.141261337567381, 48.79567663989319],
                            [2.142141851963426, 48.795715917344765],
                        ],
                    },
                },
                1499: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M10",
                        "rer": 0,
                        "extcode": "100110010:10",
                        "geo_point_2d": [48.8463246064327, 2.281856008706449],
                        "indice_lig": "10",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01380",
                        "navette": 0,
                        "idrefliga": "A01543",
                        "shape_leng": 609.884234675,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.27771230631379,
                            48.84612369457793,
                            2.285999222059007,
                            48.84653463673119,
                        ),
                        "coordinates": [
                            [2.285999222059007, 48.84653463673119],
                            [2.285008359441256, 48.84647630135761],
                            [2.282241091696688, 48.84634261931395],
                            [2.278622377938214, 48.846167701848614],
                            [2.27771230631379, 48.84612369457793],
                        ],
                    },
                },
                1500: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89105729420857, 2.397455131943946],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 678.623998201,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.39557220941337,
                            48.88900764950694,
                            2.39852783938677,
                            48.89388028252993,
                        ),
                        "coordinates": [
                            [2.395681074711603, 48.88900764950694],
                            [2.395607051593033, 48.88926497535537],
                            [2.395580929597121, 48.889370491188686],
                            [2.395574095922421, 48.88939972418179],
                            [2.395573772778498, 48.88942756191666],
                            [2.39557220941337, 48.88946895694193],
                            [2.395577249098973, 48.88950110520864],
                            [2.395582395144031, 48.88952397392353],
                            [2.395599291668168, 48.88956046460037],
                            [2.395654003276828, 48.889634914892085],
                            [2.395721058975073, 48.88970170498508],
                            [2.395775857519928, 48.88973695967611],
                            [2.395841506152829, 48.889770126904445],
                            [2.395915831003113, 48.88980191154433],
                            [2.395972456852261, 48.88981968538128],
                            [2.396435443173253, 48.88994158817537],
                            [2.397979023450783, 48.89034193871283],
                            [2.398157932923125, 48.8903945912031],
                            [2.398220808247738, 48.89041810694837],
                            [2.398287175202982, 48.89045175305242],
                            [2.398337333137883, 48.89048293807659],
                            [2.398377582355018, 48.89051288349555],
                            [2.398415964182958, 48.89054817316644],
                            [2.398470241826432, 48.89061328586385],
                            [2.398501972977102, 48.89067769082893],
                            [2.398516041232675, 48.890709288929365],
                            [2.398523796755709, 48.89074085531846],
                            [2.39852783938677, 48.8907813270003],
                            [2.398525554167831, 48.89082295579585],
                            [2.398522394998458, 48.890862200601674],
                            [2.398512830998047, 48.89090914647867],
                            [2.398485312921162, 48.89100573360603],
                            [2.3977994705343, 48.893646807296925],
                            [2.397738850646979, 48.89388028252993],
                        ],
                    },
                },
                1501: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.822356454878886, 2.329428351401183],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 604.221844257,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.325509577822384,
                            48.82150891739615,
                            2.333339832857646,
                            48.82315163312808,
                        ),
                        "coordinates": [
                            [2.325509577822384, 48.82315163312808],
                            [2.326539617964447, 48.82291810438619],
                            [2.326696685193155, 48.822888845217435],
                            [2.326792691814314, 48.8228774878401],
                            [2.326871297140492, 48.82287412236353],
                            [2.327007577837537, 48.82286965502499],
                            [2.327135955157648, 48.82286323817189],
                            [2.327227625155516, 48.82285280758902],
                            [2.327372799748276, 48.82282935268072],
                            [2.327570867418367, 48.82278430141329],
                            [2.32798937993435, 48.82269146991572],
                            [2.329034137320272, 48.82245970763791],
                            [2.330049295738674, 48.82223520739089],
                            [2.330665409761472, 48.82210090754522],
                            [2.33300956015286, 48.821582276484655],
                            [2.333339832857646, 48.82150891739615],
                        ],
                    },
                },
                1502: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.833564090586336, 2.2860584511340343],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 352.793269466,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.284007243303418,
                            48.83267687187787,
                            2.288069457597242,
                            48.83435816545286,
                        ),
                        "coordinates": [
                            [2.284007243303418, 48.83435816545286],
                            [2.284843960213089, 48.8340563572796],
                            [2.285792071951544, 48.83371435699311],
                            [2.286070423407089, 48.833603225333164],
                            [2.286248758214755, 48.83353076028029],
                            [2.28671321488788, 48.83333221644874],
                            [2.286911245624788, 48.833242734739386],
                            [2.287046249540378, 48.83317572028152],
                            [2.287184603913188, 48.83310087318106],
                            [2.287326388089217, 48.833012483756335],
                            [2.28742118053174, 48.83296022096629],
                            [2.287524621458467, 48.83290800961863],
                            [2.287629584628226, 48.83286192480688],
                            [2.287725120624473, 48.83282230154392],
                            [2.288069457597242, 48.83267687187787],
                        ],
                    },
                },
                1503: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.823952993017905, 2.3221760305282926],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 520.898297641,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.318829692620227,
                            48.82315163312808,
                            2.325509577822384,
                            48.824711018803754,
                        ),
                        "coordinates": [
                            [2.318829692620227, 48.824711018803754],
                            [2.319193251824705, 48.82463045678805],
                            [2.319716872476494, 48.82451505036298],
                            [2.321417862640702, 48.82413773035869],
                            [2.322374299308383, 48.8239251216185],
                            [2.323106186758516, 48.82376269333863],
                            [2.323489253793088, 48.823680979452156],
                            [2.32386430686648, 48.823591782950054],
                            [2.324055674527656, 48.82352891257127],
                            [2.324220099607042, 48.82345934663755],
                            [2.324404721203489, 48.8233955444896],
                            [2.32453814168439, 48.8233656437071],
                            [2.325509577822384, 48.82315163312808],
                        ],
                    },
                },
                1504: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.765712674778406, 2.368151187672823],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 549.770535894,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.36779053573481,
                            48.763375152982455,
                            2.368286437029008,
                            48.76822178037075,
                        ),
                        "coordinates": [
                            [2.36779053573481, 48.763375152982455],
                            [2.368034039175843, 48.763599627384544],
                            [2.368135122757792, 48.76369439931107],
                            [2.368209045883692, 48.7637728459457],
                            [2.368245812386709, 48.76382824974177],
                            [2.368268214828294, 48.763880721881094],
                            [2.368283246527272, 48.76394743427763],
                            [2.368286437029008, 48.76404073665589],
                            [2.36826942425776, 48.76437571243474],
                            [2.368203145875424, 48.765450047037604],
                            [2.368041520670991, 48.76822178037075],
                        ],
                    },
                },
                1505: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.829241942271956, 2.2982552229104534],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 402.070726172,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.295661982822295,
                            48.82867193954727,
                            2.300851826132675,
                            48.82982637901667,
                        ),
                        "coordinates": [
                            [2.295661982822295, 48.82982637901667],
                            [2.295879475615844, 48.82976906699559],
                            [2.296105790617629, 48.82971804818833],
                            [2.296759941569041, 48.82957277412794],
                            [2.298740946324668, 48.82913136869585],
                            [2.299045669401167, 48.829065335646085],
                            [2.300543639526568, 48.82873858110735],
                            [2.300851826132675, 48.82867193954727],
                        ],
                    },
                },
                1506: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89730948664646, 2.390841683274731],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 644.596149042,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.38658143311372,
                            48.89693775969607,
                            2.395041749682104,
                            48.897432849464856,
                        ),
                        "coordinates": [
                            [2.395041749682104, 48.897432849464856],
                            [2.394598854873905, 48.89740872030357],
                            [2.393395660706164, 48.89734552553767],
                            [2.393299057996128, 48.897335518748484],
                            [2.393219856013449, 48.89731893702615],
                            [2.393165170006011, 48.897304383326315],
                            [2.393103323056537, 48.89728503414137],
                            [2.393044417656895, 48.89726094156008],
                            [2.39298842190372, 48.89723495984832],
                            [2.392948325658948, 48.89720715485517],
                            [2.392893918664949, 48.897168808383384],
                            [2.39283248129136, 48.89711424577676],
                            [2.392759574946711, 48.897052961961364],
                            [2.392725209317884, 48.89702899364221],
                            [2.392700869802586, 48.897011738277385],
                            [2.392672179079234, 48.89699636379098],
                            [2.392610375725567, 48.89697320776575],
                            [2.392564339914771, 48.896959650029736],
                            [2.392513930698625, 48.8969498759909],
                            [2.392462054903742, 48.896941999239075],
                            [2.392412998506548, 48.896939846517164],
                            [2.392376934633518, 48.89693775969607],
                            [2.392335062670987, 48.89693849961693],
                            [2.392248288310272, 48.896952335907436],
                            [2.392157105736437, 48.896972811883835],
                            [2.392048445934587, 48.89700652421443],
                            [2.391805042101367, 48.89708238208505],
                            [2.391522709782244, 48.897154234878805],
                            [2.391153744878112, 48.89722755045582],
                            [2.390754567642249, 48.897292144333974],
                            [2.390349804070821, 48.8973405288787],
                            [2.389985757667388, 48.89736342065155],
                            [2.389558165515077, 48.89738884365351],
                            [2.389381949611924, 48.897397463661534],
                            [2.389124898643553, 48.89740567021397],
                            [2.388983383217812, 48.89740970745916],
                            [2.388304870195828, 48.89741290588982],
                            [2.38658143311372, 48.89742873557869],
                        ],
                    },
                },
                1507: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.8870606636051, 2.396342896639675],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 454.111964854,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.395681074711603,
                            48.885016789193514,
                            2.396751288803897,
                            48.88900764950694,
                        ),
                        "coordinates": [
                            [2.396751288803897, 48.885016789193514],
                            [2.396717024527988, 48.88524920869868],
                            [2.396607627278079, 48.88594054661692],
                            [2.396529888265382, 48.886484100485795],
                            [2.396502041540912, 48.88664528784616],
                            [2.396464807514807, 48.88686924554023],
                            [2.396407444060713, 48.88714878055078],
                            [2.396359527921665, 48.88735514478465],
                            [2.396136875145937, 48.88816637050284],
                            [2.396113374226313, 48.888232638992136],
                            [2.396097823722312, 48.88826682471033],
                            [2.396083429102873, 48.88829459150336],
                            [2.39606362340266, 48.888322331001795],
                            [2.396042766664905, 48.88834721074901],
                            [2.396017589888968, 48.888371353740716],
                            [2.395991305481988, 48.88839763332276],
                            [2.395961774130225, 48.88842389651892],
                            [2.395935539358061, 48.888445892870884],
                            [2.395895075402751, 48.88848138099201],
                            [2.395867625304918, 48.888514792576366],
                            [2.395828078369334, 48.88856456202387],
                            [2.395803701178, 48.88861297988098],
                            [2.395788208333744, 48.888642169211444],
                            [2.395776118362847, 48.88867626891686],
                            [2.39575509709845, 48.88875032355244],
                            [2.395681074711603, 48.88900764950694],
                        ],
                    },
                },
                1508: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.83361261934133, 2.402573654870787],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 729.11744661,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.398350103858007,
                            48.831993087108515,
                            2.406657147135102,
                            48.8355222083493,
                        ),
                        "coordinates": [
                            [2.398350103858007, 48.831993087108515],
                            [2.39869312714813, 48.832135802287254],
                            [2.398900294164674, 48.83222131845308],
                            [2.399007025265789, 48.832264687145006],
                            [2.399187360398282, 48.83233281632091],
                            [2.399749094753739, 48.83253730621117],
                            [2.400717611276693, 48.83288125270989],
                            [2.401532487533407, 48.83317135816234],
                            [2.402494189155415, 48.8335145417672],
                            [2.404358287304835, 48.83418916802383],
                            [2.404662760597016, 48.834324892457936],
                            [2.404901342395635, 48.83445457641379],
                            [2.405150519151228, 48.8346035868386],
                            [2.40532017538498, 48.83470865597224],
                            [2.405718299107428, 48.83494899673847],
                            [2.406349193797894, 48.835326971837894],
                            [2.406657147135102, 48.8355222083493],
                        ],
                    },
                },
                1509: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93673538662796, 2.3485751313898127],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 366.717866751,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.34644376242267,
                            48.93613469226443,
                            2.350400018540065,
                            48.93750989644162,
                        ),
                        "coordinates": [
                            [2.350400018540065, 48.93750989644162],
                            [2.35024007846667, 48.93702760711193],
                            [2.350208293097548, 48.93697475196173],
                            [2.350170679362546, 48.93693433199337],
                            [2.35012393221469, 48.93689828427512],
                            [2.35006919944172, 48.936867499917625],
                            [2.35000783117432, 48.93684273443789],
                            [2.349941337686147, 48.93682459853873],
                            [2.349871355518788, 48.936813538141905],
                            [2.349799610720771, 48.936809826995216],
                            [2.349727865764831, 48.93681355469448],
                            [2.349701825576966, 48.93681678663092],
                            [2.349044058167084, 48.9369257777465],
                            [2.348997361312688, 48.93693005831583],
                            [2.348914199366566, 48.936931899765156],
                            [2.348831406135883, 48.93692642207677],
                            [2.348750461504366, 48.93691372232154],
                            [2.34863600312478, 48.93688179081671],
                            [2.347941366208955, 48.93664465718516],
                            [2.346855168971187, 48.9362846930754],
                            [2.34644376242267, 48.93613469226443],
                        ],
                    },
                },
                1510: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.83108543976075, 2.3959336200561037],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 403.77383647,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.393449698306368,
                            48.83038859059281,
                            2.398350103858007,
                            48.831993087108515,
                        ),
                        "coordinates": [
                            [2.393449698306368, 48.83038859059281],
                            [2.393829467500255, 48.830468743970634],
                            [2.394305824254208, 48.83057288491898],
                            [2.394922312831014, 48.83071461607494],
                            [2.395430785806886, 48.830846874528106],
                            [2.395917402451413, 48.83099924718361],
                            [2.396134602524732, 48.83107351659227],
                            [2.396319401433938, 48.831144646951046],
                            [2.39674724983463, 48.83131456656865],
                            [2.397634031979359, 48.8316944149103],
                            [2.39800708380837, 48.8318503709347],
                            [2.398350103858007, 48.831993087108515],
                        ],
                    },
                },
                1511: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.9353283686779, 2.3305597781173697],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 557.08921999,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.326793312266221,
                            48.93497582668586,
                            2.334332914535763,
                            48.93560570835985,
                        ),
                        "coordinates": [
                            [2.326793312266221, 48.93497582668586],
                            [2.327355790059927, 48.93504019854807],
                            [2.328627077712501, 48.935178192148584],
                            [2.328875903971432, 48.93520694930931],
                            [2.329247361826735, 48.93524828811963],
                            [2.329810063885335, 48.93530259202479],
                            [2.330531665979612, 48.9353577818704],
                            [2.331029628572286, 48.93539149429184],
                            [2.331527714109706, 48.93541568725698],
                            [2.33177495127591, 48.9354277737944],
                            [2.332707757234658, 48.93548888601129],
                            [2.334332914535763, 48.93560570835985],
                        ],
                    },
                },
                1512: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93101364174572, 2.2861896028149578],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 403.033120725,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.283722557340777,
                            48.930214211387565,
                            2.28865600459439,
                            48.93181399693573,
                        ),
                        "coordinates": [
                            [2.28865600459439, 48.93181399693573],
                            [2.288277633643099, 48.931701346615434],
                            [2.287572777910893, 48.93148491658263],
                            [2.28734418525752, 48.93140551382684],
                            [2.286762164164482, 48.93118600259414],
                            [2.286486039601835, 48.93109679711257],
                            [2.285582813653699, 48.93081064750997],
                            [2.285295125883763, 48.93072232175197],
                            [2.284731413402817, 48.93053812518699],
                            [2.2842741947987, 48.93038311377723],
                            [2.283722557340777, 48.930214211387565],
                        ],
                    },
                },
                1513: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.85584240710167, 2.4101978286536188],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 640.386183924,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.409685730819104,
                            48.85298727790374,
                            2.410741136126437,
                            48.85870374873417,
                        ),
                        "coordinates": [
                            [2.410741136126437, 48.85298727790374],
                            [2.41068045916785, 48.85333068137955],
                            [2.410614606160832, 48.85367581745287],
                            [2.410528488577648, 48.854020900323874],
                            [2.41045235827232, 48.854399470888175],
                            [2.41004450157411, 48.85663908908413],
                            [2.409990142998091, 48.85694934900909],
                            [2.409732824204991, 48.85843031322071],
                            [2.409685730819104, 48.85870374873417],
                        ],
                    },
                },
                1514: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.933111495165036, 2.3014880045710293],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 75.3013201112,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.301291291129663,
                            48.93279020802075,
                            2.301826356702229,
                            48.933272274648566,
                        ),
                        "coordinates": [
                            [2.301826356702229, 48.933272274648566],
                            [2.301656283456398, 48.93325647329314],
                            [2.30157464831808, 48.93323271217897],
                            [2.301503810488928, 48.93320799773716],
                            [2.30142074687486, 48.93315421517787],
                            [2.301375394350616, 48.93308923136997],
                            [2.301358776649418, 48.93303583607963],
                            [2.301291291129663, 48.93279020802075],
                        ],
                    },
                },
                1515: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.8610707302265, 2.409269617593899],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 529.680892781,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.408832465143973,
                            48.85870374873417,
                            2.409685730819104,
                            48.86343374196472,
                        ),
                        "coordinates": [
                            [2.409685730819104, 48.85870374873417],
                            [2.409638517840872, 48.8589707343775],
                            [2.409368498719932, 48.860516993198175],
                            [2.409059816272108, 48.86229880552671],
                            [2.4088898770217, 48.863157607792125],
                            [2.408832465143973, 48.86343374196472],
                        ],
                    },
                },
                1516: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.95080907103659, 2.3552965775880255],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 4035.11503375,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.344386363594881,
                            48.93445554506131,
                            2.372103138402569,
                            48.96375542962029,
                        ),
                        "coordinates": [
                            [2.345604378196291, 48.93445554506131],
                            [2.34552682729569, 48.934759881220835],
                            [2.345435526614926, 48.935194669214006],
                            [2.345360667089803, 48.93555115323384],
                            [2.345304411272231, 48.935866884124174],
                            [2.345187141814928, 48.936525023869564],
                            [2.345094819779337, 48.93693648596403],
                            [2.344825212527904, 48.938001662135036],
                            [2.344718752966593, 48.93841979525869],
                            [2.344611081014025, 48.93884268321627],
                            [2.344492760423405, 48.939715484610716],
                            [2.344449451713561, 48.94002023074903],
                            [2.344426725934739, 48.940216765315945],
                            [2.344406526368034, 48.94038831718981],
                            [2.344398960539695, 48.9405215612369],
                            [2.344388869813095, 48.94067479150671],
                            [2.344386363594881, 48.940819693614955],
                            [2.344391450840797, 48.94102455463337],
                            [2.344394007356398, 48.941211094180694],
                            [2.344406677124401, 48.94139263774116],
                            [2.344421878962407, 48.94161082197553],
                            [2.344454785915123, 48.94186398073844],
                            [2.344480761382309, 48.94203325430529],
                            [2.344505400498639, 48.942167105925336],
                            [2.344543354885731, 48.94235031275322],
                            [2.344591425426755, 48.942551839250726],
                            [2.344657201755636, 48.942788342004455],
                            [2.344773562352791, 48.943123105910715],
                            [2.344841858252559, 48.94328965547715],
                            [2.344905093424825, 48.94343455322234],
                            [2.344978444802704, 48.94359443964079],
                            [2.345056852649428, 48.9437476629708],
                            [2.345160554023738, 48.94393919254359],
                            [2.345251605312194, 48.94409574554805],
                            [2.3453628903806, 48.944273949404725],
                            [2.345479233030904, 48.94445215376108],
                            [2.345630988745441, 48.94465927517137],
                            [2.345744792574485, 48.94481522076713],
                            [2.345866846172878, 48.944981240905655],
                            [2.345993796188436, 48.94513674175982],
                            [2.346081166795825, 48.94523990525407],
                            [2.34620256560829, 48.945378134589895],
                            [2.346344192807948, 48.94552635625603],
                            [2.346485822191318, 48.94567457684265],
                            [2.34666032877667, 48.94585110854772],
                            [2.346910710341534, 48.946095920969036],
                            [2.347077629787674, 48.946247470074574],
                            [2.347310303207732, 48.946438984731834],
                            [2.347467104395332, 48.94656721653107],
                            [2.347616318620489, 48.94668212448929],
                            [2.347755417327525, 48.946788705656054],
                            [2.347919807494888, 48.94691193855022],
                            [2.348160067789278, 48.94708346577434],
                            [2.348367451062664, 48.94722834625719],
                            [2.349632014884843, 48.948115941355844],
                            [2.351614937136265, 48.94950309253226],
                            [2.352925502951169, 48.95042330992545],
                            [2.354537664028993, 48.95155011271105],
                            [2.356157561485857, 48.9527088039936],
                            [2.358757902510807, 48.95454963877417],
                            [2.36106372220096, 48.95614927708678],
                            [2.363384152136846, 48.957766710501666],
                            [2.365578229885342, 48.95931393844462],
                            [2.367595302377924, 48.96072436064664],
                            [2.370028171937784, 48.96232973251893],
                            [2.372103138402569, 48.96375542962029],
                        ],
                    },
                },
                1517: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.784433727796014, 2.222750561440362],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 441.602409844,
                    },
                    "geometry": {
                        "type": "LineString",
                        "coordinates": [
                            [2.220009516856533, 48.78496976326486],
                            [2.220505961656042, 48.78493230944223],
                            [2.220715765726624, 48.78491797222479],
                            [2.220927601615295, 48.7849122139824],
                            [2.221061638043986, 48.78490737650261],
                            [2.221215247505283, 48.7848940994499],
                            [2.221354030971031, 48.78486073593376],
                            [2.221866955206655, 48.78465989680889],
                            [2.222197224285886, 48.78453639787042],
                            [2.222462250468724, 48.78444103013559],
                            [2.222739685614918, 48.78438286618463],
                            [2.223617178789192, 48.7842207999997],
                            [2.223912607282982, 48.78416822322763],
                            [2.224380061720888, 48.78411795335137],
                            [2.224658468080146, 48.784093088769446],
                            [2.224786594457847, 48.78407592086708],
                            [2.224834638031615, 48.78406119511735],
                            [2.224880130362842, 48.78404238651022],
                            [2.224922303035728, 48.7840198219507],
                            [2.224960357854996, 48.78399400084061],
                            [2.224994455796061, 48.783964898144504],
                            [2.225024432812136, 48.783932654010904],
                            [2.225050197562004, 48.78389737038431],
                        ],
                        "bbox": (
                            2.220009516856533,
                            48.78389737038431,
                            2.225050197562004,
                            48.78496976326486,
                        ),
                    },
                },
                1518: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.977807711180425, 2.3788997832420358],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 444.241681112,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.377419674665871,
                            48.976522525178765,
                            2.380206531722886,
                            48.97933686825804,
                        ),
                        "coordinates": [
                            [2.380206531722886, 48.97927566503136],
                            [2.380016421712522, 48.979304423428694],
                            [2.379883352902135, 48.97932395967784],
                            [2.379804626634978, 48.97933306941305],
                            [2.379734096385647, 48.97933686825804],
                            [2.379664625266178, 48.97932758669483],
                            [2.379618705840134, 48.979313668978065],
                            [2.379571988617295, 48.979290823887794],
                            [2.379533453277249, 48.979263858483414],
                            [2.379504929808244, 48.979230995434165],
                            [2.379484601046491, 48.9791928224471],
                            [2.379454758965711, 48.979118910916405],
                            [2.378606721002566, 48.97673525453281],
                            [2.378561769901307, 48.97664044579999],
                            [2.378534165618162, 48.976606398382536],
                            [2.378497532474672, 48.97657170887352],
                            [2.378444515007396, 48.976547047414584],
                            [2.378365222741335, 48.9765281965055],
                            [2.378303846020602, 48.976522525178765],
                            [2.378175386401071, 48.9765349451964],
                            [2.377730716873566, 48.976618531043115],
                            [2.377419674665871, 48.97666569235197],
                        ],
                    },
                },
                1519: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.94347141694793, 2.3568783038066097],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 300.267491388,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356729741525478,
                            48.942125455106826,
                            2.357006356470642,
                            48.94481893267206,
                        ),
                        "coordinates": [
                            [2.357006356470642, 48.94481893267206],
                            [2.356986820129874, 48.94464608822164],
                            [2.356959715401901, 48.944384214138395],
                            [2.356955832632067, 48.944113899826924],
                            [2.356893673578281, 48.9435320538941],
                            [2.356829681927504, 48.942981605118725],
                            [2.356749980535935, 48.94229973184103],
                            [2.356729741525478, 48.942125455106826],
                        ],
                    },
                },
                1520: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.95410715106013, 2.35815027856346],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 327.744803766,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.357978331080607,
                            48.95263788257678,
                            2.358322856150864,
                            48.95557634800801,
                        ),
                        "coordinates": [
                            [2.358322856150864, 48.95557634800801],
                            [2.358307313823014, 48.95544510463247],
                            [2.358275719522132, 48.955180116927906],
                            [2.358131846068749, 48.953944885732675],
                            [2.35800241406869, 48.95285262626326],
                            [2.357978331080607, 48.95263788257678],
                        ],
                    },
                },
                1521: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.96457633836813, 2.3619815219464444],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 359.484643011,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.360250758647362,
                            48.96351794635936,
                            2.363572223970633,
                            48.96585557438446,
                        ),
                        "coordinates": [
                            [2.363572223970633, 48.96585557438446],
                            [2.363447089206622, 48.96574576076724],
                            [2.362899927854511, 48.965278297372464],
                            [2.361789483215989, 48.96433435405443],
                            [2.361577526122401, 48.964159536200896],
                            [2.361424349373036, 48.96405343689045],
                            [2.361245947563948, 48.96395615156627],
                            [2.361133536370644, 48.96390020769356],
                            [2.361069765307253, 48.96387012665613],
                            [2.360837054850494, 48.96376717104961],
                            [2.360455132145108, 48.9636033423051],
                            [2.360250758647362, 48.96351794635936],
                        ],
                    },
                },
                1522: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.95734884284048, 2.358531678166861],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 395.391457286,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358322856150864,
                            48.95557634800801,
                            2.358742504475762,
                            48.95912109831728,
                        ),
                        "coordinates": [
                            [2.358742504475762, 48.95912109831728],
                            [2.358722057428098, 48.95894789373211],
                            [2.358714742734809, 48.958881828689485],
                            [2.358623713071543, 48.95813304773097],
                            [2.358337509317531, 48.95570639687379],
                            [2.358322856150864, 48.95557634800801],
                        ],
                    },
                },
                1523: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.94816251400768, 2.3425455772102772],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 314.308500254,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.342244846070268,
                            48.94698706127986,
                            2.343251343552804,
                            48.94958134511723,
                        ),
                        "coordinates": [
                            [2.343251343552804, 48.94698706127986],
                            [2.343227861017344, 48.94699252433917],
                            [2.343203935628805, 48.94699856680016],
                            [2.343179663155026, 48.94700517300036],
                            [2.343155135234443, 48.94701232995246],
                            [2.343130446269778, 48.947020021986546],
                            [2.343105687922311, 48.947028234317095],
                            [2.343080954572201, 48.94703695307277],
                            [2.343056339246131, 48.94704616347564],
                            [2.343031934982033, 48.94705584984871],
                            [2.343007836149107, 48.947065999220065],
                            [2.342984134420379, 48.947076595905315],
                            [2.342960922822769, 48.947087625126834],
                            [2.342938295737299, 48.94709907301375],
                            [2.342916346202615, 48.94711092388935],
                            [2.342895167223318, 48.9471231647746],
                            [2.342874851849597, 48.947135779093735],
                            [2.342851813891438, 48.94715164735875],
                            [2.342830571581879, 48.94716824938116],
                            [2.342811060196619, 48.94718541304505],
                            [2.342793217753386, 48.94720296535016],
                            [2.342776976809512, 48.94722073326617],
                            [2.342762275383041, 48.947238543792615],
                            [2.342749048750616, 48.947256224813245],
                            [2.342737230834979, 48.947273603304986],
                            [2.342726758289375, 48.947290506259655],
                            [2.34271756639044, 48.947306761560796],
                            [2.34270959180283, 48.94732219530092],
                            [2.342702769802953, 48.94733663536339],
                            [2.342697035667211, 48.94734990963165],
                            [2.342692324694704, 48.94736184419052],
                            [2.342688573538053, 48.94737226603166],
                            [2.342685716096711, 48.94738100393],
                            [2.342553719124175, 48.94774487497142],
                            [2.34229107332035, 48.948529786184],
                            [2.342286742089939, 48.948542662542195],
                            [2.342282472716178, 48.94855582970573],
                            [2.342278294187544, 48.948569262653926],
                            [2.342274234116115, 48.9485829372578],
                            [2.342270318760009, 48.94859682848165],
                            [2.342266578450556, 48.94861091311071],
                            [2.342263038080681, 48.948625166101905],
                            [2.342259728004542, 48.94863956244193],
                            [2.342256675822845, 48.948654078901114],
                            [2.34225390778274, 48.948668691343016],
                            [2.342251452884506, 48.94868337384773],
                            [2.342249340094239, 48.94869810319303],
                            [2.342247594305408, 48.94871285433572],
                            [2.342246245860726, 48.94872760316192],
                            [2.342245322372807, 48.9487423255426],
                            [2.342244850088711, 48.94875699734137],
                            [2.342244846070268, 48.948770701390075],
                            [2.342245275769789, 48.94878433407758],
                            [2.34224613905114, 48.94879790619444],
                            [2.342247431648234, 48.948811431206416],
                            [2.342249152071227, 48.948824918997346],
                            [2.342251298807124, 48.94883838124949],
                            [2.342253870343331, 48.948851829645136],
                            [2.342256863790301, 48.94886527675826],
                            [2.342260276281535, 48.94887873336441],
                            [2.34226410768079, 48.94889221025408],
                            [2.342268356464002, 48.94890572000883],
                            [2.342273017022545, 48.94891927428832],
                            [2.342278091950846, 48.94893288389811],
                            [2.342283575640285, 48.94894656049795],
                            [2.3422894679322, 48.94896031667678],
                            [2.342295765971186, 48.94897416231088],
                            [2.342398915209412, 48.9491432956441],
                            [2.34244086651517, 48.949253927151354],
                            [2.342485672489332, 48.949424533495176],
                            [2.342521826040314, 48.94958134511723],
                        ],
                    },
                },
                1524: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.94243457725298, 2.346857522187035],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 714.547983834,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345207505927952,
                            48.93968870865853,
                            2.347692201300065,
                            48.94555553922783,
                        ),
                        "coordinates": [
                            [2.347312925167514, 48.94555553922783],
                            [2.347210395345678, 48.94534940496736],
                            [2.34714991115833, 48.945160631727134],
                            [2.347146257692962, 48.94510636193603],
                            [2.347176904456155, 48.94490951930851],
                            [2.347430518307241, 48.94369743224],
                            [2.347691177233965, 48.94244112625761],
                            [2.347692201300065, 48.94241215609647],
                            [2.347686594853674, 48.94238447898954],
                            [2.34767516270773, 48.942358146977575],
                            [2.347658712436813, 48.94233320941797],
                            [2.347638050236463, 48.94230971655967],
                            [2.347613980934943, 48.94228771864421],
                            [2.34758731073472, 48.94226726502156],
                            [2.347558847167755, 48.94224840774745],
                            [2.347529393714253, 48.942231195259],
                            [2.347499759279288, 48.94221567872139],
                            [2.347470748683035, 48.94220190837917],
                            [2.347443166744677, 48.94218993447764],
                            [2.347417822389177, 48.942179806385866],
                            [2.347395519058515, 48.94217157524218],
                            [2.347377062935964, 48.942165291300974],
                            [2.347363261581721, 48.94216100392503],
                            [2.347349590769863, 48.94215664891285],
                            [2.347333155156884, 48.9421506880165],
                            [2.347314297481799, 48.942143115007454],
                            [2.347293360495387, 48.94213392275814],
                            [2.347270685572019, 48.942123105032756],
                            [2.347246616816544, 48.942110655610605],
                            [2.347221495625943, 48.94209656645783],
                            [2.347195663374694, 48.94208083133927],
                            [2.347169464167127, 48.942063444035],
                            [2.347143239388206, 48.942044397411166],
                            [2.347117330422636, 48.94202368433428],
                            [2.347092081373364, 48.942001298585176],
                            [2.347067833612453, 48.941977233930146],
                            [2.347044929887562, 48.94195148324388],
                            [2.347023711591534, 48.94192403849469],
                            [2.347004521436443, 48.94189489525536],
                            [2.346737532505836, 48.94141090748438],
                            [2.346646016950976, 48.94127764049583],
                            [2.346279796161858, 48.94093016110998],
                            [2.346144619460624, 48.940822352538305],
                            [2.346035574368226, 48.94070469354534],
                            [2.345899020928413, 48.94053406225695],
                            [2.345794490520273, 48.94040215152773],
                            [2.345698142399813, 48.94030883042131],
                            [2.345427634881954, 48.94010605976126],
                            [2.34535268822641, 48.940034269848844],
                            [2.345310121283359, 48.93997265048138],
                            [2.345261807530487, 48.93985103908482],
                            [2.345207505927952, 48.93968870865853],
                        ],
                    },
                },
                1525: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.95488575910265, 2.3437397116345604],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 472.424955562,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.34310923572538,
                            48.9527263298977,
                            2.344100126256551,
                            48.9566718460312,
                        ),
                        "coordinates": [
                            [2.343461279526826, 48.9527263298977],
                            [2.343543842597136, 48.952968759185346],
                            [2.343604357447491, 48.953154677873826],
                            [2.343672107701491, 48.953626156815574],
                            [2.343777668372663, 48.954193489882634],
                            [2.343759019268076, 48.954468913789846],
                            [2.343748745618755, 48.95459591379836],
                            [2.343762278674679, 48.95472589928028],
                            [2.343791131112674, 48.954844547847195],
                            [2.343860121294246, 48.95504621641696],
                            [2.344093997830418, 48.95575272738306],
                            [2.344095771106083, 48.9557599159577],
                            [2.344097381673621, 48.95576950289513],
                            [2.344098718583735, 48.955781298741634],
                            [2.344099670875501, 48.95579511494258],
                            [2.344100126256551, 48.95581076023846],
                            [2.344099972400247, 48.95582804606717],
                            [2.344099099732996, 48.95584678208329],
                            [2.344097393196711, 48.95586677970983],
                            [2.344094744605515, 48.95588784681042],
                            [2.344091040243569, 48.95590979661387],
                            [2.344086169193668, 48.95593243696877],
                            [2.344080019127551, 48.955955579313006],
                            [2.344072477728111, 48.95597903418526],
                            [2.344063435420263, 48.95600261123978],
                            [2.344052779886649, 48.95602612101509],
                            [2.344040397444497, 48.95604937404218],
                            [2.344030134989393, 48.956065861767385],
                            [2.344018576961181, 48.95608210679466],
                            [2.344005897519121, 48.95609805072475],
                            [2.343992273519689, 48.95611363787086],
                            [2.34397787908883, 48.95612881253141],
                            [2.343962889740646, 48.95614351721395],
                            [2.343947480978502, 48.95615769532524],
                            [2.343931829659966, 48.95617129117886],
                            [2.343916108558117, 48.95618424816685],
                            [2.343900495907763, 48.956196509711226],
                            [2.343885164482259, 48.95620801920423],
                            [2.343870292517151, 48.956218720068065],
                            [2.34385605278617, 48.95622855569508],
                            [2.343842622159495, 48.95623746950021],
                            [2.343830176130695, 48.95624540579011],
                            [2.343818888839265, 48.9562523079649],
                            [2.343363487637536, 48.95652300670883],
                            [2.34310923572538, 48.9566718460312],
                        ],
                    },
                },
                1526: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.758755798303206, 2.367929022141009],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 461.306009339,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.366398000043218,
                            48.75673943351173,
                            2.368364698633332,
                            48.75971717791522,
                        ),
                        "coordinates": [
                            [2.368364698633332, 48.75673943351173],
                            [2.368312609166361, 48.75772869242253],
                            [2.368277989490791, 48.75827912662529],
                            [2.36827840441093, 48.75848283483992],
                            [2.368330606633246, 48.75887076606382],
                            [2.368330323434917, 48.75918941638556],
                            [2.36832174692897, 48.75942568380984],
                            [2.368318625021238, 48.759456698429474],
                            [2.36831165479177, 48.75948713145114],
                            [2.368300927646653, 48.75951673601532],
                            [2.368286534993017, 48.759545265262176],
                            [2.368268569642543, 48.75957246874133],
                            [2.36824712298223, 48.7595981013911],
                            [2.368222289164565, 48.7596219145666],
                            [2.368194158262459, 48.75964365960109],
                            [2.368162823049067, 48.759663089640775],
                            [2.368128374949755, 48.759679956925154],
                            [2.368090908111823, 48.75969401370794],
                            [2.368050513964275, 48.75970501222834],
                            [2.368007282588219, 48.75971270381896],
                            [2.367961308125829, 48.75971684163252],
                            [2.367912683371941, 48.75971717791522],
                            [2.367861498413782, 48.75971346399927],
                            [2.367069765649857, 48.75960018464829],
                            [2.366745287798628, 48.75958325888413],
                            [2.366398000043218, 48.75957353526183],
                        ],
                    },
                },
                1527: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.909162564643374, 2.2382814723671878],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 230.639608371,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.236878028463527,
                            48.90869458435905,
                            2.239684117127617,
                            48.90963293312601,
                        ),
                        "coordinates": [
                            [2.236878028463527, 48.90869458435905],
                            [2.238445939948255, 48.90921623446079],
                            [2.239684117127617, 48.90963293312601],
                        ],
                    },
                },
                1528: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.897899487891365, 2.3416285043569802],
                        "indice_lig": "3",
                        "idf": 0,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 528.585097515,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.338026740232628,
                            48.897832385089565,
                            2.345228293777086,
                            48.89802474646223,
                        ),
                        "coordinates": [
                            [2.345228293777086, 48.89802474646223],
                            [2.344867664361268, 48.89800218256474],
                            [2.343839145645033, 48.89794277080218],
                            [2.3418519097825, 48.89789496290001],
                            [2.339529113312897, 48.89784761011449],
                            [2.338026740232628, 48.897832385089565],
                        ],
                    },
                },
                1529: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89820150189701, 2.3485277516921226],
                        "indice_lig": "3",
                        "idf": 0,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 485.255062214,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345228293777086,
                            48.89802474646223,
                            2.351829550128707,
                            48.89832555844204,
                        ),
                        "coordinates": [
                            [2.351829550128707, 48.89832555844204],
                            [2.351277902243605, 48.898316792561744],
                            [2.348201347912253, 48.898207105872885],
                            [2.346766823464596, 48.898120993545746],
                            [2.345228293777086, 48.89802474646223],
                        ],
                    },
                },
                1530: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.93726885320287, 2.3460825918423596],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 553.418522164,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.345079130466015,
                            48.93526614581903,
                            2.347862407755533,
                            48.93968870865853,
                        ),
                        "coordinates": [
                            [2.345207505927952, 48.93968870865853],
                            [2.345153204675653, 48.93952637728393],
                            [2.345092574339443, 48.939350449177844],
                            [2.345086845659963, 48.93928903006254],
                            [2.345079130466015, 48.9392133239564],
                            [2.345084650571082, 48.93911913163801],
                            [2.345103298073819, 48.939015017293485],
                            [2.345135953472966, 48.93883103400138],
                            [2.345405286912643, 48.937748943610174],
                            [2.345437257873819, 48.93761920477691],
                            [2.345510218920342, 48.93750396591276],
                            [2.345608949941572, 48.93740742714754],
                            [2.346265505710323, 48.936894212177535],
                            [2.346283187259655, 48.936880072024756],
                            [2.346300905653951, 48.93686484573293],
                            [2.346318600628861, 48.936848657974124],
                            [2.346336209201656, 48.93683163250615],
                            [2.346353671120091, 48.936813893101956],
                            [2.346370923390656, 48.93679556441872],
                            [2.346387903020206, 48.93677677111371],
                            [2.346404551122049, 48.93675763696741],
                            [2.346420803338711, 48.93673828662966],
                            [2.346436598042597, 48.93671884476533],
                            [2.346451874994323, 48.936699434248276],
                            [2.34646657120192, 48.936680179735994],
                            [2.34648062640377, 48.93666120590082],
                            [2.346493976243277, 48.93664263739285],
                            [2.346506559105758, 48.936624597977875],
                            [2.346518316105997, 48.936607211436545],
                            [2.346534696979306, 48.936581850055674],
                            [2.346549746936495, 48.93655714059251],
                            [2.346563591542428, 48.936533084631485],
                            [2.346576359069269, 48.93650968557017],
                            [2.346588175058657, 48.93648694679125],
                            [2.34659916505204, 48.9364648716773],
                            [2.346609455978131, 48.93644346181983],
                            [2.346619173366545, 48.93642272150047],
                            [2.346628444145483, 48.93640265231068],
                            [2.346637393844086, 48.93638325853199],
                            [2.34664615075496, 48.936364541763155],
                            [2.346654837677132, 48.936346506270795],
                            [2.346663584256484, 48.93632915456028],
                            [2.346672514678932, 48.9363124891071],
                            [2.346681755849052, 48.93629651330088],
                            [2.34669143467119, 48.93628123053115],
                            [2.346833718555854, 48.93608187254817],
                            [2.346981923373608, 48.93589899367728],
                            [2.34706439073205, 48.93580783444848],
                            [2.34715596151151, 48.93572957914767],
                            [2.347301792831563, 48.93562712540774],
                            [2.347516151689879, 48.93548911087054],
                            [2.347862407755533, 48.93526614581903],
                        ],
                    },
                },
                1531: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T11",
                        "rer": 0,
                        "extcode": "800:T11",
                        "geo_point_2d": [48.95821650582868, 2.315347210074075],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01999",
                        "navette": 0,
                        "idrefliga": "A02225",
                        "shape_leng": 2152.88361692,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.302305082030494,
                            48.95456256277915,
                            2.329275699763007,
                            48.95912802097736,
                        ),
                        "coordinates": [
                            [2.329275699763007, 48.95912802097736],
                            [2.328599986361255, 48.95903439253367],
                            [2.327664583815892, 48.9589047743084],
                            [2.32678756511394, 48.95882847318848],
                            [2.326093512116676, 48.95885312628799],
                            [2.325247714102556, 48.95887692246294],
                            [2.322318075002199, 48.95910309127009],
                            [2.321093192362122, 48.95910330080921],
                            [2.320205152471072, 48.95904116503137],
                            [2.318667628549135, 48.95891109373031],
                            [2.317217009818487, 48.95876722072987],
                            [2.314747462733848, 48.95862464983912],
                            [2.308792517149472, 48.95811222521074],
                            [2.308751579478196, 48.958108612450594],
                            [2.308693028028055, 48.95810450874262],
                            [2.308617944191606, 48.958099413107085],
                            [2.308527410754496, 48.95809282276928],
                            [2.308422509154479, 48.958084234044364],
                            [2.308304323518739, 48.95807314685844],
                            [2.308173935298867, 48.958059057524586],
                            [2.308032427295607, 48.958041464162875],
                            [2.307880880964864, 48.95801986398807],
                            [2.307720379112669, 48.95799375602385],
                            [2.307552005967126, 48.95796263570849],
                            [2.307376841620424, 48.957926002057675],
                            [2.307195968915855, 48.957883353208615],
                            [2.3070104720937, 48.95783418551328],
                            [2.306821432633989, 48.95777799801156],
                            [2.306629932046517, 48.95771428795089],
                            [2.306514329302789, 48.9576719165534],
                            [2.306397470887823, 48.95762572126645],
                            [2.30627976192978, 48.95757594273678],
                            [2.30616160075031, 48.95752281977475],
                            [2.306043392470787, 48.95746659303035],
                            [2.305925536758827, 48.957407502224186],
                            [2.305808436008879, 48.95734578709445],
                            [2.305692493988625, 48.95728168648953],
                            [2.30557810896355, 48.9572154419254],
                            [2.305465686057901, 48.957147292261396],
                            [2.30535562627093, 48.95707747813321],
                            [2.305248331974651, 48.95700623928644],
                            [2.305144202817487, 48.9569338145531],
                            [2.305043642515897, 48.95686044458853],
                            [2.304947052050733, 48.956786370033385],
                            [2.304854835165146, 48.95671182884744],
                            [2.30271606859119, 48.95487422604924],
                            [2.302305082030494, 48.95456256277915],
                        ],
                    },
                },
                1532: {
                    "attributes": {
                        "reseau": "RER E",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER E",
                        "rer": 1,
                        "extcode": "800:E",
                        "geo_point_2d": [48.89774509584506, 2.387198109649301],
                        "indice_lig": "E",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01729",
                        "navette": 0,
                        "idrefliga": "A01843",
                        "shape_leng": 1943.41763871,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37412297552969,
                            48.89667381116845,
                            2.400361703159176,
                            48.898112306280396,
                        ),
                        "coordinates": [
                            [2.37412297552969, 48.89667381116845],
                            [2.374818930611102, 48.896865708299686],
                            [2.375445584326413, 48.89702902838996],
                            [2.375900379373193, 48.89714783915272],
                            [2.376293810477423, 48.89724763452135],
                            [2.376658360513129, 48.89732840342263],
                            [2.377022904332032, 48.89740203420142],
                            [2.377362172688801, 48.8974566387352],
                            [2.377878289584649, 48.897532591757866],
                            [2.378289728606982, 48.89758002777298],
                            [2.378683120433279, 48.89762033249879],
                            [2.379152292562753, 48.89765584784654],
                            [2.37957454059956, 48.89767948292994],
                            [2.380108662674742, 48.897705452903956],
                            [2.381418698487198, 48.89775728944898],
                            [2.382472507283918, 48.89780207738675],
                            [2.382992194458232, 48.89782328181689],
                            [2.383591271275544, 48.897842069683506],
                            [2.384064042196673, 48.89786090918635],
                            [2.384442970317296, 48.8978655095026],
                            [2.384789418078747, 48.89786774294937],
                            [2.387925444273986, 48.89784733806379],
                            [2.388820421101058, 48.89784217277669],
                            [2.389628789129359, 48.897839420144976],
                            [2.390422717423798, 48.89783191032933],
                            [2.391483710550859, 48.89783854166949],
                            [2.394341940227716, 48.89789185470043],
                            [2.39740225604469, 48.89793309172566],
                            [2.397979671764541, 48.89793991938611],
                            [2.398355011671776, 48.89795875222289],
                            [2.398683432624051, 48.89797522863239],
                            [2.399051570105814, 48.89800595970357],
                            [2.400361703159176, 48.898112306280396],
                        ],
                    },
                },
                1533: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.80332842597664, 2.1698798444123617],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 534.887088263,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.169070049430458,
                            48.80107761141682,
                            2.170967401079032,
                            48.80570415485828,
                        ),
                        "coordinates": [
                            [2.170967401079032, 48.80107761141682],
                            [2.170706027340271, 48.801437836133395],
                            [2.170622591240168, 48.80156555962446],
                            [2.170541108710919, 48.80169695272259],
                            [2.170461705577933, 48.801831808539035],
                            [2.170384495074464, 48.80196994168384],
                            [2.1703096201705, 48.80211109502055],
                            [2.170236034908995, 48.80225742708076],
                            [2.170165251730904, 48.80240612780249],
                            [2.170097528357411, 48.802556660230216],
                            [2.170033257115613, 48.80270815735917],
                            [2.169972153559417, 48.80286146896398],
                            [2.169915951874933, 48.80301243201373],
                            [2.1698657157526, 48.80315829270378],
                            [2.169824953710979, 48.803288890453466],
                            [2.169759463653584, 48.803504447687125],
                            [2.169673492720527, 48.80377171644067],
                            [2.169316519425796, 48.80483470652087],
                            [2.169191849723529, 48.80521873539956],
                            [2.169137933416594, 48.80539705400605],
                            [2.169100107138706, 48.805535711521365],
                            [2.169077561037828, 48.80563769288815],
                            [2.169070049430458, 48.80570415485828],
                        ],
                    },
                },
                1534: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T11",
                        "rer": 0,
                        "extcode": "800:T11",
                        "geo_point_2d": [48.95973438619032, 2.3363328919766566],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01999",
                        "navette": 0,
                        "idrefliga": "A02225",
                        "shape_leng": 1042.68587613,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.329275699763007,
                            48.95912802097736,
                            2.343414543882292,
                            48.96003376394423,
                        ),
                        "coordinates": [
                            [2.343414543882292, 48.96003376394423],
                            [2.342027018925945, 48.959995527556885],
                            [2.340085118805303, 48.959948690459846],
                            [2.338066030721977, 48.959834775401845],
                            [2.335522911600436, 48.95978644773623],
                            [2.334765893905593, 48.95976131182601],
                            [2.333887870566819, 48.95970504439094],
                            [2.332906259139324, 48.95961202840575],
                            [2.331890406864872, 48.95948455235957],
                            [2.330438185561749, 48.95928908863154],
                            [2.3299514169636, 48.95922164561279],
                            [2.329275699763007, 48.95912802097736],
                        ],
                    },
                },
                1535: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.8193240911388, 2.3620891692086206],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 298.224889906,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.360129742015262,
                            48.81905151465142,
                            2.36401545946979,
                            48.81976126665727,
                        ),
                        "coordinates": [
                            [2.36401545946979, 48.81976126665727],
                            [2.363669891887395, 48.819652331813614],
                            [2.36283388130373, 48.81941562941297],
                            [2.362581105944968, 48.819340989894854],
                            [2.36240283793562, 48.819302917529],
                            [2.36173636045291, 48.819229877479145],
                            [2.361337642359848, 48.81918491460739],
                            [2.361026705409235, 48.8191518425528],
                            [2.360129742015262, 48.81905151465142],
                        ],
                    },
                },
                1536: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE H",
                        "rer": 0,
                        "extcode": "800:H",
                        "geo_point_2d": [49.045431012009466, 2.1031051862686283],
                        "indice_lig": "H",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01737",
                        "navette": 0,
                        "idrefliga": "A01849",
                        "shape_leng": 295.647988421,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.101108482966614,
                            49.045311648350264,
                            2.105110703444507,
                            49.04564873988319,
                        ),
                        "coordinates": [
                            [2.105110703444507, 49.045311648350264],
                            [2.104628215681291, 49.04532047996179],
                            [2.104374559147197, 49.04533000897707],
                            [2.104086670840201, 49.04534147623432],
                            [2.103441731027953, 49.045386363089136],
                            [2.10270505892091, 49.04544511964608],
                            [2.102295453480011, 49.045478428084046],
                            [2.101824629861494, 49.0455337048508],
                            [2.101108482966614, 49.04564873988319],
                        ],
                    },
                },
                1537: {
                    "attributes": {
                        "reseau": "GRANDES LIGNES",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.9944939518614, 1.666806027152818],
                        "indice_lig": "GL",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 5479.84243843,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.63016762729846,
                            48.989502508030505,
                            1.703016134167223,
                            48.99739200091919,
                        ),
                        "coordinates": [
                            [1.703016134167223, 48.989502508030505],
                            [1.702229252761286, 48.98982613658998],
                            [1.701117874093648, 48.990332962137074],
                            [1.700209104186259, 48.99071099479692],
                            [1.699177153526214, 48.99110736786792],
                            [1.698352248295661, 48.99142874751734],
                            [1.697610888866044, 48.991719654366115],
                            [1.696851246640918, 48.99196456862695],
                            [1.695527734695914, 48.99233216723468],
                            [1.69408322699894, 48.99268596160869],
                            [1.693114936652899, 48.99290656285181],
                            [1.692328098556521, 48.993075829826566],
                            [1.690863496640551, 48.993367376662306],
                            [1.690201699342695, 48.99348377964712],
                            [1.688848912001961, 48.99371094157248],
                            [1.687634475182295, 48.9938812206661],
                            [1.687442830000291, 48.99390531376858],
                            [1.68487389525556, 48.99419017274886],
                            [1.683806667794129, 48.99429269634315],
                            [1.682196184793544, 48.994397704259356],
                            [1.681173829670414, 48.99443792217545],
                            [1.680303001069112, 48.99445810890186],
                            [1.678492990542466, 48.994499869002205],
                            [1.675790041477323, 48.994579611067365],
                            [1.675226803595984, 48.99459254315479],
                            [1.672834185723328, 48.994664117058534],
                            [1.67044292643981, 48.994735649385284],
                            [1.668053015001883, 48.99480803943132],
                            [1.666569395749004, 48.99486590619205],
                            [1.664074259051832, 48.994936696944755],
                            [1.663955319087725, 48.99493959499422],
                            [1.663878743441095, 48.99494274164851],
                            [1.66213417449838, 48.994993621236326],
                            [1.660388247932471, 48.995043566399985],
                            [1.658645051046726, 48.99509350142313],
                            [1.656460225528515, 48.995156971641485],
                            [1.653043557642145, 48.99525351551286],
                            [1.651140492796044, 48.99529968258946],
                            [1.646900537918747, 48.995433373233624],
                            [1.646538295715394, 48.99543838269525],
                            [1.646018646227835, 48.99546042728361],
                            [1.642034566713777, 48.99557030198722],
                            [1.641487745866455, 48.99558047016644],
                            [1.640544464949111, 48.99559901508954],
                            [1.640119193298352, 48.99561531252166],
                            [1.638883748279223, 48.99571450411125],
                            [1.637754624258731, 48.99582212083545],
                            [1.637033152297899, 48.99590854090188],
                            [1.636188238910179, 48.996025677164766],
                            [1.634736148869059, 48.99626408691703],
                            [1.634052241097602, 48.99639928213538],
                            [1.633735688980259, 48.996458490703745],
                            [1.632745794770312, 48.99667813053987],
                            [1.631856996759631, 48.99690018397305],
                            [1.631125697618198, 48.99709892086752],
                            [1.63016762729846, 48.99739200091919],
                        ],
                    },
                },
                1538: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.820978713726234, 2.322796599148775],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 730.716232136,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.319740313298555,
                            48.818676409912605,
                            2.325575636212245,
                            48.82341162898738,
                        ),
                        "coordinates": [
                            [2.325575636212245, 48.82341162898738],
                            [2.325509577822384, 48.82315163312808],
                            [2.325423188743549, 48.82291226849904],
                            [2.325336735508265, 48.82257445174043],
                            [2.325256349396013, 48.82232939796314],
                            [2.325222914819017, 48.82224272388747],
                            [2.325187662817771, 48.82216261941381],
                            [2.325147188294452, 48.822082455770214],
                            [2.325103430044681, 48.8220071320327],
                            [2.325056136207219, 48.82193621867145],
                            [2.32500518783133, 48.821869540531445],
                            [2.324948471880594, 48.82180482463444],
                            [2.324887673758162, 48.82174444676143],
                            [2.324822740988661, 48.82168835714467],
                            [2.324753647960644, 48.821636534947665],
                            [2.324680355523443, 48.821588952961214],
                            [2.324602866347756, 48.8215456147908],
                            [2.32452117367398, 48.82150651589372],
                            [2.324435269354961, 48.82147165351766],
                            [2.324217686595571, 48.821392880232374],
                            [2.323987862305369, 48.82131392851141],
                            [2.323743465681697, 48.82123399364569],
                            [2.323480144619665, 48.82115164968479],
                            [2.323218880873767, 48.82107298895631],
                            [2.322924720232362, 48.82098707672897],
                            [2.321954425219659, 48.82071163522853],
                            [2.321788357774853, 48.820662979370965],
                            [2.321636062706693, 48.82061550765318],
                            [2.321496758641267, 48.8205689755592],
                            [2.321369665772429, 48.82052312328429],
                            [2.321254137356204, 48.82047772325013],
                            [2.321149296572159, 48.82043243594204],
                            [2.321054410673665, 48.820386945141756],
                            [2.320968693192792, 48.820340876760376],
                            [2.320893740741961, 48.820295351523306],
                            [2.320825849682257, 48.82024841114276],
                            [2.320764210027768, 48.82019950150627],
                            [2.320707793208316, 48.82014780643552],
                            [2.32065651935205, 48.820093497266036],
                            [2.320607543815679, 48.820033814721455],
                            [2.320559001651262, 48.819966595082214],
                            [2.320504976610192, 48.81988367429837],
                            [2.319740313298555, 48.818676409912605],
                        ],
                    },
                },
                1539: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.92024266454959, 2.2209855029358008],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 843.699860872,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.217589799339642,
                            48.91751490757929,
                            2.224812188878315,
                            48.92326825505121,
                        ),
                        "coordinates": [
                            [2.224812188878315, 48.91751490757929],
                            [2.224306622254671, 48.917874179516815],
                            [2.22350066849636, 48.91847092349682],
                            [2.223156847631895, 48.918719962901804],
                            [2.222691073253968, 48.91901175489078],
                            [2.222241421598002, 48.91931150069058],
                            [2.221191555475463, 48.92005491744707],
                            [2.219265712184658, 48.92142507366189],
                            [2.219041571837397, 48.921588151010006],
                            [2.218272407778031, 48.92213516317432],
                            [2.217948539754506, 48.922362665474594],
                            [2.217877288305588, 48.922418711311394],
                            [2.217819682978733, 48.922467709254036],
                            [2.217767252014568, 48.92253280084426],
                            [2.217743203334904, 48.92257130971803],
                            [2.217720736365665, 48.92262469991837],
                            [2.217696258367653, 48.922691759098086],
                            [2.217673845058652, 48.92280166142745],
                            [2.21766187747787, 48.92287713078888],
                            [2.217589799339642, 48.92326825505121],
                        ],
                    },
                },
                1540: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.8984494626641, 2.3768062499420326],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 594.588099712,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.3733837959986,
                            48.89754867140033,
                            2.380537035488634,
                            48.898733990652936,
                        ),
                        "coordinates": [
                            [2.380537035488634, 48.898733990652936],
                            [2.380126152563155, 48.898726213412104],
                            [2.378457679641209, 48.8986934743426],
                            [2.376496651267881, 48.8986547277927],
                            [2.375752921613218, 48.89864014538788],
                            [2.375395710136047, 48.898633524671624],
                            [2.375326268976045, 48.898630782906224],
                            [2.37523976567483, 48.89862140868064],
                            [2.37516953006235, 48.89860973967862],
                            [2.375115570635776, 48.89859518152599],
                            [2.375055387652536, 48.89857285766509],
                            [2.37498898251153, 48.89854276809321],
                            [2.374938157254547, 48.89851132269305],
                            [2.374897635506211, 48.898479682838804],
                            [2.374868699250181, 48.89844740917242],
                            [2.374760447895887, 48.89828315795317],
                            [2.374519554280241, 48.89783218578036],
                            [2.37445757275582, 48.89773430430342],
                            [2.374405016331608, 48.897678113030516],
                            [2.374352238422865, 48.897640361041645],
                            [2.374290375310286, 48.89760791518725],
                            [2.374213145082988, 48.89757776859198],
                            [2.374146555778018, 48.89756314398626],
                            [2.374084419760438, 48.89755330179681],
                            [2.373995155243828, 48.89754867140033],
                            [2.373686440348671, 48.89754975255682],
                            [2.3733837959986, 48.897552809900425],
                        ],
                    },
                },
                1541: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.4344627039764, 2.154361980927693],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 934.747457589,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.149101178683954,
                            48.43222560109566,
                            2.159530553968522,
                            48.43692392480675,
                        ),
                        "coordinates": [
                            [2.159530553968522, 48.43692392480675],
                            [2.158762830775237, 48.43663245077884],
                            [2.15828087410655, 48.4364223164085],
                            [2.157849002363648, 48.43620512206463],
                            [2.157106634802726, 48.43582802364478],
                            [2.154979652132243, 48.43471351329087],
                            [2.153805613821133, 48.43408587517735],
                            [2.153320265961851, 48.43383764698317],
                            [2.152681390830034, 48.43353206466669],
                            [2.152106678117004, 48.43328130648193],
                            [2.151546192305663, 48.433051980618124],
                            [2.150960669656199, 48.4328273707947],
                            [2.150378653997573, 48.432621797185966],
                            [2.149725165900776, 48.43240896531335],
                            [2.149214451943943, 48.432260606137234],
                            [2.149101178683954, 48.43222560109566],
                        ],
                    },
                },
                1542: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.935903155970365, 2.3427853287801246],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 542.210057635,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.339108387008138,
                            48.93574804209917,
                            2.34644376242267,
                            48.93613469226443,
                        ),
                        "coordinates": [
                            [2.339108387008138, 48.93574804209917],
                            [2.339761957918525, 48.93577458416564],
                            [2.340642003584845, 48.935796154733474],
                            [2.341053636427091, 48.93580317761512],
                            [2.341536102659855, 48.9358088823106],
                            [2.342005901586283, 48.935842870041284],
                            [2.342858612728645, 48.93592749502062],
                            [2.343172673912119, 48.93593921035003],
                            [2.343991439667332, 48.935966536500935],
                            [2.344998485576679, 48.93601344563673],
                            [2.345499571139827, 48.93604065262693],
                            [2.34560607547683, 48.93604104443448],
                            [2.345700281630967, 48.9360372655656],
                            [2.345884784251514, 48.93601257554339],
                            [2.345995363973521, 48.93600746852721],
                            [2.346140180613078, 48.93603681100999],
                            [2.34644376242267, 48.93613469226443],
                        ],
                    },
                },
                1543: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.905317918668686, 2.2391288499031567],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 559.804549142,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.23830716268489,
                            48.90276802555433,
                            2.23954203495258,
                            48.907662933574414,
                        ),
                        "coordinates": [
                            [2.23954203495258, 48.90276802555433],
                            [2.239482457132671, 48.90315922585737],
                            [2.239437204440153, 48.90348968396771],
                            [2.239219103232205, 48.90497784424359],
                            [2.238982911263422, 48.90661626914093],
                            [2.238944226923623, 48.90689204047457],
                            [2.238933735771444, 48.906933090798674],
                            [2.238895157856255, 48.9070534842613],
                            [2.238857173335633, 48.907133193472994],
                            [2.238804134699306, 48.907205667290434],
                            [2.238751325569724, 48.907262438590706],
                            [2.238645947095737, 48.90735956463059],
                            [2.23830716268489, 48.907662933574414],
                        ],
                    },
                },
                1544: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93567337791971, 2.3367191272374366],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 351.633993409,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.334332914535763,
                            48.93560570835985,
                            2.339108387008138,
                            48.93574804209917,
                        ),
                        "coordinates": [
                            [2.334332914535763, 48.93560570835985],
                            [2.334606755044989, 48.935627453963285],
                            [2.334803786244142, 48.93563996863293],
                            [2.335141533306115, 48.93566325744271],
                            [2.335399126895982, 48.93568467279184],
                            [2.335585562246368, 48.93567856791572],
                            [2.335830929931536, 48.935639240511286],
                            [2.33613022035347, 48.93561948483575],
                            [2.336253059452791, 48.9356302075345],
                            [2.336413724584776, 48.935648179169114],
                            [2.336556643155108, 48.93565610892811],
                            [2.336862041847092, 48.935667078827194],
                            [2.337173934008135, 48.93567879699378],
                            [2.337585659369906, 48.93567845634913],
                            [2.338799869329657, 48.93573560297827],
                            [2.339108387008138, 48.93574804209917],
                        ],
                    },
                },
                1545: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.915803864540926, 2.2272073746893377],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 520.371904031,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.224808888996176,
                            48.91404768156708,
                            2.229571613274198,
                            48.91751575946233,
                        ),
                        "coordinates": [
                            [2.229571613274198, 48.91404768156708],
                            [2.229179473542786, 48.9143821482972],
                            [2.228909071622439, 48.914596675774966],
                            [2.228855010890124, 48.91463915774244],
                            [2.228739735250658, 48.914719792999584],
                            [2.225311148805808, 48.91715733808334],
                            [2.224808888996176, 48.91751575946233],
                        ],
                    },
                },
                1546: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78027050709352, 2.1939578244070663],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 376.682870654,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.191409919273295,
                            48.780087151988496,
                            2.196505812489855,
                            48.78045471153041,
                        ),
                        "coordinates": [
                            [2.191409919273295, 48.78045471153041],
                            [2.191719209203265, 48.78043324467488],
                            [2.191883547476815, 48.78042436187721],
                            [2.192917480854468, 48.78034710747245],
                            [2.194515956229145, 48.78022796048543],
                            [2.196194376602579, 48.78010790263032],
                            [2.196505812489855, 48.780087151988496],
                        ],
                    },
                },
                1547: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.761129814578595, 2.365861831773172],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 605.704411711,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.364458242042019,
                            48.75956373081654,
                            2.36779053573481,
                            48.763375152982455,
                        ),
                        "coordinates": [
                            [2.366398000043218, 48.75957353526183],
                            [2.365901495641807, 48.75956373081654],
                            [2.365875799623551, 48.75956413763716],
                            [2.365850702157327, 48.75956488221738],
                            [2.365826253869102, 48.75956594054182],
                            [2.365802502675179, 48.75956728768145],
                            [2.365779501922234, 48.75956889963538],
                            [2.365757299515788, 48.759570752373925],
                            [2.36573594474362, 48.75957282007594],
                            [2.36571549094179, 48.75957507964003],
                            [2.365695984655595, 48.759577507029285],
                            [2.365677477904505, 48.75958007553769],
                            [2.365660019922024, 48.759582763840946],
                            [2.365643661367511, 48.759585545225775],
                            [2.365628451507063, 48.75958839566977],
                            [2.365614442327791, 48.759591291165016],
                            [2.365601681735654, 48.75959420768182],
                            [2.365590220368343, 48.759597120305656],
                            [2.364692467623468, 48.75985431340922],
                            [2.364633804807959, 48.75988411595382],
                            [2.36458487140988, 48.75991448830386],
                            [2.364545000193286, 48.75994526052701],
                            [2.36451352531516, 48.75997625999706],
                            [2.364489778199664, 48.76000731497009],
                            [2.364473094329327, 48.76003825552053],
                            [2.36446280377634, 48.76006890899409],
                            [2.364458242042019, 48.76009910366347],
                            [2.364458741893987, 48.76012866868528],
                            [2.364463636109256, 48.760157432316085],
                            [2.364472257462811, 48.76018522281209],
                            [2.364483938716639, 48.760211869328586],
                            [2.364498014013154, 48.76023719922948],
                            [2.364513814739265, 48.76026104256239],
                            [2.364530676383295, 48.76028322759812],
                            [2.364547930361667, 48.760303581686834],
                            [2.364996236769034, 48.760732891507274],
                            [2.365766898687191, 48.76147232480998],
                            [2.366887652822459, 48.76255200666338],
                            [2.366991858911121, 48.762647769394995],
                            [2.367155328226758, 48.76280062042521],
                            [2.367297890804937, 48.76291798249889],
                            [2.367490331335615, 48.763077967823484],
                            [2.36779053573481, 48.763375152982455],
                        ],
                    },
                },
                1548: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.82018199020522, 2.3555908841325492],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 752.843669469,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.350932878064576,
                            48.81899558746953,
                            2.360129742015262,
                            48.82088507611958,
                        ),
                        "coordinates": [
                            [2.350932878064576, 48.82087335522631],
                            [2.351058070052232, 48.82087456714488],
                            [2.351220540831439, 48.82087592453946],
                            [2.352043120207179, 48.820875955304565],
                            [2.352355171950101, 48.82087350869158],
                            [2.353040531642785, 48.82087757581044],
                            [2.354521580837046, 48.82088507611958],
                            [2.354755292701444, 48.820884641251176],
                            [2.354962669944396, 48.82088291716119],
                            [2.355048698996813, 48.82087378931869],
                            [2.355108594452975, 48.82086429652927],
                            [2.355184164478724, 48.82084703485318],
                            [2.355241679158166, 48.82082949769832],
                            [2.355318771835085, 48.8208024292168],
                            [2.355571900674191, 48.82070242188295],
                            [2.355747749934256, 48.82063421434869],
                            [2.35582124958633, 48.820602037491916],
                            [2.355866670047883, 48.82057584130629],
                            [2.355922622393609, 48.82054294569088],
                            [2.355963954557442, 48.82051428383119],
                            [2.355999407265259, 48.82048714262131],
                            [2.35609568032677, 48.82041526100264],
                            [2.356628138289168, 48.81999993693929],
                            [2.356819017384005, 48.81985232954055],
                            [2.357001670047731, 48.819710058579666],
                            [2.3571144403597, 48.81962404741202],
                            [2.357208221408471, 48.819558398557994],
                            [2.357427561086184, 48.819416736051416],
                            [2.35755774901955, 48.819350659286634],
                            [2.357706561575916, 48.81928312739414],
                            [2.357905950071034, 48.819210824086895],
                            [2.358032409485907, 48.81917304467954],
                            [2.358184737285864, 48.81913307909312],
                            [2.358345662256725, 48.81910146163143],
                            [2.358516250304362, 48.81907524890897],
                            [2.358732190184381, 48.819053205872244],
                            [2.359177424726857, 48.81901166170219],
                            [2.359354475799134, 48.818997646547665],
                            [2.359503145387738, 48.81899558746953],
                            [2.359607960817337, 48.818999360566345],
                            [2.359819756346946, 48.81901995639567],
                            [2.360129742015262, 48.81905151465142],
                        ],
                    },
                },
                1549: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.845746907929765, 2.410475265149581],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 438.369052512,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.409551429787372,
                            48.84377178668507,
                            2.410936411148564,
                            48.846948151851734,
                        ),
                        "coordinates": [
                            [2.41013203807822, 48.84377178668507],
                            [2.410226357731701, 48.844058604938496],
                            [2.410300203518146, 48.84428729657582],
                            [2.410523229693839, 48.84496858108805],
                            [2.410616352118057, 48.84527790456375],
                            [2.410738662199128, 48.84568445879206],
                            [2.410802510159742, 48.84590464298894],
                            [2.410822145053051, 48.846017530437805],
                            [2.410833966852388, 48.84611990911143],
                            [2.410843701604704, 48.84621561507973],
                            [2.410857933374933, 48.84629611351898],
                            [2.410930829031644, 48.84654537322356],
                            [2.410935410542729, 48.84657331982549],
                            [2.410936411148564, 48.84660028738585],
                            [2.410933829694499, 48.846626257012616],
                            [2.410927667802333, 48.84665120533049],
                            [2.410917928375286, 48.846675116164946],
                            [2.410904622706167, 48.846697954495994],
                            [2.410887771596064, 48.84671968804819],
                            [2.410867401347464, 48.84674028007615],
                            [2.410843119095104, 48.84676000834256],
                            [2.410815308373691, 48.846778455634954],
                            [2.410784063881623, 48.84679556216069],
                            [2.410749554304691, 48.84681123251702],
                            [2.410711383260836, 48.84682557357064],
                            [2.410670613409564, 48.84683812288866],
                            [2.410627656978512, 48.846848698131666],
                            [2.410594435514634, 48.8468548083618],
                            [2.409951143457477, 48.8469122853566],
                            [2.409551429787372, 48.846948151851734],
                        ],
                    },
                },
                1550: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.97674264124126, 2.368460348428379],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 814.70731556,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.366004450463085,
                            48.97365901297958,
                            2.372243374179225,
                            48.97805731459596,
                        ),
                        "coordinates": [
                            [2.372243374179225, 48.97749198715536],
                            [2.371963176509492, 48.97753562770761],
                            [2.368608451149945, 48.97805192434755],
                            [2.368547661922774, 48.97805731459596],
                            [2.368442170354616, 48.97805295271182],
                            [2.368380120881154, 48.97804310925348],
                            [2.368300860342746, 48.97802175376374],
                            [2.368246190314671, 48.97799957632599],
                            [2.368197370743005, 48.97797172034344],
                            [2.368137229429166, 48.9779238179876],
                            [2.368091650323856, 48.97786742696167],
                            [2.368046393922648, 48.97778439015606],
                            [2.367895476099769, 48.97747333858149],
                            [2.367752794327838, 48.97719849436546],
                            [2.367426713732872, 48.97666857721104],
                            [2.367020056781713, 48.97598881504764],
                            [2.366580325829448, 48.97517658923916],
                            [2.366129903439056, 48.974293876965966],
                            [2.366045163371088, 48.974129735456415],
                            [2.366022103800066, 48.9740646587509],
                            [2.366005644538394, 48.9739917664468],
                            [2.366004450463085, 48.97391181565488],
                            [2.366011491055534, 48.97387259957961],
                            [2.366051715676765, 48.97365901297958],
                        ],
                    },
                },
                1551: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.835302511083114, 2.2810815860453197],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 475.356265894,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.278119178310992,
                            48.83435816545286,
                            2.284007243303418,
                            48.836122980192656,
                        ),
                        "coordinates": [
                            [2.278119178310992, 48.836122980192656],
                            [2.278237951915641, 48.83609678405708],
                            [2.278545683690248, 48.836029383303604],
                            [2.278886774789366, 48.835952306842685],
                            [2.279136697498584, 48.83588988213628],
                            [2.27918442915688, 48.83587717651966],
                            [2.279327472206564, 48.83583910001133],
                            [2.279778361451642, 48.83570762905595],
                            [2.280111493313643, 48.83560738813478],
                            [2.280892373310332, 48.835377397016735],
                            [2.281109972614775, 48.835314455471575],
                            [2.281269227285819, 48.83526722579823],
                            [2.28185500116781, 48.83509729971104],
                            [2.282259596293275, 48.834973342612216],
                            [2.28255746721389, 48.8348780483874],
                            [2.282918239478059, 48.83475152918301],
                            [2.283174875597654, 48.83465981933597],
                            [2.284007243303418, 48.83435816545286],
                        ],
                    },
                },
                1552: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.869966656552634, 2.408845743642952],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 544.131033924,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.408577577424641,
                            48.86752135721475,
                            2.409011164385188,
                            48.87240409441091,
                        ),
                        "coordinates": [
                            [2.408978939744509, 48.86752135721475],
                            [2.408998837129106, 48.86777765233132],
                            [2.409011164385188, 48.86798819761391],
                            [2.409006685113483, 48.86809211005284],
                            [2.408990504879415, 48.86837376355297],
                            [2.408960120092491, 48.86876289936185],
                            [2.408927039963372, 48.869159100390995],
                            [2.408876607496787, 48.869841233933265],
                            [2.408832396642393, 48.870399562956116],
                            [2.408811113804008, 48.870657989614685],
                            [2.408779088384545, 48.87096502433882],
                            [2.408766035928567, 48.87108215033496],
                            [2.408724683104051, 48.87137985862855],
                            [2.40866848548691, 48.8717545888889],
                            [2.408617791113111, 48.87211716561576],
                            [2.408577577424641, 48.87240409441091],
                        ],
                    },
                },
                1553: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.86547416646594, 2.4088318084387956],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 455.512187843,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.408718956428521,
                            48.86343374196472,
                            2.408978939744509,
                            48.86752135721475,
                        ),
                        "coordinates": [
                            [2.408832465143973, 48.86343374196472],
                            [2.408775052647432, 48.863709876940206],
                            [2.408757769459771, 48.86380310890794],
                            [2.408740447470364, 48.86389939393395],
                            [2.408728470523134, 48.86400141526672],
                            [2.408723773567325, 48.86412917209632],
                            [2.408718956428521, 48.86426763585822],
                            [2.408736300972492, 48.86445546413098],
                            [2.408768756205262, 48.86483725022594],
                            [2.408790955925442, 48.86512147287147],
                            [2.408838800700704, 48.865751550438944],
                            [2.408862278243629, 48.86606642679951],
                            [2.408888821138226, 48.86638136676809],
                            [2.408958939259751, 48.8672663565713],
                            [2.408978939744509, 48.86752135721475],
                        ],
                    },
                },
                1554: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.87453330722043, 2.4079483356333045],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 478.645222353,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.407034921962184,
                            48.87240409441091,
                            2.408577577424641,
                            48.87656877529156,
                        ),
                        "coordinates": [
                            [2.408577577424641, 48.87240409441091],
                            [2.408537363303342, 48.87269102221869],
                            [2.40848599919699, 48.87305298643375],
                            [2.408439256175569, 48.87335733063182],
                            [2.408375674455264, 48.873619711400984],
                            [2.408277248042592, 48.87390095599983],
                            [2.408196435989193, 48.87415563763391],
                            [2.408098656528367, 48.87437977849391],
                            [2.407992219165962, 48.87460387551569],
                            [2.407887339688682, 48.87483369086203],
                            [2.40721564514209, 48.87624583414235],
                            [2.407034921962184, 48.87656877529156],
                        ],
                    },
                },
                1555: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.977083281892575, 2.3748319792812764],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 390.027450412,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.372242923708274,
                            48.97666569235197,
                            2.377419674665871,
                            48.9774930899753,
                        ),
                        "coordinates": [
                            [2.377419674665871, 48.97666569235197],
                            [2.377108630538615, 48.97671285194592],
                            [2.376692916847606, 48.97677778819444],
                            [2.376163498216597, 48.97686021381992],
                            [2.375933115401471, 48.97690231790471],
                            [2.375536037780502, 48.9769801955793],
                            [2.375160138999204, 48.97704009835741],
                            [2.374763964948241, 48.97710275029474],
                            [2.373577676464839, 48.97728499969507],
                            [2.37252357000156, 48.97744834683884],
                            [2.372242923708274, 48.9774930899753],
                        ],
                    },
                },
                1556: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93333305333445, 2.3012098780388235],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 91.3392442283,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.300593399375418,
                            48.933272274648566,
                            2.301826356702229,
                            48.933393832020336,
                        ),
                        "coordinates": [
                            [2.301826356702229, 48.933272274648566],
                            [2.300593399375418, 48.933393832020336],
                        ],
                    },
                },
                1557: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE L",
                        "rer": 0,
                        "extcode": "800:L",
                        "geo_point_2d": [48.918559045836986, 2.189066380171806],
                        "indice_lig": "L",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01740",
                        "navette": 0,
                        "idrefliga": "A02176",
                        "shape_leng": 678.061753092,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.185353376302864,
                            48.91674629011933,
                            2.192783100891459,
                            48.920379373924355,
                        ),
                        "coordinates": [
                            [2.185353376302864, 48.920379373924355],
                            [2.186145208575256, 48.9200021067702],
                            [2.186767090397931, 48.919707886644076],
                            [2.188218351335855, 48.9189764806864],
                            [2.191073467000742, 48.917556762960395],
                            [2.192783100891459, 48.91674629011933],
                        ],
                    },
                },
                1558: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89705310906513, 2.321228667241783],
                        "indice_lig": "3",
                        "idf": 0,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 397.459147626,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.318802327261341,
                            48.89622649469053,
                            2.32372791300899,
                            48.89751671682976,
                        ),
                        "coordinates": [
                            [2.32372791300899, 48.89751671682976],
                            [2.323214017945659, 48.89750350760383],
                            [2.322382883556183, 48.89748435664232],
                            [2.322125764960298, 48.897460530954284],
                            [2.321828068740849, 48.89737126788545],
                            [2.318802327261341, 48.89622649469053],
                        ],
                    },
                },
                1559: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.921614381160495, 2.374410385257585],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 1880.72628955,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.362665598830465,
                            48.9181138030661,
                            2.386388291064694,
                            48.92435387966092,
                        ),
                        "coordinates": [
                            [2.362665598830465, 48.9181138030661],
                            [2.363478143656108, 48.91855141330591],
                            [2.36405306968269, 48.918812641663706],
                            [2.36451170589102, 48.91899959963967],
                            [2.365139271643608, 48.9192362595873],
                            [2.365832607695872, 48.91949305336527],
                            [2.366612598408511, 48.91974506184772],
                            [2.36714514342469, 48.919891589139716],
                            [2.367702052962826, 48.92003153025176],
                            [2.369381165336558, 48.92044744485632],
                            [2.374833951750855, 48.921787697589636],
                            [2.379077229578892, 48.9228450042737],
                            [2.381294626002303, 48.92338188875586],
                            [2.381998846325951, 48.92353864835505],
                            [2.382645281011191, 48.923676390866945],
                            [2.383505430681238, 48.92384717430447],
                            [2.384730442788796, 48.92406508965816],
                            [2.386215731473625, 48.924325531484065],
                            [2.386388291064694, 48.92435387966092],
                        ],
                    },
                },
                1560: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.93233098386442, 2.440228169391454],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 2149.90241574,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.425791425559954,
                            48.93073957031752,
                            2.454766382765777,
                            48.93276675757436,
                        ),
                        "coordinates": [
                            [2.425791425559954, 48.93073957031752],
                            [2.428528152212983, 48.93121178102294],
                            [2.430449835739028, 48.931570316835035],
                            [2.431520359358567, 48.931769964868174],
                            [2.433019732132433, 48.93203392978435],
                            [2.433756318582966, 48.93215836933001],
                            [2.434427421807771, 48.93226561039017],
                            [2.435154163202631, 48.93237280145819],
                            [2.436119854435582, 48.93250134014763],
                            [2.436673064985291, 48.932565545240536],
                            [2.437330991420099, 48.93262534376327],
                            [2.438231110321013, 48.932689237300416],
                            [2.439023182895177, 48.932729502346184],
                            [2.439838142529295, 48.93275895904921],
                            [2.440751239867408, 48.93276675757436],
                            [2.441906477903701, 48.93275707894835],
                            [2.443500240424713, 48.93274051079149],
                            [2.446327784323606, 48.932714121405446],
                            [2.447404462303159, 48.93269799355768],
                            [2.448147360264926, 48.932697272787074],
                            [2.448936099679803, 48.93270728607904],
                            [2.450788480793716, 48.93272486113904],
                            [2.453118638538401, 48.93272683062279],
                            [2.454766382765777, 48.93270621869947],
                        ],
                    },
                },
                1561: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.85503716906271, 2.2772881755497036],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 451.794529677,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.27516715468514,
                            48.85364805716894,
                            2.279487064962566,
                            48.8565315515406,
                        ),
                        "coordinates": [
                            [2.279487064962566, 48.85364805716894],
                            [2.278645134797464, 48.85415838819558],
                            [2.278597403766687, 48.85418804014216],
                            [2.278437847581405, 48.85428418111049],
                            [2.278358749742464, 48.85433360060904],
                            [2.278279650199504, 48.85438391940398],
                            [2.277717754978346, 48.854750534707186],
                            [2.276984019153974, 48.85521687696223],
                            [2.276653971583136, 48.855426235360966],
                            [2.276383924800431, 48.85560235021971],
                            [2.275899743151141, 48.85591863805947],
                            [2.275633768115702, 48.856103746925],
                            [2.275591482314248, 48.856134299385424],
                            [2.275307697992698, 48.8563922394989],
                            [2.275198539468295, 48.85649919474854],
                            [2.27516715468514, 48.8565315515406],
                        ],
                    },
                },
                1562: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.98362554148879, 2.653732769480825],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 2394.39688482,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.64240630231019,
                            48.97585875402045,
                            2.665059869307301,
                            48.99139140287414,
                        ),
                        "coordinates": [
                            [2.64240630231019, 48.97585875402045],
                            [2.644168510727709, 48.97706830926519],
                            [2.646324793730389, 48.97854483863396],
                            [2.647533687069544, 48.97937433914831],
                            [2.648557443154792, 48.980073465693806],
                            [2.654911340271517, 48.984434006448296],
                            [2.65855352505687, 48.98693167218184],
                            [2.663826827186031, 48.99055001233438],
                            [2.665059869307301, 48.99139140287414],
                        ],
                    },
                },
                1563: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.39414324789303, 2.8160168742601543],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 5136.87881929,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.79881830701568,
                            48.38677098743939,
                            2.842037388815223,
                            48.406805624897885,
                        ),
                        "coordinates": [
                            [2.842037388815223, 48.38677098743939],
                            [2.841698881704751, 48.386999855953114],
                            [2.839878665702851, 48.388226761946115],
                            [2.838143556900413, 48.38939972730359],
                            [2.837544526780852, 48.3897806892631],
                            [2.837134553605594, 48.390044821344645],
                            [2.836607065462349, 48.39034694415141],
                            [2.836119512082447, 48.390623907423375],
                            [2.835668945823051, 48.39084895411695],
                            [2.83408240518332, 48.39162148003852],
                            [2.831103505507769, 48.39303713316291],
                            [2.830528054791314, 48.39329765203071],
                            [2.83014956152507, 48.39346073478158],
                            [2.829881566168277, 48.393570672299724],
                            [2.829475620129279, 48.393706276319996],
                            [2.829154593818274, 48.393803848238434],
                            [2.828783556965095, 48.39390201192865],
                            [2.828467665926816, 48.39396967455417],
                            [2.82819794773668, 48.39402411696262],
                            [2.827832568496383, 48.39408122055157],
                            [2.827554901269172, 48.394120146885705],
                            [2.827264014486758, 48.39414773189826],
                            [2.826947988577312, 48.39416337781052],
                            [2.826575607155586, 48.39417034414367],
                            [2.826206466922244, 48.39417185217857],
                            [2.825833254602233, 48.394168191691634],
                            [2.825493437900992, 48.394164144647036],
                            [2.823783457785881, 48.39415226351903],
                            [2.822075734626787, 48.39415188405467],
                            [2.821592307910325, 48.39414946085202],
                            [2.821004911651968, 48.39414748154223],
                            [2.820705133902505, 48.39414606685596],
                            [2.820512033981404, 48.39414509454646],
                            [2.820186600917884, 48.394143788154],
                            [2.818838946406499, 48.39413695136086],
                            [2.818134064314846, 48.39413365817376],
                            [2.817606926935894, 48.3941249601547],
                            [2.817134530248559, 48.394100139419905],
                            [2.81668732339413, 48.39406819439624],
                            [2.816189815861812, 48.394009725785196],
                            [2.815771432355487, 48.39394251182733],
                            [2.815344499143934, 48.39386402912943],
                            [2.814991137657181, 48.39377915781205],
                            [2.814626141900765, 48.39368131112806],
                            [2.814188401472606, 48.39355691528615],
                            [2.813810556940763, 48.393435269505986],
                            [2.81333235213053, 48.39327092283402],
                            [2.812866592582483, 48.39310485479284],
                            [2.810843540665898, 48.39238392395131],
                            [2.808921195536454, 48.39168293027749],
                            [2.808442865797487, 48.39153324602262],
                            [2.807978570626317, 48.39140221830429],
                            [2.807614516569224, 48.39131201022576],
                            [2.807227671772651, 48.391238981846094],
                            [2.806732858670969, 48.391170897165715],
                            [2.806365347543632, 48.39113681719301],
                            [2.805944332402294, 48.39111327451771],
                            [2.805494019388149, 48.39109600426463],
                            [2.805111107451884, 48.391102760838336],
                            [2.804690703437515, 48.391129483769184],
                            [2.804291947776909, 48.39117931388007],
                            [2.803946614445723, 48.39123369876228],
                            [2.80366598979983, 48.39128718308189],
                            [2.803361137018171, 48.391350897184736],
                            [2.803099018722284, 48.391415250073045],
                            [2.802767779300291, 48.391513735138396],
                            [2.802447273412157, 48.39161698111626],
                            [2.802160754888316, 48.3917212653797],
                            [2.80189543125758, 48.391833807340085],
                            [2.80161448719968, 48.39195945593684],
                            [2.801339809708058, 48.39209977357042],
                            [2.801083953852368, 48.39224715035056],
                            [2.800780296939549, 48.39244111928857],
                            [2.800553958666709, 48.392593726580365],
                            [2.800295944181789, 48.39279821346106],
                            [2.800104647443416, 48.39297387530976],
                            [2.799905606796075, 48.39318168871287],
                            [2.799719898161118, 48.39338230983161],
                            [2.799531687052304, 48.39360256885954],
                            [2.799354223955843, 48.39387084124223],
                            [2.799233652168398, 48.39407439127353],
                            [2.799058488530579, 48.39445103470504],
                            [2.798960953198262, 48.39472267337228],
                            [2.798878916885008, 48.39500891820664],
                            [2.798842060542242, 48.39525906216381],
                            [2.79881830701568, 48.39552745645012],
                            [2.798819688616015, 48.39576273790373],
                            [2.7988629031904, 48.39610306069818],
                            [2.798896612390761, 48.39627185304748],
                            [2.798955570222556, 48.39646671462843],
                            [2.79905535965127, 48.396720382766084],
                            [2.799164181649549, 48.39701357850241],
                            [2.799300111446354, 48.397343466945806],
                            [2.799693675869852, 48.39824578350198],
                            [2.800055071403618, 48.39911101458101],
                            [2.800343730305794, 48.399787607719276],
                            [2.800588390616098, 48.40035353915334],
                            [2.800757533644887, 48.40074478578029],
                            [2.800895851718446, 48.4010985264152],
                            [2.801012627868062, 48.40139531976349],
                            [2.801069428520899, 48.4016139890723],
                            [2.801119812843373, 48.40195100447751],
                            [2.801144531048189, 48.40228722641916],
                            [2.801125588776809, 48.40259362862679],
                            [2.801084528943882, 48.40288344168194],
                            [2.801028098486295, 48.40313210892875],
                            [2.800936066678826, 48.40340316470453],
                            [2.800810398204481, 48.4036600247816],
                            [2.799779951109957, 48.405739683526534],
                            [2.799282511992191, 48.40672011416103],
                            [2.79923356025455, 48.406805624897885],
                        ],
                    },
                },
                1564: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.892455464731384, 2.7582854399744288],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 8655.33980794,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.706014179759928,
                            48.8821891367053,
                            2.810248220733339,
                            48.903072914208664,
                        ),
                        "coordinates": [
                            [2.706014179759928, 48.8821891367053],
                            [2.709375484980779, 48.8824111676089],
                            [2.710428777822778, 48.88248024410835],
                            [2.715016478477014, 48.8827798994872],
                            [2.726280027769635, 48.88351967938649],
                            [2.733400652177743, 48.88398428339932],
                            [2.739468032494127, 48.88437964400651],
                            [2.743862614581742, 48.88466438091066],
                            [2.744726926529753, 48.88472610325666],
                            [2.745340448209582, 48.88477309701174],
                            [2.745882480979813, 48.88482517884707],
                            [2.746495718033818, 48.88489159190308],
                            [2.746840051525796, 48.88494127218361],
                            [2.747203192642843, 48.885001685685246],
                            [2.747624962042376, 48.885078859665086],
                            [2.748006974436393, 48.88515771831079],
                            [2.748417177408356, 48.88525036101571],
                            [2.74881106788649, 48.88535077492454],
                            [2.749277757544674, 48.885483327259614],
                            [2.750009668731057, 48.885716753406264],
                            [2.750448469377692, 48.8858710023898],
                            [2.750929706032121, 48.88606366984338],
                            [2.751295984417808, 48.886218180256925],
                            [2.751824445451146, 48.886461590756376],
                            [2.752360201792092, 48.886737373488415],
                            [2.75292206344036, 48.887056262525334],
                            [2.753284295874559, 48.88728484180385],
                            [2.753778447093127, 48.88761940219653],
                            [2.754265859448557, 48.8879863870438],
                            [2.754675859175334, 48.8883289660809],
                            [2.755043763381204, 48.8886732407984],
                            [2.755357689361623, 48.88899765449675],
                            [2.755558413213702, 48.889216018463884],
                            [2.75576878506965, 48.88946829178819],
                            [2.755974544595164, 48.88972829554118],
                            [2.756187637709572, 48.890025302831944],
                            [2.756360684190425, 48.890290056707435],
                            [2.75652209584913, 48.890562565532406],
                            [2.756671969373155, 48.890853633702314],
                            [2.756840993479977, 48.891195548075224],
                            [2.75698903908279, 48.891546797393445],
                            [2.75721378960307, 48.892113777664406],
                            [2.757603999355214, 48.89315229252828],
                            [2.757814398444073, 48.893680750144405],
                            [2.757971831374042, 48.8940335065392],
                            [2.758138402333915, 48.89435999828909],
                            [2.758337842922513, 48.894698712696865],
                            [2.758487293073494, 48.89493731988943],
                            [2.758683886851511, 48.895215867748966],
                            [2.758920498766613, 48.895522042031395],
                            [2.759211263597993, 48.895866588669385],
                            [2.759520635252419, 48.89619717975332],
                            [2.759820052266498, 48.896486183767394],
                            [2.760180044938074, 48.896806065861604],
                            [2.760608430153115, 48.897147107148456],
                            [2.761154160992185, 48.89753696420038],
                            [2.761634268536855, 48.89784782916249],
                            [2.762159759267567, 48.898147816280115],
                            [2.762649218468428, 48.898411531340855],
                            [2.763239459277655, 48.8986855750103],
                            [2.76386205664282, 48.89894450396552],
                            [2.764416048543446, 48.89915657475931],
                            [2.765184816505803, 48.89941494959372],
                            [2.765920799171059, 48.8996370382502],
                            [2.766617588765472, 48.89983357178607],
                            [2.767307833512905, 48.90002370265334],
                            [2.767975180775979, 48.90019464107499],
                            [2.768805210766345, 48.90039708352339],
                            [2.769557015633235, 48.90056769493517],
                            [2.770292473736756, 48.90072551383138],
                            [2.770891181636923, 48.90084530194581],
                            [2.77208670812417, 48.90105967288213],
                            [2.773405842432053, 48.90128113630096],
                            [2.774270944580586, 48.90140417193767],
                            [2.774992813700457, 48.9014913456884],
                            [2.77582835188858, 48.90157593559043],
                            [2.776572583156457, 48.90162018447221],
                            [2.77737836005821, 48.90164491708148],
                            [2.778235840434936, 48.90163946549079],
                            [2.778781351905856, 48.901618082922695],
                            [2.779355998920116, 48.90158587736057],
                            [2.780037604331866, 48.90152755685707],
                            [2.780702814484427, 48.901452164550804],
                            [2.781419761235691, 48.90135086906315],
                            [2.781935479120705, 48.901267484700895],
                            [2.782768946833287, 48.90112075705325],
                            [2.787251530648178, 48.900322385530146],
                            [2.789125085937413, 48.89998863475841],
                            [2.789851562247297, 48.89986797619329],
                            [2.790419099092084, 48.89977149854775],
                            [2.790931655312532, 48.899700935975645],
                            [2.791567610992399, 48.89962773797598],
                            [2.792109629840084, 48.899582749744525],
                            [2.79266804479731, 48.89955482537314],
                            [2.793262283951812, 48.899537461239184],
                            [2.793973666945937, 48.89954318173152],
                            [2.794500015915063, 48.89956034695148],
                            [2.795058981720607, 48.89959236796883],
                            [2.795663677426774, 48.89965204289343],
                            [2.796294497248336, 48.89972659925727],
                            [2.796919020764601, 48.899822591446465],
                            [2.797680440216833, 48.899969421854344],
                            [2.798360702739717, 48.90012085993051],
                            [2.801170345093357, 48.90081829129491],
                            [2.802954501630847, 48.901262871821125],
                            [2.804185168500983, 48.9015662124856],
                            [2.807294562927077, 48.902343645665994],
                            [2.808327509011944, 48.902598694966855],
                            [2.810248220733339, 48.903072914208664],
                        ],
                    },
                },
                1565: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.61195541721638, 2.5767288541006903],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 3798.63575937,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.56958354823646,
                            48.595563837991776,
                            2.58394771106125,
                            48.62837555172384,
                        ),
                        "coordinates": [
                            [2.58394771106125, 48.595563837991776],
                            [2.583117344654084, 48.59747915687793],
                            [2.582574627318395, 48.598818573486696],
                            [2.582073603471251, 48.59996344602832],
                            [2.581087273327229, 48.60219500150275],
                            [2.580061588083991, 48.60446708110959],
                            [2.57951153778809, 48.605705508428805],
                            [2.578744745254357, 48.60738457044565],
                            [2.578446637034757, 48.60805855514081],
                            [2.577967609656476, 48.60916120253005],
                            [2.577655265455324, 48.60986376665252],
                            [2.577413868423425, 48.61039962783699],
                            [2.57667563520148, 48.61207861536173],
                            [2.576015382845692, 48.61356708785904],
                            [2.575553905565817, 48.61461020447449],
                            [2.575163322747977, 48.61547472146526],
                            [2.574698130966103, 48.61649880773506],
                            [2.574378699718054, 48.61723944756969],
                            [2.574123182059039, 48.617839572326695],
                            [2.573853385855744, 48.61845638251498],
                            [2.573217440869168, 48.619818948949],
                            [2.572913166623866, 48.620506889587936],
                            [2.57278970824799, 48.62078771955357],
                            [2.572663601230039, 48.62108204337581],
                            [2.572528048157026, 48.62138717766877],
                            [2.572392486483136, 48.62169051357187],
                            [2.572189848438892, 48.62215226050985],
                            [2.572032792067063, 48.622500604154915],
                            [2.571867703899166, 48.622872345615335],
                            [2.571656994738576, 48.62335029486997],
                            [2.571456971374416, 48.62379404918274],
                            [2.571285164909932, 48.62418109122728],
                            [2.570953586615855, 48.62492007805811],
                            [2.570797867899989, 48.625268416959315],
                            [2.570660987433426, 48.62558434382758],
                            [2.570541557777406, 48.625861565249814],
                            [2.570313429010005, 48.6264135510181],
                            [2.57010763665612, 48.62696626527897],
                            [2.569971896368711, 48.627297121567615],
                            [2.569800402378706, 48.62775385935917],
                            [2.569698750821867, 48.62803512581767],
                            [2.56958354823646, 48.62837555172384],
                        ],
                    },
                },
                1566: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.43712714134036, 2.756774937871566],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01745",
                        "navette": 0,
                        "idrefliga": "A02171",
                        "shape_leng": 1447.60649302,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.753177568842823,
                            48.430970724114694,
                            2.760926733738456,
                            48.442882064226566,
                        ),
                        "coordinates": [
                            [2.753177568842823, 48.430970724114694],
                            [2.753227367847633, 48.43108280821532],
                            [2.75339639305608, 48.431422105938125],
                            [2.754164768115173, 48.43276305632415],
                            [2.754629576730084, 48.433628840442324],
                            [2.755394865834612, 48.43497580257816],
                            [2.755929416209419, 48.43587488365372],
                            [2.756147380557123, 48.436244572186816],
                            [2.756363958669194, 48.43660976815724],
                            [2.756601118571874, 48.43701175793484],
                            [2.757408964657009, 48.43842509495271],
                            [2.757838092539092, 48.43917950611003],
                            [2.758226072944558, 48.439818093906354],
                            [2.758465072481294, 48.440174098574076],
                            [2.758744445361875, 48.44054058274868],
                            [2.759161056041372, 48.44106239900572],
                            [2.759440760725487, 48.44138390370022],
                            [2.759751457988305, 48.44171285281196],
                            [2.760926733738456, 48.442882064226566],
                        ],
                    },
                },
                1567: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M4",
                        "rer": 0,
                        "extcode": "100110004:4",
                        "geo_point_2d": [48.87822871699615, 2.3581444902607536],
                        "indice_lig": "4",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01374",
                        "navette": 0,
                        "idrefliga": "A01537",
                        "shape_leng": 501.871467035,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.356995164008545,
                            48.8759910648072,
                            2.358778837450684,
                            48.87955128443897,
                        ),
                        "coordinates": [
                            [2.357880771925327, 48.8759910648072],
                            [2.357917702575783, 48.87622647851419],
                            [2.357923200598282, 48.876678108822844],
                            [2.357922101797075, 48.87672377382293],
                            [2.357927603834513, 48.87682459981545],
                            [2.357943998129405, 48.876924910443215],
                            [2.357971198331283, 48.877024194416656],
                            [2.358009067597747, 48.87712194377018],
                            [2.358057413006152, 48.87721766462429],
                            [2.358092542404636, 48.87727577639196],
                            [2.358337336461553, 48.87770347181571],
                            [2.358719275252796, 48.87877903328285],
                            [2.358776635843635, 48.87909982572529],
                            [2.358778837450684, 48.879121902634296],
                            [2.358773238682761, 48.87915713186549],
                            [2.358756657966335, 48.87919082197179],
                            [2.358729819665947, 48.87922150462221],
                            [2.358693893865047, 48.879247835281326],
                            [2.358650454590658, 48.87926866403394],
                            [2.35860504932023, 48.87928227678857],
                            [2.356995164008545, 48.87955128443897],
                        ],
                    },
                },
                1568: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.90712643463097, 2.281447637918914],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 450.365738606,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.279278948726629,
                            48.90570604953261,
                            2.283628702682815,
                            48.908565915509755,
                        ),
                        "coordinates": [
                            [2.283628702682815, 48.90570604953261],
                            [2.283600782032804, 48.905721936264776],
                            [2.282318556436694, 48.9065398258799],
                            [2.28164308646769, 48.90699395643027],
                            [2.281184347458327, 48.907293531361624],
                            [2.280819511455299, 48.907539614892606],
                            [2.280186463797945, 48.90796168102705],
                            [2.279278948726629, 48.908565915509755],
                        ],
                    },
                },
                1569: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.86334100609141, 2.3333116189076137],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 517.130665118,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.330129877112861,
                            48.86234803084025,
                            2.336496460942477,
                            48.86434377873391,
                        ),
                        "coordinates": [
                            [2.336496460942477, 48.86234803084025],
                            [2.335772244523042, 48.8625777063287],
                            [2.331884205239422, 48.863779524727505],
                            [2.330129877112861, 48.86434377873391],
                        ],
                    },
                },
                1570: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.904450851080874, 2.204780681736337],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 3415.52982871,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192783100891459,
                            48.89692808639933,
                            2.221777707808168,
                            48.91674629011933,
                        ),
                        "coordinates": [
                            [2.192783100891459, 48.91674629011933],
                            [2.193725735015726, 48.9161839992704],
                            [2.194101940510942, 48.91592274315056],
                            [2.194503568944324, 48.915606791968955],
                            [2.194785931771599, 48.91533589863436],
                            [2.195090149149546, 48.91499603060137],
                            [2.19538003626147, 48.9146156958898],
                            [2.195604952597295, 48.91423052106892],
                            [2.195742977281143, 48.91393327354401],
                            [2.195859462951818, 48.91359317156233],
                            [2.195950690285819, 48.913248279133455],
                            [2.195994967487779, 48.91291046745926],
                            [2.196006627076923, 48.91261782283162],
                            [2.19599290884069, 48.91236321639478],
                            [2.19595772263991, 48.912041961833445],
                            [2.195882915835033, 48.91168972665501],
                            [2.195704434070419, 48.9109828424452],
                            [2.195654588800859, 48.910740087105765],
                            [2.195611954574173, 48.91049972194895],
                            [2.195594480129716, 48.910297455551444],
                            [2.195580801017772, 48.91003095341317],
                            [2.195592509592611, 48.90972165288696],
                            [2.195618607894856, 48.90942902524874],
                            [2.195659120032608, 48.90914593452513],
                            [2.195706809724843, 48.90887712822257],
                            [2.195783549645252, 48.90854649402663],
                            [2.19587843244082, 48.908182572445455],
                            [2.19602037815799, 48.90776874192739],
                            [2.196143991080384, 48.90745482099916],
                            [2.196292990889578, 48.90709810399634],
                            [2.196485401404511, 48.90670574892706],
                            [2.196717567255284, 48.90629440815585],
                            [2.196891643008049, 48.90600196227802],
                            [2.197130799896365, 48.90566914715772],
                            [2.197431391694582, 48.90530785493849],
                            [2.197735422495251, 48.905006050261],
                            [2.198075508941352, 48.904716183715976],
                            [2.198364842109605, 48.904504773816555],
                            [2.198686658119753, 48.904293402445255],
                            [2.199055415927369, 48.90407256929897],
                            [2.199449377132043, 48.90387317886656],
                            [2.199868571987392, 48.90368333569223],
                            [2.200352717387131, 48.903498326002484],
                            [2.200952406116703, 48.903294416912864],
                            [2.201515940545721, 48.903111874664084],
                            [2.202707989957476, 48.902734963218506],
                            [2.205164315518815, 48.90194549484479],
                            [2.206038467192384, 48.90166097580946],
                            [2.206522489156107, 48.90150687183555],
                            [2.207107573433606, 48.90134811996209],
                            [2.207383854603411, 48.90127586280445],
                            [2.208376972161176, 48.90102953145274],
                            [2.21094069439901, 48.90038609217506],
                            [2.21103760354624, 48.9003610196595],
                            [2.211223226295985, 48.900315360236],
                            [2.211305634022634, 48.90029358157169],
                            [2.211402021577201, 48.900272391331974],
                            [2.211750043883058, 48.9001945349828],
                            [2.213704419545095, 48.89975151155565],
                            [2.214135683471314, 48.89965575219874],
                            [2.214491896411483, 48.89957160135835],
                            [2.214528745653255, 48.89956264828615],
                            [2.216256644337465, 48.89912203675955],
                            [2.218055495817916, 48.89865719226297],
                            [2.218778877879909, 48.89845830109352],
                            [2.219526901819428, 48.898218063825986],
                            [2.219582882383434, 48.89819384002888],
                            [2.219625202304824, 48.898177696713724],
                            [2.219656603876241, 48.8981651389211],
                            [2.219670257945743, 48.898158857927484],
                            [2.220238209303541, 48.897928323764816],
                            [2.220746184668005, 48.897678840754786],
                            [2.221131434470219, 48.89741484356145],
                            [2.221201114629203, 48.8973636544105],
                            [2.221418348168514, 48.89720560104489],
                            [2.221642436581132, 48.897032266313985],
                            [2.221777707808168, 48.89692808639933],
                        ],
                    },
                },
                1571: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.97675212855222, 2.2649559103886157],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 1389.9858931,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.262935722791332,
                            48.97051992210463,
                            2.270035426257897,
                            48.980377556311645,
                        ),
                        "coordinates": [
                            [2.270035426257897, 48.980377556311645],
                            [2.269081199987407, 48.980237598400976],
                            [2.268398152677566, 48.9801301234452],
                            [2.268033150235689, 48.98006566282356],
                            [2.267538065876373, 48.97996305262211],
                            [2.267180319859156, 48.9798819389715],
                            [2.266802722503067, 48.979771230636224],
                            [2.266421558315122, 48.97964116253644],
                            [2.266154222341803, 48.97953392843443],
                            [2.265843556403992, 48.97939335562487],
                            [2.265536517149731, 48.97924326665335],
                            [2.265272845884962, 48.979102721946525],
                            [2.26501643663722, 48.97894076571651],
                            [2.264741989672952, 48.97875500467351],
                            [2.26453256734434, 48.97859783791925],
                            [2.264272625131723, 48.9783835331386],
                            [2.264059665491615, 48.978174015887724],
                            [2.263897256079431, 48.97800498014507],
                            [2.263691593327449, 48.97775263831284],
                            [2.263561710145016, 48.977588382515464],
                            [2.263421081252494, 48.977359876771],
                            [2.263291310966419, 48.97712185947384],
                            [2.263165215872408, 48.97684101568385],
                            [2.263086014920816, 48.97662682343224],
                            [2.2630176916121, 48.97639122715924],
                            [2.26295666875579, 48.97610566593455],
                            [2.262938928509338, 48.975881997856966],
                            [2.262935722791332, 48.975608371534236],
                            [2.262946885926966, 48.97539423777607],
                            [2.262976140104324, 48.975168219881205],
                            [2.26302713927824, 48.97489938767443],
                            [2.263358352013193, 48.973348272954006],
                            [2.263557622576995, 48.972443461278715],
                            [2.263883026060117, 48.97072420004332],
                            [2.263924959788352, 48.97051992210463],
                        ],
                    },
                },
                1572: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.90933605194981, 2.214401158156069],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 3618.69234236,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.192783100891459,
                            48.906318772930035,
                            2.236878028463527,
                            48.91674629011933,
                        ),
                        "coordinates": [
                            [2.192783100891459, 48.91674629011933],
                            [2.193915561241419, 48.91622336999507],
                            [2.195619087440587, 48.91542111950458],
                            [2.200583681399877, 48.91300098223639],
                            [2.205766616901968, 48.91046872340311],
                            [2.207078776833063, 48.90983951859015],
                            [2.20826488470903, 48.90926499397887],
                            [2.208916038325867, 48.90898458381016],
                            [2.209645387921564, 48.90869956889323],
                            [2.210328442301554, 48.90844729986156],
                            [2.211118152610841, 48.908178742960885],
                            [2.211843789736813, 48.90794759651771],
                            [2.212804110778444, 48.907669843799354],
                            [2.213821236911601, 48.907410885171636],
                            [2.214841854740157, 48.90717300926446],
                            [2.215745060978295, 48.90698419743309],
                            [2.216303296889348, 48.90688404392444],
                            [2.217074837322181, 48.906758342074454],
                            [2.21794943210056, 48.90663742525696],
                            [2.218799099304425, 48.90653521810571],
                            [2.219929542608957, 48.90642860870042],
                            [2.220768420154927, 48.90637791965439],
                            [2.221610819313726, 48.90633894333512],
                            [2.222524257991393, 48.906318772930035],
                            [2.223469633201166, 48.906319713687424],
                            [2.224798803220401, 48.90633976445279],
                            [2.225832811763191, 48.90637021566337],
                            [2.226970585991264, 48.90643515480475],
                            [2.228398733302602, 48.906573771226874],
                            [2.229391170253993, 48.90667365826203],
                            [2.230223814786464, 48.906776581474865],
                            [2.231051530430233, 48.90692098714641],
                            [2.231772672864093, 48.90708763450442],
                            [2.232595374004243, 48.90731821074712],
                            [2.233601896691025, 48.90764151294627],
                            [2.235102013580883, 48.90813122937256],
                            [2.236878028463527, 48.90869458435905],
                        ],
                    },
                },
                1573: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.86663277356688, 2.318207826209037],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 744.651110372,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313545549946741,
                            48.86589520521479,
                            2.322943412243542,
                            48.86790534489709,
                        ),
                        "coordinates": [
                            [2.322943412243542, 48.866285804583875],
                            [2.322791612316988, 48.866265512685175],
                            [2.322629286699457, 48.866240551872785],
                            [2.322473102947478, 48.8662139762067],
                            [2.322299448247759, 48.86618220031736],
                            [2.321647897114153, 48.86605489495015],
                            [2.321376990947967, 48.866004727928456],
                            [2.321231146501717, 48.865979960280725],
                            [2.321095387063231, 48.865958848846184],
                            [2.320967066548198, 48.86594098383384],
                            [2.320844854143403, 48.86592618054484],
                            [2.32069893628887, 48.86591178219359],
                            [2.320559667000209, 48.86590185788466],
                            [2.320426065619082, 48.86589634091773],
                            [2.320297495845765, 48.86589520521479],
                            [2.320173259657679, 48.8658984540221],
                            [2.320053146910467, 48.86590610144838],
                            [2.319936828756733, 48.865918169919816],
                            [2.319824052647728, 48.86593468499269],
                            [2.318894868605297, 48.866219176534294],
                            [2.314543523694076, 48.86759079843662],
                            [2.31388193904531, 48.867799734463226],
                            [2.313545549946741, 48.86790534489709],
                        ],
                    },
                },
                1574: {
                    "attributes": {
                        "reseau": "PARIS EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.87951177074579, 2.5389265225235627],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01747",
                        "navette": 0,
                        "idrefliga": "A02170",
                        "shape_leng": 2173.91762563,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.525434250765843,
                            48.877157839702775,
                            2.552881649780832,
                            48.88373428097723,
                        ),
                        "coordinates": [
                            [2.525434250765843, 48.88373428097723],
                            [2.526666287004969, 48.88322464273962],
                            [2.529893665234711, 48.88189251276156],
                            [2.532193078549603, 48.88094638425414],
                            [2.53263711346043, 48.880766017590894],
                            [2.533258374056588, 48.88052186468117],
                            [2.533787208099623, 48.880321963756685],
                            [2.534420641712197, 48.88009741051807],
                            [2.535060507629551, 48.87988882378437],
                            [2.53570041386419, 48.87969165420274],
                            [2.536810253929025, 48.87937564330709],
                            [2.53760020105514, 48.87917439357388],
                            [2.538355588221693, 48.87899223367205],
                            [2.538972613438071, 48.87885219000443],
                            [2.539638713895057, 48.878715863499934],
                            [2.540322132397052, 48.87858140561485],
                            [2.54108058223252, 48.878446808795324],
                            [2.541775614810747, 48.87833135645167],
                            [2.542626436694511, 48.878204198988534],
                            [2.543448481188119, 48.87809802464671],
                            [2.5444321247588, 48.87798964755984],
                            [2.545955286181782, 48.87784791717988],
                            [2.54833518545465, 48.87762083257569],
                            [2.552881649780832, 48.877157839702775],
                        ],
                    },
                },
                1575: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.22528740794571, 2.4313955383037325],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01746",
                        "navette": 0,
                        "idrefliga": "A02173",
                        "shape_leng": 3421.96527609,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.417369391049351,
                            49.21385632476746,
                            2.44364447306937,
                            49.23889870640681,
                        ),
                        "coordinates": [
                            [2.417369391049351, 49.21385632476746],
                            [2.423768295033752, 49.21710297449618],
                            [2.426015745894975, 49.218571759838966],
                            [2.430514530664024, 49.22334732339265],
                            [2.44364447306937, 49.23889870640681],
                        ],
                    },
                },
                1576: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.859803289024555, 2.344207399008999],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 506.508296612,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.341108591634067,
                            48.85879919807379,
                            2.347305852747763,
                            48.8608062912721,
                        ),
                        "coordinates": [
                            [2.347305852747763, 48.85879919807379],
                            [2.346739760099759, 48.8589837404775],
                            [2.341108591634067, 48.8608062912721],
                        ],
                    },
                },
                1577: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M1",
                        "rer": 0,
                        "extcode": "100110001:1",
                        "geo_point_2d": [48.85811344252387, 2.349434369864337],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01371",
                        "navette": 0,
                        "idrefliga": "A01534",
                        "shape_leng": 346.385650611,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.347305852747763,
                            48.85747798252934,
                            2.351577562994996,
                            48.85879919807379,
                        ),
                        "coordinates": [
                            [2.351577562994996, 48.85747798252934],
                            [2.351292209334574, 48.85755155329652],
                            [2.350512141088024, 48.85775267693639],
                            [2.347305852747763, 48.85879919807379],
                        ],
                    },
                },
                1578: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [49.046150180136536, 2.0981522761291633],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 446.377365123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.095195067225969,
                            49.04564873988319,
                            2.101108482966614,
                            49.04664576264113,
                        ),
                        "coordinates": [
                            [2.101108482966614, 49.04564873988319],
                            [2.099538274275683, 49.04593526764531],
                            [2.096377570034755, 49.04643086426444],
                            [2.095195067225969, 49.04664576264113],
                        ],
                    },
                },
                1579: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.81473854538891, 2.249093345756752],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1983.69373123,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.240883069335648,
                            48.80749262578012,
                            2.258759767033708,
                            48.81967448818826,
                        ),
                        "coordinates": [
                            [2.258759767033708, 48.81967448818826],
                            [2.258506352776809, 48.81957010317677],
                            [2.257893897515079, 48.81934396260658],
                            [2.257583586959452, 48.81923043900402],
                            [2.256594130534755, 48.81887543201725],
                            [2.256519273925318, 48.818849300662436],
                            [2.256136816724805, 48.818722233052924],
                            [2.255992534474839, 48.818680763821654],
                            [2.255652246683856, 48.818583400392406],
                            [2.255077804364769, 48.81844360293296],
                            [2.254879051828954, 48.81840209336958],
                            [2.253531883174579, 48.81813072459972],
                            [2.252545718540255, 48.817927280408895],
                            [2.251944238953642, 48.81779597063782],
                            [2.25164166513815, 48.81771389460787],
                            [2.251278000468443, 48.81761226471433],
                            [2.25094671016942, 48.81750494549433],
                            [2.250626258966474, 48.817380977153945],
                            [2.25039944963085, 48.81727849423599],
                            [2.250154672734464, 48.8171498247847],
                            [2.24990630200787, 48.817016392461504],
                            [2.249621957896679, 48.8168520006654],
                            [2.249348443604211, 48.816675720510254],
                            [2.248995841976396, 48.8164018264063],
                            [2.248733210482238, 48.81618748238978],
                            [2.248481417867572, 48.81595649242603],
                            [2.248258431002338, 48.81573742008663],
                            [2.248057023649177, 48.81553977796389],
                            [2.247877238868138, 48.81533977386025],
                            [2.247744229427276, 48.815175496319114],
                            [2.247589735663198, 48.814937440920666],
                            [2.247481984705417, 48.814751767959145],
                            [2.247374270913074, 48.81454706029154],
                            [2.247301184889382, 48.81438023178854],
                            [2.246993242965602, 48.81373970536708],
                            [2.246864387481381, 48.813462627047706],
                            [2.246753355226291, 48.81324269514836],
                            [2.246622855236019, 48.812999309169584],
                            [2.246326852250612, 48.81254224249612],
                            [2.246155698888792, 48.81231728722722],
                            [2.246018485062752, 48.81214811409195],
                            [2.245851335133564, 48.811969024947025],
                            [2.245688227582815, 48.81181332020108],
                            [2.245525125996986, 48.811654917048436],
                            [2.245232835999329, 48.81140918049756],
                            [2.245016712422211, 48.811242804130856],
                            [2.244708005097074, 48.81100858003137],
                            [2.244063511801291, 48.81052964281425],
                            [2.243227257418416, 48.80994083343499],
                            [2.242926769142224, 48.80972206221579],
                            [2.24267117380369, 48.80952401075466],
                            [2.242418308941523, 48.80932326341211],
                            [2.242198158636191, 48.80910365737626],
                            [2.241866636933593, 48.80874277190482],
                            [2.24170636582845, 48.8085394027854],
                            [2.241470040372006, 48.80823884723812],
                            [2.241178040929646, 48.80786270460133],
                            [2.240883069335648, 48.80749262578012],
                        ],
                    },
                },
                1580: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.58280828379595, 2.2920727742292355],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01857",
                        "navette": 0,
                        "idrefliga": "A02179",
                        "shape_leng": 3812.58387719,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.289865556646717,
                            48.565593862821814,
                            2.297950577822679,
                            48.599059348508746,
                        ),
                        "coordinates": [
                            [2.297950577822679, 48.599059348508746],
                            [2.297796610370011, 48.598739963504954],
                            [2.29742850385053, 48.598064147306225],
                            [2.297065960805043, 48.59739274863074],
                            [2.29646365374937, 48.5962699549272],
                            [2.295961268022348, 48.59534440502075],
                            [2.295430363290502, 48.59435816283735],
                            [2.294850945938367, 48.59329794612421],
                            [2.294274423986171, 48.59222445438471],
                            [2.293692204962389, 48.59115475080187],
                            [2.293112861085381, 48.59009642094857],
                            [2.292827498452052, 48.5895520879013],
                            [2.292553570329796, 48.58901344682872],
                            [2.292288231678495, 48.58846532684841],
                            [2.292045760295363, 48.58792480030807],
                            [2.291806154535732, 48.587378585916504],
                            [2.291586565575498, 48.58683048298481],
                            [2.291244437224698, 48.58588791063855],
                            [2.291056305540707, 48.5853341299479],
                            [2.290910974206209, 48.58486190564954],
                            [2.290748567703737, 48.584313824869284],
                            [2.290600474524313, 48.58374488968763],
                            [2.290469525048672, 48.58318165066457],
                            [2.290347151288747, 48.58262220726403],
                            [2.290236220000186, 48.582055184476786],
                            [2.290142434970886, 48.581490063626234],
                            [2.290062936435053, 48.580930638275824],
                            [2.289997746245572, 48.58035415126983],
                            [2.289946827126436, 48.57979663468733],
                            [2.289901645858044, 48.57921826042657],
                            [2.289873600697814, 48.57865316685381],
                            [2.289865556646717, 48.57808997802331],
                            [2.289866099180354, 48.577513520210275],
                            [2.289878059465193, 48.57695033959064],
                            [2.28990146075575, 48.57637578711881],
                            [2.290106470664412, 48.57411364920344],
                            [2.290322897717185, 48.57184393218805],
                            [2.290481595376772, 48.57018288599388],
                            [2.290591216436173, 48.56905466561792],
                            [2.290686413694198, 48.568072448890774],
                            [2.290796029791331, 48.566940435592386],
                            [2.290924468489718, 48.565593862821814],
                        ],
                    },
                },
                1581: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.74638396186467, 2.422303450937929],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1574.8577434,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.418113047325797,
                            48.739830699436546,
                            2.426399820474823,
                            48.75288655674139,
                        ),
                        "coordinates": [
                            [2.426399820474823, 48.739830699436546],
                            [2.426225698495076, 48.74022229971281],
                            [2.425884234238307, 48.74087274164829],
                            [2.425800210283278, 48.74102658370741],
                            [2.42533649689724, 48.741750860369116],
                            [2.424837441032456, 48.742489550721984],
                            [2.424658408258681, 48.742742384591885],
                            [2.424049480877902, 48.74364392478024],
                            [2.423513832793183, 48.74447346464863],
                            [2.423211442085479, 48.744953906391345],
                            [2.42294702566572, 48.7453794629365],
                            [2.422442529908542, 48.74615951408769],
                            [2.422161801042074, 48.74659587273325],
                            [2.420869300454085, 48.748607609694574],
                            [2.420646855145592, 48.74894769907054],
                            [2.420140972652831, 48.74975381966134],
                            [2.419362382815036, 48.7509540180889],
                            [2.418988003244222, 48.751535219516676],
                            [2.418516375847919, 48.75226363932598],
                            [2.418113047325797, 48.75288655674139],
                        ],
                    },
                },
                1582: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.766125081475366, 2.307399127262847],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 1104.04289776,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.30422734755186,
                            48.7616936904074,
                            2.310205453235823,
                            48.77072199352213,
                        ),
                        "coordinates": [
                            [2.30422734755186, 48.7616936904074],
                            [2.30448702498211, 48.762229499190795],
                            [2.304606587808542, 48.76244445960616],
                            [2.304757403499962, 48.76271068674241],
                            [2.304954437543657, 48.763029983643435],
                            [2.305046842631872, 48.763175691180855],
                            [2.305124300128375, 48.76329801372624],
                            [2.305207195918283, 48.76342483441108],
                            [2.305688330605782, 48.76406974500996],
                            [2.305969704377148, 48.764404350828926],
                            [2.306066213182814, 48.76452218093062],
                            [2.306354406473963, 48.76483520483564],
                            [2.308714389418808, 48.76753542538213],
                            [2.308825862906582, 48.767673940826114],
                            [2.30910437360496, 48.76804598520257],
                            [2.309266299431651, 48.76827296357564],
                            [2.309416533349663, 48.76853048513031],
                            [2.309621019229655, 48.76890793546103],
                            [2.309821382815505, 48.769329612286604],
                            [2.310027046018928, 48.76990192873632],
                            [2.310123662310302, 48.77024347468075],
                            [2.310184716362251, 48.770556435561986],
                            [2.310205453235823, 48.77072199352213],
                        ],
                    },
                },
                1583: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.83456161181582, 2.26714065541585],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 1119.0257888,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.263689648725751,
                            48.830119640157896,
                            2.270458243787242,
                            48.83908975542995,
                        ),
                        "coordinates": [
                            [2.270458243787242, 48.83908975542995],
                            [2.269785380384059, 48.83836404985602],
                            [2.269323566514949, 48.83782621806188],
                            [2.268981743080527, 48.837388216974766],
                            [2.268672504633892, 48.836900536377016],
                            [2.26837402517641, 48.836403075973415],
                            [2.267993049190534, 48.83562004519543],
                            [2.267885248402062, 48.8353844250816],
                            [2.267661327415963, 48.83487388104411],
                            [2.267500638937627, 48.83458208794027],
                            [2.267353175919909, 48.83436072036364],
                            [2.267252457364585, 48.83421789828468],
                            [2.267112139057428, 48.83404412060627],
                            [2.266953785359692, 48.833879849245115],
                            [2.266298799978871, 48.83319419792548],
                            [2.265906533237247, 48.83278708759249],
                            [2.265773372363419, 48.83265376200334],
                            [2.265557462502357, 48.832420452297434],
                            [2.265442328836309, 48.83228475829323],
                            [2.265305600083296, 48.8321276359963],
                            [2.264175608397526, 48.83072037315834],
                            [2.263779952993441, 48.830230914423204],
                            [2.263689648725751, 48.830119640157896],
                        ],
                    },
                },
                1584: {
                    "attributes": {
                        "reseau": "RER B",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER B",
                        "rer": 1,
                        "extcode": "810:B",
                        "geo_point_2d": [48.75832306385392, 2.302599679605472],
                        "indice_lig": "B",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01743",
                        "navette": 0,
                        "idrefliga": "A01857",
                        "shape_leng": 787.196375798,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.300986855734952,
                            48.75494652553112,
                            2.30422734755186,
                            48.7616936904074,
                        ),
                        "coordinates": [
                            [2.300986855734952, 48.75494652553112],
                            [2.301184446329389, 48.75542156373634],
                            [2.301358939329943, 48.75582394922426],
                            [2.301664510199875, 48.75645533362131],
                            [2.302104585864887, 48.757306179921684],
                            [2.303090678472115, 48.7592965669328],
                            [2.30321020511161, 48.75954480098906],
                            [2.303475064212575, 48.76010422645533],
                            [2.30404826993731, 48.76131031756729],
                            [2.30422734755186, 48.7616936904074],
                        ],
                    },
                },
                1585: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.75272752082853, 1.4405264439085566],
                        "indice_lig": "TER",
                        "idf": 0,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 11587.0232382,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.369974234117775,
                            48.73095466998517,
                            1.513333052350337,
                            48.76842177662328,
                        ),
                        "coordinates": [
                            [1.513333052350337, 48.76842177662328],
                            [1.465087663005076, 48.75628477235596],
                            [1.453261783992116, 48.75423281718814],
                            [1.446780135690037, 48.75393724152336],
                            [1.439360958395429, 48.75424666912322],
                            [1.432504311525692, 48.75419242763463],
                            [1.424917643412635, 48.7535191730065],
                            [1.413293012822981, 48.750729351540116],
                            [1.401502801422001, 48.74695655934176],
                            [1.396905322603665, 48.74508042925141],
                            [1.388290529355104, 48.740106922724124],
                            [1.383530027802968, 48.7371259191559],
                            [1.369974234117775, 48.73095466998517],
                        ],
                    },
                },
                1586: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.87066403567573, 2.3785906030104242],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 455.960618937,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.376702144728945,
                            48.86909116202569,
                            2.380542586000037,
                            48.872310113783094,
                        ),
                        "coordinates": [
                            [2.376702144728945, 48.872310113783094],
                            [2.377029776704534, 48.8719936917602],
                            [2.378114126560166, 48.870986284180276],
                            [2.379312767350272, 48.870078267242796],
                            [2.380542586000037, 48.86909116202569],
                        ],
                    },
                },
                1587: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.883189158332556, 2.334615129417215],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 430.6871953,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.331926590885041,
                            48.88239015067237,
                            2.337294790567405,
                            48.88395857351673,
                        ),
                        "coordinates": [
                            [2.331926590885041, 48.88395857351673],
                            [2.333960951053968, 48.88339507806021],
                            [2.335458319446941, 48.88295223114213],
                            [2.337085136498658, 48.88244269088155],
                            [2.337294790567405, 48.88239015067237],
                        ],
                    },
                },
                1588: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.84896893179731, 2.397693650095946],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 681.743611059,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.395056004207901,
                            48.84783295373849,
                            2.39919387441627,
                            48.85151027816436,
                        ),
                        "coordinates": [
                            [2.398302344267162, 48.85151027816436],
                            [2.398414955977225, 48.85133544305261],
                            [2.39877478097606, 48.850454059634906],
                            [2.399182922285433, 48.84903746583947],
                            [2.39918838920797, 48.84901515606063],
                            [2.39919387441627, 48.84896041030399],
                            [2.399188253332958, 48.848905671727465],
                            [2.399171627842572, 48.84885191663927],
                            [2.399144293539979, 48.8488001034311],
                            [2.399106739914161, 48.84875115639131],
                            [2.399059635533251, 48.8487059503419],
                            [2.399003820104906, 48.84866528991464],
                            [2.39894029364709, 48.848629903201726],
                            [2.398870184033299, 48.84860042000954],
                            [2.398794748407294, 48.84857736736989],
                            [2.398739726011954, 48.84856532462844],
                            [2.398468738179878, 48.848515128486845],
                            [2.398327946079994, 48.84848815491886],
                            [2.398041273774171, 48.848427616400365],
                            [2.397758145529699, 48.84836020777725],
                            [2.397478937884238, 48.84828601820655],
                            [2.39720402043055, 48.84820514760561],
                            [2.396933765374897, 48.848117704901334],
                            [2.396804421962322, 48.8480729422465],
                            [2.396489562180373, 48.84795874178327],
                            [2.396384292911742, 48.84792045403692],
                            [2.396299125084866, 48.847889447172825],
                            [2.396209229947739, 48.847864927714475],
                            [2.396153439679273, 48.84785435213684],
                            [2.396115741736055, 48.847847205358484],
                            [2.396019835215954, 48.847836501872514],
                            [2.395922714753978, 48.84783295373849],
                            [2.39582560216002, 48.84783660309789],
                            [2.395729721607581, 48.84784740576996],
                            [2.395636275171406, 48.84786522573187],
                            [2.395546441425514, 48.847889838708966],
                            [2.395461344074135, 48.8479209347137],
                            [2.395382061408112, 48.8479581252878],
                            [2.395309582775471, 48.84800093698621],
                            [2.395244823268825, 48.84804883753179],
                            [2.395188596629219, 48.84810122218725],
                            [2.395141612322898, 48.848157430827335],
                            [2.395104457700725, 48.84821675864022],
                            [2.395077602043129, 48.84827845974458],
                            [2.395061382838217, 48.84834175521392],
                            [2.395056004207901, 48.84840585105542],
                            [2.395061531403424, 48.848469942678356],
                            [2.39506230542588, 48.84847428597437],
                        ],
                    },
                },
                1589: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98532092323638, 2.1710129580525397],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 1746.00734146,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.161906605592158,
                            48.98026352072714,
                            2.180012382147682,
                            48.99028999637593,
                        ),
                        "coordinates": [
                            [2.180012382147682, 48.98026352072714],
                            [2.179744028518352, 48.980534397773155],
                            [2.17943952143388, 48.9808052247129],
                            [2.179149542791524, 48.98105465508013],
                            [2.178729144981954, 48.98139194229784],
                            [2.178265330202148, 48.98173868401558],
                            [2.177888571497791, 48.98199037099218],
                            [2.177461178654776, 48.98224912582839],
                            [2.177026603469663, 48.98249121140953],
                            [2.176501567665112, 48.98275934306846],
                            [2.175944033983173, 48.983013150491665],
                            [2.17535761170449, 48.98325739537508],
                            [2.174525169018463, 48.98355839521004],
                            [2.17337421097981, 48.98397552111971],
                            [2.171919191813018, 48.98450402653379],
                            [2.171463047489131, 48.984696093955996],
                            [2.170995990963719, 48.98490718010388],
                            [2.170572318568492, 48.98511594750829],
                            [2.170134094507895, 48.985350864954775],
                            [2.169710270453896, 48.98560245836311],
                            [2.16924290881962, 48.98589919035854],
                            [2.166532546034458, 48.98769873133757],
                            [2.16506500094823, 48.98866017298146],
                            [2.164586749680049, 48.98895211373551],
                            [2.164267965424287, 48.9891324616969],
                            [2.163963686196905, 48.98929855765896],
                            [2.161906605592158, 48.99028999637593],
                        ],
                    },
                },
                1590: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.957827453533355, 2.1115298712040653],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01748",
                        "navette": 0,
                        "idrefliga": "A02174",
                        "shape_leng": 2796.60246074,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.093521901580612,
                            48.95540224453111,
                            2.129363096573621,
                            48.95942081579221,
                        ),
                        "coordinates": [
                            [2.093521901580612, 48.95540224453111],
                            [2.095275119180811, 48.955654064388554],
                            [2.096018815220241, 48.95577460055809],
                            [2.096618009515849, 48.95589244985157],
                            [2.097199058945369, 48.956026914310016],
                            [2.097718688332133, 48.95616124466473],
                            [2.098281520495417, 48.95632897650449],
                            [2.098880347475981, 48.956525331014426],
                            [2.099544077984347, 48.956750368259605],
                            [2.100608189393563, 48.95711899271907],
                            [2.101315248701186, 48.95735362746025],
                            [2.101924995466158, 48.95753809210881],
                            [2.102520396662549, 48.9577011077294],
                            [2.103123116157908, 48.957845103723315],
                            [2.10378009657946, 48.95797730778482],
                            [2.105895487496369, 48.958393226526475],
                            [2.106750946297849, 48.95858172935578],
                            [2.107656871894758, 48.9587976901254],
                            [2.10843651616127, 48.95897532140973],
                            [2.109136849052834, 48.959114719293304],
                            [2.109956464466103, 48.959244833795324],
                            [2.110639000414662, 48.959327083613374],
                            [2.111484219680787, 48.95939061488035],
                            [2.112322369032908, 48.95942081579221],
                            [2.113048645423283, 48.95941985921476],
                            [2.113803934326044, 48.95939516179983],
                            [2.114483473045252, 48.959341760471695],
                            [2.115260661327089, 48.95926713041187],
                            [2.1162728894209, 48.959152498848795],
                            [2.117111658406051, 48.95904228229965],
                            [2.118178295502507, 48.95887777293547],
                            [2.11932823883308, 48.95866582398323],
                            [2.120514540667297, 48.958412715591315],
                            [2.121747998698349, 48.95815101361782],
                            [2.124008480816989, 48.95763495050819],
                            [2.124915992428352, 48.957424777452],
                            [2.12539347128279, 48.957297175832075],
                            [2.126178595154797, 48.95704403509915],
                            [2.126703321605904, 48.95684989304958],
                            [2.127304104646893, 48.956610682942866],
                            [2.127894166345738, 48.95634289591625],
                            [2.128563966706861, 48.95601338786181],
                            [2.129363096573621, 48.95558242610153],
                        ],
                    },
                },
                1591: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M14",
                        "rer": 0,
                        "extcode": "100110014:14",
                        "geo_point_2d": [48.83676484897362, 2.3844875413450612],
                        "indice_lig": "14",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01384",
                        "navette": 0,
                        "idrefliga": "A01547",
                        "shape_leng": 1086.04027817,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.37955401121414,
                            48.83333855925167,
                            2.388074174847077,
                            48.84000138864879,
                        ),
                        "coordinates": [
                            [2.386632402066985, 48.83333855925167],
                            [2.386738426372, 48.83342675340629],
                            [2.386778482521536, 48.83346162487016],
                            [2.387526666161088, 48.834112950974614],
                            [2.387746957134371, 48.83434358081963],
                            [2.387955197062759, 48.83465324954469],
                            [2.387985944939953, 48.83470666101391],
                            [2.388024274151433, 48.8347902633905],
                            [2.388051869840857, 48.83487569050738],
                            [2.388068542821571, 48.83496234242655],
                            [2.388074174847077, 48.83504961057664],
                            [2.388068722626193, 48.83513688406897],
                            [2.388052227350062, 48.835223550645296],
                            [2.388024806457447, 48.83530900203223],
                            [2.387986648124007, 48.8353926393091],
                            [2.387938020778722, 48.83547387475582],
                            [2.387879268923678, 48.83555213992606],
                            [2.387810800875353, 48.83562688558483],
                            [2.387733099610712, 48.83569758626143],
                            [2.387646707709098, 48.83576374646837],
                            [2.387552232781376, 48.83582490252857],
                            [2.38745033652869, 48.83588062611724],
                            [2.387341734722308, 48.83593052606141],
                            [2.387227187645048, 48.83597425008992],
                            [2.387199805356289, 48.83598349287898],
                            [2.386277716774315, 48.836249882327515],
                            [2.384953747061909, 48.836531970322454],
                            [2.384411453478561, 48.836666510898795],
                            [2.383863477284354, 48.83685187159666],
                            [2.383405463336317, 48.837121616806414],
                            [2.38086053177193, 48.83909241655969],
                            [2.3805100980109, 48.839336225367006],
                            [2.37955401121414, 48.84000138864879],
                        ],
                    },
                },
                1592: {
                    "attributes": {
                        "reseau": "PARIS NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE K",
                        "rer": 0,
                        "extcode": "800:K",
                        "geo_point_2d": [48.94876873710224, 2.584765994787457],
                        "indice_lig": "K",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01738",
                        "navette": 0,
                        "idrefliga": "A02175",
                        "shape_leng": 2866.56229588,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.566448016963,
                            48.94418106597472,
                            2.603135305118449,
                            48.9531483875826,
                        ),
                        "coordinates": [
                            [2.566448016963, 48.94418106597472],
                            [2.566891948596433, 48.94430274383506],
                            [2.568060084076771, 48.944602570357915],
                            [2.569195661927715, 48.944888173339194],
                            [2.569817732203788, 48.94505108464606],
                            [2.570754486773528, 48.94530138872618],
                            [2.571557405897602, 48.94551150926684],
                            [2.573604556880427, 48.94605454643058],
                            [2.576045849572909, 48.94667048694143],
                            [2.578678916716112, 48.94733831537988],
                            [2.58119625510733, 48.94796588262504],
                            [2.58410432923042, 48.94869724276722],
                            [2.585019430124057, 48.948923681494264],
                            [2.586169571382587, 48.949192430824624],
                            [2.588419224238586, 48.94971334949363],
                            [2.591652740358425, 48.95046283702698],
                            [2.592202519073878, 48.950590098723566],
                            [2.59297655268225, 48.95076920162161],
                            [2.594032738515728, 48.951016666970744],
                            [2.59547956323488, 48.95135127815666],
                            [2.596702132176895, 48.95163165419941],
                            [2.601719329292711, 48.95281697296261],
                            [2.60283348429561, 48.95307849550037],
                            [2.603135305118449, 48.9531483875826],
                        ],
                    },
                },
                1593: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [48.67200222409053, 2.3921565247678718],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1205.31733738,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.386783798391594,
                            48.667915766467786,
                            2.397532093159732,
                            48.67609243396569,
                        ),
                        "coordinates": [
                            [2.397532093159732, 48.667915766467786],
                            [2.397141435131696, 48.66820463955351],
                            [2.395082323196283, 48.66977943331398],
                            [2.394378289718845, 48.67031755452876],
                            [2.392928104177906, 48.67141178963424],
                            [2.392621512695499, 48.671646649773166],
                            [2.390286699430575, 48.67342652445058],
                            [2.389482165217006, 48.67404289880722],
                            [2.387955778057604, 48.67519016271495],
                            [2.386783798391594, 48.67609243396569],
                        ],
                    },
                },
                1594: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.88416352940067, 2.329832617226012],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 341.694250207,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.327839556114741,
                            48.88361499223493,
                            2.331926590885041,
                            48.88445054240861,
                        ),
                        "coordinates": [
                            [2.327839556114741, 48.88361499223493],
                            [2.327990981033983, 48.88367274116094],
                            [2.328404651851541, 48.88392364468587],
                            [2.328974198945408, 48.88426908304032],
                            [2.329012032902579, 48.8842909428704],
                            [2.329097980315677, 48.884333488011634],
                            [2.329190108238735, 48.884369979247616],
                            [2.329287434355075, 48.88440002884634],
                            [2.329388931789777, 48.884423319875864],
                            [2.32949352230527, 48.88443960526708],
                            [2.329600096710151, 48.88444871152632],
                            [2.329707528450262, 48.88445054240861],
                            [2.329814673600441, 48.884445079817574],
                            [2.329920399558386, 48.884432379469075],
                            [2.330023586330487, 48.884412577193864],
                            [2.33003584162854, 48.88440971035616],
                            [2.331767626182095, 48.88399650421244],
                            [2.331926590885041, 48.88395857351673],
                        ],
                    },
                },
                1595: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.09019258602023, 2.201395865842013],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "NR",
                        "navette": 0,
                        "idrefliga": "NR",
                        "shape_leng": 205.938948237,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.200978026879316,
                            49.08930709608885,
                            2.201823484236059,
                            49.091073452190784,
                        ),
                        "coordinates": [
                            [2.201823484236059, 49.091073452190784],
                            [2.201233908368463, 49.08986674700063],
                            [2.200978026879316, 49.08930709608885],
                        ],
                    },
                },
                1596: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.88289446047459, 2.3245639083614287],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 505.959535452,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.321274926766349,
                            48.88222690081934,
                            2.327839556114741,
                            48.88361499223493,
                        ),
                        "coordinates": [
                            [2.321274926766349, 48.88222690081934],
                            [2.322071212289492, 48.88238773359316],
                            [2.323631376741496, 48.88270308006737],
                            [2.327228335720636, 48.8834300138257],
                            [2.327839556114741, 48.88361499223493],
                        ],
                    },
                },
                1597: {
                    "attributes": {
                        "reseau": "Métro",
                        "val": 0,
                        "metro": 1,
                        "res_com": "M2",
                        "rer": 0,
                        "extcode": "100110002:2",
                        "geo_point_2d": [48.88437410489533, 2.3631875198406718],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Metro",
                        "tramway": 0,
                        "idrefligc": "C01372",
                        "navette": 0,
                        "idrefliga": "A01535",
                        "shape_leng": 395.830890443,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.360491318526145,
                            48.88427894428395,
                            2.365881358169887,
                            48.88439879515334,
                        ),
                        "coordinates": [
                            [2.360491318526145, 48.88439879515334],
                            [2.363522433510913, 48.88438826656061],
                            [2.364029321870817, 48.884386084849275],
                            [2.364374530992764, 48.88437518444293],
                            [2.364934788129637, 48.884343742008596],
                            [2.365881358169887, 48.88427894428395],
                        ],
                    },
                },
                1598: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78272209166048, 2.2384744235266005],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 602.421487006,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.237132704968193,
                            48.7805463528623,
                            2.23983201762499,
                            48.784942021215976,
                        ),
                        "coordinates": [
                            [2.23983201762499, 48.780730969150184],
                            [2.239449300188737, 48.780566059021666],
                            [2.239400277226862, 48.78055408862541],
                            [2.239348985222709, 48.780547463427155],
                            [2.239296749990607, 48.7805463528623],
                            [2.239244919800865, 48.78055078620128],
                            [2.239194834135365, 48.78056064875312],
                            [2.239147785507711, 48.78057568701865],
                            [2.239104989486866, 48.780595511197504],
                            [2.239067550455081, 48.78061961025977],
                            [2.239044691218436, 48.78063457588425],
                            [2.239023070296703, 48.78066037754906],
                            [2.238997682320994, 48.780719113684086],
                            [2.238972930188749, 48.78081450176091],
                            [2.238775822386634, 48.7814905170206],
                            [2.238590726063231, 48.78223133684816],
                            [2.238481329548291, 48.78267041294818],
                            [2.238383021333183, 48.783040546857016],
                            [2.238310710287636, 48.7833070908596],
                            [2.238227467857973, 48.78363163079702],
                            [2.238147005319916, 48.78391382919028],
                            [2.238079788346808, 48.78417659719695],
                            [2.237996544454746, 48.78450113673453],
                            [2.237923745193258, 48.78477119920294],
                            [2.237909584453203, 48.78480801839486],
                            [2.237887971072039, 48.7848418129697],
                            [2.237859823980987, 48.78487117039938],
                            [2.237825565367338, 48.78489570032609],
                            [2.237785915655429, 48.78491500170192],
                            [2.23774084455026, 48.7849291921525],
                            [2.237690558523208, 48.78493820733146],
                            [2.237635209046236, 48.784942021215976],
                            [2.237132704968193, 48.78490216629835],
                        ],
                    },
                },
                1599: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T6",
                        "rer": 0,
                        "extcode": "100112016:T6",
                        "geo_point_2d": [48.78004291317508, 2.2029358507618895],
                        "indice_lig": "6",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01794",
                        "navette": 0,
                        "idrefliga": "A02149",
                        "shape_leng": 992.795905783,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.196505812489855,
                            48.779526763526846,
                            2.209129227294876,
                            48.78140432088544,
                        ),
                        "coordinates": [
                            [2.196505812489855, 48.780087151988496],
                            [2.196817246768812, 48.78006640052533],
                            [2.19895857397284, 48.77990943530125],
                            [2.202083976598856, 48.779683330932336],
                            [2.204160376885011, 48.77953155037745],
                            [2.204260153826614, 48.779526763526846],
                            [2.204361015322786, 48.77952751709742],
                            [2.204462581686626, 48.77953381215581],
                            [2.204564226154826, 48.77954560944933],
                            [2.204669417041846, 48.77956367319426],
                            [2.20477192385183, 48.77958729813282],
                            [2.20482709001261, 48.77960272712689],
                            [2.204878852209464, 48.77961924603386],
                            [2.204929059537333, 48.779637865528365],
                            [2.204947022659797, 48.77964590362941],
                            [2.204949024534125, 48.77964742709045],
                            [2.204944787218652, 48.77964631148476],
                            [2.204934308216892, 48.77964236341807],
                            [2.205161884422703, 48.77973668780142],
                            [2.205451719199853, 48.77985712693825],
                            [2.205900353888764, 48.78004858469015],
                            [2.206593745809632, 48.78034161605611],
                            [2.20774026602458, 48.78081612837955],
                            [2.209129227294876, 48.78140432088544],
                        ],
                    },
                },
                1600: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.831186808682084, 2.2918415937382157],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 642.328663089,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.288069457597242,
                            48.82982637901667,
                            2.295661982822295,
                            48.83267687187787,
                        ),
                        "coordinates": [
                            [2.288069457597242, 48.83267687187787],
                            [2.288252677402633, 48.8326011933349],
                            [2.288617766893444, 48.83244313510742],
                            [2.288829504225798, 48.832367810561195],
                            [2.289128609729947, 48.832276996042076],
                            [2.28931345531928, 48.83221275031367],
                            [2.289482359665819, 48.83214464300725],
                            [2.291992211632134, 48.83105823045695],
                            [2.292240920332573, 48.83095407959132],
                            [2.292613966250177, 48.83081448800567],
                            [2.292902985677884, 48.83071256899171],
                            [2.29499919480473, 48.83003135444681],
                            [2.295282256904263, 48.829939362356654],
                            [2.295534289767215, 48.829861821509546],
                            [2.295661982822295, 48.82982637901667],
                        ],
                    },
                },
                1601: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.94887756666292, 2.3340075625367076],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 794.151955002,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.328832171353944,
                            48.94780764959912,
                            2.339180923415564,
                            48.94993773565708,
                        ),
                        "coordinates": [
                            [2.328832171353944, 48.94993773565708],
                            [2.329996802372402, 48.949691672913666],
                            [2.332072922101749, 48.949271169653116],
                            [2.335013850441657, 48.94868031080397],
                            [2.3365669506192, 48.94836151770648],
                            [2.338794302242333, 48.94788582058565],
                            [2.339180923415564, 48.94780764959912],
                        ],
                    },
                },
                1602: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.951165228628774, 2.342950218423288],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 356.736351435,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.342521826040314,
                            48.94958134511723,
                            2.343461279526826,
                            48.9527263298977,
                        ),
                        "coordinates": [
                            [2.342521826040314, 48.94958134511723],
                            [2.342557978455381, 48.949738155798805],
                            [2.342634321329633, 48.95003957445234],
                            [2.342713022774787, 48.95050112178],
                            [2.34281691963272, 48.95085573665592],
                            [2.342952805815642, 48.95125192651885],
                            [2.343076195585745, 48.95160807487963],
                            [2.343378718602915, 48.95248389960678],
                            [2.343461279526826, 48.9527263298977],
                        ],
                    },
                },
                1603: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.82017447129626, 2.3482559017305644],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 389.899925003,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.3458035798426,
                            48.81950050990105,
                            2.350710129390121,
                            48.82084126211055,
                        ),
                        "coordinates": [
                            [2.3458035798426, 48.81950050990105],
                            [2.350218533837916, 48.820714525867345],
                            [2.350536022340142, 48.82079732802219],
                            [2.350710129390121, 48.82084126211055],
                        ],
                    },
                },
                1604: {
                    "attributes": {
                        "reseau": "SNCF ST LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [49.0573237318088, 1.529019984282989],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 11048.1629342,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.478703609465158,
                            49.03299339039881,
                            1.581532102335019,
                            49.0910096786847,
                        ),
                        "coordinates": [
                            [1.581532102335019, 49.0387620447533],
                            [1.581276262372023, 49.03872299880559],
                            [1.580518126519983, 49.038565111837634],
                            [1.579910510694322, 49.03841698952659],
                            [1.579249951959872, 49.03821678884989],
                            [1.578830096527714, 49.038064707427736],
                            [1.578337350272843, 49.03787440495051],
                            [1.578297961716302, 49.037856157388845],
                            [1.578263988899655, 49.037841543312524],
                            [1.578001629738589, 49.03773458583084],
                            [1.577080850405673, 49.03730220497555],
                            [1.577018362884167, 49.03727391220525],
                            [1.576981669309402, 49.03725838058277],
                            [1.574027287881379, 49.035825915190614],
                            [1.573696000444206, 49.035666327729714],
                            [1.572716391312308, 49.03523981481945],
                            [1.571928535883366, 49.03492541875965],
                            [1.571073801351587, 49.034611912225465],
                            [1.570392711973072, 49.034391673147894],
                            [1.569909918764586, 49.034248218679274],
                            [1.569310157442812, 49.03407182770409],
                            [1.568512241808568, 49.0338622320899],
                            [1.567849457910452, 49.03370764898351],
                            [1.567132510747216, 49.03356287405248],
                            [1.566287425290697, 49.033414294110635],
                            [1.565543762581622, 49.03330137010243],
                            [1.563921664235111, 49.03312316123833],
                            [1.563070495006647, 49.03306345471545],
                            [1.562230002343015, 49.03302090134391],
                            [1.561977068031699, 49.033014693415836],
                            [1.561301702873599, 49.032995733366505],
                            [1.560823031984419, 49.03299339039881],
                            [1.559143939616171, 49.033049450106226],
                            [1.558842773497118, 49.033066290130186],
                            [1.558329445060223, 49.03309337970564],
                            [1.557283613713525, 49.03314921768815],
                            [1.55677155275009, 49.03318260392136],
                            [1.555762486739533, 49.03324857158051],
                            [1.555073023262373, 49.033298673776365],
                            [1.554357045205925, 49.0333837683706],
                            [1.553583884006641, 49.03349449583932],
                            [1.55226010223712, 49.0337408424074],
                            [1.550478105966066, 49.03415939641561],
                            [1.550175943233786, 49.03423825973146],
                            [1.549875205145137, 49.034313535904836],
                            [1.549371013086333, 49.034453061951105],
                            [1.548922819966511, 49.03459746874591],
                            [1.548393261689953, 49.03478358123359],
                            [1.548184192012527, 49.03485678488816],
                            [1.547646377832877, 49.03504553542393],
                            [1.54748544688406, 49.0351019829139],
                            [1.547068640862204, 49.035250196102055],
                            [1.545578927243583, 49.03577501031975],
                            [1.545285875883721, 49.035881803139446],
                            [1.543845360090701, 49.03640693563929],
                            [1.543069015055703, 49.03671182378234],
                            [1.542720768418656, 49.03684790527007],
                            [1.542332337983386, 49.03701608317419],
                            [1.54154111365109, 49.03739460271761],
                            [1.540401509024111, 49.03800092115488],
                            [1.539773563249925, 49.03834638933434],
                            [1.538535737401306, 49.039103092664746],
                            [1.537790086595059, 49.039620399349914],
                            [1.537104777979092, 49.04012733156154],
                            [1.536989668453411, 49.040224553453996],
                            [1.536036707265728, 49.04103987663916],
                            [1.535382966057178, 49.04162256194857],
                            [1.534687081633557, 49.04227239784787],
                            [1.533960094216572, 49.04298316550007],
                            [1.533551100565966, 49.04340208116082],
                            [1.532900769369306, 49.0441079836356],
                            [1.532378410437217, 49.04476711765207],
                            [1.531847998520263, 49.04549993707329],
                            [1.53126455752894, 49.0463798704645],
                            [1.530515587864895, 49.0475095473659],
                            [1.529943312223785, 49.048457001843715],
                            [1.529423527805069, 49.04937244779646],
                            [1.529348499469841, 49.04952660265586],
                            [1.528941003650431, 49.05035110681632],
                            [1.528678619351795, 49.050918528026806],
                            [1.528457243309889, 49.051488036290706],
                            [1.528224062779394, 49.05202598534768],
                            [1.527334264317489, 49.054311177064506],
                            [1.527070708922736, 49.05494783465414],
                            [1.52680561541536, 49.05567800978445],
                            [1.526291252689631, 49.057006269919086],
                            [1.526048121373296, 49.05756392916333],
                            [1.525428100747455, 49.05915763734414],
                            [1.525159449683598, 49.05976817377859],
                            [1.524778578765379, 49.06054518886602],
                            [1.524524913022502, 49.060992153454215],
                            [1.524444598415076, 49.061132778173054],
                            [1.524411586902485, 49.06118996611213],
                            [1.524352954568542, 49.06129670409302],
                            [1.524230924289281, 49.06147750267928],
                            [1.524044102535795, 49.061754221948036],
                            [1.523669953703582, 49.062302699882096],
                            [1.523532807943096, 49.0624869873695],
                            [1.523234701487187, 49.062888667493745],
                            [1.522079029966925, 49.064338260157065],
                            [1.522018942956616, 49.06441337644401],
                            [1.52196303543089, 49.06448402510848],
                            [1.521370557753488, 49.06522355140208],
                            [1.520600555062029, 49.06618664173986],
                            [1.520001060181972, 49.06693420563649],
                            [1.518406414494689, 49.068928321396285],
                            [1.516899001937751, 49.07060647822849],
                            [1.516181544377341, 49.0713621724539],
                            [1.514880718305695, 49.07254355662357],
                            [1.514514111518433, 49.07285838878731],
                            [1.514172436918312, 49.07315541169595],
                            [1.513099182575742, 49.074064116292455],
                            [1.51252716653694, 49.07454653862474],
                            [1.512443889261567, 49.074615187190375],
                            [1.512432774710515, 49.074625000336894],
                            [1.51217027738229, 49.07485154012976],
                            [1.511848096876696, 49.07512711367843],
                            [1.511025941861798, 49.075831659805054],
                            [1.509430747984814, 49.077164648221654],
                            [1.509383470876559, 49.07720837375053],
                            [1.509359841105364, 49.077229786968836],
                            [1.509284841631437, 49.07729399719712],
                            [1.50914728460961, 49.07741531183557],
                            [1.508723581757911, 49.07778367371438],
                            [1.508108096534845, 49.0783224180098],
                            [1.5071440287561, 49.07907447523395],
                            [1.506584114888967, 49.079481413173475],
                            [1.506324920323401, 49.07967109175234],
                            [1.505397651767913, 49.08026691879266],
                            [1.505049243559004, 49.080469437700735],
                            [1.504810066371897, 49.08060799698905],
                            [1.504723038646763, 49.080654129940854],
                            [1.504641518360784, 49.08069850488468],
                            [1.504402473861098, 49.0808289695692],
                            [1.503758552587811, 49.08118132466787],
                            [1.502123803660662, 49.082077753074486],
                            [1.500487626695681, 49.082974148551884],
                            [1.498850022963881, 49.08387051195875],
                            [1.497725265206916, 49.0844756268522],
                            [1.497658942411302, 49.08451111492802],
                            [1.497576024720438, 49.08455637408547],
                            [1.49646536958483, 49.08513550023593],
                            [1.495684112874506, 49.08550569050356],
                            [1.495617894664926, 49.08553488282281],
                            [1.495558582604798, 49.08556052750571],
                            [1.494550332992961, 49.08599289697331],
                            [1.494175240863612, 49.086149322907595],
                            [1.493752122771307, 49.086311689133325],
                            [1.492889465827328, 49.08663539650534],
                            [1.492813661029106, 49.08666451655277],
                            [1.492419791993912, 49.08679741536718],
                            [1.49204110170919, 49.08692322984871],
                            [1.49099495120055, 49.087246470646534],
                            [1.490209283007259, 49.08747000189864],
                            [1.489426730991015, 49.08767106785773],
                            [1.489264530315387, 49.08770764054453],
                            [1.489104884279971, 49.08775502402131],
                            [1.487619291827881, 49.08807048941299],
                            [1.486061937492089, 49.088337738223565],
                            [1.485618338358145, 49.08841448617119],
                            [1.484798021628155, 49.08858016656981],
                            [1.483750026595684, 49.08884667071334],
                            [1.483374378568234, 49.08895269498391],
                            [1.482159865774084, 49.08934564974116],
                            [1.481958682805087, 49.08941879459835],
                            [1.480973899340743, 49.08982873820999],
                            [1.480139879298803, 49.09022990718184],
                            [1.479435372955225, 49.0905843735567],
                            [1.4789527604403, 49.09085595916263],
                            [1.478703609465158, 49.0910096786847],
                        ],
                    },
                },
                1605: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89734897367776, 2.383443005767217],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 695.418744178,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.380537035488634,
                            48.8961041618284,
                            2.38658143311372,
                            48.89874714249711,
                        ),
                        "coordinates": [
                            [2.38658143311372, 48.89742873557869],
                            [2.386335805313858, 48.89743286050715],
                            [2.385862108555557, 48.89743519147452],
                            [2.385795346585332, 48.89743459998661],
                            [2.385702431366433, 48.89743377718817],
                            [2.385631904983348, 48.89743039371237],
                            [2.385585246762694, 48.89742484839017],
                            [2.385531178977195, 48.897419217369105],
                            [2.385479001283658, 48.89740645726085],
                            [2.385415879599093, 48.897387169498074],
                            [2.385374755600823, 48.897371420088895],
                            [2.385340642236788, 48.89735696838579],
                            [2.385306597753559, 48.89733656895733],
                            [2.385265421149716, 48.89730899324797],
                            [2.385214978144538, 48.897268552917964],
                            [2.384136376466567, 48.896278873954365],
                            [2.38408205439148, 48.896233860813695],
                            [2.384041987561855, 48.89620414908441],
                            [2.383980314216476, 48.896170520295634],
                            [2.383927165083035, 48.89614835573964],
                            [2.383872518056326, 48.89613094263351],
                            [2.383801980171648, 48.89611439921472],
                            [2.38372845496454, 48.89610640726606],
                            [2.383662079830361, 48.8961041618284],
                            [2.383555163584654, 48.89611217751508],
                            [2.383488595491673, 48.89612611148309],
                            [2.383407435627896, 48.89615329545268],
                            [2.383342086342747, 48.89618627053797],
                            [2.383299900564464, 48.89621365511406],
                            [2.38325323649049, 48.896253389401416],
                            [2.3832020841587, 48.89630642571793],
                            [2.383075545461376, 48.89650850221135],
                            [2.382781202451369, 48.89698382609574],
                            [2.382621123039184, 48.89721428329305],
                            [2.382366694322129, 48.897609862552414],
                            [2.382146688584812, 48.897963098245114],
                            [2.381871725223989, 48.8984156767423],
                            [2.381811062312893, 48.89850958928567],
                            [2.381769294512492, 48.89856219670373],
                            [2.381739716313054, 48.89859131129601],
                            [2.381686183891011, 48.89863172350205],
                            [2.38164691245989, 48.898656504592054],
                            [2.381571862931242, 48.898685384358274],
                            [2.38147835870721, 48.89871845220196],
                            [2.381342723972868, 48.89874344953702],
                            [2.38122466576659, 48.89874712216441],
                            [2.381090410813122, 48.89874714249711],
                            [2.380947918547456, 48.898741765584866],
                            [2.380537035488634, 48.898733990652936],
                        ],
                    },
                },
                1606: {
                    "attributes": {
                        "reseau": "RER D",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER D",
                        "rer": 1,
                        "extcode": "800:D",
                        "geo_point_2d": [49.132272564662394, 2.497950740042826],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1736.16476318,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.490178985421196,
                            49.12678094198271,
                            2.506143689252232,
                            49.13828637527201,
                        ),
                        "coordinates": [
                            [2.490178985421196, 49.13828637527201],
                            [2.490349291561337, 49.13809403642042],
                            [2.490996953887674, 49.13739531446677],
                            [2.491242397352285, 49.13714515520918],
                            [2.491953530408366, 49.1364580011712],
                            [2.492361045727361, 49.136089368274625],
                            [2.492918001003793, 49.13562060039208],
                            [2.493404151972852, 49.13524019941674],
                            [2.493791562554617, 49.13494154196967],
                            [2.494196757930338, 49.13464951961561],
                            [2.494642485778367, 49.1343341248341],
                            [2.495402343475325, 49.13383008963637],
                            [2.497071506114415, 49.13274185163363],
                            [2.498489816409119, 49.131805504662964],
                            [2.499872647718742, 49.13090083560325],
                            [2.501379539620796, 49.12992102235472],
                            [2.502731858205192, 49.129031350774675],
                            [2.504165156232819, 49.12808658330806],
                            [2.50511726379409, 49.12745395682368],
                            [2.505884114233885, 49.12695040939013],
                            [2.506143689252232, 49.12678094198271],
                        ],
                    },
                },
                1607: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.897903723054114, 2.3710962675855853],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 392.337368809,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.369036949316923,
                            48.897552809900425,
                            2.3733837959986,
                            48.89861121402444,
                        ),
                        "coordinates": [
                            [2.3733837959986, 48.897552809900425],
                            [2.373081150259879, 48.89755586557284],
                            [2.372920017917267, 48.8975583764221],
                            [2.372225927344606, 48.89756616138559],
                            [2.37191191027733, 48.89756951242374],
                            [2.371532893654486, 48.897576090044325],
                            [2.371428911642282, 48.897579826875976],
                            [2.371366085251868, 48.897582352439485],
                            [2.371253419362873, 48.89758794738806],
                            [2.37086104893549, 48.897624434171505],
                            [2.370731985941814, 48.897643029336294],
                            [2.370573380701314, 48.89768716795372],
                            [2.370455889192074, 48.89773366286115],
                            [2.370373075561079, 48.89777748554277],
                            [2.370316174066737, 48.897827154166954],
                            [2.370286279061316, 48.897881962265586],
                            [2.37027045832572, 48.89793684436043],
                            [2.370253944137277, 48.898228001800504],
                            [2.37025091919478, 48.898275098336676],
                            [2.37024175165728, 48.89831692855464],
                            [2.370229744066487, 48.89835493703384],
                            [2.370213404608095, 48.89839292183168],
                            [2.370182584517563, 48.898434638176376],
                            [2.37015331106461, 48.89846779576773],
                            [2.37011976600024, 48.89849617260771],
                            [2.370064497889144, 48.89853014673117],
                            [2.370013686918022, 48.898553673546395],
                            [2.369971617545718, 48.89857058419876],
                            [2.369890551851073, 48.89858919352162],
                            [2.369792220284696, 48.898602952759305],
                            [2.369663644199317, 48.898610842085446],
                            [2.369452584910968, 48.89861121402444],
                            [2.369036949316923, 48.89860117217836],
                        ],
                    },
                },
                1608: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93266294673004, 2.2985795996754397],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 486.732803648,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.295922020386378,
                            48.93233442401981,
                            2.301291291129663,
                            48.933568568710506,
                        ),
                        "coordinates": [
                            [2.301291291129663, 48.93279020802075],
                            [2.301220390384253, 48.93251933745803],
                            [2.301175344107643, 48.93243151325283],
                            [2.301115214892289, 48.93239118900318],
                            [2.301034812146941, 48.9323545531931],
                            [2.300933958225158, 48.93233492958497],
                            [2.30084729242225, 48.93233442401981],
                            [2.300743191124457, 48.93234143098413],
                            [2.300031454566507, 48.9324172233191],
                            [2.299669807549598, 48.93245508413516],
                            [2.299530962568381, 48.932467597529296],
                            [2.299400834031286, 48.932476354107855],
                            [2.299173878906397, 48.932488351971884],
                            [2.298886243248888, 48.932500945881344],
                            [2.298683791064, 48.93251689287489],
                            [2.298549253318292, 48.932531334144315],
                            [2.296796514845554, 48.93278184343072],
                            [2.296668991348676, 48.93281155059615],
                            [2.296581810072839, 48.93284910963893],
                            [2.296500264440373, 48.932897170380606],
                            [2.296429965787547, 48.93296813915899],
                            [2.296387188245112, 48.93303355895612],
                            [2.29637366046399, 48.93307250169263],
                            [2.296262459390908, 48.933390686160465],
                            [2.296181777231794, 48.93348158059298],
                            [2.296050912919168, 48.93354458000293],
                            [2.295922020386378, 48.933568568710506],
                        ],
                    },
                },
                1609: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.87967435489815, 2.2299118469510577],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 1001.27416748,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.22595909514488,
                            48.87600129150149,
                            2.233871433804006,
                            48.88333487565445,
                        ),
                        "coordinates": [
                            [2.22595909514488, 48.87600129150149],
                            [2.226279127789141, 48.876304973042195],
                            [2.226489280680938, 48.876513616472934],
                            [2.227714104210437, 48.87765129267148],
                            [2.230233880944409, 48.87997922844338],
                            [2.230322056282379, 48.88005475034293],
                            [2.230876130750888, 48.88058537469012],
                            [2.231207121530225, 48.88089610062686],
                            [2.231735802185757, 48.88138677225535],
                            [2.232144402370125, 48.881763406124776],
                            [2.232402425805931, 48.881979692495236],
                            [2.233205889404134, 48.88264589024374],
                            [2.23336396979421, 48.88278584644745],
                            [2.233419542686757, 48.88284842146283],
                            [2.233535264518247, 48.88296583847934],
                            [2.233616255531622, 48.883051800713844],
                            [2.233871433804006, 48.88333487565445],
                        ],
                    },
                },
                1610: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T2",
                        "rer": 0,
                        "extcode": "100112012:T2",
                        "geo_point_2d": [48.90927168259307, 2.2361806435861746],
                        "indice_lig": "2",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01390",
                        "navette": 0,
                        "idrefliga": "A01192",
                        "shape_leng": 472.806577973,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.233988601425483,
                            48.90766458394418,
                            2.238309302290676,
                            48.91080258974541,
                        ),
                        "coordinates": [
                            [2.238309302290676, 48.90766458394418],
                            [2.237968374324959, 48.90796630147574],
                            [2.237236985370548, 48.90862089874573],
                            [2.237044487680393, 48.908763035269835],
                            [2.236948755389561, 48.90882964517443],
                            [2.236833976941698, 48.90890267711115],
                            [2.236744813299395, 48.908952077038634],
                            [2.236681151241351, 48.908985578447584],
                            [2.23647666391531, 48.90908361771123],
                            [2.236396705671829, 48.90912058449532],
                            [2.236181907292988, 48.909244731328684],
                            [2.235971303608232, 48.90939032002759],
                            [2.235617429942788, 48.909643853262835],
                            [2.234655301044831, 48.91032656261621],
                            [2.234395339864913, 48.910514067822014],
                            [2.233988601425483, 48.91080258974541],
                        ],
                    },
                },
                1611: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93431985632116, 2.317312266176646],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 618.453049857,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.313132640491603,
                            48.933932029779314,
                            2.32149519817071,
                            48.93461219740006,
                        ),
                        "coordinates": [
                            [2.313132640491603, 48.933932029779314],
                            [2.314305553112345, 48.93404137601092],
                            [2.316312939596243, 48.93422416001085],
                            [2.317236286858049, 48.9343150812171],
                            [2.31746522548988, 48.93434493771271],
                            [2.31795921534324, 48.93440485490132],
                            [2.318453424528332, 48.934448115532334],
                            [2.319344341319773, 48.934534077863525],
                            [2.319623869656728, 48.9345618379966],
                            [2.320033295420969, 48.93459866284625],
                            [2.320322039655793, 48.93461219740006],
                            [2.320609226872418, 48.93460668805594],
                            [2.320934566018035, 48.9345835477858],
                            [2.321091639742276, 48.93458562742132],
                            [2.32149519817071, 48.93460856766366],
                        ],
                    },
                },
                1612: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.933477116962244, 2.2952604602936804],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 99.7654200314,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.294602989386074,
                            48.933355382229045,
                            2.295922020386378,
                            48.933568568710506,
                        ),
                        "coordinates": [
                            [2.295922020386378, 48.933568568710506],
                            [2.295652123859516, 48.933550802724966],
                            [2.295358085061835, 48.93350243781223],
                            [2.294602989386074, 48.933355382229045],
                        ],
                    },
                },
                1613: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T1",
                        "rer": 0,
                        "extcode": "100112011:T1",
                        "geo_point_2d": [48.93331787408944, 2.3044594510800303],
                        "indice_lig": "1",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01389",
                        "navette": 0,
                        "idrefliga": "A01191",
                        "shape_leng": 386.62401219,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.301826356702229,
                            48.93327135517497,
                            2.307089653527023,
                            48.93344984077206,
                        ),
                        "coordinates": [
                            [2.307089653527023, 48.93344984077206],
                            [2.306179185780559, 48.93339746117437],
                            [2.305166164774668, 48.93331735564964],
                            [2.304585949297125, 48.93327972726751],
                            [2.304127409046971, 48.93327135517497],
                            [2.301826356702229, 48.933272274648566],
                        ],
                    },
                },
                1614: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.754141433698514, 2.3657980582853098],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 734.624004314,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.361952152582564,
                            48.75281135969812,
                            2.368428452800028,
                            48.75673943351173,
                        ),
                        "coordinates": [
                            [2.361952152582564, 48.75281135969812],
                            [2.362197001685937, 48.75297806080686],
                            [2.36223725329106, 48.75300446636781],
                            [2.362275909856257, 48.75302972021725],
                            [2.362313433034861, 48.75305377805173],
                            [2.362350284447746, 48.75307659826516],
                            [2.362386927098923, 48.7530981374594],
                            [2.362423821283956, 48.75311835132188],
                            [2.362461429996839, 48.753137197352736],
                            [2.36250021624351, 48.75315463215203],
                            [2.362540640298723, 48.75317061320417],
                            [2.362583166528687, 48.75318509711526],
                            [2.362628253870377, 48.75319803956216],
                            [2.362676368028133, 48.75320939895534],
                            [2.362727967938438, 48.75321913096999],
                            [2.362783516606846, 48.753227192201194],
                            [2.362843477015929, 48.75323354104169],
                            [2.362908310820831, 48.753238133177405],
                            [2.363383300064474, 48.75325705762433],
                            [2.364421442558883, 48.75329963613338],
                            [2.364810083351776, 48.75333761025923],
                            [2.365168154769019, 48.75340176317255],
                            [2.365517248518083, 48.75349565828828],
                            [2.365641411701984, 48.75353131663055],
                            [2.365972534570664, 48.75365733617305],
                            [2.366141699305991, 48.7537298613676],
                            [2.366278483640701, 48.75380834410804],
                            [2.366499863644959, 48.75394152830368],
                            [2.367005655692959, 48.75430305296592],
                            [2.367842088359634, 48.754897123616644],
                            [2.368208046088762, 48.75517035192773],
                            [2.368276331992812, 48.7552378223751],
                            [2.368338054448669, 48.75531239683961],
                            [2.368376058459214, 48.75538399012801],
                            [2.368409830288428, 48.75544842223904],
                            [2.368428004035554, 48.755552750611606],
                            [2.368428452800028, 48.75569411010259],
                            [2.368364698633332, 48.75673943351173],
                        ],
                    },
                },
                1615: {
                    "attributes": {
                        "reseau": "SNCF NORD",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.97028780889855, 2.3813228872928898],
                        "indice_lig": "D",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01728",
                        "navette": 0,
                        "idrefliga": "A01842",
                        "shape_leng": 1980.06913723,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.372103138402569,
                            48.96375542962029,
                            2.390593652641838,
                            48.976747848293925,
                        ),
                        "coordinates": [
                            [2.390593652641838, 48.976747848293925],
                            [2.389074440432978, 48.975694505290775],
                            [2.386774020009822, 48.97407758080194],
                            [2.384350850926132, 48.972444006492786],
                            [2.382029040997859, 48.970817480279564],
                            [2.379645899112885, 48.96913382405482],
                            [2.377631751779957, 48.967721233206106],
                            [2.375828980372487, 48.96645332426752],
                            [2.374388358663936, 48.965409627836195],
                            [2.372300682997742, 48.96389115417943],
                            [2.372103138402569, 48.96375542962029],
                        ],
                    },
                },
                1616: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.84961338401423, 2.4109629980377556],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 732.623852805,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.40965605640417,
                            48.84730264431995,
                            2.411360892810457,
                            48.85298727790374,
                        ),
                        "coordinates": [
                            [2.410741136126437, 48.85298727790374],
                            [2.410801812285185, 48.8526438742911],
                            [2.410869575384146, 48.85213137467559],
                            [2.410933208825992, 48.8517270480544],
                            [2.411214581810407, 48.850107437346466],
                            [2.411334703158301, 48.84944526397384],
                            [2.411358714054376, 48.849234792596185],
                            [2.411360892810457, 48.84912177456799],
                            [2.411348844130621, 48.84899143605841],
                            [2.411331313267522, 48.84886761334574],
                            [2.411295176356425, 48.84863543054074],
                            [2.411253604436056, 48.84832588560317],
                            [2.411213896246061, 48.848010995887044],
                            [2.411172197609698, 48.84771275228956],
                            [2.411154668948927, 48.84758893031487],
                            [2.411140663726829, 48.84752123361828],
                            [2.411126286348139, 48.84748804237053],
                            [2.411107612108806, 48.84745693085942],
                            [2.411085290770403, 48.847428764761275],
                            [2.411059214229479, 48.84740322247301],
                            [2.411029523996061, 48.84738044318935],
                            [2.410996322784603, 48.84736050205984],
                            [2.410960341500675, 48.84734371565522],
                            [2.410921128628869, 48.8473297633789],
                            [2.410878750689137, 48.847318667139845],
                            [2.410833266085396, 48.84731044341076],
                            [2.410784742840169, 48.84730510151682],
                            [2.410733214981011, 48.84730264431995],
                            [2.410678724720188, 48.84730307382302],
                            [2.40965605640417, 48.84739389049608],
                        ],
                    },
                },
                1617: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.87809889080571, 2.4042111185353825],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 578.077409029,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.401221761278451,
                            48.87656877529156,
                            2.407034921962184,
                            48.87947036907198,
                        ),
                        "coordinates": [
                            [2.407034921962184, 48.87656877529156],
                            [2.406854196551487, 48.87689171517408],
                            [2.406632028913935, 48.87727343721557],
                            [2.406533628107843, 48.877424284099824],
                            [2.406497013205023, 48.87747169238988],
                            [2.406464790726144, 48.87751341170367],
                            [2.406410828045976, 48.87756358842375],
                            [2.406354033175164, 48.877608993621514],
                            [2.406292985380084, 48.87764771366951],
                            [2.406242135193613, 48.87767791905327],
                            [2.406176801844106, 48.8777128109243],
                            [2.406102832514813, 48.87774575693572],
                            [2.406007208250126, 48.87777954694564],
                            [2.405923256695696, 48.87780197332537],
                            [2.405833546005268, 48.87782341957207],
                            [2.405528390794322, 48.8778828188818],
                            [2.403194274811058, 48.87832616250713],
                            [2.402420560728749, 48.87847363743113],
                            [2.402206238304295, 48.87853919328768],
                            [2.402100400571739, 48.87858244676831],
                            [2.401914477832625, 48.8786881190981],
                            [2.40183297218126, 48.87874862610898],
                            [2.401786316029312, 48.87879027201803],
                            [2.401722083235019, 48.8788546730171],
                            [2.401701575178207, 48.878881220331394],
                            [2.401417669208879, 48.879225301551074],
                            [2.401221761278451, 48.87947036907198],
                        ],
                    },
                },
                1618: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.73963215042772, 2.365067524814438],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 868.915794417,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.359467821095852,
                            48.73856277815784,
                            2.369910148025347,
                            48.739987430378214,
                        ),
                        "coordinates": [
                            [2.369910148025347, 48.73856277815784],
                            [2.369871422500828, 48.73923697963774],
                            [2.369867614164166, 48.739272879676626],
                            [2.369859512342015, 48.73930881101818],
                            [2.369847116755184, 48.739344457955745],
                            [2.369830423078109, 48.73937950206261],
                            [2.369809432370528, 48.73941362943721],
                            [2.36978414028672, 48.73944652345068],
                            [2.369754546572399, 48.73947786659592],
                            [2.369720648211378, 48.73950734494859],
                            [2.369682444952389, 48.7395346410006],
                            [2.369639935164798, 48.739559439035126],
                            [2.369593114511009, 48.73958142242112],
                            [2.369541984073631, 48.73960027635453],
                            [2.369486540891247, 48.739615683311115],
                            [2.369426781983615, 48.73962732756499],
                            [2.369362707104136, 48.7396348925047],
                            [2.369294314628299, 48.739638063309926],
                            [2.369167331230327, 48.73963689588368],
                            [2.365450970350227, 48.73954580688676],
                            [2.365111903632141, 48.73955685450042],
                            [2.364506220446447, 48.739591750239356],
                            [2.363196839623805, 48.73969199463057],
                            [2.362049335005401, 48.7397898095508],
                            [2.360703805593365, 48.739894580718335],
                            [2.359467821095852, 48.739987430378214],
                        ],
                    },
                },
                1619: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T5",
                        "rer": 0,
                        "extcode": "100112015:T5",
                        "geo_point_2d": [48.961533985124, 2.3591531787603475],
                        "indice_lig": "5",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01684",
                        "navette": 0,
                        "idrefliga": "A01760",
                        "shape_leng": 521.82063343,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358742504475762,
                            48.95912109831728,
                            2.360250670038741,
                            48.963517489061424,
                        ),
                        "coordinates": [
                            [2.360250670038741, 48.963517489061424],
                            [2.360046208607715, 48.9634316354623],
                            [2.359868260077433, 48.96335692730706],
                            [2.359660029396718, 48.96325530592445],
                            [2.359622341436806, 48.963226537802214],
                            [2.359595492231745, 48.963206170008384],
                            [2.359546387887236, 48.963158916801795],
                            [2.359528563721485, 48.96313919160382],
                            [2.359475208509986, 48.96307050241916],
                            [2.359417570455701, 48.962982754734426],
                            [2.35926324614364, 48.96275054274158],
                            [2.359210984963246, 48.96266639283166],
                            [2.359175026981065, 48.962578761739046],
                            [2.359141308388518, 48.96245604705166],
                            [2.359084662634503, 48.961994754023365],
                            [2.358993695527053, 48.961240027280645],
                            [2.358966622842695, 48.96101801246941],
                            [2.358869417301483, 48.960256708523175],
                            [2.358762950305181, 48.95929430196443],
                            [2.358742504475762, 48.95912109831728],
                        ],
                    },
                },
                1620: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.74017203210654, 2.3556826234987116],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 648.390380517,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.352795381310017,
                            48.73979173726946,
                            2.359467821095852,
                            48.741684493136425,
                        ),
                        "coordinates": [
                            [2.359467821095852, 48.739987430378214],
                            [2.358501335520786, 48.74005886535592],
                            [2.358390394136607, 48.7400687404801],
                            [2.358267986067903, 48.740074746521145],
                            [2.358047400483066, 48.740086858842176],
                            [2.357805852638289, 48.74008654012281],
                            [2.357608704273903, 48.74008452693094],
                            [2.357420296044741, 48.740073994161385],
                            [2.353961934578281, 48.739795774221236],
                            [2.353875631973588, 48.73979173726946],
                            [2.353769379740284, 48.739800681870676],
                            [2.35368999340252, 48.73981928974009],
                            [2.3536285059748, 48.73984513515161],
                            [2.35357417170071, 48.73987458825644],
                            [2.353525041563518, 48.739919538148825],
                            [2.353482516253756, 48.7399855842597],
                            [2.353307048434887, 48.740584122765895],
                            [2.353171434960803, 48.740943040253335],
                            [2.352795381310017, 48.741684493136425],
                        ],
                    },
                },
                1621: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3A",
                        "rer": 0,
                        "extcode": "100112013:T3A",
                        "geo_point_2d": [48.819732237267814, 2.3421858951822876],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01391",
                        "navette": 0,
                        "idrefliga": "A01193",
                        "shape_leng": 547.859322809,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.338580749640995,
                            48.819340190110665,
                            2.345803581204492,
                            48.82035003419019,
                        ),
                        "coordinates": [
                            [2.338580749640995, 48.82035003419019],
                            [2.338974594373079, 48.82026274248328],
                            [2.339504423149501, 48.82014525746896],
                            [2.340736992420012, 48.81987721384988],
                            [2.340887344004361, 48.819848285765644],
                            [2.341032938389505, 48.81982288743151],
                            [2.341180897663498, 48.81980207260865],
                            [2.34130507212713, 48.81978626475],
                            [2.343162536112064, 48.81956360294706],
                            [2.344998749359737, 48.81934594578711],
                            [2.345072318771144, 48.81934135180269],
                            [2.345120981151821, 48.819340190110665],
                            [2.345170688980845, 48.819341890560835],
                            [2.345207405766885, 48.81934494716935],
                            [2.345249484351184, 48.81935160187363],
                            [2.345306128851897, 48.819363482579135],
                            [2.345425706508199, 48.81939697546892],
                            [2.345803581204492, 48.8195005099085],
                        ],
                    },
                },
                1622: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.77550532782544, 2.3676108742711115],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 763.577874912,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.367405864497286,
                            48.77207421663938,
                            2.367815001629962,
                            48.7789363930864,
                        ),
                        "coordinates": [
                            [2.367815001629962, 48.77207421663938],
                            [2.367795898017862, 48.772354865877745],
                            [2.367653758919648, 48.77477570573472],
                            [2.367490206686805, 48.777575751745665],
                            [2.367405864497286, 48.7789363930864],
                        ],
                    },
                },
                1623: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T7",
                        "rer": 0,
                        "extcode": "100112017:T7",
                        "geo_point_2d": [48.78102192492528, 2.3672810843440844],
                        "indice_lig": "7",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01774",
                        "navette": 0,
                        "idrefliga": "A02134",
                        "shape_leng": 464.141937669,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.367157833315663,
                            48.7789363930864,
                            2.367405864497286,
                            48.783107550449365,
                        ),
                        "coordinates": [
                            [2.367405864497286, 48.7789363930864],
                            [2.367374727961229, 48.77943868272039],
                            [2.367301947212796, 48.78071204397023],
                            [2.367271947910294, 48.78110892437152],
                            [2.367224946339179, 48.781962641655305],
                            [2.367199299026799, 48.78241377003274],
                            [2.367157833315663, 48.783107550449365],
                        ],
                    },
                },
                1624: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T8",
                        "rer": 0,
                        "extcode": "100112018:T8",
                        "geo_point_2d": [48.95580713365316, 2.305147200284381],
                        "indice_lig": "8",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01795",
                        "navette": 0,
                        "idrefliga": "A02150",
                        "shape_leng": 524.283794069,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.302222741813793,
                            48.955006613111124,
                            2.30787256835423,
                            48.956516052072224,
                        ),
                        "coordinates": [
                            [2.302222741813793, 48.95584304745806],
                            [2.302735895382526, 48.95588886065475],
                            [2.302815562505147, 48.95590164907557],
                            [2.302894401831511, 48.95591649661561],
                            [2.302972290696721, 48.95593338017383],
                            [2.303049107914345, 48.95595227348143],
                            [2.303124733964929, 48.95597314714259],
                            [2.303199051181931, 48.95599596868034],
                            [2.303271943934746, 48.9560207025869],
                            [2.303343298808603, 48.95604731037907],
                            [2.303413004780997, 48.956075750658016],
                            [2.303480953394405, 48.956105979173685],
                            [2.303547038925011, 48.95613794889364],
                            [2.303611158547203, 48.95617161007624],
                            [2.303673212493542, 48.956206910347966],
                            [2.303733104209978, 48.956243794784996],
                            [2.303790740506096, 48.956282205998555],
                            [2.303846031700096, 48.956322084224176],
                            [2.303991920203287, 48.95642238813245],
                            [2.304008000629913, 48.95643220801796],
                            [2.304024745895177, 48.95644143014627],
                            [2.304042043887737, 48.95645006465765],
                            [2.304059785214758, 48.956458122607515],
                            [2.304077856423308, 48.956465612329886],
                            [2.304096146755017, 48.95647254487238],
                            [2.304114544097914, 48.956478930375496],
                            [2.304132936352421, 48.95648477808065],
                            [2.304151212760019, 48.95649009903561],
                            [2.304169261220655, 48.95649490248193],
                            [2.304186970975976, 48.956499199467494],
                            [2.304204229926007, 48.95650299923393],
                            [2.30422092595885, 48.95650631192222],
                            [2.304236946962519, 48.956509147673266],
                            [2.304252182202659, 48.956511515736835],
                            [2.304266520908747, 48.956513428060326],
                            [2.30428528990281, 48.956515206916826],
                            [2.30430463536535, 48.956516052072224],
                            [2.304324503922272, 48.9565159722093],
                            [2.304344844930693, 48.95651497602668],
                            [2.304365606369986, 48.95651307311435],
                            [2.304386734890215, 48.956510270356794],
                            [2.304408179824162, 48.95650657825115],
                            [2.304429889163288, 48.95650200548825],
                            [2.304451809557642, 48.95649655895266],
                            [2.30447389169346, 48.95649025004877],
                            [2.304496080867382, 48.95648308475407],
                            [2.304518327765803, 48.95647507447303],
                            [2.304540577673301, 48.9564662260824],
                            [2.304562781312339, 48.95645654828915],
                            [2.30458488528517, 48.956446051574744],
                            [2.304606837607383, 48.95643474283205],
                            [2.305769836862209, 48.95578811763573],
                            [2.306859582486631, 48.95515961580196],
                            [2.307054154306659, 48.95503653988817],
                            [2.307152000966538, 48.9550142637753],
                            [2.307310348560474, 48.955006613111124],
                            [2.307446736394205, 48.955020248919254],
                            [2.307554716798114, 48.955050852591015],
                            [2.30760635888721, 48.95507970278624],
                            [2.307645014472448, 48.9551070499208],
                            [2.30769852086946, 48.955158752405985],
                            [2.307734590183292, 48.95521749262713],
                            [2.30787256835423, 48.95543742610714],
                        ],
                    },
                },
                1625: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T11",
                        "rer": 0,
                        "extcode": "800:T11",
                        "geo_point_2d": [48.95045573136708, 2.401830474476779],
                        "indice_lig": "11",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01999",
                        "navette": 0,
                        "idrefliga": "A02225",
                        "shape_leng": 2018.21991627,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.390955086162519,
                            48.94363000666017,
                            2.41147348701014,
                            48.95492900449691,
                        ),
                        "coordinates": [
                            [2.41147348701014, 48.94363000666017],
                            [2.411187235537409, 48.94387804071994],
                            [2.409207954225988, 48.945592989314406],
                            [2.406216852360538, 48.94813836829348],
                            [2.404173512149467, 48.94991748246044],
                            [2.40288283280398, 48.95094844462586],
                            [2.402024012518065, 48.95149140786896],
                            [2.400831616763216, 48.95213738827818],
                            [2.399887590975565, 48.952546668165965],
                            [2.398828554922729, 48.952903019343275],
                            [2.395813020042299, 48.95373965622301],
                            [2.394109829499087, 48.95418313103382],
                            [2.390955086162519, 48.95492900449691],
                        ],
                    },
                },
                1626: {
                    "attributes": {
                        "reseau": "SNCF SAINT-LAZARE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE J",
                        "rer": 0,
                        "extcode": "800:J",
                        "geo_point_2d": [48.909162564643374, 2.2382814723671878],
                        "indice_lig": "J",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01739",
                        "navette": 0,
                        "idrefliga": "A01852",
                        "shape_leng": 230.639608371,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.236878028463527,
                            48.90869458435905,
                            2.239684117127617,
                            48.90963293312601,
                        ),
                        "coordinates": [
                            [2.236878028463527, 48.90869458435905],
                            [2.238445939948255, 48.90921623446079],
                            [2.239684117127617, 48.90963293312601],
                        ],
                    },
                },
                1627: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89843269435564, 2.361012103411991],
                        "indice_lig": "3",
                        "idf": 1,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 386.840141617,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.358375469325785,
                            48.8983918970627,
                            2.363648616675142,
                            48.89849092948227,
                        ),
                        "coordinates": [
                            [2.363648616675142, 48.89849092948227],
                            [2.363252431800338, 48.89848418415395],
                            [2.362569451538462, 48.898467701548704],
                            [2.361515174248667, 48.898445667657086],
                            [2.360984889162861, 48.8984264214822],
                            [2.360514122117625, 48.8984096320473],
                            [2.359855920808744, 48.89840326036696],
                            [2.359466289241538, 48.8983918970627],
                            [2.359393901115884, 48.89839295328538],
                            [2.35894975469691, 48.89839912653656],
                            [2.358375469325785, 48.89839212567741],
                        ],
                    },
                },
                1628: {
                    "attributes": {
                        "reseau": "RER A",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER A",
                        "rer": 1,
                        "extcode": "810:A",
                        "geo_point_2d": [48.918559045836986, 2.189066380171806],
                        "indice_lig": "A",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01742",
                        "navette": 0,
                        "idrefliga": "A01856",
                        "shape_leng": 678.061753092,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.185353376302864,
                            48.91674629011933,
                            2.192783100891459,
                            48.920379373924355,
                        ),
                        "coordinates": [
                            [2.185353376302864, 48.920379373924355],
                            [2.186145208575256, 48.9200021067702],
                            [2.186767090397931, 48.919707886644076],
                            [2.188218351335855, 48.9189764806864],
                            [2.191073467000742, 48.917556762960395],
                            [2.192783100891459, 48.91674629011933],
                        ],
                    },
                },
                1629: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89537880220003, 2.316433359499921],
                        "indice_lig": "3",
                        "idf": 0,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 395.37334769,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.314064654430934,
                            48.89453086415558,
                            2.318802327261341,
                            48.89622649469053,
                        ),
                        "coordinates": [
                            [2.318802327261341, 48.89622649469053],
                            [2.316847681021233, 48.895510708790844],
                            [2.31622203391147, 48.895297886332635],
                            [2.315825856771956, 48.895182180255006],
                            [2.314650367913476, 48.894749398843736],
                            [2.314064654430934, 48.89453086415558],
                        ],
                    },
                },
                1630: {
                    "attributes": {
                        "reseau": "TRAMWAY",
                        "val": 0,
                        "metro": 0,
                        "res_com": "T3B",
                        "rer": 0,
                        "extcode": "100112003:T3B",
                        "geo_point_2d": [48.89836674345647, 2.355102594951666],
                        "indice_lig": "3",
                        "idf": 0,
                        "train": 0,
                        "fer": 0,
                        "mode": "Tramway",
                        "tramway": 1,
                        "idrefligc": "C01679",
                        "navette": 0,
                        "idrefliga": "A01757",
                        "shape_leng": 480.408809168,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.351829550128707,
                            48.89832555844204,
                            2.358375469336868,
                            48.898400595114694,
                        ),
                        "coordinates": [
                            [2.358375469336868, 48.89839212477815],
                            [2.356087079311239, 48.898346914436466],
                            [2.355220978286784, 48.898400595114694],
                            [2.351829550128707, 48.89832555844204],
                        ],
                    },
                },
                1631: {
                    "attributes": {
                        "reseau": "PARIS SUD EST",
                        "val": 0,
                        "metro": 0,
                        "res_com": "LIGNE R",
                        "rer": 0,
                        "extcode": "800:R",
                        "geo_point_2d": [48.780158328704076, 2.4346983885028064],
                        "indice_lig": "R",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "Train",
                        "tramway": 0,
                        "idrefligc": "C01731",
                        "navette": 0,
                        "idrefliga": "A01845",
                        "shape_leng": 2000.81066407,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.432070116592686,
                            48.771266038121055,
                            2.436086604214256,
                            48.78891489668918,
                        ),
                        "coordinates": [
                            [2.435306339706323, 48.771266038121055],
                            [2.435440225383158, 48.771483751195284],
                            [2.435599222770678, 48.77179292605963],
                            [2.435707728226891, 48.772052178641204],
                            [2.435801803257095, 48.77229478945914],
                            [2.435888725779706, 48.772561198963075],
                            [2.435964941428433, 48.77287282512524],
                            [2.436030391339495, 48.77320111586854],
                            [2.436045485215397, 48.773325107882],
                            [2.436070647682407, 48.77353180770079],
                            [2.436081968925176, 48.77379352470407],
                            [2.436086604214256, 48.774312214586466],
                            [2.436069378558162, 48.774700061127184],
                            [2.436034282355853, 48.77515216508829],
                            [2.435981075256809, 48.77554956048242],
                            [2.435934794066609, 48.775808948132415],
                            [2.435874186419337, 48.77610641735578],
                            [2.435742251869427, 48.77674181418208],
                            [2.435556595845548, 48.77752001822261],
                            [2.435435118980712, 48.77798647205676],
                            [2.435349417951659, 48.77834106731402],
                            [2.435281670358444, 48.77867185364237],
                            [2.435224660798823, 48.778971698871864],
                            [2.435203497645432, 48.77919299477181],
                            [2.435125864478978, 48.779987759728854],
                            [2.435072837405683, 48.7804827069834],
                            [2.435047950953678, 48.780642143702984],
                            [2.435019534129465, 48.78083727365759],
                            [2.434948213410398, 48.78118471805605],
                            [2.434866002252994, 48.7814869643202],
                            [2.434765819013104, 48.781805881325134],
                            [2.434536769171052, 48.782505602836856],
                            [2.434296855593278, 48.78317678079791],
                            [2.43390645793184, 48.7842287804001],
                            [2.433211275030803, 48.785944871156936],
                            [2.432913868180616, 48.786694614061545],
                            [2.432634422468911, 48.7874276843418],
                            [2.432222909326854, 48.78854485112556],
                            [2.432070116592686, 48.78891489668918],
                        ],
                    },
                },
                1632: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [49.02530767207706, 2.1407440104440876],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 2590.05747503,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.128263873923673,
                            49.01913673984224,
                            2.154663485640923,
                            49.033987636271455,
                        ),
                        "coordinates": [
                            [2.154663485640923, 49.01913673984224],
                            [2.153012708040501, 49.01958148730108],
                            [2.1525802036884, 49.01969859749183],
                            [2.15187945004989, 49.01988361913078],
                            [2.150826891488006, 49.020175078735726],
                            [2.149978124031571, 49.020447077518284],
                            [2.149305915162764, 49.020671697973114],
                            [2.148826714662678, 49.02083817803502],
                            [2.148341998062405, 49.021016337694384],
                            [2.147705252554311, 49.02125989135247],
                            [2.147065696758275, 49.02152142255902],
                            [2.146498651858204, 49.021770480878665],
                            [2.14594799358884, 49.022024060222314],
                            [2.145346607428395, 49.02231082549486],
                            [2.144350588173181, 49.02280825434546],
                            [2.144093057933043, 49.02292652594874],
                            [2.143931358634076, 49.0230152822196],
                            [2.143650524185861, 49.02314790214863],
                            [2.143031225952273, 49.02346250313366],
                            [2.142701050689537, 49.023622914676324],
                            [2.142370881211854, 49.02378152687329],
                            [2.140962391049982, 49.0244841602294],
                            [2.139784055706185, 49.0250711659449],
                            [2.139636077743041, 49.02514465214651],
                            [2.139127744838577, 49.025396473601596],
                            [2.13819053882378, 49.02585977871451],
                            [2.137680805934782, 49.02611608728359],
                            [2.137340936435868, 49.026298048944646],
                            [2.137228556776113, 49.026359004402956],
                            [2.137055835991663, 49.026462120063606],
                            [2.136598001860149, 49.02673200308702],
                            [2.136292293463326, 49.02691851828956],
                            [2.135953572336817, 49.02715173687216],
                            [2.135933000988131, 49.02716608896057],
                            [2.13552704267224, 49.02745494442121],
                            [2.1353610539308, 49.02758234935377],
                            [2.13530891614649, 49.02762452376745],
                            [2.135145673271377, 49.027749236079515],
                            [2.134734036963733, 49.02808663965612],
                            [2.134330518977245, 49.02844383931215],
                            [2.133111242287299, 49.029505863609465],
                            [2.132522779267561, 49.03005920334172],
                            [2.131989640429896, 49.030574865619776],
                            [2.13162187645773, 49.03091147979036],
                            [2.131232357216787, 49.03125697622124],
                            [2.130733854692106, 49.03170399224864],
                            [2.13009097662359, 49.03227744575314],
                            [2.129407148815588, 49.03290435640467],
                            [2.129093756160098, 49.03321072338393],
                            [2.128263873923673, 49.033987636271455],
                        ],
                    },
                },
                1633: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.792776165880106, 2.0554436206259865],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 1973.87595046,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.044621987173176,
                            48.787390238280715,
                            2.066485347074011,
                            48.79761321151646,
                        ),
                        "coordinates": [
                            [2.044621987173176, 48.787390238280715],
                            [2.044851105628235, 48.78750349640637],
                            [2.046741304126305, 48.78844003846329],
                            [2.047258327554183, 48.78869832312603],
                            [2.048565214852195, 48.78936071667585],
                            [2.049383771745726, 48.78978630894997],
                            [2.051178973182095, 48.79070687265457],
                            [2.052959877315797, 48.79162023425542],
                            [2.054245460494912, 48.792256337309674],
                            [2.058741619891684, 48.794489710908344],
                            [2.061679413663929, 48.79595062396591],
                            [2.062070911434097, 48.79614191596519],
                            [2.062516342039329, 48.79634999307187],
                            [2.062907965074912, 48.79651986861153],
                            [2.063242176986505, 48.796651535583436],
                            [2.063705846985577, 48.79681920285661],
                            [2.064173185834679, 48.79697497863914],
                            [2.064637031043277, 48.797111711223465],
                            [2.066485347074011, 48.79761321151646],
                        ],
                    },
                },
                1634: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.797753871396914, 2.1568400234820144],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 2245.04465357,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.142141851963426,
                            48.795715917344765,
                            2.171389812756379,
                            48.80071846386355,
                        ),
                        "coordinates": [
                            [2.142141851963426, 48.795715917344765],
                            [2.142706607881934, 48.79574745613372],
                            [2.143856757254184, 48.79579486437915],
                            [2.147234244824272, 48.795959949065534],
                            [2.148995074205409, 48.79602948652837],
                            [2.150017745902113, 48.796064478878215],
                            [2.150442631394686, 48.79608658921006],
                            [2.150781082583517, 48.79610855609176],
                            [2.151285101512348, 48.7961569644232],
                            [2.151641490132594, 48.796197992654015],
                            [2.152030230622056, 48.79625572855427],
                            [2.152480159919246, 48.796323079295],
                            [2.152976821918897, 48.79641429648562],
                            [2.154495584415558, 48.796699879271635],
                            [2.155085753590148, 48.7968293061806],
                            [2.155636272857649, 48.79696818445126],
                            [2.155923219353944, 48.797048173958764],
                            [2.15683568548617, 48.797310081377546],
                            [2.157683680908086, 48.79753481665686],
                            [2.158322075302499, 48.79769604510322],
                            [2.15939704124788, 48.797973103336034],
                            [2.15992599538207, 48.79810716886839],
                            [2.160246219863137, 48.79819570134629],
                            [2.161170405599215, 48.7984774257692],
                            [2.161958736431169, 48.79873738058273],
                            [2.162850799732983, 48.799041995934324],
                            [2.163084630812713, 48.79912087097465],
                            [2.163649432820911, 48.79930969882626],
                            [2.164192683305267, 48.7994818365617],
                            [2.164692812178737, 48.79962773303816],
                            [2.165730297934967, 48.79991052985321],
                            [2.166345438479331, 48.80006859693602],
                            [2.167049172095505, 48.80023603764411],
                            [2.167687736234038, 48.80036640154266],
                            [2.168447606155488, 48.80048769712934],
                            [2.169202898781894, 48.8005843309325],
                            [2.169697168739786, 48.80062819510285],
                            [2.170326695902241, 48.80067533554842],
                            [2.170830357527754, 48.800700720559675],
                            [2.171389812756379, 48.80071846386355],
                        ],
                    },
                },
                1635: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.78038186975661, 2.0258616290799933],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 3145.01228687,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.006566869057667,
                            48.77480280977951,
                            2.044621987173176,
                            48.787390238280715,
                        ),
                        "coordinates": [
                            [2.006566869057667, 48.77480280977951],
                            [2.009207627400197, 48.77551998221428],
                            [2.012150762593544, 48.77632073131186],
                            [2.013135320830001, 48.776604296916304],
                            [2.013800047485958, 48.776801289944],
                            [2.014321057356297, 48.776955044031524],
                            [2.014838545728923, 48.777096890365996],
                            [2.015273377671665, 48.77721708596506],
                            [2.015790903839563, 48.77735416849987],
                            [2.016340756002657, 48.777503236601405],
                            [2.016991261209501, 48.777676377637114],
                            [2.017799895689103, 48.7778927864028],
                            [2.018586969518075, 48.77810436950985],
                            [2.021627507027376, 48.778921801016935],
                            [2.022874635557149, 48.779260733614514],
                            [2.02367252431761, 48.77947707071204],
                            [2.025383362444883, 48.77993621619956],
                            [2.026896514915116, 48.78034721175265],
                            [2.028894962887152, 48.78088322525144],
                            [2.029732462123214, 48.78110676527361],
                            [2.03116305426704, 48.78148892845829],
                            [2.032309533113018, 48.7818227289014],
                            [2.032880911060994, 48.78200032632209],
                            [2.03345940904871, 48.782192215908246],
                            [2.034469285971461, 48.7825525525616],
                            [2.035018876698637, 48.78276339320652],
                            [2.03554684069051, 48.782978932581834],
                            [2.036074765672647, 48.783201606342466],
                            [2.036588280324179, 48.783426619685514],
                            [2.037187879655413, 48.78370658173795],
                            [2.037826906024246, 48.784017576032426],
                            [2.039083350065184, 48.78464425604487],
                            [2.040031099034028, 48.78511546056952],
                            [2.040684464390339, 48.78544313177748],
                            [2.042483131752127, 48.78633291093265],
                            [2.044621987173176, 48.787390238280715],
                        ],
                    },
                },
                1636: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.620881306919074, 2.3068372804199155],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 3328.50757854,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.302059691582639,
                            48.60674494894811,
                            2.308841734746331,
                            48.63587586133943,
                        ),
                        "coordinates": [
                            [2.306833164014825, 48.63587586133943],
                            [2.307030374826495, 48.63462527064926],
                            [2.30717380077652, 48.63368618466834],
                            [2.307277314218528, 48.633008166481204],
                            [2.307382922215318, 48.632275039515875],
                            [2.307612452251724, 48.630645887326075],
                            [2.307750017598194, 48.6297142845968],
                            [2.307914861653962, 48.62852100444024],
                            [2.308267717822225, 48.62590603522561],
                            [2.308439331169083, 48.62469207282878],
                            [2.308748394611611, 48.62272324378916],
                            [2.308800300469259, 48.62232353345129],
                            [2.308834980221083, 48.621919536550266],
                            [2.308841734746331, 48.62139561477266],
                            [2.308816148021596, 48.620945920291376],
                            [2.308773381828687, 48.62041342144164],
                            [2.30873357795134, 48.620078027638165],
                            [2.308657864312481, 48.619648160758054],
                            [2.308558746733582, 48.61923419838383],
                            [2.308463245795803, 48.61888838253313],
                            [2.308337077188706, 48.618477241894105],
                            [2.308117682759952, 48.61790525586545],
                            [2.307937526977359, 48.61750144147813],
                            [2.307780876322851, 48.617176005394406],
                            [2.307555499278999, 48.616740568374766],
                            [2.306613939002589, 48.6150065456005],
                            [2.306109993412017, 48.61407747368937],
                            [2.305192934512777, 48.61235963316916],
                            [2.304909832188939, 48.61183708307746],
                            [2.304238856573783, 48.610594593989894],
                            [2.30364940737448, 48.60956671102588],
                            [2.303210751644092, 48.608807110806396],
                            [2.30293551347242, 48.60834734827669],
                            [2.302733394480765, 48.60799895894463],
                            [2.302354970072312, 48.607343585276624],
                            [2.302059691582639, 48.60674494894811],
                        ],
                    },
                },
                1637: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.982797574591515, 2.2636157549922533],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 1016.7562533,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.25747415725031,
                            48.98091190326584,
                            2.269851993930268,
                            48.98500470125915,
                        ),
                        "coordinates": [
                            [2.269851993930268, 48.98091190326584],
                            [2.26954526509951, 48.98096437982222],
                            [2.269004726617549, 48.98105798659492],
                            [2.268027562605059, 48.981275029387575],
                            [2.267747367056282, 48.98135669483977],
                            [2.266934115114945, 48.98159361082247],
                            [2.266826128905727, 48.98163041570474],
                            [2.266060654556562, 48.981888936410705],
                            [2.26429179731313, 48.98251102926852],
                            [2.263314407492389, 48.982847635066406],
                            [2.261622025452842, 48.983449052471265],
                            [2.261108001244041, 48.9836411590941],
                            [2.260894732323527, 48.983721952743366],
                            [2.258429804144584, 48.984645647981104],
                            [2.257613609603145, 48.984951740311374],
                            [2.25747415725031, 48.98500470125915],
                        ],
                    },
                },
                1638: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "RER C",
                        "rer": 1,
                        "extcode": "800:C",
                        "geo_point_2d": [48.67003972308248, 2.338573416745282],
                        "indice_lig": "C",
                        "idf": 1,
                        "train": 0,
                        "fer": 1,
                        "mode": "RER",
                        "tramway": 0,
                        "idrefligc": "C01727",
                        "navette": 0,
                        "idrefliga": "A01840",
                        "shape_leng": 889.84312629,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.332622929210473,
                            48.66948372520816,
                            2.344492790482471,
                            48.670783940999655,
                        ),
                        "coordinates": [
                            [2.344492790482471, 48.670783940999655],
                            [2.344000616577513, 48.67065073289476],
                            [2.343452536635048, 48.67051690183254],
                            [2.343045018523067, 48.670429513991444],
                            [2.342513337894879, 48.670329610743806],
                            [2.342035549685687, 48.670263013236685],
                            [2.341385884934257, 48.67019197883171],
                            [2.340880805352075, 48.670146135636],
                            [2.34021279968859, 48.67009579970791],
                            [2.33975117009595, 48.6700688351794],
                            [2.336582378460657, 48.66989196734917],
                            [2.335684299785311, 48.66984199761172],
                            [2.335264000352498, 48.66981344068433],
                            [2.334886809428474, 48.669782505244534],
                            [2.334283283091729, 48.66972966051765],
                            [2.333924076383457, 48.669689692530945],
                            [2.333500189677468, 48.669632578105414],
                            [2.33308708014005, 48.66956832376093],
                            [2.332753002791134, 48.669508830645235],
                            [2.332622929210473, 48.66948372520816],
                        ],
                    },
                },
                1639: {
                    "attributes": {
                        "reseau": "RER C",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.98059332055262, 2.2733998353909346],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01863",
                        "navette": 0,
                        "idrefliga": "A02181",
                        "shape_leng": 192.880431892,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            2.272084772747633,
                            48.98054054067926,
                            2.274714898034236,
                            48.980646100425986,
                        ),
                        "coordinates": [
                            [2.274714898034236, 48.98054054067926],
                            [2.272084772747633, 48.980646100425986],
                        ],
                    },
                },
                1640: {
                    "attributes": {
                        "reseau": "PARIS RIVE GAUCHE",
                        "val": 0,
                        "metro": 0,
                        "res_com": "TER",
                        "rer": 0,
                        "extcode": "800:TER",
                        "geo_point_2d": [48.66709106514783, 1.84695431729289],
                        "indice_lig": "TER",
                        "idf": 1,
                        "train": 1,
                        "fer": 1,
                        "mode": "TER",
                        "tramway": 0,
                        "idrefligc": "C01744",
                        "navette": 0,
                        "idrefliga": "A02172",
                        "shape_leng": 5803.08638244,
                    },
                    "geometry": {
                        "type": "LineString",
                        "bbox": (
                            1.832935470348963,
                            48.644221953457865,
                            1.85659206528713,
                            48.69309659121679,
                        ),
                        "coordinates": [
                            [1.832935470348963, 48.644221953457865],
                            [1.833897742269862, 48.64483970101746],
                            [1.835324124189156, 48.64581915998322],
                            [1.837193509659841, 48.647087998505334],
                            [1.837546513719914, 48.64734404631596],
                            [1.837880828061444, 48.64756943559603],
                            [1.838592317774448, 48.648077952894106],
                            [1.839019356772323, 48.64839637123526],
                            [1.839398873945023, 48.648717278382605],
                            [1.839692151481013, 48.64897665520306],
                            [1.840174788476924, 48.64943739944275],
                            [1.840632878565732, 48.64991062359412],
                            [1.840973934304241, 48.650279918877594],
                            [1.84136941477331, 48.65077265161532],
                            [1.841696257529263, 48.651207530340436],
                            [1.841780606608487, 48.65132390458805],
                            [1.84212318915172, 48.651814606109895],
                            [1.842467448349342, 48.65241053000372],
                            [1.842700474059629, 48.65286388334804],
                            [1.842881098071016, 48.65326394998563],
                            [1.843184643382457, 48.653998184763765],
                            [1.843497540193419, 48.65488533688768],
                            [1.843637183017852, 48.65531310298988],
                            [1.843757091376512, 48.65567783303002],
                            [1.843855995510116, 48.6559705289699],
                            [1.844004976773792, 48.65641542091583],
                            [1.844318665800132, 48.65736282719837],
                            [1.844397785343592, 48.65759788274752],
                            [1.844863599274432, 48.658949724640365],
                            [1.845328071822014, 48.66030245851917],
                            [1.845792578715679, 48.66165429048384],
                            [1.845941424720584, 48.662116266278225],
                            [1.846145666036338, 48.662743049090736],
                            [1.846531023941065, 48.66386521919959],
                            [1.846669758325678, 48.66425250942441],
                            [1.847209896930332, 48.66578991522906],
                            [1.847784738395138, 48.66752980553356],
                            [1.847842821808982, 48.6676982212138],
                            [1.84819155495819, 48.66868623537434],
                            [1.849019203452952, 48.67109897112784],
                            [1.849326236649587, 48.67205173070517],
                            [1.849676484314482, 48.67302985490711],
                            [1.850197493462145, 48.67459863843122],
                            [1.850333551960932, 48.67498771165959],
                            [1.850452338978258, 48.675338041394504],
                            [1.850614680494159, 48.675817155022685],
                            [1.851188007576962, 48.6774573760777],
                            [1.851490623368341, 48.67831461180392],
                            [1.851726601402419, 48.67904314001343],
                            [1.85217323906696, 48.680313034994754],
                            [1.852618550278436, 48.681582023410364],
                            [1.853062524695244, 48.682851004731404],
                            [1.853326603331995, 48.683627311174284],
                            [1.853672770973487, 48.68464887205584],
                            [1.854165322260302, 48.68606973363427],
                            [1.854458800034756, 48.686899219198416],
                            [1.854710960338351, 48.68764889444398],
                            [1.854862228152567, 48.68801694176579],
                            [1.854986597374976, 48.6883582972875],
                            [1.855143765850118, 48.68881939675369],
                            [1.855344426080367, 48.68941827137432],
                            [1.855428977361471, 48.68966413381634],
                            [1.855925175448971, 48.69116623973367],
                            [1.856240942407902, 48.69208484429995],
                            [1.85659206528713, 48.69309659121679],
                        ],
                    },
                },
            },
        },
    },
}


def test_all():
    # # create_geolayer_from_i_feat_list
    # print(
    #     test_function(
    #         create_geolayer_from_i_feat_list,
    #         create_geolayer_from_i_feat_list_parameters,
    #     )
    # )
    # 
    # # reproject_geolayer
    # print(test_function(reproject_geolayer, reproject_geolayer_parameters))
    # 
    # # multi_geometry_to_single_geometry_geolayer
    # print(
    #     test_function(
    #         multi_geometry_to_single_geometry_geolayer,
    #         multi_geometry_to_single_geometry_geolayer_parameters,
    #     )
    # )

    # geolayer_to_2d_geolayer
    print(test_function(geolayer_to_2d_geolayer, geolayer_to_2d_geolayer_parameters))


if __name__ == "__main__":
    test_all()
